/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  sanitizeHTML,
  stripHTML,
  stripTags
} from "./ids-chunk-5K4YUTOH-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-xss-mixin/ids-xss-mixin.ts
var IdsXssMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
    if (!this.state) {
      this.state = {};
    }
    this.state.xssIgnoredTags = "<a><b><br><br/><del><em><i><ins><mark><small><strong><sub><sup>";
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.XSS_IGNORED_TAGS
    ];
  }
  /**
   * @returns {void}
   */
  connectedCallback() {
    super.connectedCallback?.();
    if (this.hasAttribute(attributes.XSS_IGNORED_TAGS)) {
      this.xssIgnoredTags = this.getAttribute(attributes.XSS_IGNORED_TAGS);
    }
  }
  /**
   * @param {string} val string containing a list of allowed HTML Tags
   */
  set xssIgnoredTags(val) {
    if (typeof val === "string" && val !== this.state.xssIgnoredTags) {
      this.state.xssIgnoredTags = sanitizeHTML(val);
    }
  }
  /**
   * @returns {string} containing a list of HTML tags that will be ignored
   *   by this component when processing for XSS attacks
   */
  get xssIgnoredTags() {
    return this.state.xssIgnoredTags;
  }
  /**
   * Uses the stored list of ignored HTML tags while processing a text string for XSS attacks.
   * @param {string} str the string to check
   * @returns {string} the "fixed" string with XSS attack vectors removed
   */
  xssSanitize(str) {
    const ignored = this.xssIgnoredTags;
    if (ignored?.length) {
      return stripTags(str, ignored);
    }
    return stripHTML(str);
  }
};
var ids_xss_mixin_default = IdsXssMixin;

export {
  ids_xss_mixin_default
};
//# sourceMappingURL=ids-chunk-26CSEAWA-full.js.map
