/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  ids_events_mixin_default
} from "./ids-chunk-KKFANICI-full.js";
import {
  IdsElement
} from "./ids-chunk-UTR2KJV7-full.js";
import {
  customElement
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet,
  __publicField
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-data-grid/ids-data-grid-cell.ts
var _memoizedColumn, _memoizedColumnIndex, _IdsDataGridCell_instances, startCellEdit_fn, saveCellValue_fn, saveDirtyState_fn, saveValidState_fn, resetValidState_fn;
var IdsDataGridCell = class extends ids_events_mixin_default(IdsElement) {
  constructor() {
    super({ noShadowRoot: true });
    __privateAdd(this, _IdsDataGridCell_instances);
    __publicField(this, "rootNode");
    __publicField(this, "isInValid", false);
    /** The editor element */
    __publicField(this, "editor");
    // Add memoization for frequently accessed properties
    __privateAdd(this, _memoizedColumn);
    // Add memoization for frequently accessed properties
    __privateAdd(this, _memoizedColumnIndex);
    /** Previous Value before Editing */
    __publicField(this, "originalValue");
    /** Previous Invalid state before reseting */
    __publicField(this, "previousInvalidState", "");
    /** If currently in edit mode */
    __publicField(this, "isEditing");
  }
  connectedCallback() {
    this.renderCell();
    this.tabIndex = this.rowIndex === 0 && this.columnIndex === 0 ? 0 : -1;
    this.setAttribute("tabindex", String(this.tabIndex));
    this.addEventListener("focus", this.onFocus);
  }
  onFocus() {
    this.dataGrid.lastActiveCell = this.activate();
    this.dataGrid.offEvent("blur.ids-data-grid-cell", this);
    this.dataGrid.onEvent("blur.ids-data-grid-cell", this, this.onBlur);
  }
  onBlur() {
    this.dataGrid.offEvent("focus.ids-data-grid-cell", this);
    this.dataGrid.offEvent("blur.ids-data-grid-cell", this);
  }
  disconnectedCallback() {
    this.offEvent("focusin.ids-cell", this);
    this.offEvent("focusout.ids-cell", this);
  }
  get isEditable() {
    if (this.classList.contains("is-readonly") || this.classList.contains("is-disabled")) return false;
    const column = this.column;
    if (column.formatter?.name === "selectionCheckbox") return true;
    if (!column.editor) return false;
    const columnEditor = this.dataGrid.editors.find((editor) => editor.type === column?.editor?.type);
    return !!columnEditor?.editor;
  }
  /**
   * Reference to the data grid parent
   * @returns {IdsDataGrid} the data grid parent
   */
  get dataGrid() {
    if (!this.rootNode) this.rootNode = this.getRootNode().host;
    return this.rootNode;
  }
  /**
   * Gets data grid row below this cell
   * @returns {IdsDataGridRow} row below
   */
  get rowBelow() {
    if (this.dataGrid.treeGrid) {
      let nextRow = this.parentElement?.nextElementSibling;
      while (nextRow?.hasAttribute("hidden")) {
        nextRow = nextRow?.nextElementSibling;
      }
      return nextRow ?? null;
    }
    return this.dataGrid.rowByIndex(this.rowIndex + 1) ?? null;
  }
  /**
   * Gets data grid row above this cell
   * @returns {IdsDataGridRow} row above
   */
  get rowAbove() {
    if (this.dataGrid.treeGrid) {
      let prevRow = this.parentElement?.previousElementSibling;
      while (prevRow?.hasAttribute("hidden")) {
        prevRow = prevRow?.previousElementSibling;
      }
      return prevRow ?? null;
    }
    return this.dataGrid.rowByIndex(this.rowIndex - 1) ?? null;
  }
  /**
   * Get the cell above this cell
   * @returns {IdsDataGridCell | null} the cell above this cell
   */
  get cellAbove() {
    return this.rowAbove?.cellByIndex(this.columnIndex) ?? null;
  }
  /**
   * Get the cell below this cell
   * @returns {IdsDataGridCell | null} the cell below this cell
   */
  get cellBelow() {
    return this.rowBelow?.cellByIndex(this.columnIndex) ?? null;
  }
  /**
   * Get the cell to the left of this cell
   * @returns {IdsDataGridCell | null} the cell to the left of this cell
   */
  get cellLeft() {
    const cellLeft = this.dataGrid?.rowByIndex(this.rowIndex)?.cellByIndex(this.columnIndex - 1);
    if (cellLeft && cellLeft !== this) return cellLeft;
    return this.rowAbove?.cellByIndex(this.dataGrid?.columns.length ?? 0) ?? null;
  }
  /**
   * Get the cell to the right of this cell
   * @returns {IdsDataGridCell | null} the cell to the right of this cell
   */
  get cellRight() {
    const cellRight = this.dataGrid?.rowByIndex(this.rowIndex)?.cellByIndex(this.columnIndex + 1) ?? null;
    if (cellRight && cellRight !== this) return cellRight;
    return this.rowBelow?.cellByIndex(0) ?? null;
  }
  /**
   * Get the next editable cell to the left of this cell
   * @returns {IdsDataGridCell | null} the next editabled cell to the left of this cell
   */
  get cellLeftEditable() {
    if (!this.dataGrid?.isEditable) return null;
    if (this?.columnIndex === 0 && this?.rowIndex === 0) return null;
    let nextCell = this.cellLeft;
    const maxColumns = this.dataGrid?.visibleColumns?.length || 0;
    let attempts = 0;
    while (nextCell && !nextCell.isEditable && attempts < maxColumns) {
      nextCell = nextCell.cellLeft;
      attempts++;
    }
    if (attempts >= maxColumns || !nextCell?.isEditable) {
      return null;
    }
    return nextCell;
  }
  /**
   * Get the next editable cell to the right of this cell
   * @returns {IdsDataGridCell | null} the next editabled cell to the right of this cell
   */
  get cellRightEditable() {
    if (!this.dataGrid?.isEditable) return null;
    let nextCell = this.cellRight;
    const maxColumns = this.dataGrid?.visibleColumns?.length || 0;
    let attempts = 0;
    while (nextCell && !nextCell.isEditable && attempts < maxColumns) {
      nextCell = nextCell.cellRight;
      attempts++;
    }
    if (attempts >= maxColumns || !nextCell?.isEditable) {
      return null;
    }
    return nextCell;
  }
  /**
   * Update this cell's dataset and refresh
   * @param {string} value the new data for the cell
   * @param {boolean} refresh if true, rerender the cell
   */
  updateData(value, refresh = true) {
    const rowIndex = this.rowIndex;
    const record = this.dataGrid?.data[rowIndex];
    const columnIndex = this.columnIndex;
    const visibleColumns = this.dataGrid?.visibleColumns;
    const column = visibleColumns[columnIndex];
    if (!column?.field) return;
    const updatedRecord = {
      ...record,
      [column.field]: value
    };
    this.editor?.change?.(value);
    if (refresh) {
      this.dataGrid?.updateDatasetAndRefresh?.(this.rowIndex, updatedRecord, false);
    } else {
      this.dataGrid?.updateDataset?.(this.rowIndex, updatedRecord, false);
    }
  }
  /**
   * Get the column definition
   * @returns {IdsDataGridColumn} the current cells column
   */
  get column() {
    if (!__privateGet(this, _memoizedColumn) || this.columnIndex !== __privateGet(this, _memoizedColumnIndex)) {
      __privateSet(this, _memoizedColumn, this.dataGrid?.visibleColumns[this.columnIndex]);
      __privateSet(this, _memoizedColumnIndex, this.columnIndex);
    }
    return __privateGet(this, _memoizedColumn);
  }
  /**
   * Get the column header cell element
   * @returns {IdsDataGridColumn} the current cells column
   */
  get columnHeader() {
    return this.dataGrid?.header?.columns[this.columnIndex];
  }
  /**
   * Gets the column # in which this cell exists
   * @returns {number} the column-index
   */
  get columnIndex() {
    return Number(this.getAttribute?.("aria-colindex") ?? 1) - 1;
  }
  /**
   * Gets the row-index # in which this cell exists
   * @returns {number} the row-index
   */
  get rowIndex() {
    return Number(this.parentElement?.getAttribute?.("row-index") ?? -1);
  }
  /**
   * Get row of table cell
   * @returns {number} table row index
   */
  get row() {
    return this.rowIndex;
  }
  /**
   * Get data value of this cell
   * @returns {any} the data value of this cell
   */
  get value() {
    if (this.editor && this.contains(this.editor?.input ?? null)) {
      return this.editor?.value?.();
    }
    const column = this.dataGrid?.columns?.[this.columnIndex];
    const record = this.dataGrid?.data?.[this.rowIndex];
    return record?.[column?.field ?? -1] ?? this.textContent ?? "";
  }
  /**
   * Get the default/original value of this cell
   * @returns {any} the default value of this cell
   */
  get defaultValue() {
    const column = this.dataGrid?.visibleColumns?.[this.columnIndex];
    const record = this.dataGrid?.data?.[this.rowIndex];
    const dirtyCells = record?.dirtyCells ?? [];
    return dirtyCells.find((row) => row?.columnId === column?.id)?.originalValue ?? this.value;
  }
  /**
   * Rerender a cell - may be used later
   */
  renderCell() {
    const dataGrid = this.dataGrid;
    const rowIndex = this.rowIndex;
    const rowData = dataGrid?.data[rowIndex];
    if (rowData?.isGroupRow) return;
    if (dataGrid.virtualScroll) {
      const tooManyColumns = dataGrid.columns.length > dataGrid.TOO_MANY_COLUMNS;
      const columnsStale = dataGrid.hasAttribute("columns-stale");
      const columnsFresh = !columnsStale;
      const columnHeaders = this.columnHeader;
      const columnOffScreen = columnHeaders?.hasAttribute("column-offscreen");
      if (tooManyColumns && columnsFresh && columnOffScreen) {
        return;
      }
      const columnOnScreen = columnHeaders?.hasAttribute("column-onscreen");
      const columnOffScreenLeft = columnHeaders?.hasAttribute("column-offscreen-left");
      const columnOffScreenRight = columnHeaders?.hasAttribute("column-offscreen-right");
      this.toggleAttribute("column-onscreen", columnOnScreen);
      this.toggleAttribute("column-offscreen", columnOffScreen);
      this.toggleAttribute("column-offscreen-left", columnOffScreenLeft);
      this.toggleAttribute("column-offscreen-right", columnOffScreenRight);
    }
    const column = this.column;
    const columnIndex = this.columnIndex;
    const template = IdsDataGridCell.template(rowData, column, rowIndex, dataGrid);
    if (this.innerHTML !== template) {
      try {
        this.innerHTML = template;
      } catch (e) {
        requestAnimationFrame(() => {
          this.innerHTML = template;
        });
      }
    }
    const cssClasses = this?.cellCssClasses(column, columnIndex, template) ?? "";
    if (cssClasses) {
      this.classList.remove(...this.classList);
      this.classList.add(...cssClasses.split(" "));
    }
    const cssPart = this?.cellCssPart(column, columnIndex) ?? "";
    if (cssPart) this.setAttribute("part", cssPart);
    if (dataGrid.lastActiveCell?.cell === columnIndex && dataGrid.lastActiveCell?.row === rowIndex) {
      this.onFocus();
    }
  }
  /**
   * Return the cells' css part
   * @param {IdsDataGridColumn} column - the column definition
   * @param {number} columnIndex - the column index
   * @returns {string} The css part string for the cell
   */
  cellCssPart(column, columnIndex) {
    const dataGrid = this.dataGrid;
    const rowIndex = this.rowIndex;
    const rowData = dataGrid.data[rowIndex];
    const cacheKey = IdsDataGridCell.cacheKey(rowIndex, rowData, column, dataGrid);
    const cellCacheKey = `${cacheKey}:${dataGrid.cacheCellPart}`;
    if (IdsDataGridCell.cellCache[cellCacheKey]) {
      return IdsDataGridCell.cellCache[cellCacheKey];
    }
    let part = column.cssPart || "cell";
    const rowSelection = dataGrid?.rowSelection;
    const isSelectable = rowSelection === "mixed" || rowSelection === "single" || rowSelection === "multiple";
    if (isSelectable && rowData.rowSelected) {
      if (column.cellSelectedCssPart) part = column.cellSelectedCssPart;
      else part = "cell-selected";
    }
    let recordIndex = null;
    const pKey = rowData[this.dataGrid.datasource.primaryKey];
    if (pKey !== void 0) {
      const pKeyIndex = this.dataGrid.datasource.primaryKey;
      recordIndex = this.dataGrid.datasource.getRecordIndex(pKeyIndex, pKey);
    }
    if (typeof part === "function") {
      part = part({
        rowIndex,
        columnIndex,
        recordIndex,
        rowData
      });
    }
    IdsDataGridCell.cellCache[cellCacheKey] = part;
    return part;
  }
  /**
   * Return the cells' css classes
   * @param {IdsDataGridColumn} column - the column definition
   * @param {number} columnIndex - the column index
   * @param {string} content - the cells html or text content
   * @returns {string} The classList string for the cell
   */
  cellCssClasses(column, columnIndex, content) {
    const dataGrid = this.dataGrid;
    const rowIndex = this.rowIndex;
    const rowData = dataGrid.data[rowIndex];
    const cacheKey = IdsDataGridCell.cacheKey(rowIndex, rowData, column, dataGrid);
    const cellCacheKey = `${cacheKey}:${dataGrid.cacheCellClass}`;
    if (IdsDataGridCell.cellCache[cellCacheKey]) {
      return IdsDataGridCell.cellCache[cellCacheKey];
    }
    const isDirtyCell = (currentRow) => {
      if (!currentRow.dirtyCells) return false;
      return currentRow.dirtyCells.findIndex((item) => item.cell === columnIndex) !== -1;
    };
    const isInvalidCell = (currentRow) => {
      if (!currentRow.invalidCells) return false;
      return currentRow.invalidCells.findIndex((item) => item.cell === columnIndex) !== -1;
    };
    const isReadonly = () => {
      if (column.readonly && column?.readonly === true) return true;
      if (typeof column?.readonly === "function") return column?.readonly(rowIndex, content, column, rowData);
      return false;
    };
    const isColumnDisabled = () => {
      if (!column?.disabled) return false;
      if (typeof column?.disabled === "function") return column?.disabled(rowIndex, content, column, rowData);
      if (typeof column?.disabled === "boolean") return column?.disabled;
      return false;
    };
    const isUppercase = () => {
      if (typeof column?.uppercase === "function") return column.uppercase("body-cell", column, rowIndex, content, rowData);
      return column?.uppercase === "true" || column?.uppercase === true;
    };
    const frozenLast = dataGrid?.leftFrozenColumns.length;
    const hasReadonlyClass = isReadonly();
    const hasDisabledClass = this.parentElement.disabled || isColumnDisabled();
    const hasUppercaseClass = isUppercase();
    const hasInlineClass = column?.editor && column?.editor?.inline;
    const editorType = column.editor?.type;
    let cssClasses = "ids-data-grid-cell";
    cssClasses += editorType ? ` is-${editorType}` : "";
    cssClasses += column.excludeReadonlyStyling ? " exclude-readonly-style" : "";
    cssClasses += hasReadonlyClass ? " is-readonly" : "";
    cssClasses += hasDisabledClass ? " is-disabled" : "";
    cssClasses += hasUppercaseClass ? " is-uppercase" : "";
    cssClasses += isDirtyCell(rowData) ? " is-dirty" : "";
    cssClasses += isInvalidCell(rowData) ? " is-invalid" : "";
    cssClasses += column?.align ? ` align-${column?.align}` : "";
    cssClasses += column?.formatter?.name ? ` formatter-${column.formatter.name}` : "";
    cssClasses += column?.frozen ? ` frozen frozen-${column?.frozen}${columnIndex + 1 === frozenLast ? " frozen-last" : ""}` : "";
    cssClasses += column?.editor ? ` is-editable` : "";
    cssClasses += hasInlineClass && (!hasReadonlyClass || hasReadonlyClass && !column.excludeReadonlyStyling) ? ` is-inline` : "";
    cssClasses += column?.formatter?.name === "selectionCheckbox" ? " is-editable" : "";
    IdsDataGridCell.cellCache[cellCacheKey] = cssClasses;
    return cssClasses;
  }
  /**
   * Set the active cell for focus
   * @param {boolean} nofocus If true, do not focus the cell
   * @returns {object} the current active cell
   */
  activate(nofocus = false) {
    const previousActiveCell = this.dataGrid.activeCell.node;
    this.dataGrid.activeCell.node = this;
    if (!nofocus) {
      this.dataGrid.shadowRoot?.querySelector('ids-data-grid-cell[tabindex="0"]')?.setAttribute("tabindex", "-1");
      this.tabIndex = 0;
      this.focus();
    }
    if (previousActiveCell !== this) {
      this.dataGrid.triggerEvent("activecellchanged", this.dataGrid, { detail: { elem: this, activeCell: this.dataGrid.activeCell } });
    }
    return this.dataGrid.activeCell;
  }
  /**
   * Validate cell
   */
  validateCell() {
    const column = this.column;
    if (!column.editor) return;
    const columnEditor = this.dataGrid.editors.find((obj) => obj.type === column?.editor?.type);
    if (!columnEditor || !columnEditor.editor) return;
    this.originalValue = this.value;
    this.editor = columnEditor.editor;
    this.editor.init(this);
    const input = this.editor?.input;
    if (!input) return;
    const editorType = this.editor?.type;
    input?.offEvent("focusout", input);
    input?.offEvent("close", input);
    if (["input", "tree"].includes(editorType) && input?.setDirtyTracker) {
      input?.setDirtyTracker(input?.value);
    }
    if (["input", "tree"].includes(editorType) && input?.checkValidation) {
      input?.checkValidation();
    }
    if (editorType === "dropdown") {
      input?.input?.checkValidation();
    }
    if (editorType === "timepicker" || editorType === "datepicker") {
      input?.checkValidation();
    }
    const isValid = input?.isValid;
    const newValue = this.editor?.save(this);
    __privateMethod(this, _IdsDataGridCell_instances, saveCellValue_fn).call(this, newValue?.value);
    if (!isValid) __privateMethod(this, _IdsDataGridCell_instances, saveValidState_fn).call(this, input?.validationMessages);
    if (this.isInValid && isValid) __privateMethod(this, _IdsDataGridCell_instances, resetValidState_fn).call(this);
    this.isInValid = !isValid;
    this.editor?.destroy(this);
    this.renderCell();
  }
  /**
   * Start Edit Mode
   * @param {MouseEvent} clickEvent event passed if activated by click (vs keyboard)
   */
  startCellEdit(clickEvent) {
    if (this.dataGrid.activeCellEditor instanceof IdsDataGridCell && this.dataGrid.activeCellEditor !== this) {
      this.dataGrid.activeCellEditor.endCellEdit();
    }
    const column = this.column;
    if (!column.editor) return;
    const columnEditor = this.dataGrid.editors.find((obj) => obj.type === column?.editor?.type);
    if (!columnEditor || !columnEditor.editor || this.isEditing) return;
    let canEdit = !(this.classList.contains("is-readonly") || this.classList.contains("is-disabled"));
    if (!canEdit) {
      return;
    }
    this.dataGrid.triggerEvent("beforecelledit", this.dataGrid, {
      detail: {
        elem: this,
        editor: this.editor,
        column,
        data: this.dataGrid.data[this.dataGrid.activeCell.row],
        response: (veto) => {
          canEdit = veto;
        }
      }
    });
    if (canEdit instanceof Promise || canEdit?.constructor?.name === "AsyncFunction") {
      (canEdit instanceof Promise ? canEdit : canEdit()).then((veto) => {
        if (veto !== false) __privateMethod(this, _IdsDataGridCell_instances, startCellEdit_fn).call(this, column, columnEditor, clickEvent);
      }).catch(() => {
      });
    } else if (canEdit !== false) {
      __privateMethod(this, _IdsDataGridCell_instances, startCellEdit_fn).call(this, column, columnEditor, clickEvent);
    }
  }
  /* End Cell Edit */
  endCellEdit() {
    const column = this.column;
    const input = this.editor?.input;
    if (!input) return;
    const editorType = this.editor?.type;
    input?.offEvent("focusout", input);
    input?.offEvent("close", input);
    if (["input", "tree"].includes(editorType) && input?.setDirtyTracker) {
      input?.setDirtyTracker(input?.value);
    }
    if (["input", "tree"].includes(editorType) && input?.checkValidation) {
      input?.checkValidation();
    }
    if (editorType === "dropdown") {
      input?.input?.checkValidation();
    }
    if (editorType === "lookup") {
      input?.input?.checkValidation();
    }
    if (editorType === "timepicker" || editorType === "datepicker") {
      input?.checkValidation();
    }
    const isDirty = column.editor?.editorSettings?.dirtyTracker && (input?.isDirty || input?.input.isDirty);
    const isDirtyCheckbox = column.editor?.editorSettings?.dirtyTracker && editorType === "checkbox" && input?.isDirty;
    const isValid = input?.isValid;
    const newValue = this.editor?.save(this);
    __privateMethod(this, _IdsDataGridCell_instances, saveCellValue_fn).call(this, newValue?.value);
    if (isDirty || isDirtyCheckbox) __privateMethod(this, _IdsDataGridCell_instances, saveDirtyState_fn).call(this, newValue?.dirtyCheckValue ?? newValue?.value);
    if (!isValid) __privateMethod(this, _IdsDataGridCell_instances, saveValidState_fn).call(this, input?.validationMessages);
    if (this.isInValid && isValid) __privateMethod(this, _IdsDataGridCell_instances, resetValidState_fn).call(this);
    this.isInValid = !isValid;
    this.editor?.destroy(this);
    this.renderCell();
    this.isEditing = false;
    this.classList.remove("is-editing");
    this.dataGrid?.triggerEvent("endcelledit", this.dataGrid, {
      detail: {
        elem: this,
        editor: this.editor,
        column,
        data: this.dataGrid.data[this.row]
      }
    });
    this.detachTooltipEvents();
    this.dataGrid.activeCellEditor = void 0;
    this.dataGrid.openMenu = null;
  }
  /* Cancel Cell Edit */
  cancelCellEdit() {
    const column = this.column;
    const input = this.editor?.input;
    input?.offEvent("focusout", input);
    input?.setDirtyTracker(input?.value);
    this.dataGrid?.updateDataset(this.row, { [String(column?.field)]: this.originalValue });
    this.editor?.destroy(this);
    this.renderCell();
    this.isEditing = false;
    this.classList.remove("is-editing");
    this.dataGrid?.triggerEvent("cancelcelledit", this.dataGrid, {
      detail: {
        elem: this,
        editor: this.editor,
        column,
        data: this.dataGrid.data[this.row],
        oldValue: this.originalValue
      }
    });
    this.dataGrid.activeCellEditor = void 0;
    this.dataGrid.openMenu = null;
  }
  /**
   * Track value changes for dirty tracking
   * @param {any} newValue the new value
   * @param {boolean} programmaticUpdate if true, the value was changed by a programmatic update
   */
  trackValueChange(newValue, programmaticUpdate = false) {
    __privateMethod(this, _IdsDataGridCell_instances, saveDirtyState_fn).call(this, newValue, programmaticUpdate);
  }
  /**
   * Return the Template for the cell contents
   * @param {object} rowData The data item for the row
   * @param {object} column The column data for the row
   * @param {object} rowIndex The running row-index
   * @param {IdsDataGrid} dataGrid The dataGrid instance
   * @returns {string} The template to display
   */
  static template(rowData, column, rowIndex, dataGrid) {
    const cacheKey = IdsDataGridCell.cacheKey(rowIndex, rowData, column, dataGrid);
    if (!IdsDataGridCell.cellCache[cacheKey]) {
      const dataGridFormatters = dataGrid.formatters;
      let template = "";
      if (!dataGridFormatters[column?.formatter?.name || "text"] && column?.formatter) template = column?.formatter(rowData, column, rowIndex, dataGrid);
      else template = dataGridFormatters[column?.formatter?.name || "text"](rowData, column, rowIndex, dataGrid);
      if (rowData.invalidCells) {
        const message = rowData.invalidCells.find((info) => info.cell === dataGrid.columnIdxById(column.id));
        if (message) template += `<ids-alert icon="error" tooltip="${message?.validationMessages[0]?.message}"></ids-alert>`;
      }
      IdsDataGridCell.cellCache[cacheKey] = template;
    }
    return IdsDataGridCell.cellCache[cacheKey];
  }
  /**
   * Return cache key of current cell
   * @param {number} rowIndex number
   * @param {object} rowData The data item for the row
   * @param {object} column The column data for the row
   * @param {IdsDataGrid} dataGrid The dataGrid instance
   * @returns {string} Cache key
   */
  static cacheKey(rowIndex, rowData, column, dataGrid) {
    const cacheHash = dataGrid.cacheHash;
    const selected = rowData.rowSelected ? dataGrid.cacheSelected : dataGrid.cacheDeselected;
    const expanded = rowData.rowExpanded ? dataGrid.cacheExpanded : dataGrid.cacheCollapsed;
    return `${cacheHash}:${column.id}:${rowIndex}:${selected}:${expanded}`;
  }
  /**
   * Clears cell cache
   */
  clearCache() {
    const dataGrid = this.dataGrid;
    const rowIndex = Number(this.parentElement?.getAttribute("row-index"));
    const row = dataGrid.data[rowIndex];
    const cacheKey = IdsDataGridCell.cacheKey(rowIndex, row, this.column, dataGrid);
    delete IdsDataGridCell.cellCache[cacheKey];
  }
  /**
   * Refreshes the cell
   */
  refreshCell() {
    this.clearCache();
    this.renderCell();
  }
  /**
   * Checks on the cell editor to see if its current state allows it to be closed.
   * @returns {boolean} true if the cell editor is able to "close"
   */
  canClose() {
    if (this.isEditing) return false;
    if (this.editor?.popup?.visible) return false;
    if (this.column?.editor?.inline) return false;
    return true;
  }
  /**
   * Removes all tooltip-related event listeners from the data grid cell
   * @private
   * @description Detaches hover, click, popup, longpress, and focus events
   * associated with the tooltip functionality
   */
  detachTooltipEvents() {
    this.dataGrid.tooltip?.offEvent("hoverend.tooltip", this);
    this.dataGrid.tooltip?.offEvent("click.tooltip", this);
    this.dataGrid.tooltip?.offEvent("click.popup", this.dataGrid.tooltip?.popup);
    this.dataGrid.tooltip?.offEvent("longpress.tooltip", this);
    this.dataGrid.tooltip?.offEvent("focusin.tooltip", this);
    this.dataGrid.tooltip?.offEvent("focus.keyboardfocus", this);
  }
};
_memoizedColumn = new WeakMap();
_memoizedColumnIndex = new WeakMap();
_IdsDataGridCell_instances = new WeakSet();
/* Start Cell Edit */
startCellEdit_fn = function(column, columnEditor, clickEvent) {
  if (!columnEditor || !columnEditor.editor || this.isEditing) return;
  this.detachTooltipEvents();
  this.originalValue = this.value;
  this.editor = columnEditor.editor;
  this.editor.clickEvent = clickEvent;
  const editorType = this.editor.type;
  if (editorType === "dropdown") {
    this.originalValue = this.querySelector("[data-value]")?.getAttribute("data-value");
  }
  this.classList.add("is-editing");
  this.editor.init(this);
  if (this.classList.contains("is-invalid")) {
    this.classList.remove("is-invalid");
    this.isInValid = true;
  }
  if (column.editor?.inline) this.classList.add("is-inline");
  this.isEditing = true;
  if (column.align) {
    let columnAlign = column.align;
    if (columnAlign === "left") columnAlign = "start";
    if (columnAlign === "right") columnAlign = "end";
    this.editor?.input?.setAttribute("text-align", `${columnAlign}`);
  }
  if (["datepicker", "timepicker", "lookup"].includes(editorType)) {
    this.editor.input?.onEvent("focusout", this.editor.input, () => {
      requestAnimationFrame(() => {
        if (this.editor?.popup?.visible || this.contains(this.dataGrid.shadowRoot.activeElement)) return;
        this.tabIndex = -1;
      });
    });
    this.onEvent("hide.popup", this.editor?.popup, () => {
      this.offEvent("hide.popup");
      this.endCellEdit();
      this.focus();
    });
  } else if (editorType === "dropdown") {
    this.editor.input?.onEvent("close", this.editor.input, () => {
      this.endCellEdit();
      this.focus();
    });
  } else {
    this.editor.input?.onEvent("focusout", this.editor.input, () => {
      this.endCellEdit();
    });
  }
  this.dataGrid?.triggerEvent("celledit", this.dataGrid, {
    detail: {
      elem: this,
      editor: this.editor,
      column,
      data: this.dataGrid.data[this.row]
    }
  });
  this.dataGrid.activeCellEditor = this;
};
/**
 * Save cell Edit Back into data set
 * @param {any} newValue the value to coerce and save
 */
saveCellValue_fn = function(newValue) {
  const column = this.column;
  this.dataGrid.resetCache(this.dataGrid?.activeCell.row);
  if (column.editor?.editorSettings?.mask === "date") {
    newValue = this.dataGrid.localeAPI.parseDate(newValue, column.formatOptions);
  }
  this.dataGrid?.updateDataset(this.row, {
    [String(column?.field)]: newValue
  });
};
/**
 * Save the dirty state info on the row
 * @param {boolean} newValue the current value
 * @param {boolean} programmaticUpdate if true, the value was changed by a progammaticUpdate update
 */
saveDirtyState_fn = function(newValue, programmaticUpdate = false) {
  let rowDirtyCells = this.dataGrid.data[this.row].dirtyCells;
  if (rowDirtyCells === void 0) rowDirtyCells = [];
  const cell = Number(this.getAttribute("aria-colindex")) - 1;
  const previousCellInfo = rowDirtyCells.filter((item) => item.cell === cell);
  if (previousCellInfo[0] && newValue === previousCellInfo[0].originalValue) {
    const oldIndex = rowDirtyCells.findIndex((item) => item.cell === cell);
    rowDirtyCells.splice(oldIndex, 1);
    this?.classList.remove("is-dirty");
    this.dataGrid?.updateDataset(this.row, {
      dirtyCells: rowDirtyCells
    });
    return;
  }
  this?.classList.add("is-dirty");
  if (previousCellInfo.length === 0) {
    const originalValue = this?.editor?.type === "checkbox" || programmaticUpdate ? this.originalValue : this?.editor?.input?.dirty?.original;
    rowDirtyCells.push({
      cell: Number(this?.getAttribute("aria-colindex")) - 1,
      columnId: this.column.id,
      originalValue
    });
    this.dataGrid?.updateDataset(this.row, {
      dirtyCells: rowDirtyCells
    });
  }
};
/**
 * Save the validation state info on the row
 * @param {any} validationMessages the current value
 */
saveValidState_fn = function(validationMessages) {
  let rowInvalidCells = this.dataGrid.data[this.row].invalidCells;
  if (!rowInvalidCells) rowInvalidCells = [];
  const cell = Number(this.getAttribute("aria-colindex")) - 1;
  const previousCellInfo = rowInvalidCells.filter((item) => item.cell === cell);
  this?.classList.add("is-invalid");
  if (previousCellInfo.length === 0) {
    this.previousInvalidState = validationMessages.id;
    rowInvalidCells.push({
      cell: Number(this?.getAttribute("aria-colindex")) - 1,
      columnId: this.column.id,
      validationMessages
    });
    this.dataGrid?.updateDataset(this.row, {
      invalidCells: rowInvalidCells
    });
  }
};
/**
 * Set back the valid state
 */
resetValidState_fn = function() {
  this?.classList.remove("is-invalid");
  this.dataGrid?.updateDataset(this.row, {
    invalidCells: void 0
  });
  this.isInValid = false;
};
// NOTE: check memory footprint of this caching strategy
__publicField(IdsDataGridCell, "cellCache", {});
IdsDataGridCell = __decorateClass([
  customElement("ids-data-grid-cell")
], IdsDataGridCell);

export {
  IdsDataGridCell
};
//# sourceMappingURL=ids-chunk-3GKCJCLH-full.js.map
