/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-loading-indicator-mixin/ids-loading-indicator-mixin.ts
var IdsLoadingIndicatorMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.LOADING_INDICATOR_ONLY,
      attributes.SHOW_LOADING_INDICATOR
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.#attachLoadingIndicator();
    this.#addClass();
  }
  /**
   * Set whether or not to show loading indicator. Disabled by default
   * @param {boolean|string|null} value show-loading-indicator attribute value
   */
  set showLoadingIndicator(value) {
    const boolVal = stringToBool(value);
    if (boolVal) {
      this.setAttribute(attributes.SHOW_LOADING_INDICATOR, boolVal.toString());
    } else {
      this.removeAttribute(attributes.SHOW_LOADING_INDICATOR);
    }
    this.#attachLoadingIndicator();
  }
  /**
   * show-loading-indicator attribute
   * @returns {boolean} showLoadingIndicator param converted to boolean from attribute value. Defaults to false
   */
  get showLoadingIndicator() {
    return stringToBool(this.getAttribute(attributes.SHOW_LOADING_INDICATOR));
  }
  /**
   * Set whether or not to replace text/icons with the loading indicator and place it at the center. Defaults to false
   * @param {boolean|string|null} value loading-indicator-only attribute value
   */
  set loadingIndicatorOnly(value) {
    const boolVal = stringToBool(value);
    if (boolVal) {
      this.setAttribute(attributes.LOADING_INDICATOR_ONLY, boolVal.toString());
    } else {
      this.removeAttribute(attributes.LOADING_INDICATOR_ONLY);
    }
  }
  /**
   * loading-indicator-only attribute
   * @returns {boolean} loadingIndicatorOnly param converted to boolean from attribute value. Defaults to false
   */
  get loadingIndicatorOnly() {
    return stringToBool(this.getAttribute(attributes.LOADING_INDICATOR_ONLY));
  }
  #getSlottedElements() {
    const slot = this.container?.querySelector('slot[name="loading-indicator"]');
    return slot?.assignedNodes();
  }
  #attachLoadingIndicator() {
    if (this.showLoadingIndicator && this.#getSlottedElements()?.length === 0) {
      const type = this.getAttribute(attributes.APPEARANCE);
      this.insertAdjacentHTML(
        "beforeend",
        `<ids-loading-indicator
          slot="loading-indicator"
          size="xs"
          class="slot-loading-indicator${type ? ` type-${type}` : ""}"
        ></ids-loading-indicator>`
      );
    }
  }
  /**
   * Add CSS class if an element provided in the slot
   */
  #addClass() {
    this.#getSlottedElements()?.forEach((item) => {
      item.classList.add("slot-loading-indicator");
    });
  }
};
var ids_loading_indicator_mixin_default = IdsLoadingIndicatorMixin;

export {
  ids_loading_indicator_mixin_default
};
//# sourceMappingURL=ids-chunk-4J54B7P5-full.js.map
