/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/utils/ids-zip/ids-zip-entry.ts
var crcTable = (() => {
  let c;
  const table = [];
  for (let n = 0; n < 256; n++) {
    c = n;
    for (let k = 0; k < 8; k++) {
      c = c & 1 ? 3988292384 ^ c >>> 1 : c >>> 1;
    }
    table[n] = c;
  }
  return table;
})();
var ZipEntry = class {
  // filename/dir name
  name;
  // is directory
  dir;
  // date modified
  date;
  // file content
  data;
  // compressed size
  // (compression not currently supported)
  compressedSize = 0;
  // uncompressed size
  uncompressedSize = 0;
  // compression algorithm (no compression)
  compression = "\0\0";
  // crc32 checksum
  crc32 = 0;
  // file comment
  comment = "";
  constructor(name, data, isDir) {
    this.name = isDir ? this.forceTrailingSlash(name) : name;
    this.dir = isDir;
    this.date = /* @__PURE__ */ new Date();
    this.data = data;
  }
  /**
   * Processes file data and calculates size and checksum
   * @returns {Uint8Array} data converted to Uin8Array
   */
  processData() {
    let data = new Uint8Array();
    if (typeof this.data === "string" && this.data.length) {
      data = this.encodeData(this.data);
      this.crc32 = this.calcCrc32(0, data, data.length, 0);
      this.compressedSize = data.length;
      this.uncompressedSize = data.length;
    }
    return data;
  }
  /**
   * Encode data string
   * @param {string} str string to convert
   * @returns {Uint8Array} buffer
   */
  encodeData(str) {
    const encoder = new TextEncoder();
    return encoder.encode(str);
  }
  forceTrailingSlash(path) {
    return path.slice(-1) !== "/" ? `${path}/` : path;
  }
  /**
   * Compute the crc32 of a buffer
   * @param {number} crc the starting value of the crc.
   * @param {any} buf the buffer to use.
   * @param {number} len the length of the buffer.
   * @param {number} pos the starting position for the crc32 computation.
   * @returns {number} the computed crc32
   */
  calcCrc32(crc, buf, len, pos) {
    const t = crcTable;
    const end = pos + len;
    crc ^= -1;
    for (let i = pos; i < end; i++) {
      crc = crc >>> 8 ^ t[(crc ^ buf[i]) & 255];
    }
    return crc ^ -1;
  }
};

export {
  ZipEntry
};
//# sourceMappingURL=ids-chunk-4L777FGO-full.js.map
