/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-form-input-mixin/ids-form-input-mixin.ts
var noop = (...params) => params;
var IdsFormInputMixin = (superclass) => class extends superclass {
  /**
   * ElementInternals adds the capability for custom elements to participate in a form submission.
   * To use this feature, we must declare that a custom element is associated with forms as follows:
   * @see https://webkit.org/blog/13711/elementinternals-and-form-associated-custom-elements/
   */
  static formAssociated = true;
  #internals;
  constructor(...args) {
    super(...args);
    this.#internals = this.attachInternals?.();
    if (this.#internals) {
      this.#internals.ariaLabel = this.name || "default aria label";
    }
  }
  /**
   * @returns {Array<string>} IdsInput component observable attributes
   */
  static get attributes() {
    return [
      ...superclass.attributes,
      ...attributes.NAME,
      ...attributes.VALUE
    ];
  }
  /**
   * @readonly
   * @returns {HTMLInputElement} the inner `input` element
   */
  get formInput() {
    return this.shadowRoot?.querySelector(`input`) ?? null;
  }
  /**
   * React to attributes changing on the web-component
   * @param {string} name The property name
   * @param {string} oldValue The property old value
   * @param {string} newValue The property new value
   */
  attributeChangedCallback(name, oldValue, newValue) {
    super.attributeChangedCallback(name, oldValue, newValue);
    if (oldValue === newValue || !this.formInput || name === attributes.ID) return;
    if (name === attributes.VALUE) {
      if (!this.formInput) return;
      const processedValue = this.getAttribute(attributes.VALUE) ?? "";
      this.formInput?.setAttribute?.(name, processedValue);
      this.formInput.value = processedValue;
      this.formInput?.dispatchEvent?.(new CustomEvent("change", {
        bubbles: true,
        composed: true,
        detail: {
          elem: this,
          value: processedValue
        }
      }));
    } else if (stringToBool(newValue)) {
      this.formInput?.setAttribute?.(name, newValue || "");
    } else {
      this.formInput?.removeAttribute?.(name);
    }
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.#ariaDefaults();
    this.offEvent("change.native", this.formInput);
    this.onEvent("change.native", this.formInput, (e) => {
      if (this.onBeforeChange()) {
        return;
      }
      this.#handleChangeEvent(e);
    });
    this.offEvent("input.native", this.formInput);
    this.onEvent("input.native", this.formInput, (e) => {
      if (this.onBeforeInput()) {
        return;
      }
      e.stopPropagation();
      this.#handleInputEvent(e);
    });
  }
  #ariaDefaults() {
    const label = this.getAttribute(attributes.LABEL) ?? this.#internals?.ariaLabel ?? "";
    this.formInput?.setAttribute("aria-label", label);
  }
  #handleChangeEvent(e) {
    const value = this.value;
    this.#internals?.setFormValue?.(value);
    if (e instanceof CustomEvent) {
      e.stopPropagation();
    }
    this.triggerEvent(`change.${this.name ?? "ids-form-input-mixin"}`, this, {
      bubbles: true,
      composed: true,
      detail: {
        elem: this,
        value,
        nativeEvent: e
      }
    });
  }
  #handleInputEvent(e) {
    const value = this.value;
    this.#internals?.setFormValue?.(value);
    const inputWrapper = e.target?.getRootNode()?.host;
    if (inputWrapper) {
      try {
        inputWrapper.value = value;
      } catch (err) {
        inputWrapper.setAttribute?.(attributes.VALUE, value);
      }
    }
    this.triggerEvent(`input.${this.name ?? "ids-form-input-mixin"}`, this, {
      bubbles: true,
      composed: true,
      detail: {
        elem: this,
        value,
        nativeEvent: e
      }
    });
  }
  get form() {
    return this.#internals?.form;
  }
  get type() {
    return this.localName;
  }
  get value() {
    return this.formInput?.value ?? this.formInput?.getAttribute?.(attributes.VALUE) ?? "";
  }
  set value(value) {
    if (value === this.value) return;
    this.setAttribute(attributes.VALUE, value ?? "");
  }
  /**
   * @see https://developer.mozilla.org/docs/Web/API/ElementInternals/validity
   * @see ElementInternals.validity
   * @returns {ValidityState} - Returns the ValidityState object for internals's target element.
   */
  get validity() {
    return this.#internals?.validity;
  }
  /**
   * @see https://developer.mozilla.org/docs/Web/API/ElementInternals/validationMessage
   * @see ElementInternals.validationMessage
   * @returns {string} - error message that would be shown to the user
   */
  get validationMessage() {
    return this.#internals?.validationMessage;
  }
  /**
   * @see https://developer.mozilla.org/docs/Web/API/ElementInternals/willValidate
   * @see ElementInternals.willValidate()
   * @returns {boolean} - true if internals's target element will be validated when the form is submitted
   */
  get willValidate() {
    return this.#internals?.willValidate;
  }
  /**
   * @see https://developer.mozilla.org/docs/Web/API/ElementInternals/checkValidity
   * @see ElementInternals.checkValidity()
   * @returns {boolean} - true if internals's target element has no validity problems
   */
  checkValidity() {
    return this.#internals?.checkValidity?.();
  }
  /**
   * @see https://developer.mozilla.org/docs/Web/API/ElementInternals/reportValidity
   * @see ElementInternals.reportValidity()
   * @returns {boolean} - true if internals's target element has no validity problems
   */
  reportValidity() {
    return this.#internals?.reportValidity?.();
  }
  /**
   * Called when the associated form-element changes to the form param.
   * ElementInternals.form returns the associated from element.
   * @param {ElementInternals['form']} form - this elements parent form element
   */
  formAssociatedCallback(form) {
    noop(form);
  }
  /**
   * Called when the form is being reset (e.g. user pressed input[type=reset] button).
   * Custom element should clear whatever value set by the user.
   */
  formResetCallback() {
  }
  /**
   * Called when the disabled state of the element changes.
   * @param {boolean} isDisabled - is disabled
   */
  formDisabledCallback(isDisabled) {
    noop(isDisabled);
  }
  /**
   * Called when the browser is trying to restore element’s value using the state param,
   * in which case the reason param is "restore".
   *
   * Also called when the browser is trying to fulfill autofill on behalf of user,
   * in which case the reason param is "autocomplete".
   *
   * In the case of "restore", state is a string, File,
   * or FormData object previously set as the second argument to setFormValue.
   * @param {File|string|FormData|null} state - the form element's state
   * @param {string} reason - "restore" or "autocomplete"
   */
  formStateRestoreCallback(state, reason) {
    noop(state, reason);
  }
  /**
   * Hook that runs before processing a change event
   * Override this method in your component to implement custom pre-change behavior
   * @returns {boolean} True to prevent default change handling
   */
  onBeforeChange() {
    return false;
  }
  /**
   * Hook that runs before processing an input event
   * Override this method in your component to implement custom pre-change behavior
   * @returns {boolean} True to prevent default input handling
   */
  onBeforeInput() {
    return false;
  }
};
var ids_form_input_mixin_default = IdsFormInputMixin;

export {
  ids_form_input_mixin_default
};
//# sourceMappingURL=ids-chunk-4PKFQUAM-full.js.map
