/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/utils/ids-xss-utils/ids-xss-utils.ts
function sanitizeConsoleMethods(html) {
  const methods = ["assert", "clear", "count", "debug", "dirxml", "dir", "error", "exception", "groupCollapsed", "groupEnd", "group", "info", "log", "markTimeline", "profileEnd", "profile", "table", "timeEnd", "timeStamp", "time", "trace", "warn"];
  const expr = new RegExp(`console\\.(${methods.join("|")})((\\s+)?\\(([^)]+)\\);?)?`, "igm");
  return typeof html !== "string" ? html : html.replace(expr, "");
}
function sanitizeHTML(html) {
  let santizedHtml = html.replace(/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/g, "");
  santizedHtml = santizedHtml.replace(/<iframe\b[^<]*(?:(?!<\/iframe>)<[^<]*)*<\/iframe>/gi, "");
  santizedHtml = santizedHtml.replace(/<iframe\b[^<]*(?:(?!>)<[^<]*)*>/gi, "");
  santizedHtml = santizedHtml.replace(/<[^>]+/g, (match) => {
    const expr = /(\/|\s)on\w+=('|")?/g;
    let str = match;
    if ((str.match(expr) || []).length > 0) {
      str = str.replace(/(\/|\s)title=('|")(.*)('|")/g, (m) => {
        if ((m.match(expr) || []).length > 0) {
          return m.replace(expr, (m2) => m2.replace("on", ""));
        }
        return m;
      });
    }
    return str.replace(/(\/|\s)on\w+=('|")?[^"]*('|")?/g, "");
  });
  santizedHtml = sanitizeConsoleMethods(santizedHtml);
  santizedHtml = santizedHtml.replace(/<\/script>/g, "");
  return santizedHtml;
}
function stripHTML(str) {
  let newStr = str;
  if (!newStr) {
    return "";
  }
  newStr = newStr.replace(/<\/?[^>]+(>|$)/g, "");
  return newStr;
}
function stripTags(html, allowed) {
  if (!html) {
    return "";
  }
  if (typeof html === "number") {
    return html;
  }
  const allowList = (`${allowed || ""}`.toLowerCase().match(/<[a-z][a-z0-9|ids\-a-z]*>/g) || []).join("");
  const tags = /<\/?([a-z][a-z0-9|ids\-a-z]*)\b[^>]*>/gi;
  const commentsAndPhpTags = /<!--[\s\S]*?-->|<\?(?:php)?[\s\S]*?\?>/gi;
  let returnHTML = "";
  returnHTML = html.replace(commentsAndPhpTags, "").replace(tags, ($0, $1) => allowList.indexOf("<" + $1.toLowerCase() + ">") > -1 ? $0 : "");
  returnHTML = returnHTML.replace(tags, ($0, $1) => allowList.indexOf("<" + $1.toLowerCase() + ">") > -1 ? $0 : "");
  return returnHTML;
}
function unescapeHTML(value) {
  if (value === "") {
    return "";
  }
  if (typeof value === "string") {
    const match = (regx) => value.match(regx)[0];
    const doc = new DOMParser().parseFromString(value, "text/html");
    return `${match(/^\s*/)}${doc.documentElement.textContent.trim()}${match(/\s*$/)}`;
  }
  return value;
}
function escapeHTML(unsafe) {
  if (!unsafe) return "";
  return unsafe.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#039;").replace(/\\/g, "&bsol;");
}

export {
  sanitizeConsoleMethods,
  sanitizeHTML,
  stripHTML,
  stripTags,
  unescapeHTML,
  escapeHTML
};
//# sourceMappingURL=ids-chunk-5K4YUTOH-full.js.map
