/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-dirty-tracker-mixin/ids-dirty-tracker-mixin.ts
var IdsDirtyTrackerMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.handleDirtyTracker();
    requestAnimationFrame(() => {
      if (this?.getAttribute("color-variant") !== "in-cell") {
        this.resetDirtyTracker();
      }
      this.#dirtyTrackerInitialized = true;
    });
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.DIRTY_TRACKER
    ];
  }
  #dirtyTrackerInitialized = false;
  dirty = {
    original: ""
  };
  isDirty = false;
  isCheckbox = false;
  isEditor = false;
  isRadioGroup = false;
  dirtyContainer;
  /**
   * Handle dirty tracker values
   * @returns {void}
   */
  handleDirtyTracker() {
    const thisAsInput = this;
    this.isCheckbox = thisAsInput.input?.getAttribute("type") === "checkbox";
    this.isEditor = !!thisAsInput.input?.classList.contains("source-textarea");
    this.isRadioGroup = !!thisAsInput.input?.classList.contains("ids-radio-group");
    if (`${this.dirtyTracker}`.toLowerCase() === "true") {
      if (thisAsInput.input) {
        const val = this.valMethod(thisAsInput.input);
        if (this.isRadioGroup && (val === null || val === void 0)) {
          this.dirty = { original: thisAsInput.value || "" };
        } else {
          this.dirty = { original: val };
        }
        this.dirtyTrackerEvents();
      }
    } else {
      this.destroyDirtyTracker();
    }
  }
  /**
   * Check if dirty tracker icon exists if not add it
   * @private
   * @returns {void}
   */
  appendDirtyTrackerIcon() {
    const thisAsInput = this;
    let icon = thisAsInput.input?.shadowRoot?.querySelector(".icon-dirty");
    if (!icon) {
      icon = document.createElement("ids-icon");
      icon.setAttribute("icon", "dirty-filled");
      icon.setAttribute("size", this.tagName === "IDS-CHECKBOX" || this.tagName === "IDS-RADIO-GROUP" ? "xsmall" : "small");
      icon.setAttribute("part", "dirty-tracker-icon");
      icon.className = "icon-dirty";
      if (this.localeAPI?.isRTL()) icon?.setAttribute("dir", "rtl");
      icon.style.pointerEvents = "none";
      if (this.isCheckbox) {
        thisAsInput.labelEl?.appendChild(icon);
        this.dirtyContainer = thisAsInput.labelEl;
      } else if (this.isRadioGroup) {
        this.dirtyContainer = this.shadowRoot?.querySelector(".ids-radio-group");
        this.dirtyContainer?.prepend(icon);
      } else if (this.isEditor) {
        this.dirtyContainer = this.shadowRoot?.querySelector(".editor-content");
        this.dirtyContainer?.appendChild(icon);
      } else if (this.tagName === "IDS-DROPDOWN" || this.tagName === "IDS-MULTISELECT") {
        this.dirtyContainer = thisAsInput.input?.fieldContainer;
        this.dirtyContainer?.prepend(icon);
      } else {
        thisAsInput.fieldContainer?.prepend(icon);
        this.dirtyContainer = thisAsInput.fieldContainer;
      }
    }
  }
  /**
   * Remove if dirty tracker icon exists
   * @private
   * @returns {void}
   */
  removeDirtyTrackerIcon() {
    const icon = this.dirtyContainer?.querySelector(".icon-dirty");
    if (icon) {
      icon.remove();
    }
  }
  /**
   * Check if dirty tracker msg exists if not add it
   * @private
   * @returns {void}
   */
  appendDirtyTrackerMsg() {
    let msg = this.labelEl?.querySelector(".msg-dirty");
    if (!msg) {
      msg = document.createElement("ids-text");
      msg.setAttribute("audible", "true");
      msg.className = "msg-dirty";
      msg.innerHTML = ", Modified";
      this.labelEl?.appendChild(msg);
    }
  }
  /**
   * Remove if dirty tracker msg exists
   * @private
   * @returns {void}
   */
  removeDirtyTrackerMsg() {
    let msg = this.labelEl?.querySelector(".msg-dirty");
    if (msg) {
      msg.remove();
    }
    msg = this.input?.shadowRoot?.querySelector(".icon-dirty");
    if (msg) {
      msg.remove();
    }
  }
  /**
   * Get the value or checked attribute if checkbox or radio
   * @private
   * @param {object} el .
   * @returns {any} element value
   */
  valMethod(el) {
    const thisAsInput = this;
    let r;
    if (this.isRadioGroup) {
      r = thisAsInput.value || "";
    } else if (this.isCheckbox) {
      r = `${thisAsInput.checked}`.toLowerCase() === "true";
    } else if (this.isEditor) {
      r = thisAsInput.value;
    } else {
      r = el?.value;
    }
    return r;
  }
  /**
   * Set dirtyTracker
   * @private
   * @param {string} val The current element value
   * @returns {void}
   */
  setDirtyTracker(val) {
    if (typeof val === "undefined") {
      this.handleDirtyTracker();
      return;
    }
    const currentVal = val === null ? "" : val;
    if ((this.dirty?.original === void 0 || this.dirty?.original === null) && this.tagName !== "IDS-TEXTAREA") {
      if (currentVal !== this.dirty && typeof currentVal !== "object" && this.dirty) {
        this.dirty.original = currentVal;
      }
    }
    const originalVal = this.dirty?.original === null ? "" : this.dirty?.original;
    const shouldBeDirty = originalVal !== currentVal;
    if (shouldBeDirty !== this.isDirty) {
      this.isDirty = shouldBeDirty;
      if (this.isDirty) {
        this.appendDirtyTrackerMsg();
        this.appendDirtyTrackerIcon();
        this.#triggerDirtyEvent("dirty");
      } else {
        this.removeDirtyTrackerMsg();
        this.removeDirtyTrackerIcon();
        this.#triggerDirtyEvent("pristine");
      }
    }
  }
  /**
   * Handle dirty tracker events
   * @private
   * @param {string} option If 'remove', will remove attached events
   * @returns {void}
   */
  dirtyTrackerEvents(option = "") {
    const thisAsInput = this;
    if (this.input) {
      const eventName = "change.dirtytrackermixin";
      if (option === "remove") {
        const handler = this?.handledEvents?.get(eventName);
        if (handler && handler.target === thisAsInput.input) {
          this.offEvent(eventName, thisAsInput.input);
        }
      } else {
        this.offEvent(eventName);
        this.onEvent(eventName, thisAsInput.input, () => {
          const val = this.valMethod(thisAsInput.input);
          this.setDirtyTracker(val);
        });
      }
    }
  }
  /** Handle Languages Changes */
  onLanguageChange = () => {
    const icon = this.dirtyContainer?.querySelector(".icon-dirty");
    if (this.localeAPI?.isRTL()) icon?.setAttribute("dir", "rtl");
    else icon?.removeAttribute("dir");
  };
  /**
   * Reset dirty tracker
   * @returns {void}
   */
  resetDirtyTracker() {
    if (this.dirty) {
      this.removeDirtyTrackerIcon();
      this.removeDirtyTrackerMsg();
      const thisAsInput = this;
      let originalValue = this.valMethod(thisAsInput.input);
      if (this.isRadioGroup && (originalValue === null || originalValue === void 0)) {
        originalValue = thisAsInput.value || "";
      }
      this.dirty = { original: originalValue };
    } else {
      this.handleDirtyTracker();
    }
    this.isDirty = false;
    this.#triggerDirtyEvent("afterresetdirty");
  }
  /**
   * Destroy dirty tracker
   * @returns {void}
   */
  destroyDirtyTracker() {
    this.dirtyTrackerEvents("remove");
    this.removeDirtyTrackerIcon();
    this.removeDirtyTrackerMsg();
    this.dirty = null;
  }
  /**
   * Runs optional callback, if possible
   * @private
   * @returns {void}
   */
  #onDirtyTrackerChange() {
    if (typeof this.onDirtyTrackerChange === "function") {
      this.onDirtyTrackerChange(this.dirtyTracker);
    }
  }
  /**
   * Set the dirty tracking feature on to indicate a changed field
   * @param {boolean|string} value If true will set `dirty-tracker` attribute
   */
  set dirtyTracker(value) {
    const val = stringToBool(value);
    if (val) {
      this.setAttribute(attributes.DIRTY_TRACKER, val.toString());
    } else {
      this.removeAttribute(attributes.DIRTY_TRACKER);
    }
    this.#onDirtyTrackerChange();
    this.handleDirtyTracker();
  }
  get dirtyTracker() {
    return stringToBool(this.getAttribute(attributes.DIRTY_TRACKER));
  }
  #triggerDirtyEvent(name) {
    if (!this.#dirtyTrackerInitialized) return;
    this.triggerEvent(name, this, {
      detail: {
        elem: this,
        ...this.dirty,
        isDirty: this.isDirty
      }
    });
  }
};
var ids_dirty_tracker_mixin_default = IdsDirtyTrackerMixin;

export {
  ids_dirty_tracker_mixin_default
};
//# sourceMappingURL=ids-chunk-6NGUFHUC-full.js.map
