/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  camelCase
} from "./ids-chunk-REOQKPVR-full.js";

// src/components/ids-upload-advanced/ids-upload-advanced-shared.ts
var IdsUploadAdvancedShared = {
  DEFAULTS: {
    autoStart: true,
    // allow automatic start upload, after files have been dropped or added
    paramName: "myfile",
    // variable name to read from server
    icon: "upload",
    // Droparea icon
    maxFileSize: -1,
    // max file size in bytes, -1 for unlimited
    maxFiles: 99999,
    // max files can be upload
    maxFilesInProcess: 99999,
    // max files can be upload while in process,
    method: "POST",
    // Sets the method to use component XMLHttpRequest method to send files
    showBrowseLink: true,
    // Browse files to upload
    // Text strings
    textBtnCancel: "",
    textBtnCancelAll: "",
    textBtnDismissError: "",
    textBtnRemove: "",
    textBtnStartUpload: "",
    textDroparea: "",
    textDropareaWithBrowse: "",
    textDropareaWithBrowseLink: "",
    textProgressLabel: "",
    // Error strings
    errorMaxFiles: "",
    errorMaxFilesInProcess: "",
    errorAcceptFileType: "",
    errorMaxFileSize: "",
    errorUrl: "",
    errorXhrHeaders: "",
    // Extra headers to use with XMLHttpRequest (JSON)
    xhrHeaders: ""
  },
  ERRORS: {
    errorMaxFiles: "error-max-files",
    errorMaxFilesInProcess: "error-max-files-in-process",
    errorAcceptFileType: "error-accept-file-type",
    errorMaxFileSize: "error-max-file-size",
    errorUrl: "error-url",
    errorXhrHeaders: "error-xhr-headers"
  },
  STATUS: {
    notStarted: "not-started",
    inProcess: "in-process",
    aborted: "aborted",
    errored: "errored",
    completed: "completed"
  },
  /**
   * Formats the file size to human readable.
   * @private
   * @param {number} bytes The size value in bytes.
   * @param {number} decimals The decimal point.
   * @returns {string} formated to use in ui.
   */
  formatBytes(bytes, decimals = 2) {
    const units = ["Bytes", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"];
    if (typeof bytes !== "number") {
      return "";
    }
    let index;
    const multiplier = 1e3;
    let val = bytes;
    for (index = 0; val > multiplier; index++) {
      val /= multiplier;
    }
    return `${parseFloat(val.toFixed(decimals))} ${units[index]}`;
  },
  /**
   * Get the value for given slot.
   * @private
   * @param {object} shadowRoot The shadow root.
   * @param {string} slotName The slot name.
   * @returns {string} The slot val.
   */
  slotVal(shadowRoot, slotName) {
    const d = this.DEFAULTS;
    const html = (slot2) => slot2?.assignedNodes()[0]?.innerHTML;
    const slot = shadowRoot?.querySelector(`slot[name="${slotName}"]`);
    return html(slot) || d[camelCase(slotName)];
  }
};
var ids_upload_advanced_shared_default = IdsUploadAdvancedShared;

export {
  ids_upload_advanced_shared_default
};
//# sourceMappingURL=ids-chunk-6WTOH5AR-full.js.map
