/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-time-picker/ids-time-picker-common.ts
var IdsTimePickerCommonAttributes = [
  attributes.AUTOSELECT,
  attributes.AUTOUPDATE,
  attributes.DISABLED,
  attributes.EMBEDDABLE,
  attributes.ID,
  attributes.LABEL,
  attributes.NO_MARGINS,
  attributes.PLACEHOLDER,
  attributes.READONLY,
  attributes.SIZE,
  attributes.TABBABLE,
  attributes.VALIDATE,
  attributes.VALIDATION_EVENTS,
  attributes.VALUE,
  attributes.ROUND_TO_INTERVAL
];
var IdsTimePickerMixinAttributes = [
  attributes.END_HOUR,
  attributes.FORMAT,
  attributes.HOURS,
  attributes.MINUTES,
  attributes.MINUTE_INTERVAL,
  attributes.PERIOD,
  attributes.SECONDS,
  attributes.SECOND_INTERVAL,
  attributes.START_HOUR,
  attributes.USE_CURRENT_TIME
];
var range = (start, stop, step = 1) => start > stop ? [] : [start, ...range(start + Math.abs(step), stop, step)];
var constructTimeString = (timeParts, format) => {
  const pad = (num) => num !== null ? num.toString().padStart(2, "0") : "00";
  const formatSegments = format.split(/[\s:]+/);
  const separators = format.match(/[:\s]/g) || [];
  let result = "";
  let separatorIndex = 0;
  formatSegments.forEach((segment, index) => {
    switch (segment.toLowerCase()) {
      case "hh":
      case "h": {
        const hours = timeParts.hours;
        if (hours !== null) {
          let hour12 = hours;
          if (hours > 12) {
            hour12 = hours - 12;
          } else if (hours === 0) {
            hour12 = 12;
          }
          result += segment === "hh" ? pad(hour12) : hour12;
        }
        break;
      }
      case "HH":
      case "H": {
        result += segment === "HH" ? pad(timeParts.hours) : timeParts.hours;
        break;
      }
      case "mm":
      case "m": {
        result += segment === "mm" ? pad(timeParts.minutes) : timeParts.minutes;
        break;
      }
      case "ss":
      case "s": {
        result += segment === "ss" ? pad(timeParts.seconds) : timeParts.seconds;
        break;
      }
      case "a": {
        result += timeParts.period || "AM";
        break;
      }
      default:
        result += "";
    }
    if (index < formatSegments.length - 1 && separatorIndex < separators.length) {
      result += separators[separatorIndex];
      separatorIndex++;
    }
  });
  return result;
};
var parseTimeFromFormat = (timeOnField, format) => {
  const parts = {
    hours: 0,
    minutes: 0,
    seconds: 0,
    period: ""
  };
  if (!timeOnField || !format) {
    return parts;
  }
  const timeSegments = timeOnField.split(/[\s:]+/);
  const formatSegments = format.split(/[\s:]+/);
  const formatMap = formatSegments.reduce((acc, segment, index) => {
    acc[segment.toLowerCase()] = index;
    return acc;
  }, {});
  if (formatMap.hasOwnProperty("hh") || formatMap.hasOwnProperty("h")) {
    parts.hours = parseInt(timeSegments[formatMap.hh || formatMap.h], 10);
  }
  if (formatMap.hasOwnProperty("HH") || formatMap.hasOwnProperty("H")) {
    parts.hours = parseInt(timeSegments[formatMap.HH || formatMap.H], 10);
  }
  if (formatMap.hasOwnProperty("mm") || formatMap.hasOwnProperty("m")) {
    parts.minutes = parseInt(timeSegments[formatMap.mm || formatMap.m], 10);
  }
  if (formatMap.hasOwnProperty("ss") || formatMap.hasOwnProperty("s")) {
    parts.seconds = parseInt(timeSegments[formatMap.ss || formatMap.s], 10);
  }
  if (formatMap.hasOwnProperty("a")) {
    let periodValue = timeSegments[formatMap.a]?.toUpperCase();
    if (!(periodValue === "AM" || periodValue === "PM")) {
      const foundPeriod = timeSegments.find((segment) => ["AM", "PM"].includes(segment.toUpperCase()));
      periodValue = foundPeriod?.toUpperCase() || "";
    }
    parts.period = periodValue;
  }
  return parts;
};

export {
  IdsTimePickerCommonAttributes,
  IdsTimePickerMixinAttributes,
  range,
  constructTimeString,
  parseTimeFromFormat
};
//# sourceMappingURL=ids-chunk-6YKCTAJI-full.js.map
