/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  FIELD_HEIGHTS,
  ids_field_height_mixin_default
} from "./ids-chunk-LZWQ252S-full.js";
import {
  ids_events_mixin_default
} from "./ids-chunk-KKFANICI-full.js";
import {
  IdsElement
} from "./ids-chunk-UTR2KJV7-full.js";
import {
  customElement
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";
import {
  __decorateClass
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-form/ids-form.ts
var Base = ids_field_height_mixin_default(
  ids_events_mixin_default(
    IdsElement
  )
);
var IdsForm = class extends Base {
  constructor() {
    super();
  }
  static get attributes() {
    return [
      ...super.attributes,
      attributes.COMPACT,
      attributes.SUBMIT_BUTTON
    ];
  }
  connectedCallback() {
    super.connectedCallback();
    this.attachSubmitButtonListener();
  }
  /**
   * Create the template for the header contents
   * @returns {string} The template
   */
  template() {
    let formAttribs = "";
    formAttribs += this.name ? ` name="${this.name}"` : "";
    return `<form${formAttribs} part="form"><slot></slot></form>`;
  }
  /**
   * Attach event listener to the submit button
   */
  attachSubmitButtonListener() {
    if (this.submitButton) {
      const button = this.querySelector(`#${this.submitButton}`);
      this.offEvent("click.form-submit");
      if (button) {
        this.onEvent("click.form-submit", button, () => {
          const formElems = this.formComponents;
          const formValues = [];
          formElems.forEach((el) => formValues.push({
            nodeName: el.nodeName,
            value: ["IDS-CHECKBOX", "IDS-SWITCH"].includes(el.nodeName) ? el.checked : el.value,
            id: el.id,
            name: el.name,
            isDirty: el.isDirty,
            isValid: el.isValid,
            originalValue: el.dirty?.original,
            validationMessages: el.validationMessages
          }));
          this.triggerEvent("submit", this, { bubbles: true, composed: true, detail: { components: formValues } });
        });
      }
    }
  }
  /**
   * Sets the compact attribute
   * @param {boolean | string} value string value for compact
   */
  set compact(value) {
    const isCompact = stringToBool(value);
    super.compact = value;
    const formComponents = this.formComponents;
    [...formComponents].forEach((el) => {
      if (isCompact) el.setAttribute(attributes.COMPACT, value.toString());
      else el.removeAttribute(attributes.COMPACT);
    });
  }
  get compact() {
    return stringToBool(this.getAttribute(attributes.COMPACT)) || false;
  }
  /**
   * Set the fieldHeight (height) of input
   * @param {string} value [xs, sm, md, lg]
   */
  set fieldHeight(value) {
    super.fieldHeight = value;
    const formComponents = this.formComponents;
    [...formComponents].forEach((el) => {
      if (value) el.setAttribute(attributes.FIELD_HEIGHT, value.toString());
      else el.removeAttribute(attributes.FIELD_HEIGHT);
    });
  }
  get fieldHeight() {
    return this.getAttribute(attributes.FIELD_HEIGHT) ?? FIELD_HEIGHTS.default;
  }
  /**
   * Set the id of the submit button
   * @param {string | null} value id of the button to attach event listener
   */
  set submitButton(value) {
    if (value) {
      this.setAttribute(attributes.SUBMIT_BUTTON, value);
      this.attachSubmitButtonListener();
      return;
    }
    this.offEvent("click.form-submit");
    this.removeAttribute(attributes.SUBMIT_BUTTON);
  }
  get submitButton() {
    return this.getAttribute(attributes.SUBMIT_BUTTON) || "";
  }
  /**
   * Returns an array containing only IdsElements
   * @private
   * @returns {Element[]} Array of IdsElements
   */
  get idsComponents() {
    const elements = [];
    const form = this;
    const findIdsElements = (el) => {
      if (el.hasChildNodes()) {
        const formChildren = [...el.children];
        formChildren.forEach((e) => {
          if (e.tagName.includes("IDS-")) {
            elements.push(e);
          }
          findIdsElements(e);
        });
      }
    };
    findIdsElements(form);
    return elements;
  }
  /**
   * Returns an array containing only Ids Elements that are considered form components.
   * @private
   * @returns {Element[]} Array of IdsElements
   */
  get formComponents() {
    const idsElements = this.idsComponents;
    const idsFormComponents = idsElements.filter((item) => item.isFormComponent === true);
    return idsFormComponents;
  }
  /**
   * Resets the dirty indicator on all form components.
   */
  resetDirtyTracker() {
    const formElems = this.formComponents;
    formElems.forEach((el) => {
      if (el.resetDirtyTracker) el.resetDirtyTracker();
    });
  }
  /**
   * Runs validation on each input
   */
  checkValidation() {
    const formElems = this.formComponents;
    formElems.forEach((el) => {
      if (el?.input?.checkValidation) el?.input?.checkValidation();
      if (el?.checkValidation) el?.checkValidation();
    });
  }
  /**
   * Return if and form fields are dirty or not
   * @returns {boolean} true if dirty
   */
  get isDirty() {
    return this.dirtyFormComponents.length > 0;
  }
  /**
   * Returs all dirty form components.
   * @returns {Array<Element>} The elements that are dirty.
   */
  get dirtyFormComponents() {
    const formElems = this.formComponents;
    return formElems.filter((item) => item.isDirty === true);
  }
  /**
   * Return if the form is valid or not
   * @returns {boolean} true if invalid
   */
  get isValid() {
    return this.errorFormComponents.length === 0;
  }
  /**
   * Return the inputs with validation errors
   * @returns {Array<Element>} The current form elements with errors
   */
  get errorFormComponents() {
    const formElems = this.formComponents;
    return formElems.filter((item) => item.isValid === false);
  }
};
IdsForm = __decorateClass([
  customElement("ids-form")
], IdsForm);

export {
  IdsForm
};
//# sourceMappingURL=ids-chunk-7B7J7QYB-full.js.map
