/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsTab
} from "./ids-chunk-7B5GPAIV-full.js";
import {
  ids_locale_mixin_default
} from "./ids-chunk-I5KDLKR6-full.js";
import {
  customElement
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  getClosest
} from "./ids-chunk-LQYSVESW-full.js";
import {
  buildClassAttrib,
  removeNewLines,
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";
import {
  __decorateClass,
  __privateAdd,
  __privateMethod
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-tabs/ids-tab-more.ts
var MORE_ACTIONS_SELECTOR = `[${attributes.MORE_ACTIONS}]`;
var _IdsTabMore_instances, moreActionsMenuTemplate_fn, moreActionsItemTemplate_fn, configureMenu_fn, attachMoreMenuEvents_fn;
var IdsTabMore = class extends ids_locale_mixin_default(IdsTab) {
  constructor() {
    super();
    __privateAdd(this, _IdsTabMore_instances);
  }
  static get attributes() {
    return [
      ...super.attributes,
      attributes.OVERFLOW
    ];
  }
  connectedCallback() {
    super.connectedCallback();
    __privateMethod(this, _IdsTabMore_instances, attachMoreMenuEvents_fn).call(this);
    this.renderOverflowedItems();
  }
  /**
   * Create the Template for the contents
   * @returns {string} the template to render
   */
  template() {
    const count = 4;
    const cssClassAttr = buildClassAttrib(
      "ids-tab",
      "more",
      this.selected,
      this.orientation
    );
    const selectedAttr = this.selected ? ' font-weight="semi-bold"' : "";
    return `<div id="tab-more" ${cssClassAttr} tabindex="-1" part="container">
      <span class="tab-more-text">
        <ids-text id="count" audible>${count}</ids-text>
        <ids-text id="more-text" size="22"${selectedAttr} translate-text="true" audible>More</ids-text>
        <ids-icon icon="dropdown"></ids-icon>
      </span>
      <ids-popup-menu id="tab-more-menu" target="#tab-more">
        <slot></slot>
      </ids-popup-menu>
    </div>`;
  }
  /**
   * @readonly
   * @returns {HTMLElement} the inner popup menu
   */
  get menu() {
    return this.shadowRoot?.querySelector("ids-popup-menu");
  }
  /**
   * @readonly
   * @returns {HTMLElement} More Actions menu group
   */
  get moreActionsGroup() {
    return this.querySelector(MORE_ACTIONS_SELECTOR);
  }
  /**
   * @readonly
   * @returns {Array<HTMLElement>} list of manually-defined menu items
   */
  get predefinedMenuItems() {
    return [...this.querySelectorAll(`:scope > ids-menu-group:not(${MORE_ACTIONS_SELECTOR}) > ids-menu-item`)];
  }
  /**
   * @readonly
   * @returns {Array<HTMLElement>} list of menu items that mirror Tabs
   */
  get overflowMenuItems() {
    const moreActionsGroup = this.moreActionsGroup;
    if (moreActionsGroup) {
      return [...moreActionsGroup.children];
    }
    return [];
  }
  /**
   * @readonly
   * @returns {Array<any>} array of IdsTab elements that can be placed in Overflow
   */
  get availableOverflowTabs() {
    return this.parentElement?.tabListElements;
  }
  /**
   * @readonly
   * @returns {HTMLElement} the "dropdown arrow" IdsIcon element
   */
  get dropdownIcon() {
    return this.shadowRoot?.querySelector('ids-icon[icon="dropdown"]');
  }
  /**
   * Refreshes the visible state of menu items representing "overflowed" elements,
   * and hides/shows this component from view
   * @returns {void}
   */
  refreshOverflowedItems() {
    let overflowed = 0;
    this.hidden = false;
    this.overflowMenuItems.forEach((item) => {
      const doHide = !this.isOverflowed(item.overflowTarget);
      item.hidden = doHide;
      item.textContent = item.overflowTarget.textContent.trim();
      if (doHide) {
        item.overflowTarget.removeAttribute(attributes.OVERFLOWED);
      } else {
        item.overflowTarget.setAttribute(attributes.OVERFLOWED, "");
        overflowed++;
      }
    });
    const countElem = this.container?.querySelector("#count");
    if (countElem) countElem.innerHTML = `${overflowed}`;
    this.hidden = !this.hasVisibleActions();
    if (!this.hasVisibleActions()) {
      this.menu?.hide();
    }
    this.disabled = !this.hasEnabledActions();
    this.parentElement.refreshScrollEffect();
  }
  /**
   * Re-renders the overflowed items
   * @private
   */
  renderOverflowedItems() {
    const el = this.querySelector(MORE_ACTIONS_SELECTOR);
    if (el && !this.overflow) {
      el.remove();
      return;
    }
    this.innerHTML = "";
    this.insertAdjacentHTML("afterbegin", __privateMethod(this, _IdsTabMore_instances, moreActionsMenuTemplate_fn).call(this));
    const handleSubmenu = (thisItem, overflowTargetMenu) => {
      if (!overflowTargetMenu) return;
      [...thisItem.submenu.children].forEach((item, i) => {
        item.overflowTarget = overflowTargetMenu.items[i];
        if (item.submenu) {
          handleSubmenu(item, item.overflowTarget.submenu);
        }
      });
    };
    const moreActionsGroup = this.moreActionsGroup;
    const parentTabs = this.availableOverflowTabs;
    const overflowMenuItems = this.overflowMenuItems;
    if (parentTabs?.length) {
      parentTabs.forEach((tab, i) => {
        let menuItem = overflowMenuItems[i];
        if (!menuItem) {
          moreActionsGroup.insertAdjacentHTML("beforeend", __privateMethod(this, _IdsTabMore_instances, moreActionsItemTemplate_fn).call(this, tab));
          menuItem = moreActionsGroup[moreActionsGroup.length - 1];
        }
        menuItem.overflowTarget = tab;
        if (menuItem.submenu) {
          handleSubmenu(menuItem, menuItem.overflowTarget.menuEl);
        }
      });
    }
  }
  /**
   * @param {boolean | string} val truthy if this More Actions menu should display overflowed Tabs from the Tab List
   */
  set overflow(val) {
    const newValue = stringToBool(val);
    const currentValue = this.overflow;
    if (newValue !== currentValue) {
      if (newValue) {
        this.setAttribute(attributes.OVERFLOW, "");
      } else {
        this.removeAttribute(attributes.OVERFLOW);
      }
    }
  }
  /**
   * @returns {boolean} true if this More Actions menu will display overflowed Tabs from the Tab List
   */
  get overflow() {
    return this.hasAttribute(attributes.OVERFLOW);
  }
  /**
   * @returns {boolean} true if there are currently visible actions in this menu
   */
  hasVisibleActions() {
    return this.querySelectorAll(":scope > ids-menu-group > ids-menu-item:not([hidden])").length > 0;
  }
  /**
   * @returns {boolean} true if there are currently enabled (read: not disabled) actions in this menu
   */
  hasEnabledActions() {
    return this.querySelectorAll(":scope > ids-menu-group > ids-menu-item:not([disabled])").length > 0;
  }
  /**
   * @param {HTMLElement} tab reference to the Tab to be checked for overflow
   * @returns {boolean} true if the Tab belongs to this Tab List and should be displayed by overflow
   */
  isOverflowed(tab) {
    if (!this.parentElement?.contains(tab)) {
      return false;
    }
    if (tab.isEqualNode(this)) {
      return false;
    }
    if (tab.hidden) {
      return false;
    }
    const tabRect = tab.getBoundingClientRect();
    const section = tab.parentElement.tagName === "IDS-SWAPPABLE-ITEM" ? tab.parentElement.parentElement.parentElement.shadowRoot.querySelector(".ids-tabs-list") : tab.parentElement.shadowRoot.querySelector(".ids-tabs-list");
    const sectionRect = section.getBoundingClientRect();
    const isBeyondRightEdge = Number(tabRect.right.toFixed(0)) > Number(sectionRect.right.toFixed(0));
    const isBeyondLeftEdge = Number(tabRect.left.toFixed(0)) < Number(sectionRect.left.toFixed(0));
    return isBeyondLeftEdge || isBeyondRightEdge;
  }
};
_IdsTabMore_instances = new WeakSet();
/**
 * @private
 * @returns {string} the template for the More Actions Menu Group
 */
moreActionsMenuTemplate_fn = function() {
  const childTabs = this.availableOverflowTabs;
  const renderedTabItems = childTabs?.map((i) => __privateMethod(this, _IdsTabMore_instances, moreActionsItemTemplate_fn).call(this, i)).join("") || "";
  return `<ids-menu-group ${attributes.MORE_ACTIONS}>
      ${renderedTabItems}
    </ids-menu-group>`;
};
/**
 * @private
 * @param {HTMLElement} item an element from inside the Tab List that will be mirrored in the More Actions menu
 * @param {boolean} isSubmenuItem true if the item provided is a submenu item
 * @returns {string} representing a single menu item
 */
moreActionsItemTemplate_fn = function(item, isSubmenuItem = false) {
  let text = "";
  let icon = "";
  let hidden = "";
  let disabled = "";
  let submenu = "";
  let overflowed = "";
  let value = "";
  if (!isSubmenuItem) {
    overflowed = this.isOverflowed(item) ? "" : " hidden";
  }
  const iconTemplate = (iconDef) => `<ids-icon slot="icon" icon="${iconDef}" size="small"></ids-icon>`;
  const handleTab = (thisItem) => {
    text = thisItem.textContent;
    if (thisItem.disabled) disabled = " disabled";
    if (thisItem.value) value = ` value="${thisItem.value}"`;
    const tabIcon = thisItem.querySelector("ids-icon");
    if (tabIcon) {
      icon = iconTemplate(tabIcon.icon);
    }
  };
  const handleSubmenu = (thisItem) => {
    const menuProp = isSubmenuItem ? "submenu" : "menuEl";
    if (thisItem[menuProp]) {
      const thisSubItems = thisItem[menuProp].items;
      submenu = `<ids-popup-menu slot="submenu">
          ${thisSubItems.map((subItem) => __privateMethod(this, _IdsTabMore_instances, moreActionsItemTemplate_fn).call(this, subItem, true)).join("") || ""}
        </ids-popup-menu>`;
    }
  };
  const handleMenuItem = (thisItem) => {
    if (thisItem.disabled) disabled = " disabled";
    if (thisItem.icon) icon = iconTemplate(thisItem.icon);
    if (thisItem.hidden) hidden = ` hidden`;
    text = thisItem.text;
    if (thisItem.submenu) {
      handleSubmenu(thisItem);
    }
  };
  switch (item.tagName) {
    case "IDS-TAB-DROPDOWN":
      handleTab(item);
      handleSubmenu(item);
      break;
    case "IDS-MENU-ITEM":
      handleMenuItem(item);
      break;
    case "IDS-TAB":
      handleTab(item);
      break;
    default:
      text = item.textContent;
      break;
  }
  text = `<span class="ids-tab-more-menu-item-text">${removeNewLines(text)?.trim()}</span>`;
  return `<ids-menu-item class="ids-tab-more-menu-item" icon-align="end" ${disabled}${hidden || overflowed}${value}>
      ${text}
      ${icon}
      ${submenu}
    </ids-menu-item>`;
};
configureMenu_fn = function() {
  if (!this.menu || !this.menu.popup) return;
  this.menu.target = this;
  this.menu.triggerType = "click";
  if (this.colorVariant !== "module") {
    this.menu.popup.arrow = "bottom";
    this.menu.popup.arrowTarget = this.dropdownIcon || this;
    this.menu.popup.align = "bottom, right";
    this.menu.popup.y = 4;
  } else if (this.menu?.popup) {
    this.menu.popup.align = "bottom, left";
    this.menu.popup.y = 0;
  }
};
attachMoreMenuEvents_fn = function() {
  this.onEvent("beforeshow", this.menu, (e) => {
    this.triggerEvent("beforeshow", this, {
      bubbles: e.bubbles,
      detail: e.detail
    });
    __privateMethod(this, _IdsTabMore_instances, configureMenu_fn).call(this);
    this.refreshOverflowedItems();
    this.container?.classList.add("is-open");
  });
  this.onEvent("beforehide", this.menu, () => {
    this.container?.classList.remove("is-open");
  });
  this.onEvent("click", this, () => {
    if (!this.menu.visible) {
      this.menu.show();
    } else {
      this.menu.hide();
    }
  });
  this.onEvent("click", this.menu, (e) => {
    const target = e.target;
    if (target) {
      if (target.tagName === "IDS-ICON" && target.getAttribute("icon") === "close") {
        const menuItem = getClosest(target, "ids-menu-item");
        if (menuItem) {
          menuItem.overflowTarget.dismiss();
        }
      }
    }
  });
  this.onEvent("selected", this.menu, (e) => {
    const elem = e.detail.elem;
    if (elem.overflowTarget) {
      elem.overflowTarget.click();
    }
  });
};
IdsTabMore = __decorateClass([
  customElement("ids-tab-more")
], IdsTabMore);

export {
  IdsTabMore
};
//# sourceMappingURL=ids-chunk-AYWLD4SJ-full.js.map
