/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  BLOCK_ELEMENTS
} from "./ids-chunk-XPCTTAAV-full.js";
import {
  sanitizeHTML
} from "./ids-chunk-5K4YUTOH-full.js";

// src/components/ids-editor/ids-editor-clean-utils.ts
function isWordFormat(content) {
  return /<font face="Times New Roman"|class="?Mso|style="[^"]*\bmso-|style='[^'']*\bmso-|w:WordDocument/i.test(content) || /class="OutlineElement/.test(content) || /id="?docs\-internal\-guid\-/.test(content);
}
function cleanWordHtml(content) {
  let s = content;
  s = s.replace(/<!--[\s\S]+?-->/gi, "");
  s = s.replace(/<(!|script[^>]*>.*?<\/script(?=[>\s])|\/?(\?xml(:\w+)?|img|meta|link|style|\w:\w+)(?=[\s\/>]))[^>]*>/gi, "");
  s = s.replace(/<(\/?)s>/gi, "<$1strike>");
  s = s.replace(/&nbsp;/gi, "\xA0");
  s = s.replace(/<span\s+style\s*=\s*"\s*mso-spacerun\s*:\s*yes\s*;?\s*"\s*>([\s\u00a0]*)<\/span>/gi, (str, spaces) => spaces.length > 0 ? spaces.replace(/./, " ").slice(Math.floor(spaces.length / 2)).split("").join("\xA0") : "");
  s = s.replace(/(\n|\r| class=(\'|")?Mso[a-zA-Z]+(\'|")?)/g, " ");
  const badTags = ["style", "script", "applet", "embed", "noframes", "noscript"];
  badTags.forEach((tag) => {
    s = s.replace(new RegExp(`<${tag}.*?${tag}(.*?)>`, "gi"), "");
  });
  return s;
}
function stripStyles(content, styleStripper) {
  const stylesToKeep = ["color", "font-size", "background", "font-weight", "font-style", "text-decoration", "text-align"];
  return content.replace(styleStripper, (m) => {
    m = m.replace(/( style=|("|\'))/gi, "");
    const attrs = m.split(";");
    let strStyle = "";
    attrs.forEach((attr) => {
      const entry = attr.split(":");
      strStyle += stylesToKeep.indexOf((entry[0] || "").trim()) > -1 ? `${entry[0]}:${entry[1]};` : "";
    });
    return strStyle !== "" ? ` style="${strStyle}"` : "";
  });
}
function stripAttribute(content, attribute, attributeStripper) {
  return attribute === "style" ? stripStyles(content, attributeStripper) : content.replace(attributeStripper, "");
}
function cleanHtml(content) {
  let attributeStripper;
  let s = content || "";
  const badAttributes = [
    "start",
    "xmlns",
    "xmlns:o",
    "xmlns:w",
    "xmlns:x",
    "xmlns:m",
    "onmouseover",
    "onmouseout",
    "onmouseenter",
    "onmouseleave",
    "onmousemove",
    "onload",
    "onfocus",
    "onblur",
    "onclick",
    "style"
  ];
  if (isWordFormat(s)) {
    s = cleanWordHtml(s);
  }
  badAttributes.forEach((attr) => {
    attributeStripper = new RegExp(` ${attr}="(.*?)"`, "gi");
    s = stripAttribute(s, attr, attributeStripper);
    attributeStripper = new RegExp(` ${attr}='(.*?)'`, "gi");
    s = stripAttribute(s, attr, attributeStripper);
  });
  s = s.replace(/\sng-[a-z-]+/, "");
  s = s.replace(/<!--(.*?)-->/gm, "");
  s = s.replace(/\s\s+/g, " ").replace(/\s>+/g, ">");
  s = s.replace(/<(ul)(.*?)>/gi, "<$1>");
  s = s.replace(/<li><\/li>/gi, "");
  s = s.replace(/<(ul|ol)><\/(ul|ol)>/gi, "");
  s = s.replace(/<\/?(html|body)(.*?)>/gi, "");
  s = s.replace(/<head\b[^>]*>(.*?)<\/head>/gi, "");
  s = s.replace(/<(div|span|p)> <\/(div|span|p)>/gi, " ");
  s = s.replace(/<[^(br|/>)]+>[\s]*<\/[^>]+>/gi, "");
  if (s.indexOf("\xB7") > -1) {
    s = s.replace(/<\/p>/gi, "</li>");
    s = s.replace(/<p><span><span>·<\/span><\/span>/gi, "<li>");
    s = s.replace(/<\/li>\s<li>/gi, "</li><li>");
    s = [s.slice(0, s.indexOf("<li>")), "<ul>", s.slice(s.indexOf("<li>"))].join("");
    s = [s.slice(0, s.lastIndexOf("</li>")), "</ul>", s.slice(s.lastIndexOf("</li>"))].join("");
  }
  return s;
}
function trimContent(content) {
  const bElems = BLOCK_ELEMENTS.join("|");
  return sanitizeHTML(content || "").trim().replace(/>\s+</g, "><").replace(/\s+/g, " ").replace(/<br(\s?\/)?>/g, "<br>\n").replace(new RegExp(`</(${bElems})>`, "gi"), "</$1>\n\n").replace(/\n\n$/, "\n").replace(new RegExp(`<(${bElems})><br>\\n</(${bElems})>\\n`, "gi"), "");
}

export {
  isWordFormat,
  cleanWordHtml,
  stripStyles,
  stripAttribute,
  cleanHtml,
  trimContent
};
//# sourceMappingURL=ids-chunk-BXFDCSSJ-full.js.map
