/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsButton,
  ids_button_default
} from "./ids-chunk-BECPNP53-full.js";
import {
  customElement,
  scss
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  parseNumberWithUnits
} from "./ids-chunk-LQYSVESW-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes,
  htmlAttributes
} from "./ids-chunk-QQAXKC5H-full.js";
import {
  __decorateClass,
  __privateAdd,
  __privateMethod
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-menu-button/ids-menu-button.ts
var _IdsMenuButton_instances, configureDropdownIcon_fn;
var IdsMenuButton = class extends IdsButton {
  constructor() {
    super();
    __privateAdd(this, _IdsMenuButton_instances);
  }
  /**
   * @returns {Array} containing configurable attributes on this component
   */
  static get attributes() {
    return [
      ...super.attributes,
      attributes.DISABLED,
      attributes.DISPLAY_SELECTED_TEXT,
      attributes.DROPDOWN_ICON,
      attributes.FORMATTER_WIDTH,
      attributes.ID,
      attributes.MENU,
      attributes.VALUE
    ];
  }
  /**
   * Toggle-Button-level `connectedCallback` implementation (adds an icon refresh)
   * @returns {void}
   */
  connectedCallback() {
    super.connectedCallback();
    if (this.hasAttribute(attributes.DROPDOWN_ICON)) {
      __privateMethod(this, _IdsMenuButton_instances, configureDropdownIcon_fn).call(this, true);
      this.setPopupArrow();
    }
    requestAnimationFrame(() => {
      this.configureMenu();
    });
  }
  /**
   * @returns {string[]} containing CSS classes that will be added to the buttons
   */
  get protoClasses() {
    const textSlot = this.querySelector("span:not(.audible), ids-text:not(.audible)");
    const iconSlot = this.querySelector("ids-icon[slot]") || this.querySelector("ids-icon");
    if (iconSlot && !textSlot) {
      if (this.parentElement?.classList.contains("has-sub-tabs")) {
        return ["ids-menu-button", "sub-tab-button", "ids-icon-button"];
      }
      return ["ids-menu-button", "ids-icon-button"];
    }
    return ["ids-menu-button"];
  }
  /**
   * @param {boolean | string} val true if the component should be disabledd
   */
  set disabled(val) {
    super.disabled = val;
    const truthyVal = stringToBool(val);
    this.menuEl.disabled = truthyVal;
  }
  /**
   * @returns {boolean} true if the component is disabled
   */
  get disabled() {
    return super.disabled;
  }
  /**
   * @param {boolean | string} val true if the menu button should adopt a selected menu item's text content when chosen
   */
  set displaySelectedText(val) {
    const bool = stringToBool(val);
    if (bool) this.setAttribute(attributes.DISPLAY_SELECTED_TEXT, `${val}`);
    else this.removeAttribute(attributes.DISPLAY_SELECTED_TEXT);
    this.configureMenu();
  }
  /**
   * @returns {string} true if the menu button will adopt a selected menu item's text content when chosen
   */
  get displaySelectedText() {
    return stringToBool(this.getAttribute(attributes.DISPLAY_SELECTED_TEXT));
  }
  /**
   * @param {string|undefined} val referencing an icon string name to use
   */
  set dropdownIcon(val) {
    const trueVal = stringToBool(val);
    if (trueVal) {
      this.setAttribute(attributes.DROPDOWN_ICON, typeof val === "string" && val.length ? `${val}` : "dropdown");
    } else {
      this.removeAttribute(attributes.DROPDOWN_ICON);
    }
    __privateMethod(this, _IdsMenuButton_instances, configureDropdownIcon_fn).call(this, trueVal);
    this.setPopupArrow();
  }
  /**
   * @returns {string|undefined} containing the type of icon being displayed as the Dropdown Icon
   */
  get dropdownIcon() {
    return this.getAttribute(attributes.DROPDOWN_ICON);
  }
  /**
   * @returns {HTMLElement|null} the decorative dropdown icon element
   */
  get dropdownIconEl() {
    return this.container?.querySelector("ids-icon:not([slot])");
  }
  /**
   * @returns {string|null} an ID selector string matching a menu
   */
  get menu() {
    return this.getAttribute(attributes.MENU);
  }
  /**
   * @param {string|null} val an ID selector string
   */
  set menu(val) {
    this.setAttribute(attributes.MENU, `${val}`);
    this.configureMenu();
  }
  /**
   * Retrieves a list of selected items from menu.
   * @returns {Array<any>} list of the values contained by selected menu items
   */
  get value() {
    const attrVal = this.getAttribute(attributes.VALUE);
    return this.menuEl?.getSelectedValues() ?? (attrVal ? [attrVal] : []);
  }
  /**
   * Set menu's selected items by value
   * @param {Array<any>|string} values array|string of value(s) contained in menu items
   * @returns {void}
   */
  set value(values) {
    if (typeof this.menuEl?.setSelectedValues === "function") {
      this.menuEl.setSelectedValues(values);
    }
  }
  /**
   * @readonly
   * @returns {HTMLElement | null} element if one is present
   */
  get menuEl() {
    const findPopup = (root) => root?.querySelector(`ids-popup-menu[id="${this.menu}"]`) || root?.querySelector(`ids-action-sheet[id="${this.menu}"]`);
    let el = findPopup(this.parentElement);
    if (!el) el = findPopup(this.getRootNode());
    return el;
  }
  /**
   * @returns {void}
   */
  configureMenu() {
    if (!this.menuEl || !this.menuEl.popup) {
      return;
    }
    this.resizeMenu();
    this.menuEl.triggerType = "click";
    this.menuEl.target = this;
    this.setAttribute(htmlAttributes.ARIA_HASPOPUP, "menu");
    if (this.menuEl.popup) {
      this.menuEl.popup.align = "bottom, left";
      this.menuEl.popup.y = this.menuEl?.target?.hasAttribute("data-filter-conditions-button") ? -2 : 4;
      this.setPopupArrow();
    }
    const hasBeforeShow = this?.handledEvents?.get("beforeshow");
    if (!hasBeforeShow) {
      this.onEvent("beforeshow", this.menuEl, () => {
        this.setActiveState(true);
        this.resizeMenu();
      });
    }
    const hasHideHandler = this?.handledEvents?.get("hide");
    if (!hasHideHandler) {
      this.onEvent("hide", this.menuEl, () => {
        this.setActiveState(false);
      });
    }
    this.offEvent("selected.menu");
    if (this.menuEl && this.displaySelectedText) {
      this.onEvent("selected.menu", this.menuEl, (e) => {
        this.updateBtnText(e.detail.elem.textContent.trim());
      });
    }
  }
  /**
   * Updates button text
   * @param {string} text button text
   */
  updateBtnText(text) {
    let btnTextEl = this.querySelector("ids-text, span");
    if (!btnTextEl) btnTextEl = this;
    btnTextEl.textContent = text;
  }
  /**
   * Set button's active state
   * @param {boolean} isActive true when menu is open
   */
  setActiveState(isActive) {
    if (isActive) {
      this.button?.classList.add("is-active");
    } else {
      this.button?.classList.remove("is-active");
    }
  }
  /**
   * @returns {void}
   */
  resizeMenu() {
    if (!this.menuEl || !this.menuEl.popup || !this.menuEl.popup.container) {
      return;
    }
    this.menuEl.popup.container.style.minWidth = `${this.button?.clientWidth}px`;
  }
  /**
   * @returns {void}
   */
  setPopupArrow() {
    if (!this.menuEl || !this.menuEl.popup) {
      return;
    }
    const popupMenuEl = document.querySelector(`#${this.menu}`);
    let arrow = "bottom";
    this.menuEl.popup.arrowTarget = this.dropdownIconEl || this;
    if (popupMenuEl && popupMenuEl.getAttribute("arrow")) {
      arrow = popupMenuEl.arrow || "";
    }
    this.menuEl.popup.arrow = arrow;
  }
  /**
   * Set the formatter width for menu button
   * @param {string | number} value The formatter width value
   */
  set formatterWidth(value) {
    const val = parseNumberWithUnits(value);
    this.container?.classList[/%$/g.test(val) ? "add" : "remove"]("formatter-width-percentage");
    if (val) {
      this.setAttribute(attributes.FORMATTER_WIDTH, String(value));
      this.container?.classList.add(attributes.FORMATTER_WIDTH);
      if (this.container) this.container.style.minWidth = val;
    } else {
      this.removeAttribute(attributes.FORMATTER_WIDTH);
      this.container?.classList.remove(attributes.FORMATTER_WIDTH);
      if (this.container) this.container.style.minWidth = "";
    }
  }
};
_IdsMenuButton_instances = new WeakSet();
configureDropdownIcon_fn = function(doShow) {
  const icon = this.dropdownIconEl;
  const iconType = this.dropdownIcon?.length ? this.dropdownIcon : "dropdown";
  if (doShow) {
    if (!icon) {
      this.container?.insertAdjacentHTML("beforeend", `<ids-icon icon="${iconType}" class="ids-icon dropdown-icon"></ids-icon>`);
    } else {
      icon.icon = iconType;
    }
  } else if (icon) {
    icon.remove();
  }
};
IdsMenuButton = __decorateClass([
  customElement("ids-menu-button"),
  scss(ids_button_default)
], IdsMenuButton);

export {
  IdsMenuButton
};
//# sourceMappingURL=ids-chunk-DC2YKNGX-full.js.map
