/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  getClosest
} from "./ids-chunk-LQYSVESW-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-tooltip-mixin/ids-tooltip-mixin.ts
var IdsTooltipMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.TOOLTIP,
      attributes.TOOLTIP_PLACEMENT,
      attributes.TOOLTIP_PLAIN_TEXT
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.handleTooltipEvents();
  }
  /**
   * Init the mixin events and states
   * @private
   */
  handleTooltipEvents() {
    this.offEvent("hoverend.tooltipmixin");
    if (!this.tooltip) return;
    this.onEvent("hoverend.tooltipmixin", this, (e) => {
      e.stopPropagation();
      this.showTooltip();
    }, { delay: 500, bubbles: true });
  }
  /**
   * @returns {IdsTooltip | null} reference to an established IdsTooltip
   */
  get tooltipEl() {
    return this.getTooltipContainer()?.querySelector("#mixin-tooltip");
  }
  /**
   * Return the correct target element
   * @private
   * @returns {HTMLElement | SVGElement} The correct target element
   */
  get toolTipTarget() {
    let target = this;
    if (typeof this.onTooltipTargetDetection === "function") {
      target = this.onTooltipTargetDetection(this.tooltipEl);
    }
    return target;
  }
  /**
   * @returns {HTMLElement} reference to the correct container element in which to find the mixin tooltip.
   */
  getTooltipContainer() {
    let container = this.closest("ids-container");
    if (!container) {
      container = document.body;
    }
    return container;
  }
  /**
   * Show the tooltip if available
   */
  showTooltip() {
    if (typeof this.canTooltipShow === "function") {
      if (!this.canTooltipShow(this.tooltipEl, this.tooltip)) return;
    }
    const container = this.getTooltipContainer();
    let tooltip = container.querySelector("#mixin-tooltip");
    if (!tooltip) {
      tooltip = document.createElement("ids-tooltip");
      tooltip.id = "mixin-tooltip";
      container?.appendChild(tooltip);
    }
    if (!tooltip.state) {
      tooltip.state = {};
    }
    tooltip.target = this.toolTipTarget;
    tooltip.state.noAria = true;
    try {
      if (this.hasAttribute(attributes.TOOLTIP_PLAIN_TEXT)) {
        tooltip.textContent = this.tooltip === "true" ? this.textContent : this.tooltip;
      } else {
        tooltip.innerHTML = this.tooltip === "true" ? this.innerHTML : this.tooltip;
      }
    } catch (e) {
      tooltip.textContent = this.tooltip === "true" ? this.textContent : this.tooltip;
    }
    if (this.hasAttribute(attributes.TOOLTIP_PLACEMENT)) {
      tooltip.placement = this.getAttribute(attributes.TOOLTIP_PLACEMENT);
    }
    const rootNode = this.getRootNode().host;
    if (rootNode && rootNode.name === "ids-tab" && rootNode.firstChild.wholeText !== "") {
      tooltip.innerHTML = rootNode.firstChild.wholeText;
    }
    tooltip.visible = true;
    tooltip.popup?.place();
    if (getClosest(this, "ids-container")?.getAttribute("dir") === "rtl") tooltip.popup?.setAttribute("dir", "rtl");
    if (this.beforeTooltipShow) this.beforeTooltipShow(tooltip);
    tooltip.onEvent("hide.tooltipmixin", tooltip, () => {
      document.querySelector("#mixin-tooltip")?.remove();
    });
  }
  /**
   * Setup some special config for the tooltip
   * @param {any} tooltip The tooltip to configure
   */
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  beforeTooltipShow(tooltip) {
  }
  /**
   * Set the tooltip to a particular string
   * @param {string} value The tooltips value
   */
  set tooltip(value) {
    if (value) {
      this.setAttribute("tooltip", value);
      this.container?.setAttribute("tooltip", value);
      this.handleTooltipEvents();
    }
  }
  get tooltip() {
    return this.getAttribute("tooltip");
  }
};
var ids_tooltip_mixin_default = IdsTooltipMixin;

export {
  ids_tooltip_mixin_default
};
//# sourceMappingURL=ids-chunk-FAXKPNFO-full.js.map
