/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-module-nav/ids-module-nav-display-mode-mixin.ts
var IdsModuleNavDisplayModeMixin = (superclass) => class extends superclass {
  previousDisplayMode = false;
  constructor(...args) {
    super(...args);
  }
  /**
   * Return the attributes we handle as getters/setters
   * @returns {Array} The attributes as an array
   */
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.DISPLAY_MODE
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
    if (this.hasAttribute(attributes.DISPLAY_MODE)) {
      this.displayMode = this.getAttribute(attributes.DISPLAY_MODE);
    }
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
  }
  /**
   * Set the type for toolbar
   * @param {IdsModuleNavDisplayMode | null} value Display Mode setting
   */
  set displayMode(value) {
    let safeValue = false;
    if (typeof value === "string" && (value === "expanded" || value === "collapsed")) {
      safeValue = value;
    }
    const currentValue = this.previousDisplayMode;
    if (currentValue !== safeValue) {
      if (safeValue !== false) {
        this.setAttribute(attributes.DISPLAY_MODE, `${safeValue}`);
      } else {
        this.removeAttribute(attributes.DISPLAY_MODE);
        safeValue = false;
      }
      this.previousDisplayMode = safeValue;
      this.#setDisplayMode(currentValue, safeValue);
    }
  }
  get displayMode() {
    return this.getAttribute(attributes.DISPLAY_MODE) ?? false;
  }
  #setDisplayMode(currentValue, newValue) {
    if (this.container) {
      if (currentValue) this.container?.classList.remove(`display-mode-${currentValue}`);
      if (newValue) this.container?.classList.add(`display-mode-${newValue}`);
    }
    if (typeof this.onDisplayModeChange === "function") {
      this.onDisplayModeChange(currentValue, newValue);
    }
  }
  /**
   * Detects if state changes from outside the component library have occured against
   * the `display-mode` attribute and corrects component state.
   */
  checkDisplayMode() {
    if (this.previousDisplayMode !== this.displayMode) {
      this.#setDisplayMode(this.previousDisplayMode, this.displayMode);
    }
  }
};
var ids_module_nav_display_mode_mixin_default = IdsModuleNavDisplayModeMixin;

export {
  ids_module_nav_display_mode_mixin_default
};
//# sourceMappingURL=ids-chunk-FZNHNWK6-full.js.map
