/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  ids_focus_capture_mixin_default
} from "./ids-chunk-ORDSAQSV-full.js";
import {
  ids_popup_interactions_mixin_default
} from "./ids-chunk-WBLEXBDY-full.js";
import {
  ids_attachment_mixin_default
} from "./ids-chunk-R42WXYZK-full.js";
import {
  ids_events_mixin_default
} from "./ids-chunk-KKFANICI-full.js";
import {
  IdsElement
} from "./ids-chunk-UTR2KJV7-full.js";
import {
  customElement
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  getClosest
} from "./ids-chunk-LQYSVESW-full.js";
import {
  __decorateClass
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-popup/ids-picker-popup.ts
var Base = ids_focus_capture_mixin_default(
  ids_popup_interactions_mixin_default(
    ids_events_mixin_default(
      ids_attachment_mixin_default(
        IdsElement
      )
    )
  )
);
var IdsPickerPopup = class extends Base {
  constructor() {
    super();
  }
  connectedCallback() {
    super.connectedCallback();
    const isFilterField = this.target?.parentElement?.classList.contains("ids-data-grid-header-cell-filter-wrapper");
    if (this.popup && (isFilterField === false || !this.popup.onOutsideClick)) {
      this.popup.onOutsideClick = this.onOutsideClick.bind(this);
    }
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
  }
  static get attributes() {
    return [...super.attributes];
  }
  /**
   * Inner template contents
   * @returns {string} The template
   */
  template() {
    return `<ids-popup class="ids-picker-popup" type="menu" align="bottom, left" arrow="bottom" tabIndex="-1" animated>
      <slot slot="content"></slot>
    </ids-popup>`;
  }
  /**
   * @returns {Array<string>} Date Picker vetoable events
   */
  vetoableEventTypes = ["beforeshow"];
  /**
   * @readonly
   * @returns {boolean} true if the inner IdsPopup is visible
   */
  get visible() {
    return this.popup?.visible || false;
  }
  /**
   * Hides this menu and any of its submenus.
   * @param {boolean} [doFocus] if true, instructs the listening component that focus should change to a different element
   * @returns {void}
   */
  async hide(doFocus) {
    if (!this.popup?.visible) return;
    this.popup.visible = false;
    await this.popup.hide();
    if (typeof this.onHide === "function") this.onHide();
    this.popup?.removeOpenEvents();
    this.triggerEvent("hide", this, {
      bubbles: true,
      detail: {
        doFocus,
        elem: this
      }
    });
    this.hidden = true;
  }
  /**
   * @returns {void}
   */
  show() {
    if (!this.popup || this.popup.visible) return;
    if (!this.triggerVetoableEvent("beforeshow")) {
      return;
    }
    this.hidden = false;
    let offsetY = 2;
    if (this.popup.classList.contains("ids-date-picker-popup") || this.popup.classList.contains("ids-time-picker-popup")) {
      if (this.target === null && this.triggerElem !== null) {
        if (this.triggerElem.nodeName === "IDS-TRIGGER-BUTTON") {
          this.target = this.triggerElem.parentElement;
        } else {
          this.target = this.triggerElem;
        }
      }
      const isDataGrid = this.getAttribute("attachment") === ".ids-data-grid-wrapper";
      const isFilterRow = isDataGrid && this.hasAttribute("data-filter-type");
      const rowHeight = isDataGrid ? this.getRootNode().host?.getAttribute("row-height") : "";
      const isCompact = getClosest(this.popup, ".compact");
      const isFilterField = getClosest(this, "ids-date-picker")?.parentElement?.nodeName === "IDS-FILTER-FIELD" || getClosest(this, "ids-time-picker")?.parentElement?.nodeName === "IDS-FILTER-FIELD";
      if (isFilterField) offsetY = 0;
      if (isDataGrid) {
        offsetY = rowHeight === "xs" || rowHeight === "xxs" ? -2 : -5;
        if (isFilterRow) {
          offsetY = 3;
        }
      }
      if (isCompact) offsetY = isFilterField ? 0 : -11;
      this.popup.onPlaceEnd = (popupRect, popup) => {
        if (popup?.arrowEl) {
          let arrowOffset = parseInt(popup?.arrowEl?.style.marginLeft);
          if (isFilterRow) arrowOffset = parseInt(popup?.arrowEl?.style.marginLeft);
          popup.arrowEl.style.marginLeft = `${arrowOffset}px`;
        }
        if (popup?.container?.classList.contains("flipped")) {
          let flippedOffset = this.popup?.classList.contains("ids-date-picker-popup") ? 1 : 9;
          if (isDataGrid) {
            flippedOffset = this.popup?.classList.contains("ids-date-picker-popup") ? 8 : 9;
            if (rowHeight === "xs" || rowHeight === "xxs") flippedOffset = this.popup?.classList.contains("ids-date-picker-popup") ? 5 : 6;
          }
          popup.style.top = `${parseInt(popup.style.top) + flippedOffset}px`;
        }
        return popupRect;
      };
    }
    this.popup.y = offsetY;
    this.popup.visible = true;
    this.popup.show();
    if (typeof this.onShow === "function") this.onShow();
    this.popup?.addOpenEvents();
    this.triggerEvent("show", this, {
      bubbles: true,
      detail: {
        elem: this
      }
    });
  }
  /**
   * Toggles visibility of the popup on/off depending on its current state
   * @returns {void}
   */
  toggleVisibility() {
    if (!this.popup) return;
    if (!this.popup.visible) {
      this.show();
    } else {
      this.hide();
    }
  }
  onOutsideClick(e) {
    const target = e.target;
    if (!this.contains(target)) {
      this.hide();
    }
  }
  /**
   * Inherited from `IdsPopupInteractionsMixin`
   * @param {Event} _ the original click event
   */
  // eslint-disable-next-line
  onTriggerClick(_) {
    this.toggleVisibility();
  }
  /**
   * Inherited from the Popup Interactions Mixin.
   * Runs as soon as the Popup is connected to the DOM.
   * @returns {void}
   */
  onTriggerImmediate() {
    this.show();
  }
};
IdsPickerPopup = __decorateClass([
  customElement("ids-picker-popup")
], IdsPickerPopup);
var ids_picker_popup_default = IdsPickerPopup;

export {
  ids_picker_popup_default
};
//# sourceMappingURL=ids-chunk-GYIHCFQS-full.js.map
