/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-selection-mixin/ids-selection-mixin.ts
var IdsSelectionMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.SELECTED,
      attributes.SELECTION,
      attributes.PRE_SELECTED
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
  }
  /**
   * Set the selection to a particular string
   * @param {string} value The selection value
   */
  set selection(value) {
    this.setAttribute(attributes.SELECTION, String(value));
    if (value === "multiple" || value === "single" || value === "mixed") {
      this.container?.classList.add("is-selectable");
    } else {
      this.container?.classList.remove("is-selectable");
    }
  }
  get selection() {
    return this.getAttribute(attributes.SELECTION) || "";
  }
  /**
   * Set the selected to a boolean value
   * @param {string | boolean} value The selected value
   */
  set selected(value) {
    this.setAttribute(attributes.SELECTED, String(value));
    if (this.selection === "multiple" || this.selection === "single" || this.selection === "mixed") {
      this.container?.classList[value === "true" ? "add" : "remove"]("is-selected");
    }
  }
  get selected() {
    return stringToBool(this.getAttribute(attributes.SELECTED));
  }
  /**
   * Set the preselected to a boolean value
   * @param {boolean} value The preselected value
   */
  set preselected(value) {
    this.setAttribute(attributes.PRE_SELECTED, String(value));
    if (this.selection === "mixed") {
      this.container?.classList[value === "true" ? "add" : "remove"]("pre-selected");
    }
  }
  get preselected() {
    return this.getAttribute(attributes.PRE_SELECTED);
  }
};
var ids_selection_mixin_default = IdsSelectionMixin;

export {
  ids_selection_mixin_default
};
//# sourceMappingURL=ids-chunk-IZ2DTGJC-full.js.map
