/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  isObjectAndNotEmpty
} from "./ids-chunk-3T5UDKOL-full.js";
import {
  isValidDate
} from "./ids-chunk-KNXP4KUS-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-validation-mixin/ids-validation-mixin.ts
function isIdsValidatedElement(element) {
  return typeof element?.checkValidation === "function" && typeof element?.validate === "string";
}
var IdsValidationMixin = (superclass) => class extends superclass {
  isTypeNotValid;
  constructor(...args) {
    super(...args);
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.useRules = /* @__PURE__ */ new Map();
    this.handleValidation();
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.VALIDATE,
      attributes.VALIDATION_EVENTS,
      attributes.VALIDATION_ICON,
      attributes.VALIDATION_ID,
      attributes.VALIDATION_MESSAGE,
      attributes.VALIDATION_TYPE,
      attributes.REQUIRED
    ];
  }
  // Map of rules to use
  useRules = /* @__PURE__ */ new Map();
  // List of events to validate on
  validationEventsList = [];
  // Default icon
  VALIDATION_DEFAULT_ICON = "user-profile";
  // Icons
  VALIDATION_ICONS = {
    alert: "alert",
    error: "error",
    info: "info",
    success: "success"
  };
  #hideErrorMessage = false;
  /**
   * Handle the validation rules
   * @returns {void}
   */
  handleValidation() {
    const thisAsInput = this;
    const isRadioGroup = thisAsInput.input?.classList.contains("ids-radio-group");
    const canRadio = !isRadioGroup || !!(isRadioGroup && this.querySelector("ids-radio"));
    if (thisAsInput.labelEl && typeof this.validate === "string" && canRadio) {
      const events = this.validationEvents && typeof this.validationEvents === "string" ? this.validationEvents : "change.validationmixin blur.validationmixin";
      this.validationEventsList = [...new Set(events.split(" "))];
      const getRule = (id) => ({ id, rule: this.rules[id] });
      let isRulesAdded = false;
      let hasRequired = this.required;
      this.validate.split(" ").forEach((strRule) => {
        if (!getRule(strRule).rule) return;
        if (strRule === "required") {
          hasRequired = true;
        }
        const setRules = (input) => {
          const useRules = this.useRules.get(input);
          if (useRules) {
            const found = useRules.some((r) => r.id === strRule);
            if (!found) {
              const mergeRule = [...useRules, getRule(strRule)];
              this.useRules.set(input, mergeRule);
              isRulesAdded = true;
            }
          } else {
            this.useRules.set(input, [getRule(strRule)]);
            isRulesAdded = true;
          }
        };
        setRules(thisAsInput.input);
      });
      if (isRulesAdded) {
        this.handleValidationEvents();
      }
      if (hasRequired) this.renderRequired();
      const arrayValidate = this.validate?.split(" ");
      let rules = this.useRules.get(thisAsInput.input);
      if (thisAsInput.input && rules?.length > arrayValidate?.length) {
        const removed = [];
        arrayValidate.forEach((id) => {
          rules = rules.filter((r) => {
            if (r.id === id) return true;
            removed.push(r.id);
            return false;
          });
        });
        removed.forEach((id) => this.removeValidationMessage({ id }));
        this.useRules.set(thisAsInput.input, rules);
      }
    } else {
      this.destroyValidation();
      if (this.required) this.renderRequired();
    }
  }
  hideErrorMessage(toHide) {
    this.#hideErrorMessage = toHide || false;
  }
  /**
   * Check the validation and add/remove errors as needed
   * @private
   * @returns {void}
   */
  checkValidation() {
    const checkRules = (input) => {
      this.isTypeNotValid = {};
      let isValid = true;
      const useRules = this.useRules.get(input);
      useRules?.forEach((thisRule) => {
        if (thisRule.rule !== void 0 && !thisRule.rule?.check(input, this.rules) && this.isTypeNotValid) {
          if (thisRule.rule.messageId) {
            thisRule.rule.message = this.localeAPI?.translate(thisRule.rule.messageId, { showBrackets: false });
          }
          this.addMessage(thisRule.rule);
          isValid = false;
          this.isTypeNotValid[thisRule.rule.type] = true;
        } else if (thisRule.rule !== void 0) {
          this.removeMessage(thisRule.rule);
        }
      });
      this.isTypeNotValid = null;
      this.#triggerValidateEvent(isValid);
    };
    if (this.input) {
      checkRules(this.input);
      this.#setValidationMessagesCountAttr();
    }
  }
  /**
   * Add validation rule/s
   * @param {IdsValidationRule} [rule] incoming rule/s settings
   * @returns {void}
   */
  addValidationRule(rule) {
    const isValid = (val) => typeof val === "string" && val !== "";
    const addToValidate = [];
    let isRulesAdded = false;
    const addRule = (newRule) => {
      const { id, type, message } = newRule;
      if (isValid(id) && isValid(type) && isValid(message) && typeof newRule.check === "function") {
        if (!this.rules[id]) {
          isRulesAdded = true;
          this.rules[id] = newRule;
          if (!this.validate || !new RegExp(id).test(this.validate)) addToValidate.push(id);
        }
      }
    };
    if (rule?.constructor === Array) {
      rule.forEach((r) => addRule(r));
    } else {
      addRule(rule);
    }
    if (isRulesAdded) {
      if (addToValidate.length) {
        const val = this.validate ? `${this.validate} ` : "";
        this.validate = `${val}${[...new Set(addToValidate)].join(" ")}`;
      }
      this.handleValidation();
    }
  }
  /**
   * Remove validation rule/s
   * @param {string} [ruleId] incoming rule/s id
   * @returns {void}
   */
  removeValidationRule(ruleId) {
    const isValid = (val) => typeof val === "string" && val !== "";
    let validate = this.validate;
    let isRulesRemoved = false;
    const removeRule = (id) => {
      if (isValid(id) && this.rules[id] && new RegExp(id).test(validate)) {
        isRulesRemoved = true;
        delete this.rules[id];
        validate = validate?.replace(id, "") || null;
      }
    };
    if (ruleId?.constructor === Array) {
      ruleId.forEach((id) => removeRule(id));
    } else {
      removeRule(ruleId);
    }
    if (isRulesRemoved) {
      this.validate = validate?.replace(/\s\s+/g, " ").trim() || null;
    }
  }
  /**
   * Add validation message/s
   * @param {Array|object} [message] incoming message/s settings
   * @returns {void}
   */
  addValidationMessage(message) {
    const addMessage = (obj) => {
      if (isObjectAndNotEmpty(obj)) this.addMessage(obj);
    };
    if (message?.constructor === Array) {
      message.forEach((m) => addMessage(m));
    } else {
      addMessage(message);
    }
    this.#setValidationMessagesCountAttr();
  }
  /**
   * Remove validation message/s
   * @param {Array|object} [message] incoming message/s settings
   * @returns {void}
   */
  removeValidationMessage(message) {
    const removeMessage = (obj) => {
      if (isObjectAndNotEmpty(obj)) this.removeMessage(obj);
    };
    if (message?.constructor === Array) {
      message.forEach((m) => removeMessage(m));
    } else {
      removeMessage(message);
    }
    this.#setValidationMessagesCountAttr();
  }
  /**
   * Add a message to an input
   * @param {object} [settings] incoming settings
   * @returns {void}
   */
  addMessage(settings) {
    const {
      id,
      type,
      message,
      icon
    } = settings;
    const thisAsInput = this;
    if (!id) return;
    let elem = this.shadowRoot?.querySelector(`div[validation-id="${id}"]`);
    const regex = new RegExp(`^\\b(${Object.keys(this.VALIDATION_ICONS).join("|")})\\b$`, "g");
    const isValidationIcon = type && regex.test(type);
    let audible = isValidationIcon ? type.replace(/^./, type[0].toUpperCase()) : null;
    audible = audible ? `<ids-text audible="true">${audible} </ids-text>` : "";
    if (elem) {
      const messageElem = elem.querySelector(".message-text");
      const messageText = settings.messageId ? `${this.localeAPI.translate(settings.messageId)}` : message;
      if (messageElem && messageElem.textContent !== messageText) {
        messageElem.innerHTML = `${audible}${messageText}`;
      }
      thisAsInput.fieldContainer?.classList.add(type ?? "");
      return;
    }
    let cssClass = "validation-message";
    let iconName = type ? this.VALIDATION_ICONS[type] : "";
    const messageId = `${thisAsInput.input?.getAttribute("id")}-${settings.type}`;
    if (!iconName && type === "icon") {
      iconName = icon || this.VALIDATION_DEFAULT_ICON;
      cssClass += iconName ? " has-custom-icon" : "";
    }
    cssClass += isValidationIcon ? ` ${type}` : "";
    cssClass += this.disabled ? " disabled" : "";
    const iconHtml = iconName ? `<ids-icon icon="${iconName}" class="ids-icon"></ids-icon>` : "";
    elem = document.createElement("div");
    elem.setAttribute("id", messageId);
    elem.setAttribute("validation-id", id);
    elem.setAttribute("type", type);
    elem.toggleAttribute("hidden", this.#hideErrorMessage);
    elem.className = cssClass;
    elem.innerHTML = `${iconHtml}<ids-text error="true" class="message-text">${audible}${message}</ids-text>`;
    this.validationElems?.main?.classList.add(type);
    thisAsInput.fieldContainer?.classList.add(type ?? "");
    thisAsInput.input?.setAttribute("aria-describedby", messageId);
    thisAsInput.input?.setAttribute("aria-invalid", "true");
    const rootEl = this.shadowRoot?.querySelector(".ids-input, .ids-textarea, .ids-checkbox");
    const parent = rootEl || this.shadowRoot;
    parent?.appendChild(elem);
    const isRadioGroup = thisAsInput.input?.classList.contains("ids-radio-group");
    if (isRadioGroup) {
      const radioArr = [].slice.call(this.querySelectorAll("ids-radio"));
      radioArr.forEach((r) => r.setAttribute("validation-has-error", "true"));
    }
    const isCheckbox = thisAsInput.input?.classList.contains("checkbox");
    if (isCheckbox) {
      thisAsInput.input?.classList.add("error");
    }
  }
  /**
   * Remove the message(s) from an input
   * @param {object} [settings] incoming settings
   * @returns {void}
   */
  removeMessage(settings) {
    const thisAsInput = this;
    const id = settings.id;
    let type = settings.type;
    const removeMsg = (elem) => {
      if (elem) {
        const thisId = id === null || typeof id === "undefined" ? elem.getAttribute("id") : id;
        if (!type) {
          type = elem.getAttribute("type");
        }
        if (!this.isTypeNotValid) {
          this.isTypeNotValid = {};
        }
        elem.remove?.();
        if (this.validationId === thisId) {
          this.validationId = null;
          this.validationType = null;
          this.validationMessage = null;
          this.validationIcon = null;
        }
      }
    };
    const el = this.shadowRoot?.querySelector(`div[validation-id="${id}"]`);
    if (el) {
      removeMsg(el);
    } else if (type && (id === null || typeof id === "undefined")) {
      const typeElms = this.shadowRoot?.querySelectorAll(`.validation-message[type="${type}"]`);
      typeElms.forEach((typeEl) => removeMsg(typeEl));
    }
    if (type) {
      if (this.isTypeNotValid && !this.isTypeNotValid[type]) {
        thisAsInput.fieldContainer?.classList.remove(type);
        thisAsInput.input?.removeAttribute("aria-describedby");
        thisAsInput.input?.removeAttribute("aria-invalid");
      }
    }
    const isRadioGroup = thisAsInput.input?.classList.contains("ids-radio-group");
    if (isRadioGroup) {
      const radioArr = [].slice.call(this.querySelectorAll("ids-radio"));
      radioArr.forEach((r) => r.removeAttribute("validation-has-error"));
    }
    const isCheckbox = thisAsInput.input?.classList.contains("checkbox");
    if (isCheckbox) {
      thisAsInput.input?.classList.remove("error");
    }
    if (type) this.validationElems?.main?.classList.remove(type);
  }
  /**
   * Remove all the validation messages
   * @returns {void}
   */
  removeAllValidationMessages() {
    const nodes = [].slice.call(this.shadowRoot?.querySelectorAll(".validation-message"));
    nodes.forEach((node) => {
      const messageSettings = {
        id: node.getAttribute("validation-id")
      };
      const type = node.getAttribute("type");
      if (type) {
        messageSettings.type = type;
      }
      this.removeMessage(messageSettings);
    });
    this.#setValidationMessagesCountAttr();
  }
  /**
   * Set validation message manually
   * @returns {void}
   */
  setMessageManually() {
    const getVal = (val) => typeof val === "string" && val.trim() !== "" ? val.trim() : "";
    const id = getVal(this.validationId);
    const type = getVal(this.validationType);
    const message = getVal(this.validationMessage);
    const icon = getVal(this.validationIcon);
    if (id && type && message) {
      const args = { id, type, message, icon };
      this.removeMessage(args);
      this.addMessage(args);
      this.#setValidationMessagesCountAttr();
    }
  }
  /**
   * Set validation messages count attribute
   * @private
   * @returns {void}
   */
  #setValidationMessagesCountAttr() {
    const count = this.validationMessagesCount;
    const attr = "validation-message-count";
    if (count > 0) this.setAttribute(attr, String(count));
    else this.removeAttribute(attr);
  }
  /**
   * Handle validation events
   * @private
   * @param {string} option If 'remove', will remove attached events
   * @returns {void}
   */
  handleValidationEvents(option = "") {
    const validationEvents = (input) => {
      this.validationEventsList.forEach((eventName) => {
        if (option === "remove") {
          const handler = this.handledEvents.get(eventName);
          if (handler && handler.target === input) {
            this.offEvent(eventName, input);
          }
        } else {
          this.offEvent(eventName, input);
          requestAnimationFrame(() => {
            this.onEvent(eventName, input, () => {
              this.checkValidation();
            });
          });
        }
      });
    };
    if (this.input) {
      validationEvents(this.input);
    }
  }
  /**
   * Destroy the validation mixin
   * @returns {void}
   */
  destroyValidation() {
    const destroy = (input) => {
      const useRules = this.useRules.get(input);
      if (useRules) {
        this.handleValidationEvents("remove");
        this.useRules.delete(input);
      }
      if (!this.hasRequiredValidation() && !this.required) {
        this.removeRequired();
      }
      this.removeAllValidationMessages();
    };
    if (this.input) {
      destroy(this.input);
    }
  }
  #triggerValidateEvent(isValid) {
    this.triggerEvent("validate", this, {
      detail: {
        elem: this,
        value: this.value,
        isValid
      },
      bubbles: true
    });
  }
  /**
   * Set all validation rules
   * @private
   */
  rules = {
    /**
     * Required validation rule
     * @private
     */
    required: {
      check: (input) => {
        if (input.getAttribute("type") === "checkbox") {
          return input.checked;
        }
        if (input.classList.contains("ids-radio-group")) {
          const radioGroup = input.getRootNode()?.host;
          const radios = radioGroup?.querySelectorAll("ids-radio");
          return Array.from(radios).some((radio) => radio.checked);
        }
        const val = input.value;
        return !(val === null || typeof val === "string" && val === "" || typeof val === "number" && Number.isNaN(val));
      },
      message: "Required",
      messageId: "Required",
      type: "error",
      id: "required"
    },
    /**
     * Email validation rule
     * @private
     */
    email: {
      check: (input) => {
        const val = input.value;
        const regex = /^([\w-]+(?:\.[\w-]+)*)@((?:[\w-]+\.)*\w[\w-]{0,66})\.([a-z]{2,16}(?:\.[a-z]{2})?)$/i;
        return val.length ? regex.test(val) : true;
      },
      message: "Email address not valid",
      type: "error",
      id: "email"
    },
    date: {
      check(input) {
        const hostCompoment = input.getRootNode().host;
        const val = input.value;
        const dateFormat = hostCompoment.format;
        const options = {};
        if (dateFormat) {
          options.dateFormat = dateFormat;
        }
        this.message = hostCompoment.localeAPI.translate("InvalidDate", { showBrackets: false });
        const parsedDate = hostCompoment.localeAPI.parseDate(val, options);
        return !(parsedDate === void 0 && val !== "");
      },
      message: "Invalid Date",
      messageId: "InvalidDate",
      type: "error",
      id: "date"
    },
    time: {
      check(input) {
        const hostCompoment = input.getRootNode().host;
        const val = input.value;
        if (!val) return true;
        const defaultFormat = hostCompoment.localeAPI.calendar(hostCompoment.localeAPI.locale.name).timeFormat;
        const attrFormat = hostCompoment.format;
        const format = attrFormat || defaultFormat;
        this.message = hostCompoment.localeAPI.translate("InvalidTime", { showBrackets: false });
        const parsedTime = hostCompoment.localeAPI.parseDate(val, { dateFormat: format, strictTime: true });
        return isValidDate(parsedTime);
      },
      message: "Invalid Time",
      type: "error",
      id: "time"
    },
    rangeDate: {
      check(input) {
        let isValid = true;
        const hostCompoment = input.getRootNode().host;
        const datepickerInput = hostCompoment.parentNode.getRootNode().host;
        const value = input.value;
        const s = datepickerInput.rangeSettings;
        const parts = value.split(s.separator);
        const checkRule = (partValue) => {
          const dateFormat = datepickerInput.format;
          const options = {};
          if (dateFormat) {
            options.dateFormat = dateFormat;
          }
          const parsedDate = hostCompoment.localeAPI.parseDate(partValue, options);
          isValid = !(parsedDate === void 0 && partValue !== "");
          if (!isValid) {
            this.message = `${datepickerInput.localeAPI.translate("InvalidDate")} (${partValue})`;
            isValid = false;
          }
          if (isValid) {
            const date = datepickerInput.localeAPI.parseDate(
              input.value,
              datepickerInput.format
            );
            isValid = !datepickerInput.picker.isDisabledByDate(date);
            if (!isValid) {
              this.message = `${datepickerInput.localeAPI.translate("UnavailableDate")} (${partValue})`;
            }
          }
        };
        if (parts.length === 1) {
          checkRule(parts[0]);
        } else if (parts.length === 2) {
          checkRule(parts[0]);
          if (isValid) {
            checkRule(parts[1]);
          }
          if (isValid && parts[0] && parts[1]) {
            const startDate = hostCompoment.localeAPI.parseDate(parts[0], { dateFormat: datepickerInput.format });
            const endDate = hostCompoment.localeAPI.parseDate(parts[1], { dateFormat: datepickerInput.format });
            isValid = startDate <= endDate;
            if (!isValid) {
              this.message = `${datepickerInput.localeAPI.translate("InvalidFromDate")} (${parts[0]})`;
            }
          }
        }
        return isValid;
      },
      message: "",
      type: "error",
      id: "rangeDate"
    }
  };
  /**
   * Sets the validation check to use
   * @param {string} value The `validate` attribute
   */
  set validate(value) {
    if (value) {
      this.setAttribute(attributes.VALIDATE, value);
    } else {
      this.removeAttribute(attributes.VALIDATE);
    }
    this.handleValidation();
  }
  get validate() {
    return this.getAttribute(attributes.VALIDATE);
  }
  /**
   * Sets which events to fire validation on
   * @param {string} value The `validation-events` attribute
   */
  set validationEvents(value) {
    if (value) {
      this.setAttribute(attributes.VALIDATION_EVENTS, value);
    } else {
      this.removeAttribute(attributes.VALIDATION_EVENTS);
    }
    this.handleValidation();
  }
  get validationEvents() {
    return this.getAttribute(attributes.VALIDATION_EVENTS);
  }
  /**
   * Sets  message icon, use with manually messages thru markup
   * @param {string} value The value
   */
  set validationIcon(value) {
    if (value) {
      this.setAttribute(attributes.VALIDATION_ICON, value);
    } else {
      this.removeAttribute(attributes.VALIDATION_ICON);
    }
    this.setMessageManually();
  }
  get validationIcon() {
    return this.getAttribute(attributes.VALIDATION_ICON);
  }
  /**
   * Sets  message id, use with manually messages thru markup
   * @param {string} value The value
   */
  set validationId(value) {
    if (value) {
      this.setAttribute(attributes.VALIDATION_ID, value);
    } else {
      this.removeAttribute(attributes.VALIDATION_ID);
    }
    this.setMessageManually();
  }
  get validationId() {
    return this.getAttribute(attributes.VALIDATION_ID);
  }
  /**
   * Sets message string, use with manually messages thru markup
   * @param {string} value The value
   */
  set validationMessage(value) {
    if (value) {
      this.setAttribute(attributes.VALIDATION_MESSAGE, value);
    } else {
      this.removeAttribute(attributes.VALIDATION_MESSAGE);
    }
    this.setMessageManually();
  }
  get validationMessage() {
    return this.getAttribute(attributes.VALIDATION_MESSAGE);
  }
  /**
   * Sets message type, use with manually messages thru markup
   * @param {string} value The value
   */
  set validationType(value) {
    if (value) {
      this.setAttribute(attributes.VALIDATION_TYPE, value);
    } else {
      this.removeAttribute(attributes.VALIDATION_TYPE);
    }
    this.setMessageManually();
  }
  get validationType() {
    return this.getAttribute(attributes.VALIDATION_TYPE);
  }
  /**
   * Return if the field is valid or not
   * @returns {boolean} true if invalid
   */
  get isValid() {
    return this.shadowRoot?.querySelectorAll(".validation-message").length === 0;
  }
  /**
   * Return if the current validation errors
   * @returns {Array<IdsValidationErrorMessage>} The current errors
   */
  get validationMessages() {
    const msgs = [];
    this.shadowRoot?.querySelectorAll(".validation-message").forEach((message) => {
      msgs.push({
        message: message.querySelector("ids-text")?.childNodes[1].textContent || "",
        type: message.getAttribute("type") || "",
        id: message.getAttribute("validation-id") || ""
      });
    });
    return msgs;
  }
  get validationMessageElems() {
    return [...this.shadowRoot?.querySelectorAll(".validation-message") || []];
  }
  /**
   * Get validation messages count
   * @returns {number} The current messages count
   */
  get validationMessagesCount() {
    return this.shadowRoot?.querySelectorAll(".validation-message")?.length || 0;
  }
  /**
   * @param {string | boolean} val true if the required indicator should be forced to display
   */
  set required(val) {
    this.toggleAttribute(attributes.REQUIRED, stringToBool(val));
    if (val) {
      this.renderRequired();
    } else if (!this.hasRequiredValidation()) {
      this.removeRequired();
    }
  }
  /**
   * @returns {boolean} true if the required indicator should be forced to display
   */
  get required() {
    return this.hasAttribute(attributes.REQUIRED);
  }
  hasRequiredValidation() {
    return this.validate && this.validate.includes("required");
  }
  /**
   * Draws the required indicator
   */
  renderRequired() {
    const thisAsInput = this;
    const isRadioGroup = thisAsInput.input?.classList.contains("ids-radio-group");
    thisAsInput.labelEl?.classList.add("required");
    thisAsInput.input?.setAttribute("aria-required", true);
    if (isRadioGroup) {
      const radios = [...this.querySelectorAll("ids-radio")];
      radios.forEach((radio) => radio.input?.setAttribute("required", "required"));
    }
    this.validationElems?.editor?.setAttribute("aria-required", true);
  }
  /**
   * Removes the required indicator
   */
  removeRequired() {
    this.labelEl?.classList.remove("required");
    this.input?.removeAttribute("aria-required");
    this.validationElems?.editor?.removeAttribute("aria-required");
  }
};
var ids_validation_mixin_default = IdsValidationMixin;

export {
  isIdsValidatedElement,
  ids_validation_mixin_default
};
//# sourceMappingURL=ids-chunk-J34VXFUP-full.js.map
