/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  stripTags
} from "./ids-chunk-5K4YUTOH-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-orientation-mixin/ids-orientation-mixin.ts
var IdsOrientationMixin = (superclass) => class extends superclass {
  currentOrientation = "horizontal";
  constructor(...args) {
    super(...args);
    this.#refreshOrientation("horizontal", this.orientation);
  }
  connectedCallback() {
    super.connectedCallback?.();
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.ORIENTATION
    ];
  }
  /**
   * @returns {Array<string>} List of available orientation for this component
   */
  orientations = ["horizontal", "vertical"];
  /**
   * @returns {string | null} the name of the orientation currently applied
   */
  get orientation() {
    return this.currentOrientation;
  }
  /**
   * @param {string|null} val the name of the orientation to be applied
   */
  set orientation(val) {
    val ??= "horizontal";
    const safeValue = String(stripTags(val, ""));
    const currentValue = this.currentOrientation;
    if (currentValue !== safeValue) {
      if (this.orientations.includes(safeValue)) {
        this.setAttribute(attributes.ORIENTATION, `${safeValue}`);
      } else {
        this.removeAttribute(attributes.ORIENTATION);
      }
      this.currentOrientation = safeValue;
      this.#refreshOrientation(currentValue, safeValue);
    }
  }
  /**
   * Refreshes the component's orientation state, driven by
   * a CSS class on the WebComponent's `container` element
   * @param {string | null} oldVariantName the orientation variant name to "remove" from the style
   * @param {string | null} newVariantName the orientation variant name to "add" to the style
   * @returns {void}
   */
  #refreshOrientation(oldVariantName, newVariantName) {
    if (!this.container) return;
    const cl = this.container.classList;
    if (oldVariantName) cl.remove(`orientation-${oldVariantName}`);
    if (newVariantName) cl.add(`orientation-${newVariantName}`);
    cl.remove(`orientation-undefined`);
    if (typeof this.onOrientationRefresh === "function") {
      this.onOrientationRefresh();
    }
  }
};
var ids_orientation_mixin_default = IdsOrientationMixin;

export {
  ids_orientation_mixin_default
};
//# sourceMappingURL=ids-chunk-KG5MH5G3-full.js.map
