/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  gregorianToUmalqura,
  isValidDate
} from "./ids-chunk-KNXP4KUS-full.js";
import {
  querySelectorAllShadowRoot
} from "./ids-chunk-LQYSVESW-full.js";

// src/components/ids-locale/data/en-US.json
var en_US_default = {
  language: "en",
  englishName: "English (United States)",
  nativeName: "English (United States)",
  direction: "left-to-right",
  calendars: [{
    name: "gregorian",
    dateFormat: {
      separator: "/",
      timeSeparator: ":",
      short: "M/d/yyyy",
      medium: "MMM d, yyyy",
      long: "MMMM d, yyyy",
      full: "EEEE, MMMM d, y",
      month: "MMMM d",
      year: "MMMM yyyy",
      dayOfWeek: "d EEE",
      timestamp: "h:mm:ss a",
      timestampMillis: "h:mm:ss:SSS a",
      hour: "h:mm a",
      datetime: "M/d/yyyy h:mm a",
      datetimeMillis: "M/d/yyyy h:mm:ss:SSS a",
      timezone: "M/d/yyyy h:mm a zz",
      timezoneLong: "M/d/yyyy h:mm a zzzz"
    },
    days: {
      wide: ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"],
      abbreviated: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
      narrow: ["S", "M", "T", "W", "T", "F", "S"]
    },
    months: {
      wide: ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"],
      abbreviated: ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"]
    },
    timeFormat: "h:mm a",
    dayPeriods: ["AM", "PM"],
    firstDayofWeek: 0
  }],
  currencySign: "$",
  currencyFormat: "\xA4###",
  numbers: {
    percentSign: "%",
    percentFormat: "### %",
    percentSuffix: " %",
    percentPrefix: "",
    minusSign: "-",
    decimal: ".",
    group: ",",
    groupSizes: [3, 3]
  }
};

// src/components/ids-locale/data/en-messages.json
var en_messages_default = {
  AboutText: { id: "AboutText", value: "Copyright &copy; {0} Infor. All rights reserved. The word and design marks set forth herein are trademarks and/or registered trademarks of Infor and/or its affiliates and subsidiaries. All other trademarks listed herein are the property of their respective owners" },
  Actions: { id: "Actions", value: "Actions", comment: "Tooltip text for the action button with additional in context actions" },
  Add: { id: "Add", value: "Add", comment: "Add" },
  AddComments: { id: "AddComments", value: "Add comments", comment: "Add comments to a form of data" },
  AddNewTab: { id: "AddNewTab", value: "Add new tab", comment: "Attached to a button that adds new tabs" },
  AdministrativeLeave: { id: "AdministrativeLeave", value: "Administrative leave", comment: "As in vacation time from work" },
  AdvancedFilter: { id: "AdvancedFilter", value: "Create advanced filter", comment: "In a data grid active an advanced filtering feature" },
  Afrikaans: { id: "Afrikaans", value: "Afrikaans", comment: "Language name for Afrikaans (South Africa)" },
  Alabaster: { id: "Alabaster", value: "Alabaster", comment: "Color in our color palette" },
  Alert: { id: "Alert", value: "Alert", comment: "Alert" },
  AlertOnPage: { id: "AlertOnPage", value: "Alert message(s) on page", comment: "Alert message(s) on page n" },
  AlignCenterHorizontally: { id: "AlignCenterHorizontally", value: "Horizontal align center", comment: "Align Center Horizontally tooltip" },
  AligntoBottom: { id: "AligntoBottom", value: "Align bottom", comment: "Align to bottom tooltip" },
  All: { id: "All", value: "All", comment: "All items in the context of a filter" },
  AllDay: { id: "AllDay", value: "All day", comment: "Label for an event which lasts all day" },
  AllResults: { id: "AllResults", value: "All results for", comment: "Search Results Text" },
  Amber: { id: "Amber", value: "Amber", comment: "Color in our color palette" },
  Amethyst: { id: "Amethyst", value: "Amethyst", comment: "Color in our color palette" },
  And: { id: "And", value: "and", comment: "Text used in calendar" },
  AppMenuTriggerText: { id: "AppMenuTriggerText", value: "Menu", comment: "Text in a special Module Tab used to trigger an Application Menu open or closed" },
  AppMenuTriggerTextAlt: { id: "AppMenuTriggerTextAlt", value: "Application menu trigger", comment: "Default text used inside of Application Menu trigger buttons" },
  Apply: { id: "Apply", value: "Apply", comment: "Text in a button to apply an action" },
  Arabic: { id: "Arabic", value: "Arabic", comment: "Language name for Arabic (general)" },
  Attach: { id: "Attach", value: "Attach", comment: "Attach" },
  Available: { id: "Available", value: "Available", comment: "Button tooltip used in a list of movable items" },
  Azure: { id: "Azure", value: "Azure", comment: "Color in our color palette" },
  BackgroundColor: { id: "BackgroundColor", value: "Background color", comment: "add or edit text background color in the editor" },
  BarChart: { id: "BarChart", value: "Bar Chart", comment: "A chart type" },
  Between: { id: "Between", value: "Between", comment: "Between in icons for filtering" },
  BillionsAbbrev: { id: "BillionsAbbrev", value: "{0}b", comment: "Refers to a value in a chart in billions. i.e. 1B, 100B" },
  Black: { id: "Black", value: "Black", comment: "Refers to an black color band" },
  Blockquote: { id: "Blockquote", value: "Block quote", comment: "Term for Block Quotations in editing" },
  Blue: { id: "Blue", value: "Blue", comment: "Refers to an blue color band" },
  Bold: { id: "Bold", value: "Bold", comment: "Make text bold" },
  BookmarkThis: { id: "BookmarkThis", value: "Bookmark this", comment: "Bookmark an element" },
  Bookmarked: { id: "Bookmarked", value: "Bookmarked", comment: "Bookmark filled - Element is already bookmarked" },
  Breadcrumb: { id: "Breadcrumb", value: "Breadcrumb", comment: "Text describing the Breadcrumb" },
  Browser: { id: "Browser", value: "Browser", comment: "As in a web browser" },
  BrowserLanguage: { id: "BrowserLanguage", value: "Browser language", comment: "Language in the current web bowser" },
  Bulgarian: { id: "Bulgarian", value: "Bulgarian", comment: "Language name for Bulgarian (Bulgaria)" },
  BulletedList: { id: "BulletedList", value: "Bulleted list", comment: "Bulleted list tooltip" },
  Calendar: { id: "Calendar", value: "Calendar", comment: "Inline Text for the title of the calendar control" },
  Camera: { id: "Camera", value: "Camera", comment: "Camera tooltip" },
  Cancel: { id: "Cancel", value: "Cancel", comment: "Cancel tooltip" },
  CapsLockOn: { id: "CapsLockOn", value: "Caps lock on", comment: "Caps lock on message" },
  Cart: { id: "Cart", value: "Cart", comment: "Cart tooltip" },
  Caution: { id: "Caution", value: "Caution", comment: "As in a caution message on screen" },
  CenterText: { id: "CenterText", value: "Center", comment: "An icon tooltip" },
  ChangeSelection: { id: "ChangeSelection", value: "To change the selected item, use the arrow keys.", comment: "Audible text for drop down list help" },
  ChangeView: { id: "ChangeView", value: "Change view", comment: "Change the current page from a list of options" },
  CharactersLeft: { id: "CharactersLeft", value: "Characters left {0}", comment: "indicator showing how many more characters you can type." },
  CharactersMax: { id: "CharactersMax", value: "Character count of {0} reached", comment: "indicator showing how many max characters you can type UPDATED" },
  Checkbox: { id: "Checkbox", value: "Checkbox", comment: "Checkbox tooltip" },
  Checked: { id: "Checked", value: "Checked", comment: "Checked tooltip" },
  Chinese: { id: "Chinese", value: "Chinese", comment: "Chinese language in general form" },
  ChooseFont: { id: "ChooseFont", value: "Choose font style", comment: "Choose a font style" },
  Classic: { id: "Classic", value: "Classic", comment: "This is the name of the older styling of all components (theme name)" },
  ClassicDarkTheme: { id: "ClassicDarkTheme", value: "Classic dark", comment: "The name of an application Theme" },
  ClassicHighContrastTheme: { id: "ClassicHighContrastTheme", value: "Classic high contrast", comment: "The name of an application Theme" },
  ClassicLightTheme: { id: "ClassicLightTheme", value: "Classic light", comment: "The name of an application Theme" },
  Clear: { id: "Clear", value: "Clear", comment: "Tooltip for a clear action" },
  ClearFilter: { id: "ClearFilter", value: "Clear filter", comment: "Clear the current filter criteria" },
  ClearFormatting: { id: "ClearFormatting", value: "Clear formatting", comment: "Clear the formatting in editor" },
  ClearSelection: { id: "ClearSelection", value: "(Clear selection)", comment: "clear dropdown selection" },
  Clickable: { id: "Clickable", value: "Clickable in editor", comment: "Clickable in editor" },
  Clock: { id: "Clock", value: "Clock", comment: "Clock tooltip" },
  Close: { id: "Close", value: "Close", comment: "Tooltip for a Close Button Action" },
  Collapse: { id: "Collapse", value: "Collapse", comment: "Collapse / close a tree/submenu" },
  CollapseAppTray: { id: "CollapseAppTray", value: "Collapse app tray", comment: "Collapse app tray tooltip" },
  Color: { id: "Color", value: "Color", comment: "Color" },
  ColorPickerSelection: { id: "ColorPickerSelection", value: "Pick a custom color", comment: "Used in accessible labels to describe a color picker fields trigger button to assistive technology" },
  ColorPickerTriggerButton: { id: "ColorPickerTriggerButton", value: "Click to open color picker", comment: "Used in accessible labels to describe a color picker fields trigger button to assistive technology" },
  Colors: { id: "Colors", value: "Colors", comment: "Color (plural)" },
  Columns: { id: "Columns", value: "Columns", comment: "Columns tooltip" },
  Comments: { id: "Comments", value: "Comments", comment: "Comments on an form" },
  CompanyHoliday: { id: "CompanyHoliday", value: "Company holiday", comment: "A holiday provided by work." },
  Completed: { id: "Completed", value: "Completed", comment: "Text for a completed status" },
  Component: { id: "Component", value: "Component", comment: "As in a UI component - building block." },
  Compose: { id: "Compose", value: "Compose", comment: "Compose tooltip" },
  Confirm: { id: "Confirm", value: "Confirm", comment: "Confirm tooltip" },
  ConfirmOnPage: { id: "ConfirmOnPage", value: "Confirm message(s) on page", comment: "Confirm message(s) on page n" },
  Contains: { id: "Contains", value: "Contains", comment: "Contains in icons for filtering" },
  Contrast: { id: "Contrast", value: "Contrast", comment: "Name of the high contrast theme" },
  CookiesEnabled: { id: "CookiesEnabled", value: "Cookies enabled", comment: "Returns if browser cookies are enabled or not." },
  Copy: { id: "Copy", value: "Copy", comment: "Copy tooltip" },
  CopyToClipboard: { id: "CopyToClipboard", value: "Copy to clipboard", comment: "Copy text" },
  Croatian: { id: "Croatian", value: "Croatian", comment: "Croatian (Croatia) language" },
  CssClass: { id: "CssClass", value: "Css class", comment: "Label for entering a Css Class name" },
  Cut: { id: "Cut", value: "Cut", comment: "Cut tooltip" },
  Czech: { id: "Czech", value: "Czech", comment: "Language name for Czech Language" },
  Danish: { id: "Danish", value: "Danish", comment: "Language name for Danish" },
  Dark: { id: "Dark", value: "Dark", comment: "The name of one of the application theme variants." },
  Datagrid: { id: "Datagrid", value: "Datagrid", comment: "Name of the datagrid component" },
  Date: { id: "Date", value: "Date", comment: "Describes filtering by a date data type" },
  DatePickerTriggerButton: { id: "DatePickerTriggerButton", value: "Date picker trigger", comment: "Used in accessible labels to describe a date picker fields trigger button to assistive technology" },
  Day: { id: "Day", value: "Day", comment: "Shows view with day events" },
  DayAbbreviatedFri: { id: "DayAbbreviatedFri", value: "Fri", comment: "Day of the week in abbreviated form" },
  DayAbbreviatedMon: { id: "DayAbbreviatedMon", value: "Mon", comment: "Day of the week in abbreviated form" },
  DayAbbreviatedSat: { id: "DayAbbreviatedSat", value: "Sat", comment: "Day of the week in abbreviated form" },
  DayAbbreviatedSun: { id: "DayAbbreviatedSun", value: "Sun", comment: "Day of the week in abbreviated form" },
  DayAbbreviatedThu: { id: "DayAbbreviatedThu", value: "Thu", comment: "Day of the week in abbreviated form" },
  DayAbbreviatedTue: { id: "DayAbbreviatedTue", value: "Tue", comment: "Day of the week in abbreviated form" },
  DayAbbreviatedWed: { id: "DayAbbreviatedWed", value: "Wed", comment: "Day of the week in abbreviated form" },
  DayNarrowFri: { id: "DayNarrowFri", value: "F", comment: "Day of the week in shortest form" },
  DayNarrowMon: { id: "DayNarrowMon", value: "M", comment: "Day of the week in shortest form" },
  DayNarrowSat: { id: "DayNarrowSat", value: "S", comment: "Day of the week in shortest form" },
  DayNarrowSun: { id: "DayNarrowSun", value: "S", comment: "Day of the week in shortest form" },
  DayNarrowThu: { id: "DayNarrowThu", value: "T", comment: "Day of the week in shortest form" },
  DayNarrowTue: { id: "DayNarrowTue", value: "T", comment: "Day of the week in shortest form" },
  DayNarrowWed: { id: "DayNarrowWed", value: "W", comment: "Day of the week in shortest form" },
  DayPeriod0: { id: "DayPeriod0", value: "AM", comment: "The am part of a date" },
  DayPeriod1: { id: "DayPeriod1", value: "PM", comment: "The pm part of a date" },
  DayWideFri: { id: "DayWideFri", value: "Friday", comment: "Day of the week in long form" },
  DayWideMon: { id: "DayWideMon", value: "Monday", comment: "Day of the week in long form" },
  DayWideSat: { id: "DayWideSat", value: "Saturday", comment: "Day of the week in long form" },
  DayWideSun: { id: "DayWideSun", value: "Sunday", comment: "Day of the week in long form" },
  DayWideThu: { id: "DayWideThu", value: "Thursday", comment: "Day of the week in long form" },
  DayWideTue: { id: "DayWideTue", value: "Tuesday", comment: "Day of the week in long form" },
  DayWideWed: { id: "DayWideWed", value: "Wednesday", comment: "Day of the week in long form" },
  Days: { id: "Days", value: "Days ", comment: "Show how many days until an event" },
  DaysOverdue: { id: "DaysOverdue", value: "{0} days overdue", comment: "For a task /date UI" },
  DaysRemaining: { id: "DaysRemaining", value: "{0} days remaining", comment: "For a task /date UI" },
  Default: { id: "Default", value: "Default", comment: "Refers to a default object of a generic type" },
  Delete: { id: "Delete", value: "Delete", comment: "Delete toolbar action tooltip" },
  DeleteEvent: { id: "DeleteEvent", value: "Delete Event", comment: "Delete an event (from a calendar)" },
  Device: { id: "Device", value: "Device", comment: "Name of the device" },
  Dirty: { id: "Dirty", value: "Row has changed", comment: "Record is dirty / modified" },
  DiscretionaryTimeOff: { id: "DiscretionaryTimeOff", value: "Discretionary time off", comment: "As in work time off" },
  DistributeHoriz: { id: "DistributeHoriz", value: "Distribute horizontally", comment: "Icon button tooltip for action that distributes elements across Horizontally" },
  Document: { id: "Document", value: "Document", comment: "Document tooltip" },
  DoesNotContain: { id: "DoesNotContain", value: "Does not contain", comment: "Does Not Contain in icons for filtering" },
  DoesNotEndWith: { id: "DoesNotEndWith", value: "Does not end with", comment: "For condition filtering" },
  DoesNotEqual: { id: "DoesNotEqual", value: "Does not equal", comment: "Does Not equal in icons for filtering" },
  DoesNotStartWith: { id: "DoesNotStartWith", value: "Does not start with", comment: "For condition filtering" },
  Down: { id: "Down", value: "Down", comment: "Down tooltip" },
  Download: { id: "Download", value: "Download", comment: "Download tooltip" },
  Drilldown: { id: "Drilldown", value: "Drill down", comment: "Drill by moving page flow into a record" },
  Drillup: { id: "Drillup", value: "Drill up", comment: "Opposite of drilldown, move back up to a larger set of records" },
  Dropdown: { id: "Dropdown", value: "Dropdown", comment: "Dropdown" },
  DropdownTriggerButton: { id: "DropdownTriggerButton", value: "Click to open dropdown", comment: "Used in accessible labels to describe a dropdown trigger button to assistive technology" },
  Duplicate: { id: "Duplicate", value: "Duplicate", comment: "Duplicate tooltip" },
  Duration: { id: "Duration", value: "Duration", comment: "The length of a time span between two times" },
  Dutch: { id: "Dutch", value: "Dutch", comment: "Language name for Dutch (Netherlands)" },
  EarlierOrEquals: { id: "EarlierOrEquals", value: "Earlier than Or equals", comment: "Earlier than or equals in icons for filtering" },
  EarlierOrUntil: { id: "EarlierOrUntil", value: "Earlier than Or until", comment: "Earlier than or equals in icons for filtering" },
  EarlierThan: { id: "EarlierThan", value: "Earlier than", comment: "Early Than in icons for filtering" },
  Edit: { id: "Edit", value: "Edit", comment: "Edit tooltip" },
  EitherSelectedOrNotSelected: { id: "EitherSelectedOrNotSelected", value: "Either selected or not selected", comment: "Either selected or not selected in icons for filtering" },
  EmailValidation: { id: "EmailValidation", value: "Email address not valid", comment: "This the rule for email validation" },
  Emerald: { id: "Emerald", value: "Emerald", comment: "Color in our color palette" },
  EndsWith: { id: "EndsWith", value: "Ends with", comment: "for condition filtering" },
  English: { id: "English", value: "English (United States)", comment: "Language name for English" },
  EnterComments: { id: "EnterComments", value: "Enter comments here...", comment: "Placeholder text for a text input (comments)" },
  Equals: { id: "Equals", value: "Equals", comment: "Equals in icons for filtering" },
  Error: { id: "Error", value: "Error", comment: "Title, spoken text describing fact an error has occured" },
  ErrorAllowedTypes: { id: "ErrorAllowedTypes", value: "File type is not allowed", comment: "Error string for file-upload" },
  ErrorMaxFileSize: { id: "ErrorMaxFileSize", value: "Exceeded file size limit", comment: "Error string for file-upload" },
  ErrorMaxFiles: { id: "ErrorMaxFiles", value: "Cannot upload more than the maximum number of files ({n}).", comment: "Error string for file-upload" },
  ErrorMaxFilesInProcess: { id: "ErrorMaxFilesInProcess", value: "Exceeded maximum files allowed limit", comment: "Error string for file-upload" },
  ErrorOnPage: { id: "ErrorOnPage", value: "Error message(s) on page", comment: "Error message(s) on page n" },
  Estonian: { id: "Estonian", value: "Estonian", comment: "Language name for Estonian" },
  Event: { id: "Event", value: "Event", comment: "As in an event that would be in a calendar" },
  EventType: { id: "EventType", value: "Event type", comment: "The kind of event, for action vacation or sick time" },
  ExampleData: { id: "ExampleData", value: "Example data", comment: "Translated text for an example piece of data instance" },
  ExampleLabel: { id: "ExampleLabel", value: "Example label", comment: "Translated text for an example label instance" },
  ExamplePlaceholder: { id: "ExamplePlaceholder", value: "Example placeholder", comment: "Translated text for an example form placeholder text" },
  ExitFullView: { id: "ExitFullView", value: "Exit full view", comment: "Exit full view tooltip" },
  Expand: { id: "Expand", value: "Expand", comment: "Expand open a tree/submenu" },
  ExpandAppTray: { id: "ExpandAppTray", value: "Expand app tray", comment: "Expand app tray tooltip" },
  ExpandCollapse: { id: "ExpandCollapse", value: "Expand / Collapse", comment: "Text to toggle a button in a container." },
  ExpandMediaGalleryImage: { id: "ExpandMediaGallerImage", value: "Expand media gallery image", comment: "Expand a media gallery image" },
  Export: { id: "Export", value: "Export", comment: "Export tooltip" },
  ExportAsSpreadsheet: { id: "ExportAsSpreadsheet", value: "Export as spreadsheet", comment: "Export as Spreadsheet tooltip" },
  ExportToCsv: { id: "ExportToCsv", value: "Export to CSV", comment: "Export to CSV menu option in datagrid" },
  ExportToExcel: { id: "ExportToExcel", value: "Export to Excel", comment: "Export to Excel menu option in datagrid" },
  ExtraSmall: { id: "ExtraSmall", value: "Extra small", comment: "A smaller font size and compressed mode for datagrid rows." },
  ExtraExtraSmall: { id: "ExtraExtraSmall", value: "Extra Extra small", comment: "An even smaller font size and compressed mode for datagrid rows." },
  Favorite: { id: "Favorite", value: "Favorite", comment: "A favorite item" },
  FieldFilter: { id: "FieldFilter", value: "Field filter", comment: "Used for Field Filter" },
  FileUpload: { id: "FileUpload", value: "File upload. Press enter to browse for a file", comment: "Screen Reader instructions" },
  Filter: { id: "Filter", value: "Filter", comment: "Filter tooltip" },
  Finnish: { id: "Finnish", value: "Finnish", comment: "Language name for Finnish" },
  FirstPage: { id: "FirstPage", value: "First page", comment: "First Page tooltip" },
  Folder: { id: "Folder", value: "Folder", comment: "Folder tooltip" },
  FontPickerHeader: { id: "FontPickerHeader", value: "Header {0}", comment: "Description of header text style on Fontpicker components" },
  FontPickerNormal: { id: "FontPickerNormal", value: "Normal text", comment: "Description of default text style on Fontpicker components" },
  FontPickerStyle: { id: "FontPickerStyle", value: "Font style", comment: "Description of font style on Fontpicker components" },
  Forms: { id: "Forms", value: "Forms", comment: "Describing a data form of fields and data labels" },
  French: { id: "French", value: "French", comment: "Language name for French" },
  From: { id: "From", value: "From", comment: "Start of a range (of dates)" },
  FullView: { id: "FullView", value: "Full view", comment: "Full View tooltip" },
  GenerateWithAI: { id: "GenerateWithAI", value: "Generate with AI", comment: "Button for Generative AI" },
  German: { id: "German", value: "German", comment: "Language name for german" },
  Go: { id: "Go", value: "Go", comment: "Go, perform a movement, start a search, move to the next thing in a workflow." },
  GoBack: { id: "GoBack", value: "Go back", comment: "Move Page / object this directionp" },
  GoDown: { id: "GoDown", value: "Go down", comment: "Move Page / object this directionp" },
  GoForward: { id: "GoForward", value: "Go forward", comment: "Move Page / object this direction" },
  GoUp: { id: "GoUp", value: "Go Up", comment: "Move page / object this direction" },
  Graphite: { id: "Graphite", value: "Graphite", comment: "Color in our color palette" },
  GreaterOrEquals: { id: "GreaterOrEquals", value: "Greater than or equals", comment: "Greater Than Or Equals in icons for filtering" },
  GreaterThan: { id: "GreaterThan", value: "Greater than", comment: "Greater Than in icons for filtering" },
  Green: { id: "Green", value: "Green", comment: "Refers to an green color band" },
  Grid: { id: "Grid", value: "Grid", comment: "Grid tooltip" },
  Group: { id: "Group", value: "Group", comment: "Group of data in a datagrid with grouped rows" },
  Groups: { id: "Groups", value: "Groups", comment: "Plural for group" },
  GroupsPerPage: { id: "GroupsPerPage", value: "{0} groups per page", comment: "Dropdown allows the user to select how many visible Groups the {} placeholder shows value. NOTE: Please change japanese to \u30DA\u30FC\u30B8\u3042\u305F\u308A\u306E\u30B0\u30EB\u30FC\u30D7\u6570 for next time" },
  HeadingFour: { id: "HeadingFour", value: "Heading four", comment: "Heading four tooltip" },
  HeadingThree: { id: "HeadingThree", value: "Heading three", comment: "Heading three tooltip" },
  Hebrew: { id: "Hebrew", value: "Hebrew", comment: "Language name for Hebrew" },
  Hide: { id: "Hide", value: "Hide", comment: "On a Button for revealing text that is hidden" },
  HighContrast: { id: "HighContrast", value: "High contrast", comment: "The name of a theme variant" },
  Highest: { id: "Highest", value: "Highest", comment: "Highest Four tooltip" },
  Highlight: { id: "Highlight", value: "Highlight", comment: "Used to highlight (select) a chart item" },
  Hindi: { id: "Hindi", value: "Hindi", comment: "Language name for Hindi" },
  Home: { id: "Home", value: "Home", comment: "Home tooltip" },
  Hour: { id: "Hour", value: "Hour", comment: "The hour portion of a time" },
  Hours: { id: "Hours", value: "Hours", comment: "The hour portion of a time (plural)" },
  HtmlView: { id: "HtmlView", value: "Html view", comment: "Html view tooltip" },
  Hungarian: { id: "Hungarian", value: "Hungarian", comment: "Language name for Hungarian" },
  Id: { id: "Id", value: "Id", comment: "Short for of identification" },
  Image: { id: "Image", value: "Image", comment: "Image of something" },
  Import: { id: "Import", value: "Import", comment: "Import tooltip" },
  InProgress: { id: "In Progress", value: "In progress", comment: "Info tooltip that an action is in progress" },
  InRange: { id: "InRange", value: "In range", comment: "In Range in icons for filtering" },
  Indonesian: { id: "Indonesian", value: "Indonesian", comment: "Language name for Indonesian" },
  Info: { id: "Info", value: "Info", comment: "Info tooltip" },
  InfoOnPage: { id: "InfoOnPage", value: "Information message(s) on page", comment: "Information message(s) on page n" },
  Insert: { id: "Insert", value: "Insert", comment: "Insert modal dialog button" },
  InsertAnchor: { id: "InsertAnchor", value: "Insert anchor", comment: "Insert a hyperlink in an editor" },
  InsertHyperlink: { id: "InsertHyperlink", value: "Insert hyperlink", comment: "Insert a hyperlink (synonymous with link or anchor tag) into an editor. Please recheck this as it was renamed from anchor." },
  InsertImage: { id: "InsertImage", value: "Insert image", comment: "Insert Image in an editor" },
  InsertLink: { id: "InsertLink", value: "Insert link", comment: "Insert link in an editor" },
  InsertUrl: { id: "InsertUrl", value: "Insert url", comment: "Insert a url in an editor" },
  InvalidDate: { id: "InvalidDate", value: "Invalid date", comment: "validation message for wrong date format (short)" },
  InvalidFromDate: { id: "InvalidFromDate", value: "From date must be before end date", comment: "validation message for wrong from date" },
  InvalidDateTime: { id: "InvalidDateTime", value: "Invalid date or time", comment: "validation message for wrong date and time format" },
  InvalidTime: { id: "InvalidTime", value: "Invalid time", comment: "validation message for wrong time format" },
  Inventory: { id: "Inventory", value: "Inventory", comment: "Icon button tooltop for inventory action" },
  IsEmpty: { id: "IsEmpty", value: "Is empty", comment: "Is Empty in icons for filtering" },
  IsNotEmpty: { id: "IsNotEmpty", value: "Is not empty", comment: "Is Not Empty in icons for filtering" },
  Italic: { id: "Italic", value: "Italic", comment: "Make text italic" },
  ItemsSelected: { id: "ItemsSelected", value: "Items selected", comment: "Num of items selected for swaplist" },
  Japanese: { id: "Japanese", value: "Japanese", comment: "Language name for Japanese" },
  JustifyCenter: { id: "JustifyCenter", value: "Center", comment: "justify text to center in the editor" },
  JustifyLeft: { id: "JustifyLeft", value: "Align left", comment: "justify text to left in the editor" },
  JustifyRight: { id: "JustifyRight", value: "Align right", comment: "justify text to right in the editor" },
  Keyword: { id: "Keyword", value: "Keyword", comment: "Describes filtering by a keyword search" },
  Korean: { id: "Korean", value: "Korean", comment: "Language name for Korean" },
  Language: { id: "Language", value: "Language", comment: "The currently used Language" },
  Large: { id: "Large", value: "Large", comment: "A larger row sizes with taller rows. NOTE: Please change french to Grande (Moyenne form)" },
  LastPage: { id: "LastPage", value: "Last page", comment: "Last Page tooltip" },
  LaterOrEquals: { id: "LaterOrEquals", value: "Later than or equals", comment: "Later than or equals in icons for filtering" },
  LaterOrOn: { id: "LaterOrOn", value: "Later than or on", comment: "Later Than Or Equals in icons for filtering" },
  LaterThan: { id: "LaterThan", value: "Later than", comment: "Later than in icons for filtering" },
  Latvian: { id: "Latvian", value: "Latvian", comment: "Language name for Latvian" },
  Launch: { id: "Launch", value: "Launch", comment: "Launch" },
  Left: { id: "Left", value: "Left", comment: "Left tooltip" },
  Legend: { id: "Legend", value: "Legend", comment: "As in a chart legend" },
  LessOrEquals: { id: "LessOrEquals", value: "Less than or equals", comment: "Less than or equals in icons for filtering" },
  LessThan: { id: "LessThan", value: "Less than", comment: "Less than in icons for filtering" },
  Light: { id: "Light", value: "Light", comment: "The name of one of the application theme variants." },
  Link: { id: "Link", value: "Link", comment: "Link - as in hyperlink - icon tooltop" },
  LineChart: { id: "LineChart", value: "Line Chart", comment: "A chart type" },
  Lithuanian: { id: "Lithuanian", value: "Lithuanian", comment: "Language name for Lithuanian" },
  Load: { id: "Load", value: "Load", comment: "Load icon tooltip" },
  Loading: { id: "Loading", value: "Loading", comment: "Text below spinning indicator to indicate loading" },
  Locale: { id: "Locale", value: "Locale", comment: "A place or locality for example en-US, it-It" },
  Locked: { id: "Locked", value: "Locked", comment: "Locked tooltip" },
  Logout: { id: "Logout", value: "Log out", comment: "Log out of the application" },
  Lookup: { id: "Lookup", value: "Lookup", comment: "Lookup - As in looking up a record or value" },
  LookupTriggerButton: { id: "LookupTriggerButton", value: "Lookup trigger", comment: "Used in accessible labels to describe a lookup fields trigger button to assistive technology" },
  Lowest: { id: "Lowest", value: "Lowest", comment: "Lowest - as in lowest value" },
  Mail: { id: "Mail", value: "Mail", comment: "Mail tooltip" },
  Malay: { id: "Malay", value: "Malay", comment: "Language name for Malay" },
  MapPin: { id: "MapPin", value: "Pin", comment: "Map Pin tooltip" },
  Maximize: { id: "Maximize", value: "Maximize", comment: "Maximize a screen or dialog in the UI" },
  Median: { id: "Median", value: "Median", comment: "Median in Mathematics" },
  Medium: { id: "Medium", value: "Medium", comment: "Describes a Medium sized Row Height in a grid/list. NOTE: Please change french to Petite (Moyenne form)" },
  Menu: { id: "Menu", value: "Menu", comment: "Menu tooltip" },
  MenuGroup: { id: "MenuGroup", value: "Menu group containing {0} item(s)", comment: "Describes the number of menu items contained inside the group (accessibility when items are focused)" },
  MillionsAbbrev: { id: "MillionsAbbrev", value: "{0}M", comment: "Refers to a value in a chart in millions. i.e. 1M, 100M" },
  MingleShare: { id: "MingleShare", value: "Share with Ming.le", comment: "Share the contextual object/action in the mingle system" },
  Minimize: { id: "Minimize", value: "Minimize", comment: "Minimize tooltip" },
  Minus: { id: "Minus", value: "Minus", comment: "Minus tooltip" },
  Minute: { id: "Minute", value: "Minute", comment: "Text use in calendar" },
  Minutes: { id: "Minutes", value: "Minutes", comment: "the minutes portion of a time" },
  Mobile: { id: "Mobile", value: "Mobile", comment: "Indicates a mobile device (phone tablet ect)" },
  Mode: { id: "Mode", value: "Mode", comment: "Indicates a mode of a theme (like dark or light mode)" },
  Modes: { id: "Modes", value: "Modes", comment: "Indicates a selection of Modes of a theme (like dark or light mode)" },
  Month: { id: "Month", value: "Month", comment: "As in a date month" },
  MonthAbbreviatedApr: { id: "MonthAbbreviatedApr", value: "Apr", comment: "Month in abbreviated form" },
  MonthAbbreviatedAug: { id: "MonthAbbreviatedAug", value: "Aug", comment: "Month in abbreviated form" },
  MonthAbbreviatedDec: { id: "MonthAbbreviatedDec", value: "Dec", comment: "Month in abbreviated form" },
  MonthAbbreviatedFeb: { id: "MonthAbbreviatedFeb", value: "Feb", comment: "Month in abbreviated form" },
  MonthAbbreviatedJan: { id: "MonthAbbreviatedJan", value: "Jan", comment: "Month in abbreviated form" },
  MonthAbbreviatedJuly: { id: "MonthAbbreviatedJuly", value: "Jul", comment: "Month in abbreviated form" },
  MonthAbbreviatedJune: { id: "MonthAbbreviatedJune", value: "Jun", comment: "Month in abbreviated form" },
  MonthAbbreviatedLowerCaseApr: { id: "MonthAbbreviatedApr", value: "Apr", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseDec: { id: "MonthAbbreviatedDec", value: "Dec", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseFeb: { id: "MonthAbbreviatedFeb", value: "Feb", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseJan: { id: "MonthAbbreviatedJan", value: "Jan", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseJuly: { id: "MonthAbbreviatedJuly", value: "Jul", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseJune: { id: "MonthAbbreviatedJune", value: "Jun", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseLowerCaseAug: { id: "MonthAbbreviatedAug", value: "Aug", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseMar: { id: "MonthAbbreviatedMar", value: "Mar", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseMay: { id: "MonthAbbreviatedMay", value: "May", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseNov: { id: "MonthAbbreviatedNov", value: "Nov", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseOct: { id: "MonthAbbreviatedOct", value: "Oct", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedLowerCaseSep: { id: "MonthAbbreviatedSep", value: "Sep", comment: "Month in abbreviated form lower case - in some languages/situations this must be lower case (but not english)" },
  MonthAbbreviatedMar: { id: "MonthAbbreviatedMar", value: "Mar", comment: "Month in abbreviated form" },
  MonthAbbreviatedMay: { id: "MonthAbbreviatedMay", value: "May", comment: "Month in abbreviated form" },
  MonthAbbreviatedNov: { id: "MonthAbbreviatedNov", value: "Nov", comment: "Month in abbreviated form" },
  MonthAbbreviatedOct: { id: "MonthAbbreviatedOct", value: "Oct", comment: "Month in abbreviated form" },
  MonthAbbreviatedSep: { id: "MonthAbbreviatedSep", value: "Sep", comment: "Month in abbreviated form" },
  MonthWideApr: { id: "MonthWideApr", value: "April", comment: "Month in wide form" },
  MonthWideAug: { id: "MonthWideAug", value: "August", comment: "Month in wide form" },
  MonthWideDec: { id: "MonthWideDec", value: "December", comment: "Month in wide form" },
  MonthWideFeb: { id: "MonthWideFeb", value: "February", comment: "Month in wide form" },
  MonthWideJan: { id: "MonthWideJan", value: "January", comment: "Month in wide form" },
  MonthWideJuly: { id: "MonthWideJuly", value: "July", comment: "Month in wide form" },
  MonthWideJune: { id: "MonthWideJune", value: "June", comment: "Month in wide form" },
  MonthWideLowerCaseApr: { id: "MonthWideApr", value: "april", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseAug: { id: "MonthWideAug", value: "august", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseDec: { id: "MonthWideDec", value: "december", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseFeb: { id: "MonthWideFeb", value: "february", comment: "Month in wide form - in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseJan: { id: "MonthWideJan", value: "january", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseJuly: { id: "MonthWideJuly", value: "july", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseJune: { id: "MonthWideJune", value: "june", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseMar: { id: "MonthWideMar", value: "march", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseMay: { id: "MonthWideMay", value: "may", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseNov: { id: "MonthWideNov", value: "november", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseOct: { id: "MonthWideOct", value: "october", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideLowerCaseSep: { id: "MonthWideSep", value: "september", comment: "Month in lower case form,in some languages/situations this must be lower case (but not english)" },
  MonthWideMar: { id: "MonthWideMar", value: "March", comment: "Month in wide form" },
  MonthWideMay: { id: "MonthWideMay", value: "May", comment: "Month in wide form" },
  MonthWideNov: { id: "MonthWideNov", value: "November", comment: "Month in wide form" },
  MonthWideOct: { id: "MonthWideOct", value: "October", comment: "Month in wide form" },
  MonthWideSep: { id: "MonthWideSep", value: "September", comment: "Month in wide form" },
  More: { id: "More", value: "More", comment: "Text indicating more buttons or form content" },
  MoreActions: { id: "MoreActions", value: "More actions", comment: "Text on the more actions button indictating hidden functions" },
  MoveToLeft: { id: "MoveToLeft", value: "Move to left", comment: "Button tooltip used in a list of movable items" },
  MoveToRight: { id: "MoveToRight", value: "Move to right", comment: "Button tooltip used in a list of movable items" },
  MsgDirty: { id: "MsgDirty", value: ", Modified", comment: "for modified form fields" },
  Neutral: { id: "Neutral", value: "Neutral", comment: "This corresponds to a neutral color" },
  New: { id: "New", value: "New", comment: "Any generic new thing" },
  NewDarkTheme: { id: "NewDarkTheme", value: "New dark", comment: "The name of an application Theme" },
  NewDocument: { id: "NewDocument", value: "New document", comment: "New document tooltip" },
  NewEvent: { id: "NewEvent", value: "New event", comment: "Menu item for adding a new calendar event." },
  NewEventDetails: { id: "NewEventDetails", value: "New event details", comment: "Placholder text for adding a new calendar event." },
  NewHighContrastTheme: { id: "NewHighContrastTheme", value: "New high contrast", comment: "The name of an application Theme" },
  NewItem: { id: "NewItem", value: "New item", comment: "New item in listbuilder" },
  NewLightTheme: { id: "NewLightTheme", value: "New light", comment: "The name of an application Theme" },
  NewRow: { id: "New", value: "New", comment: "Indicates a new row added in the datagrid" },
  NewWindow: { id: "NewWindow", value: "New window", comment: "Contents open in a new browser window." },
  Next: { id: "Next", value: "Next", comment: "Generic next for a tooltip, see Next Record and Next Page for more specific" },
  NextImage: { id: "NextImage", value: "Next image", comment: "Move to the next image in the media gallery navigation" },
  NextMonth: { id: "NextMonth", value: "Next month", comment: "The label for the button that moves calendar to next/prev" },
  NextPage: { id: "NextPage", value: "Next page", comment: "Move to next item on Pager component" },
  NextRecord: { id: "NextRecord", value: "Next record", comment: "Can be used as a tooltip for arrow navigation on a form moving between records" },
  NextWeek: { id: "NextWeek", value: "Next week", comment: "The label for the button that moves calendar to next/prev" },
  NextYear: { id: "NextYear", value: "Next year", comment: "The label for the button that moves calendar to next/prev" },
  No: { id: "No", value: "No", comment: "On a dialog button" },
  NoCommentsEntered: { id: "NoCommentsEntered", value: "No comments entered", comment: "Placeholder for where no comments are added." },
  NoData: { id: "NoData", value: "No data available", comment: "Shown when there is no rows shown in a list" },
  NoDataFilter: { id: "NoDataFilter", value: "No data available, make a new filter selection to see more results.", comment: "Shown when there is no rows shown in a list" },
  NoDataList: { id: "NoDataList", value: "No data available, make a selection in the list above to see more results.", comment: "Shown when there is no rows shown in a list" },
  NoResults: { id: "NoResults", value: "No results", comment: "Search Results Text" },
  NoResultsFound: { id: "NoResultsFound", value: "No results found", comment: "Search Results Text" },
  NoRecordSelected: { id: "NoRecordSelected", value: "0 records selected", comment: "Text showing no records selected" },
  NoTitle: { id: "NoTitle", value: "(No title)", comment: "Placeholder text for when you add an event to the calendar with no title typed." },
  None: { id: "None", value: "None", comment: "None to pick clear color" },
  Normal: { id: "Normal", value: "Normal", comment: "Normal row height" },
  Norwegian: { id: "Norwegian", value: "Norwegian", comment: "Language name for Norwegian" },
  NotSelected: { id: "NotSelected", value: "Not selected", comment: "Not selected in icons for filtering" },
  Notes: { id: "Notes", value: "Notes", comment: "Notes icon tooltip" },
  NumberList: { id: "NumberList", value: "Number list", comment: "Number list tooltip" },
  Ok: { id: "Ok", value: "Ok", comment: "Ok button on a dialog" },
  OperatingSystem: { id: "OperatingSystem", value: "Operating system", comment: "Device operating system" },
  Orange: { id: "Orange", value: "Orange", comment: "Refers to an orange color band" },
  OrderedList: { id: "OrderedList", value: "Insert/remove numbered list", comment: "Insert an ordered list in the editor" },
  Page: { id: "Page", value: "page ", comment: "Text on the pager links" },
  PageOf: { id: "PageOf", value: "Page {0} of {1}", comment: "Pager text Showing current and number of pages" },
  PageOn: { id: "PageOn", value: "You are currently on page ", comment: "Text on the pager links" },
  Pagination: { id: "Pagination", value: "Pagination", comment: "Text for a pager region on the page" },
  PaidTimeOff: { id: "PaidTimeOff", value: "Paid time off", comment: "As in vacation from work" },
  PasswordConfirmValidation: { id: "PasswordConfirmValidation", value: "Password must match", comment: "Password confirm validation" },
  PasswordValidation: { id: "PasswordValidation", value: "<strong>Password must</strong><br>Be at least 10 characters long<br>Have at least one upper case character<br>Have at least one lower case character<br>Contain one special character<br>Not contain your username<br>Can not be a Previously used password<br>", comment: "Password validation requirements" },
  Paste: { id: "Paste", value: "Paste", comment: "Paste icon tooltip" },
  Peak: { id: "Peak", value: "Peak", comment: "the max or peak value in a chart" },
  Pending: { id: "Pending", value: "Pending", comment: "An event or task is pending" },
  Period: { id: "Period", value: "Period", comment: "the am/pm portion of a time" },
  Personalization: { id: "Personalization", value: "Personalization", comment: "Refers to changing a personalization in the application like a color." },
  PersonalizeColumns: { id: "PersonalizeColumns", value: "Personalize columns", comment: "Customize columns in a grid" },
  Plan: { id: "Plan", value: "Plan", comment: "As in type of vacation plan" },
  Platform: { id: "Platform", value: "Platform", comment: "The users operating system i.e. mac, windows" },
  Polish: { id: "Polish", value: "Polish", comment: "Language name for Polish" },
  Portuguese: { id: "Portuguese", value: "Portuguese", comment: "Language name for Portuguese" },
  PressDown: { id: "PressDown", value: "Press down arrow to select", comment: "The audible label for Tooltip about how to operate a picker" },
  PressShiftF10: { id: "PressShiftF10", value: "Press Shift+F10 to open the context menu.", comment: "the audible infor for screen readers on how to use a field with a popup menu" },
  Previous: { id: "Previous", value: "Previous", comment: "Generic previous for a tooltip, see next record and next page for more specific" },
  PreviousImage: { id: "PreviousImage", value: "Previous image", comment: "Move to the previous image in the media gallery navigation" },
  PreviousMonth: { id: "PreviousMonth", value: "Previous month", comment: "the label for the button that moves calendar to next/prev" },
  PreviousPage: { id: "PreviousPage", value: "Previous page", comment: "Move to next item on Pager component" },
  PreviousRecord: { id: "PreviousRecord", value: "Previous record", comment: "Can be used as a tooltip for arrow navigation on a form moving between records" },
  PreviousWeek: { id: "PreviousWeek", value: "Previous week", comment: "the label for the button that moves calendar to next/prev" },
  PreviousYear: { id: "PreviousYear", value: "Previous year", comment: "the label for the button that moves calendar to next/prev" },
  Print: { id: "Print", value: "Print", comment: "Print tooltip" },
  Purple: { id: "Purple", value: "Purple", comment: "Refers to an purple color band" },
  Range: { id: "Range", value: "Range", comment: "Range for tooltip" },
  RecordsPerPage: { id: "RecordsPerPage", value: "{0} records per page", comment: "Shows an actual number of pages in the pager" },
  RecordsPerPageNoToken: { id: "RecordsPerPageNoToken", value: "Records per page", comment: "Shows as a title list of values for page number (without the slot/token value)" },
  RecordSelected: { id: "RecordSelected", value: "{0} record selected", comment: "Text showing current total of record selected" },
  RecordsSelected: { id: "RecordsSelected", value: "{0} records selected", comment: "Text showing current total of records selected" },
  Red: { id: "Red", value: "Red", comment: "This corresponds to a red color" },
  Redo: { id: "Redo", value: "Redo", comment: "Redo tooltip" },
  Refresh: { id: "Refresh", value: "Refresh", comment: "Refresh tooltip" },
  ReorderRows: { id: "ReorderRows", value: "Reorder rows", comment: "Drag and Reorder Grid Rows" },
  RequestTimeOff: { id: "RequestTimeOff", value: "Request time off", comment: "Making a request for time off work." },
  Required: { id: "Required", value: "Required", comment: "indicates a form field is manditory" },
  Reset: { id: "Reset", value: "Reset", comment: "Reset tooltip" },
  ResetDefault: { id: "ResetDefault", value: "Reset to default", comment: "Reset datagrid columns, filter and other layout" },
  Result: { id: "Result", value: "({0} result)", comment: "Showing a single result in a list" },
  ResultOf: { id: "ResultOf", value: "{0} of {1} result", comment: "Text Showing current and total number of result" },
  Results: { id: "Results", value: "({0} results)", comment: "As in showing {n} results (plural) in a list" },
  ResultsOf: { id: "ResultsOf", value: "{0} of {1} results", comment: "Text showing current and total number of results" },
  Right: { id: "Right", value: "Right", comment: "Right" },
  RightAlign: { id: "RightAlign", value: "Align right", comment: "Right Align tooltip" },
  Roles: { id: "Roles", value: "Roles", comment: "Roles tooltip" },
  Romanian: { id: "Romanian", value: "Romanian", comment: "Language name for Romanian" },
  RowHeight: { id: "RowHeight", value: "Row Height", comment: "Describes the height for rows in a Data Grid" },
  Ruby: { id: "Ruby", value: "Ruby", comment: "Color in our color palette" },
  RunFilter: { id: "RunFilter", value: "Run filter", comment: "Execute the current filter criteria" },
  Russian: { id: "Russian", value: "Russian", comment: "Language name for Russian" },
  SameWindow: { id: "SameWindow", value: "Same window", comment: "Contents open in the same browser window." },
  Save: { id: "Save", value: "Save", comment: "Save tooltip" },
  SaveCurrentView: { id: "SaveCurrentView", value: "Save current view", comment: "Datagrids contain view sets. This menu option saves them" },
  SavedViews: { id: "SavedViews", value: "Saved views", comment: "Label for a list of Views" },
  Schedule: { id: "Schedule", value: "Schedule", comment: "Shows a schedule view" },
  Search: { id: "Search", value: "Search", comment: "Search tooltip" },
  SearchColumnName: { id: "SearchColumnName", value: "Search for a column name", comment: "Search for a datagrid column by name" },
  SearchFolder: { id: "SearchFolder", value: "Search in folder", comment: "Search Folder tooltip" },
  SearchList: { id: "SearchList", value: "Search list", comment: "Search list tooltip" },
  Second: { id: "Second", value: "Second", comment: "Test use in calendar" },
  Seconds: { id: "Seconds", value: "Seconds", comment: "the seconds portion of a time" },
  Select: { id: "Select", value: "Select", comment: "text describing a select action" },
  SelectAll: { id: "SelectAll", value: "Select all", comment: "Describes the action of selecting all items available in a list" },
  SelectDay: { id: "SelectDay", value: "Select a day", comment: "Select a day in the calendar picker" },
  Selected: { id: "Selected", value: "Selected", comment: "Text describing a selected object" },
  SelectedOptions: { id: "SelectedOptions", value: "Selected options", comment: "shown on a list of selected dropdown options (generic)" },
  Selection: { id: "Selection", value: "Selection", comment: "Text describing current selections in a field" },
  Send: { id: "Send", value: "Send", comment: "Send tooltip" },
  Serbian: { id: "Serbian", value: "Serbian", comment: "Serbian language" },
  SetTime: { id: "SetTime", value: "Set time", comment: "Button that sets time in a field" },
  Settings: { id: "Settings", value: "Settings", comment: "Settings tooltip" },
  Short: { id: "Short", value: "Short", comment: "Describes a shorted row height in a grid/list" },
  Show: { id: "Show", value: "Show", comment: "On a Button for revealing text that is hidden" },
  ShowEvent: { id: "ShowEvent", value: "Show event", comment: "Show an event (in a calendar)" },
  ShowFilterRow: { id: "ShowFilterRow", value: "Show filter row", comment: "Toggle a row with filer info above a list" },
  ShowLess: { id: "ShowLess", value: "Show less", comment: "Show less form content" },
  ShowMore: { id: "ShowMore", value: "Show more", comment: "Show more form content" },
  SickTime: { id: "SickTime", value: "Sick time", comment: "Time off sick from work" },
  SkipToMain: { id: "SkipToMain", value: "Skip to main content", comment: "Skip link in header, jumps when clicked on to main area" },
  Slate: { id: "Slate", value: "Slate", comment: "Color in our color palette" },
  SlideOf: { id: "SlideOf", value: "Slide {0} of {1}", comment: "Slide text showing current and total number of slides" },
  SliderHandle: { id: "SliderHandle", value: "Handle for", comment: "Description of the portion of a Slider control that is focusable and changes its value, followed in code by the name of the control" },
  SliderMaximumHandle: { id: "SliderMaximumHandle", value: "Maximum range handle for", comment: "Describes a maximum value handle in a range (double slider), followed in code by the name of the control" },
  SliderMinimumHandle: { id: "SliderMinimumHandle", value: "Minimum range handle for", comment: "Describes a minimum value handle in a range (double slider), followed in code by the name of the control" },
  SlidesOf: { id: "SlidesOf", value: "Slides {0} and {1} of {2}", comment: "Slides Text Showing current slides and total number of slides" },
  Slovak: { id: "Slovak", value: "Slovak", comment: "Language name for Slovak (Slovakia)" },
  Slovenian: { id: "Slovenian", value: "Slovenian", comment: "Language name for Slovenian" },
  Small: { id: "Small", value: "Small", comment: "A more small grid setting for rows and sizes." },
  SortAtoZ: { id: "SortAtoZ", value: "Sort ascending", comment: "Sort A to Z in icons for filtering" },
  SortDown: { id: "SortDown", value: "Sort down", comment: "Sort Down tooltip" },
  SortUp: { id: "SortUp", value: "Sort Up", comment: "Sort Up tooltip" },
  SortZtoA: { id: "SortZtoA", value: "Sort descending", comment: "Sort Z to A in icons for filtering" },
  Spanish: { id: "Spanish", value: "Spanish", comment: "Language name for Spanish" },
  SplitterCollapseButton: { id: "SplitterCollapseButton", value: "Collapse splitter", comment: "Action to move the position of splitter either to left or right" },
  SplitterDragHandle: { id: "SplitterDragHandle", value: "Drag To adjust", comment: "Drags the splitter handle" },
  StartsWith: { id: "StartsWith", value: "Starts with", comment: "For condition filtering" },
  Status: { id: "Status", value: "Status", comment: "Status thats submitted fx in progress, approved" },
  StepsCompleted: { id: "StepsCompleted", value: "{0} of {1} steps completed", comment: "steps of a wizard/chart" },
  StrikeThrough: { id: "StrikeThrough", value: "Strike through", comment: "Edit text to have a strike through it in an editor" },
  String: { id: "String", value: "String", comment: "As in a text string" },
  Strings: { id: "Strings", value: "Strings", comment: "As in a text strings" },
  Subject: { id: "Subject", value: "Subject", comment: "The subject of an calendar event." },
  Success: { id: "Success", value: "Success", comment: "For a success message on screen" },
  Submit: { id: "Submit", value: "Submit", comment: "Submit on a modal dialog" },
  Subscript: { id: "Subscript", value: "Subscript", comment: "Turn on and off subscript text in text editor (like word)" },
  Subtle: { id: "Subtle", value: "Subtle", comment: "The title of one of the application themes." },
  Superscript: { id: "Superscript", value: "Superscript", comment: "Turn on and off superscript text in text editor (like word)" },
  Swedish: { id: "Swedish", value: "Swedish", comment: "Language name for Swedish" },
  Tabs: { id: "Tabs", value: "Tabs...", comment: "Used in the tabs component more menu, preceeded by a number that describes how many tabs are in the spillover menu" },
  Tack: { id: "Tack", value: "Pin", comment: "Pin an object" },
  Tagalog: { id: "Tagalog", value: "Tagalog", comment: "Language name for Tagalog (Philippines)" },
  Tall: { id: "Tall", value: "Tall", comment: "Describes a taller row height in a grid/list" },
  Target: { id: "Target", value: "Target", comment: "Label for an input to enter a Target (Url Attribute)" },
  TeamEvent: { id: "TeamEvent", value: "Team event", comment: "Having an event with a work team" },
  Teal: { id: "Teal", value: "Teal", comment: "Refers to an teal color band" },
  TestLocaleDefaults: { id: "TestLocaleDefaults", value: "Test locale defaults", comment: "Do not translate" },
  TextBtnCancel: { id: "TextBtnCancel", value: "Cancel uploading this file", comment: "text for cancel button for advanced fileupload" },
  TextBtnCloseError: { id: "TextBtnCloseError", value: "Close this error", comment: "text for error close button for advanced fileupload" },
  TextBtnRemove: { id: "TextBtnRemove", value: "Close this error", comment: "text for remove button for advanced fileupload" },
  TextColor: { id: "TextColor", value: "Text color", comment: "add or edit text color in the editor" },
  TextDropArea: { id: "DropArea", value: "Drag and drop files to upload", comment: "Text for drop area for advanced fileupload" },
  TextDropAreaWithBrowse: { id: "TextDropAreaWithBrowse", value: 'Drag and drop here or <span class="hyperlink">upload files</span> to upload', comment: "Note please recheck, dont translate the <span> markup please" },
  TextDropAreaWithBrowseLink: { id: "TextDropAreaWithBrowse", value: "Drag and drop here or {browseLink}", comment: "Updated recently" },
  Thai: { id: "Thai", value: "Thai", comment: "Language name for Thai" },
  Theme: { id: "Theme", value: "Theme", comment: "Refers to an application theme" },
  ThousandsAbbrev: { id: "ThousandsAbbrev", value: "{0}k", comment: "Refers to a value in a chart in thousands. i.e. 1K, 100K" },
  Time: { id: "Time", value: "Time", comment: "The time part of a date" },
  Timer: { id: "Timer", value: "Timer", comment: "Timer tooltip" },
  To: { id: "To", value: "To", comment: "End of a range (of dates)" },
  Today: { id: "Today", value: "Today", comment: "refering to today on a calendar" },
  ToggleBold: { id: "ToggleBold", value: "Toggle bold text", comment: "turn on and off bold in text editor (like word) please check this for thai see https://github.com/infor-design/enterprise/issues/4738" },
  ToggleH3: { id: "ToggleH3", value: "Toggle heading 3", comment: "Turn on and off heading 3 text" },
  ToggleH4: { id: "ToggleH4", value: "Toggle heading 4", comment: "Turn on and off heading 4 text" },
  ToggleItalic: { id: "ToggleItalic", value: "Toggle italic text", comment: "turn on and off Italic in text editor (like word)" },
  ToggleUnderline: { id: "ToggleUnderline", value: "Toggle underline text", comment: "turn on and off Underline in text editor (like word) please check this for thai https://github.com/infor-design/enterprise/issues/4738" },
  Toolbar: { id: "Toolbar", value: "Toolbar", comment: "describing the toolbar component" },
  TopAlign: { id: "TopAlign", value: "Top align", comment: "Top Align tooltip" },
  Total: { id: "Total", value: "Total", comment: "Mathematic total of a calculation" },
  Totals: { id: "Totals", value: "Totals", comment: "Mathematic total of a calculation (plural)" },
  TreeCollapse: { id: "TreeCollapse", value: "Collapse tree", comment: "Tree collapse tooltip" },
  TreeExpand: { id: "TreeExpand", value: "Expand tree", comment: "Tree expand tooltip" },
  TrillionsAbbrev: { id: "TrillionsAbbrev", value: "{0}T", comment: "Refers to a value in a chart in billions. i.e. 1B, 100B" },
  Turkish: { id: "Turkish", value: "Turkish", comment: "Language name for Turkish" },
  Turquoise: { id: "Turquoise", value: "Turquoise", comment: "Color in our color palette" },
  Type: { id: "Type", value: "Type", comment: "The type of event." },
  TypeToFilter: { id: "TypeToFilter", value: "Type to filter", comment: "Screen reader hit for screen reader users." },
  Ukrainian: { id: "Ukrainian", value: "Ukrainian", comment: "Language name for Ukrainian" },
  UnavailableDate: { id: "UnavailableDate", value: "Unavailable date", comment: "Unavailable date text" },
  Underline: { id: "Underline", value: "Underline", comment: "Make text underlined" },
  Undo: { id: "Undo", value: "Undo", comment: "Undo tooltip" },
  Unlocked: { id: "Unlocked", value: "Unlocked", comment: "Unlocked tooltip" },
  UnorderedList: { id: "UnorderedList", value: "Insert/remove bulleted list", comment: "Insert an unordered list in the editor" },
  Unsupported: { id: "Unsupported", value: "This content is not available because it uses features not supported in your current browser version.", comment: "Suggesting browser upgrade for missing features." },
  Up: { id: "Up", value: "Up", comment: "Up tooltip" },
  UpComing: { id: "UpComing", value: "Upcoming", comment: "List of upcoming things (general)" },
  UpComingEvents: { id: "UpComingEvents", value: "Upcoming events", comment: "List of upcoming calendar events" },
  UpComingTimeOff: { id: "UpComingTimeOff", value: "Upcoming time off", comment: "As in time off work" },
  UpliftDarkTheme: { id: "UpliftDarkTheme", value: "Uplift dark", comment: "The name of an application Theme" },
  UpliftHighContrastTheme: { id: "UpliftHighContrastTheme", value: "Uplift high contrast", comment: "The name of an application Theme" },
  UpliftLightTheme: { id: "UpliftLightTheme", value: "Uplift light", comment: "The name of an application Theme" },
  Upload: { id: "Upload", value: "Upload", comment: "Upload tooltip" },
  UploadDropArea: { id: "UploadDropArea", value: "Drag and drop here to upload files" },
  UploadErrorMaxFiles: { id: "UploadErrorMaxFiles", value: "<em>Error</em> Cannot upload more than the maximum number of files ({maxFiles})" },
  UploadErrorMaxFilesInProgress: { id: "UploadErrorMaxFiles", value: "<em>Error</em> Exceeded maximum files allowed" },
  UploadErrorMaxFileSize: { id: "UploadErrorMaxFileSize", value: "<em>Error</em> Exceeded file size limit" },
  UploadErrorAcceptedFileType: { id: "UploadErrorAcceptedFileType", value: "<em>Error</em> File type is not allowed" },
  UploadErrorUrl: { id: "UploadErrorUrl", value: "<em>Error</em> Url not found" },
  UploadErrorXHRHeaders: { id: "UploadErrorUrl", value: "<em>Error</em> Request Headers must be a valid JSON string" },
  UploadLink: { id: "UploadLink", value: "upload files" },
  UploadCancel: { id: "UploadCancel", value: "Cancel uploading this file" },
  UploadCancelAll: { id: "UploadCancelAll", value: "Cancel all" },
  UploadDismissError: { id: "UploadDismissError", value: "Dismiss this error" },
  UploadProgressLabel: { id: "UploadProgressLabel", value: "{file-name} uploaded {loaded} out of {size} ({percent}%)", comment: "Contents in {} are dynamically inserted" },
  UploadRemoveFile: { id: "UploadRemoveFile", value: "Remove this file" },
  UploadStart: { id: "UploadStart", value: "Start uploading this file" },
  Url: { id: "Url", value: "Url", comment: "Universal resource locator (web internet)" },
  UseArrow: { id: "UseArrow", value: ". Use arrow keys to select.", comment: "Instructional comments for screen readers" },
  UseEnter: { id: "UseEnter", value: ". Use enter or down arrow to lookup.", comment: "Instructional comments for screen readers" },
  User: { id: "User", value: "User", comment: "User tooltip" },
  UserProfile: { id: "UserProfile", value: "User profile", comment: "User Profile tooltip" },
  Variant: { id: "Variant", value: "Variant", comment: "Refers to an application variant (a slight UI change/variation)" },
  Version: { id: "Version", value: "IDS version", comment: "Version of IDS" },
  Versions: { id: "Versions", value: "Versions", comment: "A selection of versions of the styles" },
  VerticalMiddleAlign: { id: "VerticalMiddleAlign", value: "Vertical align center", comment: "Vertical Align tooltip" },
  Vibrant: { id: "Vibrant", value: "Vibrant", comment: "The title of one of the application themes." },
  VideoSupportMessage: { id: "VideoSupportMessage", value: "Your browser does not support the video tag.", comment: "Video tag browser support message" },
  Vietnamese: { id: "Vietnamese", value: "Vietnamese", comment: "Language name for Vietnamese" },
  ViewSource: { id: "ViewSource", value: "View source", comment: "Toggle between the source view and visual view" },
  ViewVisual: { id: "ViewVisual", value: "View visual", comment: "Toggle between the source view and visual view" },
  Warning: { id: "Warning", value: "Warning", comment: "As in a warning message on screen" },
  White: { id: "White", value: "White", comment: "Refers to an white color band" },
  Week: { id: "Week", value: "Week", comment: "Shows a view of the current weeks events" },
  WeekNumber: { id: "WeekNumber", value: "W#", comment: "Week view number header on the datepicker" },
  Year: { id: "Year", value: "Year", comment: "As in a date year" },
  Yellow: { id: "Yellow", value: "Yellow", comment: "This corresponds to a yellow color" },
  Yes: { id: "Yes", value: "Yes", comment: "On a dialog button" },
  ZoomFit: { id: "ZoomFit", value: "Zoom fit", comment: "On a media gallery button" },
  ZoomIn: { id: "ZoomIn", value: "Zoom in", comment: "On a media gallery button" },
  ZoomOut: { id: "ZoomOut", value: "Zoom out", comment: "On a media gallery button" }
};

// src/components/ids-locale/ids-locale.ts
var IdsLocale = class {
  // State object
  state;
  loadedLocales = /* @__PURE__ */ new Map();
  loadedLanguages = /* @__PURE__ */ new Map();
  localeDataPath = "../locale-data/";
  twoDigitYearCutoff = 39;
  constructor() {
    this.loadedLocales.set("en-US", en_US_default);
    this.loadedLanguages.set("en", en_messages_default);
    this.state = {
      defaultLocale: {
        language: "en",
        localeName: "en-US"
      },
      language: "en",
      localeName: "en-US"
    };
    this.setDefaults();
  }
  /**
   * Set the Defaut language and locale
   */
  async setDefaults() {
    const defaultLang = "en";
    const defaultLocale = "en-US";
    await this.setLanguage(defaultLang, false);
    await this.setLocale("en-US", false);
    this.state.defaultLocale.messages = this.language.messages;
    this.state.defaultLocale.language = defaultLang;
    this.state.defaultLocale.localeName = defaultLocale;
  }
  // Holds a single instance of Intl
  dateFormatter;
  // Locale name (code)
  name = "en-US";
  /**
   * Set the language for a component
   * @param {string} value The language string value
   */
  set language(value) {
    const lang = this.#correctLanguage(value);
    if (value && lang !== this.state.language) {
      this.setLanguage(lang, false);
    }
  }
  /**
   * Get the language data
   * @returns {object} The language data
   */
  get language() {
    return {
      name: this.state.language,
      messages: this.loadedLanguages.get(this.state.language) || {}
    };
  }
  /**
   * Maps a language value to a more correct one
   * @private
   * @param {string} value the starting language string
   * @returns {string} the updated language string
   */
  #correctLanguage(value) {
    let lang = value?.replace("-messages", "");
    const translated = /* @__PURE__ */ new Set(["fr-CA", "fr-FR", "pt-BR", "pt-PT", "zh-CN", "zh-Hans", "zh-Hant", "zh-TW"]);
    if (translated.has(lang)) {
      return lang;
    }
    lang = lang.substring(0, 2);
    if (lang === "in") {
      lang = "id";
    }
    if (lang === "iw") {
      lang = "he";
    }
    return lang;
  }
  /**
   * Load a locale or message file
   * @private
   * @param {string} value The script file name
   * @returns {Promise} A promise that will resolve when complete
   */
  loadLanguageScript(value) {
    const promise = fetch(`${this.localeDataPath}${value}-messages.json`);
    promise.then(async (response) => {
      const data = await response.json();
      this.loadedLanguages.set(value, data);
    });
    return promise;
  }
  /**
   * Maps a locale value to a more correct one
   * @private
   * @param {string} value the starting locale string
   * @returns {string} the updated locale string
   */
  #correctLocale(value) {
    let locale = value;
    if (locale === "in-ID") {
      locale = "id-ID";
    }
    if (locale?.substr(0, 2) === "iw") {
      locale = "he-IL";
    }
    return locale;
  }
  /** Holds the last set locale to prevent up processing */
  previousLocale = "en-US";
  /**
   * Set the locale for a component and wait for it to finish (async)
   * @param {string} value The locale string value
   * @param {boolean} notify Do not notify children if false
   */
  async setLocale(value, notify = true) {
    if (!value || this.previousLocale === value) {
      return;
    }
    const locale = this.#correctLocale(value);
    if (this.name !== locale) {
      this.name = locale;
      this.state.localeName = locale;
      if (!this.loadedLocales.get(this.name)) {
        await this.loadLocaleScript(locale);
      }
      await this.setLanguage(locale, false);
      const lang = this.correctLanguage(value);
      if (!this.loadedLanguages.get(lang)) {
        await this.loadLanguageScript(lang);
      }
    }
    if (notify) {
      this.#notifyElementsLocale();
      this.#notifyElementsLanguage();
    }
    this.previousLocale = value;
  }
  /**
   * Notify every component of locale changes
   */
  #notifyElementsLocale() {
    querySelectorAllShadowRoot("*").forEach((elem) => {
      if (this.previousLocale !== this.name && elem.nodeName.substring(0, 4) === "IDS-" && elem.localeAPI) {
        elem.setAttribute("locale", this.name);
        if (typeof elem.onLocaleChange === "function") {
          elem.onLocaleChange(this);
        }
        if (elem.triggerEvent) {
          elem.triggerEvent("localechange", elem, { detail: { elem, language: this.language, locale: this.state?.locale } });
        }
      }
    });
  }
  /**
   * Notify every component of language changes
   */
  #notifyElementsLanguage() {
    querySelectorAllShadowRoot("*").forEach((elem) => {
      if (elem.getAttribute("language") !== this.language.name && elem.nodeName.substring(0, 4) === "IDS-" && elem.localeAPI) {
        elem.setAttribute("language", this.language.name);
        if (typeof elem.onLanguageChange === "function") {
          elem.onLanguageChange(this);
        }
        if (elem.triggerEvent) {
          elem.triggerEvent("languagechange", elem, { detail: { elem, language: this.language, locale: this.state?.locale } });
        }
        this.updateDirectionAttribute(elem, this.language.name);
      }
    });
  }
  /**
   * Load a locale file
   * @private
   * @param {string} value The script file name
   * @returns {Promise} A promise that will resolve when complete
   */
  async loadLocaleScript(value) {
    const promise = fetch(`${this.localeDataPath}${value}.json`);
    await promise.then(async (response) => {
      const data = await response.json();
      this.loadedLocales.set(value, data);
    });
    return promise;
  }
  /**
   * Sets the lang (language) tag on an element
   * @param {string} value The value to check
   */
  setDocumentLangAttribute(value) {
    const htmlElem = document?.querySelector("html");
    if (value && htmlElem && htmlElem.getAttribute("lang") !== value) {
      htmlElem.setAttribute("lang", value);
      return;
    }
    if (!value && htmlElem) {
      document?.querySelector("html")?.removeAttribute("lang");
    }
  }
  /**
   * Sets the dir (direction) tag on an element
   * @param {HTMLElement} elem The element to set it on.
   * @param {string} value The value to check
   */
  updateDirectionAttribute(elem, value) {
    if (this.isRTL(value)) {
      elem.setAttribute("dir", "rtl");
      return;
    }
    elem.removeAttribute("dir");
  }
  /**
   * Set the language for a component and wait for it to finish (async)
   * @param {string} value The language string value
   * @param {boolean} notify notify about the language
   */
  async setLanguage(value, notify = true) {
    const lang = this.correctLanguage(value);
    if (this.state.language !== lang) {
      this.state.language = lang;
    }
    if (this.state.language === lang && !this.loadedLanguages.get(this.state.language)) {
      await this.loadLanguageScript(lang);
    }
    this.setDocumentLangAttribute(lang);
    if (notify) this.#notifyElementsLanguage();
  }
  /**
   * Maps a language value to a more correct one
   * @private
   * @param {string} value the starting language string
   * @returns {string} the updated language string
   */
  correctLanguage(value) {
    let lang = value?.replace("-messages", "");
    const translated = /* @__PURE__ */ new Set(["fr-CA", "fr-FR", "pt-BR", "pt-PT", "zh-CN", "zh-Hans", "zh-Hant", "zh-TW"]);
    if (translated.has(lang)) {
      return lang;
    }
    lang = lang.substring(0, 2);
    if (lang === "in") {
      lang = "id";
    }
    if (lang === "iw") {
      lang = "he";
    }
    return lang;
  }
  /**
   * Takes a translation key and returns the translation in the current locale
   * @param {string} key  The key to search for on the string
   * @param {object} [options] Supports showBrackets and maybe more in the future
   * @returns {string|undefined} a translated string, or nothing, depending on configuration
   */
  translate(key, options = { showAsUndefined: false, showBrackets: true }) {
    if (key === "&nsbp;") {
      return "";
    }
    if (!options?.showAsUndefined && options?.showBrackets === void 0) {
      options.showBrackets = true;
    }
    let messages = this.language.messages;
    if (options?.language) {
      messages = this.loadedLanguages.get(options?.language) || messages;
    }
    if (!messages[key]) {
      if (options.showAsUndefined) {
        return void 0;
      }
      messages = this.state.defaultLocale?.messages;
      if (!messages || !messages[key]) {
        return `${options.showBrackets ? "[" : ""}${key}${options.showBrackets ? "]" : ""}`;
      }
      return this.state.defaultLocale.messages[key].value;
    }
    return messages[key].value;
  }
  /**
   * Add an object full of translations to the given locale.
   * @param {string} lang The language to add them to.
   * @param {object} messages Strings in the form of
   */
  extendTranslations(lang, messages) {
    if (!this.loadedLanguages.has(lang)) {
      return;
    }
    const base = this.loadedLanguages.get(lang);
    Object.keys(messages).forEach((key) => {
      base[key] = messages[key];
    });
    this.loadedLanguages.set(lang, base);
  }
  /**
   * Set the locale for a component
   * @param {string} value The locale string value
   */
  set locale(value) {
    const locale = this.#correctLocale(value);
    if (value && locale !== this.state.localeName) {
      this.setLocale(locale, false);
    }
  }
  /**
   * Get the locale data
   * @returns {object} The language data
   */
  get locale() {
    return {
      name: this.state.localeName,
      options: this.loadedLocales.get(this.state.localeName) || {}
    };
  }
  /**
   * Format a number using the locale information
   * @param {string} value the starting locale string
   * @param {object} [options] the objects to use for formatting
   * @returns {string} the formatted number
   */
  formatNumber(value, options) {
    let opts = options;
    let val = value;
    const usedLocale = opts?.locale || this.state.localeName;
    if (!opts) {
      opts = {};
    }
    if (opts?.originLocale === void 0) opts.originLocale = "en-US";
    if (opts?.locale === void 0) opts.locale = "en-US";
    if (opts?.minimumFractionDigits === void 0 && !opts?.maximumFractionDigits) {
      opts.minimumFractionDigits = 2;
    }
    if (opts?.useGrouping === void 0 && opts.group === void 0) {
      opts.useGrouping = true;
    }
    opts.useGrouping = opts.useGrouping === true || opts.group !== "" && opts.group !== void 0;
    if (opts?.style === "integer") {
      opts.style = void 0;
      opts.maximumFractionDigits = 0;
      opts.minimumFractionDigits = 0;
    }
    if (typeof value === "string") {
      const parseOpts = opts;
      parseOpts.locale = parseOpts.originLocale;
      const tempGroup = opts.group;
      const tempDecimal = opts.decimal;
      if (opts.group || opts.decimal) {
        parseOpts.group = ",";
        parseOpts.decimal = ".";
      }
      val = this.parseNumber(value, parseOpts);
      if (opts.group || opts.decimal) {
        opts.group = tempGroup;
        opts.decimal = tempDecimal;
      }
    }
    if (typeof value === "string" && value.length >= 18 && value.indexOf(".") === -1 && value.indexOf(",") === -1) {
      return BigInt(value).toLocaleString(usedLocale, opts);
    }
    if (typeof value === "string" && value.length >= 18 && value.indexOf(".") > -1) {
      const index = value.indexOf(".");
      let decimalPart = value.substr(index);
      const intPart = value.substr(0, index);
      const bigInt = BigInt(intPart).toLocaleString(usedLocale);
      decimalPart = Number(decimalPart).toLocaleString(usedLocale, opts);
      return bigInt + decimalPart.substr(1);
    }
    const formattedNum = Number(val).toLocaleString(usedLocale, opts);
    const formatDecimalAndGroup = (num, altOpts) => {
      altOpts.useGrouping = altOpts.useGrouping === true || altOpts.group !== "" && altOpts.group !== void 0;
      let formatNumber = Number(num).toLocaleString("en-US", altOpts);
      if (altOpts?.group) {
        formatNumber = formatNumber.replaceAll(",", "\u2020");
      }
      if (altOpts?.decimal) {
        formatNumber = formatNumber.replaceAll(".", altOpts.decimal);
      }
      if (altOpts?.group) {
        formatNumber = formatNumber.replaceAll("\u2020", !altOpts.useGrouping ? "" : altOpts.group);
      }
      return formatNumber;
    };
    if (opts?.group || opts?.decimal) {
      return formatDecimalAndGroup(val, opts);
    }
    return formattedNum;
  }
  /**
   * Takes a locale formatted number string and converts it back to a real number object.
   * @param {string} input  The source number normally as a string.
   * @param {object} options Any special options to pass in such as the original locale
   * @returns {number} The number as an actual Number type unless the number
   * is a big int (19 significant digits), in this case a string will be returned
   */
  parseNumber(input, options) {
    const localeData = this.loadedLocales.get(options?.locale || this.locale.name);
    const numSettings = localeData.numbers;
    let numString = input;
    if (!numString) {
      return NaN;
    }
    if (typeof input === "number") {
      numString = numString.toString();
    }
    const group = options?.group ? options.group : numSettings.group;
    const decimal = options?.decimal ? options.decimal : numSettings.decimal;
    const percentSign = options?.percentSign ? options.percentSign : numSettings.percentSign;
    const currencySign = options?.currencySign ? options.currencySign : localeData.currencySign;
    const exp = group === " " ? new RegExp(/\s/g) : new RegExp(`\\${group}`, "g");
    numString = numString.replace(exp, "");
    numString = numString.replace(decimal, ".");
    numString = numString.replace(percentSign, "");
    numString = numString.replace(currencySign, "");
    numString = numString.replace("$", "");
    numString = numString.replace(" ", "");
    if (numString.indexOf(".") === -1 && numString.length >= 18) {
      return numString;
    }
    return numString.length >= 19 ? numString : parseFloat(numString);
  }
  /**
   * Convert a number in arabic/chinese or hindi numerals to an "english" number.
   * @param {string} string The string number in arabic/chinese or hindi
   * @returns {number} The english number.
   */
  convertNumberToEnglish(string) {
    const arabic = ["\u0660", "\u0661", "\u0662", "\u0663", "\u0664", "\u0665", "\u0666", "\u0667", "\u0668", "\u0669"];
    const devanagari = ["\u0966", "\u0967", "\u0968", "\u0969", "\u096A", "\u096B", "\u096C", "\u096D", "\u096E", "\u096F"];
    const chineseFinancialTraditional = ["\u96F6", "\u58F9", "\u8CB3", "\u53C4", "\u8086", "\u4F0D", "\u9678", "\u67D2", "\u634C", "\u7396"];
    const chineseFinancialSimplified = ["\u96F6", "\u58F9", "\u8D30", "\u53C1", "\u8086", "\u4F0D", "\u9646", "\u67D2", "\u634C", "\u7396"];
    const chinese = ["\u3007", "\u4E00", "\u4E8C", "\u4E09", "\u56DB", "\u4E94", "\u516D", "\u4E03", "\u516B", "\u4E5D"];
    for (let i = 0; i <= 9; i++) {
      string = string.replace(arabic[i], i);
      string = string.replace("\u066C", "");
      string = string.replace(",", "");
      string = string.replace(devanagari[i], i);
      string = string.replace(chineseFinancialTraditional[i], i);
      string = string.replace(chineseFinancialSimplified[i], i);
      string = string.replace(chinese[i], i);
      if (i === 0) {
        string = string.replace("\u96F6", i);
      }
    }
    return parseFloat(string);
  }
  /**
   * Formats a date object using the current locale or specified settings
   * to a string for Internationalization
   * @param {Date} value The date to show in the current locale.
   * @param {object} options Additional date formatting settings.
   * @returns {string} the formatted date.
   */
  formatDate(value, options) {
    const usedOptions = options;
    const usedLocale = usedOptions?.locale || this.locale.name;
    if (value === void 0 || value === "" || value === null) return "";
    if (options?.dateFormat || options?.format) {
      options.pattern = options.dateFormat || options.format;
    }
    if (options?.pattern && !(value instanceof Date)) {
      value = this.parseDate(value, options);
      if (value === void 0) return "";
    }
    if (options?.pattern && value instanceof Date) {
      const calendar = this.calendar(usedLocale);
      let year = value.getFullYear();
      let month = value.getMonth();
      let day = value.getDate();
      if (calendar.name === "islamic-umalqura") {
        const umalquraParts = gregorianToUmalqura(value);
        year = umalquraParts?.year;
        month = umalquraParts?.month;
        day = umalquraParts?.day;
      }
      const dayOfWeek = value.getDay();
      const hours = value.getHours();
      const mins = value.getMinutes();
      const seconds = value.getSeconds();
      const millis = value.getMilliseconds();
      const pattern = options.pattern;
      let result = "";
      result = pattern.replace("de", "nnnnn").replace("ng\xE0y", "nnnn").replace("th\xE1ng", "t1\xE1ng").replace("den", "nnn").replace("dd", `${day}`.padStart(2, "0")).replace("d", day).replace("yyyy", year).replace("yy", year.toString().substring(4, 2)).replace("y", year);
      const showDayPeriods = pattern.indexOf(" a") > -1 || pattern.indexOf("a") === 0;
      if (showDayPeriods && hours === 0) {
        result = result.replace("hh", "12");
        result = result.replace("h", "12");
      }
      result = result.replace("hh", hours > 12 ? `${hours - 12}`.padStart(2, "0") : `${hours}`.padStart(2, "0")).replace("h", hours > 12 ? `${hours - 12}` : `${hours}`).replace("HH", `${hours}`.padStart(2, "0")).replace("H", `${hours}`).replace("mm", `${mins}`.padStart(2, "0")).replace("ss", `${seconds}`.padStart(2, "0")).replace("SSS", `${millis}`.padStart(3, "0"));
      if (pattern.includes("MMM")) {
        result = result.replace("MMMM", calendar?.months.wide[month] || `${month + 1}`.padStart(2, "0")).replace("MMM", calendar?.months.abbreviated[month] || `${month + 1}`.padStart(2, "0"));
      } else {
        result = result.replace("MM", `${month + 1}`.padStart(2, "0")).replace("M", `${month + 1}`);
      }
      if (showDayPeriods && calendar) {
        result = result.replace(" a", ` ${hours >= 12 ? calendar.dayPeriods[1] : calendar.dayPeriods[0]}`);
        if (pattern.indexOf("a") === 0) {
          result = result.replace("a", ` ${hours >= 12 ? calendar.dayPeriods[1] : calendar.dayPeriods[0]}`);
        }
      }
      if (calendar) {
        result = result.replace("EEEE", calendar.days.wide[dayOfWeek]).replace("EEE", calendar.days.abbreviated[dayOfWeek]).replace("EE", calendar.days.narrow[dayOfWeek]);
      }
      result = result.replace("nnnnn", "de").replace("nnnn", "ng\xE0y").replace("t1\xE1ng", "th\xE1ng").replace("nnn", "den");
      return result.replace(/&lrm;|\u200E/gi, " ").trim();
    }
    let sourceDate = value;
    this.dateFormatter = new Intl.DateTimeFormat(
      usedLocale,
      usedOptions
    );
    if (/^0*$/.test(value)) {
      return "";
    }
    if (typeof value === "string") {
      sourceDate = this.parseDate(sourceDate, options);
    }
    let formattedDate = this.dateFormatter.formatToParts(sourceDate).map(({ type, value: value2 }) => {
      switch (type) {
        case "year":
          return usedOptions?.year === "2-digit" ? value2 : `${this.twoToFourDigitYear(value2)}`;
        default:
          return value2;
      }
    }).join("");
    if (!options || options?.dateStyle === "short" || options?.year === "numeric") {
      formattedDate = formattedDate.replace(", ", " ");
    }
    formattedDate = formattedDate.replace(/ /g, " ");
    return formattedDate;
  }
  /**
   * Convert the two digit year year to the correct four digit year.
   * @param {number} twoDigitYear The two digit year.
   * @returns {number} Converted 3 digit year.
   */
  twoToFourDigitYear(twoDigitYear) {
    if (twoDigitYear.length === 2) {
      return parseInt((twoDigitYear > this.twoDigitYearCutoff ? "19" : "20") + twoDigitYear, 10);
    }
    if (twoDigitYear.length === 3) {
      return parseInt((twoDigitYear.substr(1, 3) > this.twoDigitYearCutoff ? "19" : "20") + twoDigitYear.substr(1, 3), 10);
    }
    return twoDigitYear;
  }
  /**
   * Formats a number into the locale hour format
   * @param {number} hour The hours to show in the current locale
   * @param {object} options Additional date formatting settings
   * @returns {string} the hours in either 24 h or 12 h format
   */
  formatHour(hour, options) {
    let timeSeparator = this.calendar(options?.locale || this.locale.name).dateFormat.timeSeparator;
    if (typeof hour === "string" && hour.indexOf(timeSeparator) === -1) {
      timeSeparator = ":";
    }
    const date = /* @__PURE__ */ new Date();
    if (typeof hour === "number") {
      const split = hour.toString().split(".");
      date.setHours(parseInt(split[0]));
      date.setMinutes(split[1] ? parseFloat(`0.${split[1]}`) * 60 : 0);
    } else {
      const parts = hour.split(timeSeparator);
      date.setHours(parts[0]);
      date.setMinutes(parts[1] || 0);
    }
    return this.formatDate(date, { hour: "numeric", minute: "numeric" });
  }
  /**
   * Formats a number into the locales hour format.
   * @param {number} startHour The hours to show in the current locale.
   * @param {number} endHour The hours to show in the current locale.
   * @param {object} options Additional date formatting settings.
   * @returns {string} the hours in either 24 h or 12 h format
   */
  formatHourRange(startHour, endHour, options) {
    const dayPeriods = this.calendar(options?.locale || this.locale.name).dayPeriods;
    let removePeriod = false;
    let range = `${this.formatHour(startHour, options)} - ${this.formatHour(endHour, options)}`;
    if (range.indexOf(":00 AM -") > -1 || range.indexOf(":00 PM -") > -1) {
      removePeriod = true;
    }
    if (range.split(dayPeriods[0]).length - 1 > 1) {
      range = range.replace(dayPeriods[0], "");
    }
    if (range.split(dayPeriods[1]).length - 1 > 1) {
      range = range.replace(` ${dayPeriods[1]}`, "");
    }
    range = range.replace("  ", " ");
    range = range.replace("\u202F", " ");
    range = range.replace("\u202F", " ");
    if (removePeriod) {
      range = range.replace(":00 -", " -");
    }
    return range;
  }
  /**
   * Returns whether or not the default calendar is islamic
   * @param {string} locale The locale to check if not the current
   * @returns {boolean} True if this locale uses islamic as the primary calendar
   */
  isIslamic(locale) {
    const testLocale = locale || this.locale.name;
    return testLocale === "ar-SA";
  }
  /**
   * Describes whether or not this locale is one that is read in "right-to-left" fashion
   * @param {string} language The language to check if not the current
   * @returns {boolean} Whether or not this locale is "right-to-left"
   */
  isRTL(language) {
    const lang = this.correctLanguage(language || this.language.name);
    return lang === "ar" || lang === "he";
  }
  /**
   * Get the timezone part of a date
   * @param {Date} date The date object to use.
   * @param {string} timeZoneName Can be short or long.
   * @returns {string} The time zone as a string.
   */
  #getTimeZone(date, timeZoneName) {
    const currentLocale = this.locale.name || "en-US";
    const short = date.toLocaleDateString(currentLocale);
    const full = date.toLocaleDateString(currentLocale, { timeZoneName: timeZoneName === "long" ? "long" : "short" });
    const shortIndex = full.indexOf(short);
    if (shortIndex >= 0) {
      const trimmed = full.substring(0, shortIndex) + full.substring(shortIndex + short.length);
      return trimmed.replace(/^[\s,.\-:;]+|[\s,.\-:;]+$/g, "");
    }
    return full;
  }
  /**
   * Takes a formatted date string and parses back it into a date object
   * @param {string} dateString The string to parse in the current format
   * @param {string|object} options Additional options like locale and dateFormat
   * @param {boolean} isStrict If true missing date parts will be considered invalid. If false the current month/day.
   * @returns {Date | Array | undefined} The date object it could calculate from the string
   */
  parseDate(dateString, options, isStrict) {
    if (!dateString) {
      return void 0;
    }
    if (dateString.indexOf("T") > -1 && dateString.substr(dateString.length - 1) === "Z") {
      const tempDateParts = dateString.split(":");
      if (tempDateParts.length === 3 && tempDateParts[2].indexOf("Z") > -1) {
        let filteredDateString;
        const numberParts = tempDateParts[2].split(".");
        const tempSeconds = Number(numberParts[0].substring(0, numberParts[0].length - 1));
        if (numberParts.length > 1) {
          filteredDateString = `${tempDateParts[0]}:${tempDateParts[1]}:${tempSeconds > 59 ? "59" : numberParts[0]}.${numberParts[1]}`;
        } else {
          filteredDateString = `${tempDateParts[0]}:${tempDateParts[1]}:${tempSeconds > 59 ? "59" : numberParts[0].replace("Z", "")}Z`;
        }
        return new Date(filteredDateString);
      }
      return new Date(dateString);
    }
    let dateFormat = options;
    let locale = this.locale.name;
    let thisLocaleCalendar = this.calendar(locale);
    const dirtyDateString = dateString;
    if (typeof options === "object") {
      locale = options.locale || locale;
      dateFormat = options.dateFormat || this.calendar(locale).dateFormat[dateFormat.date];
    }
    if (typeof options === "object" && options.pattern) {
      dateFormat = options.pattern;
    }
    if (typeof options === "object" && options.dateFormat) {
      dateFormat = options.dateFormat;
    }
    if (typeof options === "object" && options.calendarName && options.locale) {
      thisLocaleCalendar = this.calendar(options.locale);
    }
    if (!dateFormat) {
      dateFormat = this.calendar(locale).dateFormat.short;
    }
    const orgDatestring = dateString;
    if (dateString === "0000" || dateString === "000000" || dateString === "00000000") {
      return void 0;
    }
    let formatParts;
    let dateStringParts;
    const dateObj = {};
    const isDateTime = dateFormat.toLowerCase().indexOf("h") > -1;
    const isUTC = dateString.toLowerCase().indexOf("z") > -1;
    let i;
    let l;
    const ampmHasDot = !!thisLocaleCalendar.dayPeriods.filter((x) => x.indexOf(".") > -1).length && dateFormat.indexOf("a") > -1 && dateFormat.indexOf("ah") < 0 && dateFormat.indexOf("H") < 0;
    const hasDot = (dateFormat.match(/M/g) || []).length === 3 && thisLocaleCalendar && thisLocaleCalendar.months && thisLocaleCalendar.months.abbreviated && thisLocaleCalendar.months.abbreviated.filter((v) => /\./.test(v)).length;
    if (isDateTime) {
      const shortTimeZone = this.#getTimeZone(/* @__PURE__ */ new Date(), "short");
      const longTimeZone = this.#getTimeZone(/* @__PURE__ */ new Date(), "long");
      dateString = dateString.replace(` ${shortTimeZone}`, "");
      dateString = dateString.replace(` ${longTimeZone}`, "");
      dateFormat = dateFormat.replace(" zzzz", "").replace(" zz", "");
      const regex = hasDot ? /[T\s:-]/g : /[T\s:.-]/g;
      dateFormat = dateFormat.replace(regex, "/").replace(/z/i, "");
      dateFormat = ampmHasDot ? dateFormat.replace("//", "/") : dateFormat;
      dateString = dateString.replace(ampmHasDot ? /[T\s:-]/g : regex, "/").replace(/z/i, "");
    }
    dateFormat = dateFormat.replace(" de ", " ");
    dateString = dateString.replace(" de ", " ");
    dateFormat = dateFormat.replace("ah", "a/h");
    dateString = dateString.replace("\u5348", "\u5348/");
    dateFormat = dateFormat.replace(",", "");
    dateString = dateString.replace(",", "");
    const getStartIndex = (hasMdyyyy2, hasdMyyyy2) => {
      if (hasMdyyyy2 > -1) {
        return hasMdyyyy2;
      }
      if (hasdMyyyy2 > -1) {
        return hasdMyyyy2;
      }
      return 0;
    };
    const hasMdyyyy = dateFormat.indexOf("Mdyyyy");
    const hasdMyyyy = dateFormat.indexOf("dMyyyy");
    let startIndex = -1;
    let endIndex = -1;
    if (hasMdyyyy > -1 || hasdMyyyy > -1) {
      startIndex = getStartIndex(hasMdyyyy, hasdMyyyy);
      endIndex = startIndex + dateString.indexOf("/") > -1 ? dateString.indexOf("/") : dateString.length;
      dateString = `${dateString.substr(startIndex, endIndex - 4)}/${dateString.substr(endIndex - 4, dateString.length)}`;
      dateString = `${dateString.substr(startIndex, dateString.indexOf("/") / 2)}/${dateString.substr(dateString.indexOf("/") / 2, dateString.length)}`;
    }
    if (hasMdyyyy > -1) {
      dateFormat = dateFormat.replace("Mdyyyy", "M/d/yyyy");
    }
    if (hasdMyyyy > -1) {
      dateFormat = dateFormat.replace("dMyyyy", "d/M/yyyy");
    }
    if (dateFormat.indexOf(" ") !== -1) {
      const regex = hasDot ? /[\s:]/g : /[\s:.]/g;
      dateFormat = dateFormat.replace(regex, "/");
      dateString = dateString.replace(regex, "/");
    }
    if (dateFormat.indexOf("MMMM") > -1 && this.isRTL() && dateFormat && dateFormat !== "MMMM/dd" && dateFormat !== "dd/MMMM") {
      const lastIdx = dateString.lastIndexOf("/");
      dateString = dateString.substr(0, lastIdx - 1).replace("/", " ") + dateString.substr(lastIdx);
    }
    if (dateFormat.indexOf(" ") === -1 && dateFormat.indexOf(".") === -1 && dateFormat.indexOf("/") === -1 && dateFormat.indexOf("-") === -1) {
      if (dateString.indexOf(" ") !== -1) {
        dateString = dateString.split(" ").join("");
      } else if (dateString.indexOf(".") !== -1) {
        dateString = dateString.split(".").join("");
      } else if (dateString.indexOf("/") !== -1) {
        dateString = dateString.split("/").join("");
      } else if (dateString.indexOf("-") !== -1) {
        dateString = dateString.split("-").join("");
      }
      let lastChar = dateFormat[0];
      let newFormat = "";
      let newDateString = "";
      for (i = 0, l = dateFormat.length; i < l; i++) {
        newDateString += dateFormat[i] !== lastChar ? `/${dateString[i]}` : dateString[i];
        newFormat += dateFormat[i] !== lastChar ? `/${dateFormat[i]}` : dateFormat[i];
        if (i > 1) {
          lastChar = dateFormat[i];
        }
      }
      dateString = newDateString;
      dateFormat = newFormat;
    }
    formatParts = dateFormat.split("/");
    dateStringParts = dateString.split("/");
    if (formatParts.length === 1) {
      formatParts = dateFormat.split(".");
    }
    if (dateStringParts.length === 1) {
      dateStringParts = dateString.split(".");
    }
    if (formatParts.length === 1) {
      formatParts = dateFormat.split("-");
    }
    if (dateStringParts.length === 1) {
      dateStringParts = dateString.split("-");
    }
    if (formatParts.length === 1) {
      formatParts = dateFormat.split(" ");
    }
    if (dateStringParts.length === 1) {
      dateStringParts = dateString.split(" ");
    }
    const month = this.#determineDatePart(formatParts, dateStringParts, "M", "MM", "MMM", "MMMM");
    const year = this.#determineDatePart(formatParts, dateStringParts, "y", "yy", "yyyy");
    let hasDays = false;
    let hasDayPeriodsFirst = false;
    for (i = 0, l = dateStringParts.length; i < l; i++) {
      const pattern = `${formatParts[i]}`;
      const value = dateStringParts[i];
      const numberValue = parseInt(value, 10);
      if (!hasDays) {
        hasDays = pattern.toLowerCase().indexOf("d") > -1;
      }
      let abrMonth;
      let textMonths;
      const padNumber = (num) => num < 10 ? `0${num}` : `${num}`;
      const lastDay = new Date(this.twoToFourDigitYear(year), month, 0).getDate();
      switch (pattern) {
        case "d":
          if (numberValue < 1 || numberValue > 31 || numberValue > lastDay) {
            return void 0;
          }
          dateObj.day = numberValue;
          break;
        case "dd":
          if (numberValue < 1 || numberValue > 31 || numberValue > lastDay) {
            return void 0;
          }
          dateObj.day = padNumber(numberValue);
          break;
        case "M": {
          if (numberValue < 1 || numberValue > 12) {
            return void 0;
          }
          dateObj.month = numberValue - 1;
          break;
        }
        case "MM":
          if (numberValue < 1 || numberValue > 12) {
            return void 0;
          }
          dateObj.month = parseInt(padNumber(numberValue), 10) - 1;
          break;
        case "MMM":
          abrMonth = this.calendar(locale).months.abbreviated;
          for (let len = 0; len < abrMonth.length; len++) {
            if (orgDatestring.indexOf(abrMonth[len]) > -1) {
              dateObj.month = len;
            }
          }
          break;
        case "MMMM":
          textMonths = this.calendar(locale).months.wide;
          for (let k = 0; k < textMonths.length; k++) {
            if (orgDatestring.indexOf(textMonths[k]) > -1) {
              dateObj.month = k;
            }
          }
          break;
        case "yy":
          dateObj.year = this.twoToFourDigitYear(value);
          break;
        case "y":
        case "yyyy":
          dateObj.year = value.length === 2 ? this.twoToFourDigitYear(value) : value;
          break;
        case "h":
          if (numberValue < 0 || numberValue > 12) {
            return void 0;
          }
          dateObj.h = hasDayPeriodsFirst ? dateObj.h : value;
          break;
        case "hh":
          if (numberValue < 0 || numberValue > 12) {
            return void 0;
          }
          dateObj.h = hasDayPeriodsFirst ? dateObj.h : value.length === 1 ? `0${value}` : value;
          break;
        case "H":
          if (numberValue < 0 || numberValue > 24) {
            return void 0;
          }
          dateObj.h = hasDayPeriodsFirst ? dateObj.h : value;
          break;
        case "HH":
          if (numberValue < 0 || numberValue > 24) {
            return void 0;
          }
          dateObj.h = hasDayPeriodsFirst ? dateObj.h : value.length === 1 ? `0${value}` : value;
          break;
        case "ss":
          if (numberValue < 0 || numberValue >= 60) {
            if (!options?.strictTime) {
              dateObj.ss = 0;
              break;
            } else {
              return void 0;
            }
          }
          dateObj.ss = value;
          break;
        case "SSS":
          dateObj.ms = value;
          break;
        case "mm":
          if (Number.isNaN(numberValue) || numberValue < 0 || numberValue >= 60) {
            if (!options?.strictTime) {
              dateObj.mm = 0;
              break;
            } else {
              return void 0;
            }
          }
          dateObj.mm = value;
          break;
        case "a": {
          if (!dateObj.h && formatParts[i + 1] && formatParts[i + 1].toLowerCase().substr(0, 1) === "h") {
            dateObj.h = dateStringParts[i + 1];
            hasDayPeriodsFirst = true;
          }
          const isAM = dirtyDateString?.toLowerCase()?.includes(thisLocaleCalendar.dayPeriods[0]?.toLowerCase());
          const isPM = dirtyDateString?.toLowerCase()?.includes(thisLocaleCalendar.dayPeriods[1]?.toLowerCase());
          if (!(isAM || isPM) && options?.strictTime) {
            return void 0;
          }
          if (dirtyDateString?.toLowerCase()?.includes(thisLocaleCalendar.dayPeriods[0]?.toLowerCase())) {
            dateObj.a = "AM";
            if (dateObj.h) {
              if (dateObj.h === 12 || dateObj.h === "12") {
                dateObj.h = 0;
              }
            }
          }
          if (dirtyDateString?.toLowerCase()?.includes(thisLocaleCalendar.dayPeriods[1]?.toLowerCase())) {
            dateObj.a = "PM";
            if (dateObj.h) {
              if (Number(dateObj.h) < 12) {
                dateObj.h = parseInt(dateObj.h, 10) + 12;
              }
            }
          }
          break;
        }
        default:
          break;
      }
    }
    const isLeap = (y) => y % 4 === 0 && y % 100 !== 0 || y % 400 === 0;
    const closestLeap = (y) => {
      let closestLeapYear = typeof y === "number" && !Number.isNaN(y) ? y : (/* @__PURE__ */ new Date()).getFullYear();
      for (let i2 = 0; i2 < 4; i2++) {
        if (isLeap(closestLeapYear)) {
          break;
        }
        closestLeapYear--;
      }
      return closestLeapYear;
    };
    dateObj.return = void 0;
    dateObj.leapYear = isLeap(dateObj.year);
    if (isDateTime && !dateObj.h && !dateObj.mm) {
      return void 0;
    }
    if (!dateObj.year && dateObj.year !== 0 && !isStrict) {
      dateObj.isUndefinedYear = true;
      for (i = 0, l = formatParts.length; i < l; i++) {
        if (formatParts[i].indexOf("y") > -1 && dateStringParts[i] !== void 0) {
          dateObj.isUndefinedYear = false;
          break;
        }
      }
      if (dateObj.isUndefinedYear) {
        const isFeb29 = parseInt(dateObj.day, 10) === 29 && parseInt(dateObj.month, 10) === 1;
        dateObj.year = isFeb29 ? closestLeap() : (/* @__PURE__ */ new Date()).getFullYear();
        if (thisLocaleCalendar.name === "islamic-umalqura") {
          const umDate = gregorianToUmalqura(new Date(dateObj.year, 0, 1));
          dateObj.year = umDate[0];
        }
      } else {
        delete dateObj.year;
      }
    }
    if (dateObj.year && dateObj.year.length === 2) {
      dateObj.year = `20${dateObj.year}`;
    }
    if (dateObj.year === "" || dateObj.year && !(`${dateObj.year}`.length === 2 || `${dateObj.year}`.length === 4)) {
      delete dateObj.year;
    }
    if (!dateObj.month && dateObj.month !== 0 && !isStrict) {
      dateObj.isUndefinedMonth = true;
      for (i = 0, l = formatParts.length; i < l; i++) {
        if (formatParts[i].indexOf("M") > -1 && dateStringParts[i] !== void 0) {
          dateObj.isUndefinedMonth = false;
          break;
        }
      }
      if (dateObj.isUndefinedMonth) {
        dateObj.month = (/* @__PURE__ */ new Date()).getMonth();
      }
    }
    if (!dateObj.day && dateObj.day !== 0 && (!isStrict || !hasDays)) {
      dateObj.isUndefindedDay = true;
      for (i = 0, l = formatParts.length; i < l; i++) {
        if (formatParts[i].indexOf("d") > -1 && dateStringParts[i] !== void 0) {
          dateObj.isUndefindedDay = false;
          break;
        }
      }
      if (dateObj.isUndefindedDay) {
        dateObj.day = 1;
      } else {
        delete dateObj.day;
      }
    }
    if (isDateTime) {
      if (isUTC) {
        if (dateObj.h !== void 0) {
          dateObj.return = new Date(
            Date.UTC(
              dateObj.year,
              dateObj.month,
              dateObj.day,
              dateObj.h,
              dateObj.mm
            )
          );
        }
        if (dateObj.ss !== void 0) {
          dateObj.return = new Date(
            Date.UTC(
              dateObj.year,
              dateObj.month,
              dateObj.day,
              dateObj.h,
              dateObj.mm,
              dateObj.ss
            )
          );
        }
        if (dateObj.ms !== void 0) {
          dateObj.return = new Date(
            Date.UTC(
              dateObj.year,
              dateObj.month,
              dateObj.day,
              dateObj.h,
              dateObj.mm,
              dateObj.ss,
              dateObj.ms
            )
          );
        }
      } else {
        if (!dateObj.year || !dateObj.month || !dateObj.day) {
          const today = /* @__PURE__ */ new Date();
          if (!dateObj.year) dateObj.year = today.getFullYear();
          if (!dateObj.month) dateObj.month = today.getMonth();
          if (!dateObj.day) dateObj.day = today.getDate();
        }
        if (dateObj.h !== void 0) {
          dateObj.return = new Date(
            dateObj.year,
            dateObj.month,
            dateObj.day,
            dateObj.h,
            dateObj.mm
          );
        }
        if (dateObj.ss !== void 0) {
          dateObj.return = new Date(
            dateObj.year,
            dateObj.month,
            dateObj.day,
            dateObj.h,
            dateObj.mm,
            dateObj.ss
          );
        }
        if (dateObj.ms !== void 0) {
          dateObj.return = new Date(
            dateObj.year,
            dateObj.month,
            dateObj.day,
            dateObj.h,
            dateObj.mm,
            dateObj.ss,
            dateObj.ms
          );
        }
      }
    } else {
      dateObj.return = new Date(dateObj.year, dateObj.month, dateObj.day);
    }
    if (thisLocaleCalendar.name === "islamic-umalqura") {
      return [
        parseInt(dateObj.year, 10),
        parseInt(dateObj.month, 10),
        parseInt(dateObj.day, 10),
        parseInt(dateObj.h || "0", 10),
        parseInt(dateObj.mm || "0", 10),
        parseInt(dateObj.ss || "0", 10),
        parseInt(dateObj.ms || "0", 10)
      ];
    }
    return isValidDate(dateObj.return) ? dateObj.return : void 0;
  }
  /**
   * Format out the date into parts.
   * @private
   * @param {Array} formatParts An array of the format bits.
   * @param {Array} dateStringParts An array of the date parts.
   * @param {string} filter1 The first option to filter.
   * @param {string} filter2 The second option to filter.
   * @param {string} filter3 The third option to filter.
   * @param {string} filter4 The fourth option to filter.
   * @param {string} filter5 The fifth option to filter.
   * @returns {string} The filtered out date part.
   */
  #determineDatePart(formatParts, dateStringParts, filter1, filter2, filter3, filter4, filter5) {
    let ret = "";
    for (let i = 0; i < dateStringParts.length; i++) {
      if (filter1 === formatParts[i] || filter2 === formatParts[i] || filter3 === formatParts[i] || filter4 === formatParts[i] || filter5 === formatParts[i]) {
        ret = dateStringParts[i];
      }
    }
    return ret;
  }
  /**
   * Shortcut function to get the default or any calendar
   * @param {string} locale The locale to use
   * @param {string} name the name of the calendar (fx: "gregorian", "islamic-umalqura")
   * @returns {object} containing calendar data
   */
  calendar(locale, name) {
    const localeData = this.loadedLocales.get(locale || this.locale.name);
    const calendars = localeData?.calendars;
    if (name && calendars) {
      for (let i = 0; i < calendars.length; i++) {
        const cal = calendars[i];
        if (cal.name === name) {
          return cal;
        }
      }
    }
    return calendars[0];
  }
  /**
   * Shortcut function to get the current locales numbers
   * @param {string} locale The locale to use
   * @returns {object} containing calendar data for numbers
   */
  numbers(locale) {
    const localeData = this.loadedLocales.get(locale || this.locale.name);
    return localeData.numbers;
  }
};
var ids_locale_default = IdsLocale;

export {
  ids_locale_default
};
//# sourceMappingURL=ids-chunk-KNIQC2IS-full.js.map
