/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/mixins/ids-validation-mixin/ids-validation-input-mixin.ts
var IdsValidationInputMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  connectedCallback() {
    super.connectedCallback?.();
  }
  hideErrorMessage(toHide) {
    this.input.hideErrorMessage(toHide);
  }
  /**
   * Return if the field is valid or not
   * @returns {boolean} true if invalid
   */
  get isValid() {
    return this.input?.shadowRoot?.querySelectorAll(".validation-message").length === 0;
  }
  /**
   * Return if the current validation errors
   * @returns {Array<IdsValidationErrorMessage>} The current errors
   */
  get validationMessages() {
    const msgs = [];
    this.input?.shadowRoot?.querySelectorAll(".validation-message").forEach((message) => {
      msgs.push({
        message: message.querySelector("ids-text")?.childNodes[1].textContent || "",
        type: message.getAttribute("type") || "",
        id: message.getAttribute("validation-id") || ""
      });
    });
    return msgs;
  }
  get validationMessageElems() {
    return [...this.input?.shadowRoot?.querySelectorAll(".validation-message") || []];
  }
  /**
   * Relays error message to IdsInput's addValidationMessage()
   * @param {Array<IdsValidationErrorMessage> | IdsValidationErrorMessage} message error message
   */
  addValidationMessage(message) {
    this.input?.addValidationMessage(message);
  }
  /**
   * Relays error message to IdsInput's removeValidationMessage()
   * @param {Array<IdsValidationErrorMessage> | IdsValidationErrorMessage} message error message
   */
  removeValidationMessage(message) {
    this.input?.removeValidationMessage(message);
  }
};
var ids_validation_input_mixin_default = IdsValidationInputMixin;

export {
  ids_validation_input_mixin_default
};
//# sourceMappingURL=ids-chunk-KWJ4QVJN-full.js.map
