/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  ALPHAS_REGEX,
  ANY_REGEX,
  CARET_TRAP,
  DIGITS_REGEX,
  EMPTY_STRING,
  NON_DIGITS_REGEX
} from "./ids-chunk-2GKEPJIA-full.js";
import {
  deepClone
} from "./ids-chunk-G6C62L35-full.js";
import {
  removeDuplicates
} from "./ids-chunk-REOQKPVR-full.js";

// src/components/ids-mask/ids-masks.ts
var DEFAULT_NUMBER_MASK_OPTIONS = {
  prefix: EMPTY_STRING,
  suffix: EMPTY_STRING,
  allowThousandsSeparator: true,
  symbols: {
    currency: "$",
    decimal: ".",
    negative: "-",
    thousands: ","
  },
  allowDecimal: false,
  decimalLimit: 0,
  locale: "",
  requireDecimal: false,
  allowNegative: false,
  allowLeadingZeros: false,
  integerLimit: null
};
function getLeadingZeros(formattedStr = "") {
  const match = `${formattedStr}`.match(/^0*/);
  return match ? match[0].length : 0;
}
function convertToMask(strNumber) {
  return strNumber.split(EMPTY_STRING).map((char) => DIGITS_REGEX.test(char) ? DIGITS_REGEX : char);
}
function addThousandsSeparator(n, options = {}, localeStringOpts = {}) {
  if (n === "" || Number.isNaN(n)) {
    return n;
  }
  let formatted = n;
  if (options.locale?.formatNumber) {
    formatted = options.locale.formatNumber(n, localeStringOpts);
  }
  if (options.allowLeadingZeros && n.indexOf("0") === 0) {
    let zeros = getLeadingZeros(n);
    if (formatted.indexOf("0") === 0) {
      formatted = formatted.substring(1);
    }
    while (zeros > 0) {
      zeros -= 1;
      formatted = `0${formatted}`;
    }
  }
  return formatted;
}
function getRegexForPart(part, type) {
  const types = {
    any: ANY_REGEX,
    digits: DIGITS_REGEX,
    alphas: ALPHAS_REGEX
  };
  if (!types[type]) {
    type = "any";
  }
  let size = part.toString().length;
  const arr = [];
  while (size > 0) {
    arr.push(types[type]);
    size -= 1;
  }
  return arr;
}
function numberMask(rawValue = "", options = {}) {
  let thisOptions = deepClone(DEFAULT_NUMBER_MASK_OPTIONS);
  thisOptions = Object.assign(thisOptions, options);
  const PREFIX = thisOptions.prefix;
  const SUFFIX = thisOptions.suffix;
  const DECIMAL = thisOptions.symbols.decimal;
  const THOUSANDS = thisOptions.symbols.thousands;
  const prefixLength = PREFIX?.length || 0;
  const suffixLength = SUFFIX?.length || 0;
  const thousandsSeparatorSymbolLength = THOUSANDS?.length || 0;
  let thisRawValue = rawValue;
  let mask;
  if (typeof thisRawValue !== "string") {
    thisRawValue = EMPTY_STRING;
  }
  const rawValueLength = thisRawValue.length;
  if (thisRawValue === EMPTY_STRING || thisRawValue[0] === PREFIX[0] && rawValueLength === 1) {
    mask = PREFIX.split(EMPTY_STRING).concat([DIGITS_REGEX]).concat(SUFFIX.split(EMPTY_STRING));
  }
  if (thisRawValue === DECIMAL && thisOptions.allowDecimal) {
    mask = PREFIX.split(EMPTY_STRING).concat(["0", CARET_TRAP, DECIMAL, CARET_TRAP, DIGITS_REGEX]).concat(SUFFIX.split(EMPTY_STRING));
  }
  if (Array.isArray(mask)) {
    return { mask };
  }
  const indexOfLastDecimal = thisRawValue.lastIndexOf(DECIMAL);
  const hasDecimal = indexOfLastDecimal !== -1;
  const isNegative = thisRawValue[0] === thisOptions.symbols.negative && thisOptions.allowNegative;
  let integer;
  let fraction;
  if (thisRawValue.slice(suffixLength * -1) === SUFFIX) {
    thisRawValue = thisRawValue.slice(0, suffixLength * -1);
  }
  if (hasDecimal) {
    integer = thisRawValue.slice(thisRawValue.slice(0, prefixLength) === PREFIX ? prefixLength : 0, indexOfLastDecimal);
    fraction = thisRawValue.slice(indexOfLastDecimal + 1, rawValueLength);
    fraction = convertToMask(fraction.replace(NON_DIGITS_REGEX, EMPTY_STRING));
  } else if (thisRawValue.slice(0, prefixLength) === PREFIX) {
    integer = thisRawValue.slice(prefixLength);
  } else {
    integer = thisRawValue;
  }
  if (options.integerLimit && typeof options.integerLimit === "number") {
    const thousandsSeparatorRegex = THOUSANDS === "." ? "[.]" : `${THOUSANDS}`;
    const numberOfThousandSeparators = (integer.match(new RegExp(thousandsSeparatorRegex, "g")) || []).length;
    integer = integer.slice(0, options.integerLimit + (isNegative ? 1 : 0) + numberOfThousandSeparators * thousandsSeparatorSymbolLength);
  }
  integer = integer.replace(NON_DIGITS_REGEX, EMPTY_STRING);
  if (!options.allowLeadingZeros) {
    integer = integer.replace(/^0+(0$|[^0])/, "$1");
  }
  if (options.allowThousandsSeparator) {
    const localeOptions = {
      maximumSignificantDigits: options.integerLimit,
      style: "decimal",
      useGrouping: options.allowThousandsSeparator
    };
    integer = addThousandsSeparator(integer, options, localeOptions);
  }
  mask = convertToMask(integer);
  if (hasDecimal && options.allowDecimal || options.requireDecimal === true) {
    if (thisRawValue[indexOfLastDecimal - 1] !== DECIMAL) {
      mask.push(CARET_TRAP);
    }
    mask.push(DECIMAL, CARET_TRAP);
    if (fraction) {
      if (typeof options.decimalLimit === "number") {
        fraction = fraction.slice(0, options.decimalLimit);
      }
      mask = mask.concat(fraction);
    }
    if (options.requireDecimal === true && thisRawValue[indexOfLastDecimal - 1] === DECIMAL) {
      mask.push(DIGITS_REGEX);
    }
  }
  if (prefixLength > 0) {
    mask = PREFIX.split(EMPTY_STRING).concat(mask);
  }
  if (isNegative) {
    if (mask.length === prefixLength) {
      mask.push(DIGITS_REGEX);
    }
    mask = [/-/].concat(mask);
  }
  if (SUFFIX.length > 0) {
    mask = mask.concat(SUFFIX.split(EMPTY_STRING));
  }
  return {
    mask
  };
}
var DEFAULT_DATETIME_MASK_OPTIONS = {
  format: "M/d/yyyy",
  symbols: {
    timeSeparator: ":",
    dayPeriodSeparator: " ",
    dateSeparator: "/"
  }
};
var DATE_MAX_VALUES = {
  dd: 31,
  d: 31,
  MMM: void 0,
  MM: 12,
  M: 12,
  yy: 99,
  yyyy: 9999,
  h: 12,
  hh: 12,
  H: 24,
  HH: 24,
  mm: 60,
  ss: 60,
  a: void 0
};
function getSplitterRegex(splitterStr) {
  const arr = splitterStr.split("");
  const fixedArr = arr.map((c) => {
    if (c === " ") {
      return "\\s";
    }
    if (c === "-") {
      return "\\-";
    }
    return c;
  });
  return new RegExp(`[(${fixedArr.join("|")})]+`);
}
function dateMask(rawValue = "", options = {}) {
  let thisOptions = deepClone(DEFAULT_DATETIME_MASK_OPTIONS);
  thisOptions = Object.assign(thisOptions, options);
  let mask = [];
  let thisRawValue = rawValue;
  if (typeof rawValue !== "string") {
    thisRawValue = "";
  }
  const digitRegex = DIGITS_REGEX;
  const format = thisOptions.format;
  const splitterStr = removeDuplicates(format.replace(/[dMyHhmsa]+/g, ""));
  const splitterRegex = getSplitterRegex(splitterStr);
  const formatArray = format.match(/(d{1,2}|M{1,4}|y{1,4}|H{1,2}|h{1,2}|m{1,2}|s{1,2}|a{1}|z{1, 4}|E{1, 4})/g);
  const rawValueArray = thisRawValue.split(splitterRegex);
  const maxValue = DATE_MAX_VALUES;
  formatArray.forEach((part, i) => {
    const value = maxValue[part];
    let size;
    if (part === "a" || part === "ah") {
      let am = "AM";
      let pm = "PM";
      if (options?.locale?.calendar()) {
        am = options.locale.calendar().dayPeriods[0];
        pm = options.locale.calendar().dayPeriods[1];
        const apRegex = [];
        for (let j = 0; j < am.length; j++) {
          if (am[j] && pm[j] && am[j].toLowerCase() === pm[j].toLowerCase()) {
            apRegex.push(am[j].toLowerCase());
          } else {
            apRegex.push(am[j].toLowerCase() + (pm[j] ? pm[j].toLowerCase() : ""));
          }
        }
        for (let k = 0; k < apRegex.length; k++) {
          mask.push(new RegExp(`[${apRegex[k]}]`, "i"));
        }
      } else {
        mask.push(/[aApP]/, /[Mm]/);
      }
      if (part === "ah") {
        const hourValue = rawValueArray[i].replace(am, "").replace(pm, "");
        mask = mask.concat(getRegexForPart(hourValue, "digits"));
      }
    } else if (!value) {
      mask = mask.concat(getRegexForPart(part, "alphas"));
    } else if (rawValueArray[i]) {
      const rawValueStr = rawValueArray[i].toString();
      const rawValueFirstDigit = parseInt(rawValueStr.substr(0, 1), 10);
      const maxFirstDigit = parseInt(maxValue[part].toString().substr(0, 1), 10);
      if (part.length === 1 && rawValueFirstDigit > maxFirstDigit) {
        mask.push(digitRegex);
      } else if (rawValueStr !== "0" && rawValueStr.length === 1 && rawValueFirstDigit <= maxFirstDigit && rawValueArray[i + 1] !== void 0 && part.toUpperCase() !== "HH") {
        mask.push(digitRegex);
      } else {
        mask = mask.concat(getRegexForPart(value, "digits"));
      }
    } else {
      size = value.toString().length;
      while (size > 0) {
        mask.push(digitRegex);
        size -= 1;
      }
    }
    const nextPart = formatArray[i + 1];
    if (nextPart !== void 0) {
      const thisPartSize = part.toString().length;
      const start = format.indexOf(part) + thisPartSize;
      const end = format.indexOf(nextPart);
      const literals = format.substring(start, end).split(EMPTY_STRING);
      const literalsWithCarets = [CARET_TRAP].concat(literals.concat(CARET_TRAP));
      mask = mask.concat(literalsWithCarets);
    }
  });
  return {
    mask,
    literals: splitterStr.split(""),
    literalRegex: splitterRegex
  };
}
function rangeDateMask(rawValue = "", options = {}) {
  const parts = rawValue.split(options.delimiter);
  const delimiterArr = options.delimiter?.split("") || [];
  const firstDate = dateMask(parts[0], options);
  const secondDate = dateMask(parts[1], options);
  return {
    mask: firstDate.mask.concat(delimiterArr.concat(secondDate.mask)),
    literals: delimiterArr,
    literalRegex: secondDate.literalRegex
  };
}
function autoCorrectedDatePipe(processResult, options) {
  options.dateFormat = "M/d/yyyy";
  const conformedValueArr = processResult.conformedValue.split("");
  const indexesOfPipedChars = [];
  const dateFormatArray = options.dateFormat.split(/[^dMy]+/);
  const maxValue = {
    d: 31,
    M: 12,
    yy: 99,
    yyyy: 9999
  };
  const minValue = {
    d: 1,
    M: 1,
    yy: 0,
    yyyy: 1
  };
  dateFormatArray.forEach((format) => {
    const position = options.dateFormat.indexOf(format);
    const maxFirstDigit = parseInt(maxValue[format].toString().substr(0, 1), 10);
    if (parseInt(conformedValueArr[position], 10) > maxFirstDigit) {
      conformedValueArr[position + 1] = conformedValueArr[position];
      conformedValueArr[position] = 0;
      indexesOfPipedChars.push(position);
    }
  });
  const placeholderRegex = new RegExp(`[^${processResult.placeholderChar}]`);
  const maskPieces = processResult.placeholder.split(placeholderRegex);
  const conformedPieces = processResult.conformedValue.split(/\D/g);
  const isInvalid = dateFormatArray.some((format, i) => {
    const length = maskPieces[i].length > format.length ? maskPieces[i].length : format.length;
    const textValue = conformedPieces[i] || "";
    const value = parseInt(textValue, 10);
    return value > maxValue[format] || textValue.length === length && value < minValue[format];
  });
  if (isInvalid) {
    return false;
  }
  return {
    value: conformedValueArr.join(""),
    characterIndexes: indexesOfPipedChars
  };
}

export {
  DEFAULT_NUMBER_MASK_OPTIONS,
  numberMask,
  DEFAULT_DATETIME_MASK_OPTIONS,
  dateMask,
  rangeDateMask,
  autoCorrectedDatePipe
};
//# sourceMappingURL=ids-chunk-L5LKJLMG-full.js.map
