/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-field-height-mixin/ids-field-height-mixin.ts
var FIELD_HEIGHTS = {
  default: "md",
  xxs: "xxs",
  xs: "xs",
  sm: "sm",
  md: "md",
  lg: "lg"
};
var getFieldHeightClass = (val) => `field-height-${val}`;
var IdsFieldHeightMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
    if (!this.state) {
      this.state = {};
    }
    this.state.fieldHeight = FIELD_HEIGHTS.default;
    this.state.compact = stringToBool(this.getAttribute(attributes.COMPACT)) || false;
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.COMPACT,
      attributes.FIELD_HEIGHT
    ];
  }
  connectedCallback() {
    super.connectedCallback();
    if (this.hasAttribute(attributes.COMPACT)) {
      this.compact = true;
    } else {
      this.container?.classList.add(getFieldHeightClass(this.fieldHeight));
      this.#doFieldHeightChange(this.fieldHeight);
    }
  }
  /**
   * @returns {string} that can be applied to an HTML element
   * inside a template for determining the current Field Height class
   */
  templateFieldHeight() {
    if (this.compact) return "";
    return this.fieldHeight ? `${getFieldHeightClass(this.fieldHeight)}` : "";
  }
  /**
   *  Set the compact height
   * @param {boolean|string} value If true will set `compact` attribute
   */
  set compact(value) {
    const val = stringToBool(value);
    if (val !== this.state.compact) {
      this.state.compact = val;
      if (val) {
        this.fieldHeight = "";
        this.setAttribute(attributes.COMPACT, "");
        this.container?.classList.add(attributes.COMPACT);
        this.#doFieldHeightChange(attributes.COMPACT);
      } else {
        this.removeAttribute(attributes.COMPACT);
        this.container?.classList.remove(attributes.COMPACT);
        this.#doFieldHeightChange("");
      }
    }
  }
  get compact() {
    return stringToBool(this.getAttribute(attributes.COMPACT));
  }
  /**
   * Set the fieldHeight (height) of input
   * @param {string} value [xs, sm, md, lg]
   */
  set fieldHeight(value) {
    if (!value) {
      this.state.fieldHeight = FIELD_HEIGHTS.default;
      this.clearHeightClasses();
      this.container?.classList.add(getFieldHeightClass(FIELD_HEIGHTS.default));
      this.removeAttribute(attributes.FIELD_HEIGHT);
    } else {
      const fieldHeight = FIELD_HEIGHTS[value];
      if (fieldHeight && this.state.fieldHeight !== fieldHeight) {
        this.state.fieldHeight = fieldHeight;
        this.clearHeightClasses();
        this.compact = false;
        this.setAttribute(attributes.FIELD_HEIGHT, fieldHeight);
        this.container?.classList.add(getFieldHeightClass(fieldHeight));
        this.#doFieldHeightChange(fieldHeight);
      }
    }
  }
  get fieldHeight() {
    return this.getAttribute(attributes.FIELD_HEIGHT) ?? FIELD_HEIGHTS.default;
  }
  /**
   * Clears all existing field height classes defined on this component
   * @returns {void}
   */
  clearHeightClasses() {
    const heightClasses = Object.values(FIELD_HEIGHTS).map((h) => getFieldHeightClass(h));
    this.container?.classList.remove(...heightClasses);
  }
  /**
   * Runs optional `onFieldHeightChange` callback, if possible
   * @param {string} fieldHeight the incoming `fieldHeight` or `compact` setting
   */
  #doFieldHeightChange(fieldHeight) {
    if (typeof this.onFieldHeightChange === "function") {
      this.onFieldHeightChange(fieldHeight);
    }
  }
};
var ids_field_height_mixin_default = IdsFieldHeightMixin;

export {
  FIELD_HEIGHTS,
  ids_field_height_mixin_default
};
//# sourceMappingURL=ids-chunk-LZWQ252S-full.js.map
