/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  ids_pager_default
} from "./ids-chunk-WJP2LHE6-full.js";
import {
  buttonTypes
} from "./ids-chunk-SBKUZOOS-full.js";
import {
  ids_events_mixin_default
} from "./ids-chunk-KKFANICI-full.js";
import {
  IdsElement
} from "./ids-chunk-UTR2KJV7-full.js";
import {
  customElement,
  scss
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  stringToBool,
  stringToNumber
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";
import {
  __decorateClass,
  __privateAdd,
  __privateMethod,
  __publicField
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-pager/ids-pager.ts
var _IdsPager_instances, syncChildren_fn, keepPageNumberInBounds_fn, updateButtonStates_fn;
var IdsPager = class extends ids_events_mixin_default(IdsElement) {
  constructor() {
    super();
    __privateAdd(this, _IdsPager_instances);
    __publicField(this, "DEFAULT_STEP", 3);
    __publicField(this, "DEFAULT_PAGE_SIZE", 10);
    __publicField(this, "sizes", [5, 10, 25, 50, 100]);
  }
  get elements() {
    return {
      buttons: {
        first: this.querySelector("ids-pager-button[first]"),
        previous: this.querySelector("ids-pager-button[previous]"),
        next: this.querySelector("ids-pager-button[next]"),
        last: this.querySelector("ids-pager-button[last]")
      },
      input: this.querySelector("ids-pager-input"),
      slots: {
        start: this.container?.querySelector(".pager-section.start slot"),
        middle: this.container?.querySelector(".pager-section.middle slot"),
        end: this.container?.querySelector(".pager-section.end slot")
      },
      dropdowns: this.querySelectorAll("ids-pager-dropdown")
    };
  }
  static get attributes() {
    return [
      attributes.DISABLED,
      attributes.STEP,
      attributes.TOTAL,
      // has to be in this order
      attributes.TYPE,
      attributes.PAGE_COUNT,
      attributes.PAGE_SIZE,
      attributes.PAGE_NUMBER
    ];
  }
  /**
   * React to attributes changing on the web-component
   * @param {string} name The property name
   * @param {string} oldValue The property old value
   * @param {string} newValue The property new value
   */
  attributeChangedCallback(name, oldValue, newValue) {
    super.attributeChangedCallback(name, oldValue, newValue);
    const shouldRerender = [
      attributes.DISABLED,
      attributes.PAGE_NUMBER,
      attributes.PAGE_SIZE,
      attributes.STEP,
      attributes.TOTAL,
      attributes.TYPE
    ].includes(name);
    const transformAttributes = {
      [attributes.DISABLED]: attributes.PARENT_DISABLED
    };
    if (shouldRerender) {
      if (oldValue !== newValue) {
        this.connectedCallback();
        __privateMethod(this, _IdsPager_instances, syncChildren_fn).call(this, transformAttributes[name] ?? name, newValue);
      }
    }
  }
  template() {
    switch (this.type) {
      case "list":
        return this.templatePagerList();
      default:
        return this.templatePagerButtons();
    }
  }
  templatePagerButtons() {
    return `
      <div class="ids-pager">
        <section class="pager-section start"><slot name="start"></slot></section>
        <section class="pager-section middle" role="navigation"><slot></slot></section>
        <section class="pager-section end"><slot name="end"></slot></section>
      </div>
    `;
  }
  /**
   * Set the pager template for listview
   * @returns {string} the default pager template for list-view
   */
  templatePagerList() {
    return `
      <div class="ids-pager">
        <ids-pager-button label="Previous page" previous></ids-pager-button>
        <ids-pager-number-list
          label="Page {num} of {total}"
          page-number="${this.pageNumber}"
          page-size="${this.pageSize}"
          total="${this.total}"
          step="${this.step}"
        >
        </ids-pager-number-list>
        <ids-pager-button label="Next page" next></ids-pager-button>
      </div>
    `;
  }
  connectedCallback() {
    super.connectedCallback();
    this.offEvent("pagenumberchange", this);
    this.onEvent("pagenumberchange", this, (event) => {
      const val = stringToNumber(event.detail.value);
      if (!Number.isNaN(val) && val !== this.pageNumber) {
        this.pageNumber = Number(event.detail.value);
      }
    });
    this.offEvent("pagesizechange", this);
    this.onEvent("pagesizechange", this, (event) => {
      this.pageSize = Number(event.detail.value);
    });
  }
  /**
   * @param {boolean} value Whether or not to disable the pager overall
   */
  set disabled(value) {
    const isTruthy = stringToBool(value);
    if (isTruthy && !this.hasAttribute(attributes.DISABLED)) {
      this.setAttribute(attributes.DISABLED, "");
      __privateMethod(this, _IdsPager_instances, syncChildren_fn).call(this, attributes.PARENT_DISABLED, true);
    } else if (!isTruthy && this.hasAttribute(attributes.DISABLED)) {
      this.removeAttribute(attributes.DISABLED);
      __privateMethod(this, _IdsPager_instances, syncChildren_fn).call(this, attributes.PARENT_DISABLED, false);
    }
  }
  /**
   * @returns {boolean} Whether or not the pager overall is disabled
   */
  get disabled() {
    return this.hasAttribute(attributes.DISABLED);
  }
  /** @param {number} value The number of items shown per page */
  set pageSize(value) {
    const val = this.isValidPageSize(value);
    this.setAttribute(attributes.PAGE_SIZE, String(val));
    __privateMethod(this, _IdsPager_instances, keepPageNumberInBounds_fn).call(this);
  }
  /** @returns {number} The number of items shown per page */
  get pageSize() {
    return this.isValidPageSize(this.getAttribute(attributes.PAGE_SIZE));
  }
  /**
   * Sets page sizes
   * @param {number[]} sizes array of page sizes
   */
  set pageSizes(sizes) {
    sizes = sizes.filter((n, idx) => !Number.isNaN(Number(n)) && sizes.indexOf(n) === idx);
    sizes = sizes.length ? sizes : this.sizes;
    sizes.sort((a, b) => a - b);
    this.sizes = sizes;
    this.elements.dropdowns.forEach((elem) => elem.updatePageSizes(sizes));
  }
  /**
   * Gets page sizes
   * @returns {number[]} array of page sizes
   */
  get pageSizes() {
    return this.sizes;
  }
  /**
   * Check given page size value, if not a number return default
   * @private
   * @param {number | string | null} value The value
   * @returns {number} Given value or default
   */
  isValidPageSize(value) {
    const val = stringToNumber(value);
    return !Number.isNaN(val) && val > 0 ? val : this.DEFAULT_PAGE_SIZE;
  }
  /** @param {number} value A 1-based index for the page number displayed */
  set pageNumber(value) {
    const pageNumber = this.pageNumber;
    const pageCount = this.pageCount;
    let val = stringToNumber(value);
    if (val !== pageNumber || pageNumber < 1 || pageCount && pageCount < pageNumber) {
      if (Number.isNaN(val) || val < 1) val = 1;
      else if (pageCount) val = Math.min(val, pageCount);
      this.setAttribute(attributes.PAGE_NUMBER, String(val));
    }
  }
  /** @returns {number} value A 1-based-index for the page number displayed */
  get pageNumber() {
    return Math.max(parseInt(this.getAttribute(attributes.PAGE_NUMBER) ?? "") || 1, 1);
  }
  /** @returns {number|null} The calculated pageCount using total and pageSize */
  get pageCount() {
    return this.total !== null && !Number.isNaN(this.total) ? Math.max(Math.ceil(this.total / this.pageSize), 1) : null;
  }
  /**
   * Set the number of step for page number list
   * @param {number|string} value The number of steps
   */
  set step(value) {
    const val = stringToNumber(value);
    if (!Number.isNaN(val)) {
      this.setAttribute(attributes.STEP, String(val));
      return;
    }
    this.removeAttribute(attributes.STEP);
  }
  /** @returns {number|string} value The number of steps */
  get step() {
    const val = stringToNumber(this.getAttribute(attributes.STEP));
    return !Number.isNaN(val) ? val : this.DEFAULT_STEP;
  }
  /** @param {number} value The number of items to track */
  set total(value) {
    let val = stringToNumber(value);
    const isDisable = val === 0;
    __privateMethod(this, _IdsPager_instances, updateButtonStates_fn).call(this, isDisable);
    if (Number.isNaN(val) || val < 1) val = 0;
    this.setAttribute(attributes.TOTAL, String(val));
    __privateMethod(this, _IdsPager_instances, keepPageNumberInBounds_fn).call(this);
  }
  /** @returns {number} The number of items the pager is tracking */
  get total() {
    return stringToNumber(this.getAttribute(attributes.TOTAL));
  }
  /** @param {number} value The number of items to track */
  set type(value) {
    this.setAttribute(attributes.TYPE, value);
  }
  /**
   * @returns {'buttons' | 'list'} Type of pager that should be displayed
   */
  get type() {
    return this.getAttribute(attributes.TYPE);
  }
  /**
   * Sync to refresh, must be called with related component reference as: `this.pager?.sync?.apply(this)`
   * @param {object} this The related component reference
   * @returns {void}
   */
  sync() {
    const props = ["total", "pageNumber", "pageSize"];
    const isValid = (v) => typeof v !== "undefined" && v !== null;
    props.forEach((prop) => {
      const pager = this.pager;
      const ds = this.datasource;
      const isValidProps = isValid(pager?.[prop]) && isValid(ds?.[prop]);
      if (this.initialized && isValidProps && pager[prop] !== ds[prop]) {
        this[prop] = ds[prop];
        pager[prop] = ds[prop];
      }
    });
  }
};
_IdsPager_instances = new WeakSet();
/**
 * Sync children with the given attribute
 * @param {string} attribute attribute to sync
 * @param {string|boolean} value value to sync
 * @private
 */
syncChildren_fn = function(attribute, value) {
  const pagerChildSelectors = [
    "ids-pager-input",
    "ids-pager-number-list",
    "ids-pager-button",
    "ids-pager-dropdown"
  ].join(", ");
  const pagerChildren = [
    ...this.shadowRoot?.querySelectorAll(pagerChildSelectors) || [],
    ...this.querySelectorAll(pagerChildSelectors)
  ];
  pagerChildren.forEach((element) => {
    element.setAttribute(attribute, String(value));
  });
};
keepPageNumberInBounds_fn = function() {
  const attrVal = Number.parseInt(this.getAttribute(attributes.PAGE_NUMBER) ?? "");
  let val = attrVal;
  if (Number.isNaN(val) || val <= 1) val = 1;
  else if (this.pageCount && val > this.pageCount) val = this.pageCount;
  this.elements.dropdowns.forEach((d) => {
    if (d.pageSize !== this.pageSize) d.pageSize = this.pageSize;
  });
  if (val !== attrVal && !Number.isNaN(attrVal)) this.setAttribute(attributes.PAGE_NUMBER, String(val));
};
/**
 * Sets the enabled/disabled state of navigation buttons and input field
 * @private
 * @param {boolean} shouldDisable - Determines whether to disable the pager elements
 * @returns {void}
 */
updateButtonStates_fn = function(shouldDisable) {
  const buttons = this.elements.buttons;
  buttonTypes.forEach((type) => {
    if (buttons[type]) {
      buttons[type].disabled = shouldDisable;
    }
  });
  if (this.elements.input) {
    this.elements.input.disabled = shouldDisable;
  }
};
IdsPager = __decorateClass([
  customElement("ids-pager"),
  scss(ids_pager_default)
], IdsPager);

export {
  IdsPager
};
//# sourceMappingURL=ids-chunk-M52KWQIB-full.js.map
