/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/utils/ids-color-utils/ids-color-utils.ts
function hexToRgba(hex, opacity) {
  let c;
  if (/^#([A-Fa-f0-9]{3}){1,2}$/.test(hex)) {
    c = hex.substring(1).split("");
    if (c.length === 3) {
      c = [c[0], c[0], c[1], c[1], c[2], c[2]];
    }
    c = `0x${c.join("")}`;
    if (opacity) {
      return `rgba(${[c >> 16 & 255, c >> 8 & 255, c & 255].join(" ")} / ${opacity})`;
    }
    return `rgb(${[c >> 16 & 255, c >> 8 & 255, c & 255].join(" ")})`;
  }
  return "";
}
function rgbaToHex(rgba, forceRemoveAlpha = false) {
  rgba = rgba.replace(" / ", ",").replaceAll(" ", ",");
  return `#${rgba.replace(/^rgba?\(|\s+|\)$/g, "").split(",").filter((string, index) => !forceRemoveAlpha || index !== 3).map((string) => parseFloat(string)).map((number, index) => index === 3 ? Math.round(number * 255) : number).map((number) => number.toString(16)).map((string) => string.length === 1 ? `0${string}` : string).join("")}`;
}
function contrastColor(bgColor, lightColor, darkColor) {
  const color = bgColor.charAt(0) === "#" ? bgColor.substring(1, 7) : bgColor;
  const r = parseInt(color.substring(0, 2), 16);
  const g = parseInt(color.substring(2, 4), 16);
  const b = parseInt(color.substring(4, 6), 16);
  return r * 0.299 + g * 0.587 + b * 0.114 > 186 ? darkColor : lightColor;
}
function builtinToRgba(colorName, opacity) {
  const el = document.createElement("div");
  el.style.color = colorName;
  document.body.appendChild(el);
  const cs = window.getComputedStyle(el);
  let rgb = cs.getPropertyValue("color");
  document.body.removeChild(el);
  rgb = rgb.replace(/,/g, "");
  if (opacity && rgb.indexOf("a") === -1) {
    return rgb.replace("rgb", "rgba").replace(")", ` / ${opacity})`);
  }
  return rgb;
}
function colorNameToRgba(colorName, opacity) {
  if (colorName.substring(0, 1) === "#") {
    return hexToRgba(colorName, opacity);
  }
  return builtinToRgba(colorName, opacity);
}
function darkenColor(hexColor, magnitude) {
  hexColor = hexColor.replace(`#`, ``);
  const decimalColor = parseInt(hexColor, 16);
  let r = (decimalColor >> 16) + magnitude;
  r > 255 && (r = 255);
  r < 0 && (r = 0);
  let g = (decimalColor & 255) + magnitude;
  g > 255 && (g = 255);
  g < 0 && (g = 0);
  let b = (decimalColor >> 8 & 255) + magnitude;
  b > 255 && (b = 255);
  b < 0 && (b = 0);
  let newHex = (g | b << 8 | r << 16).toString(16);
  if (newHex.length === 5) newHex = `0${newHex}`;
  if (newHex.length === 4 || newHex.length === 1) newHex = `00${newHex}`;
  return `#${newHex}`;
}
function lightenColor(hexColor, percent) {
  const rgba = hexToRgba(hexColor, percent);
  return rgbaToHex(rgba);
}
function adjustColor(hexColor, magnitude) {
  if (magnitude < 0) return darkenColor(hexColor, magnitude * 100);
  return lightenColor(hexColor, magnitude);
}
function statusToIDSColor(statusName) {
  let cssVariable;
  const statuses = [
    "base",
    "error",
    "warning",
    "caution",
    "success"
  ];
  if (statuses.includes(statusName)) {
    cssVariable = `var(--ids-color-${statusName})`;
  }
  return cssVariable || statusName;
}
function applyColorValue(color, elem, cssVar) {
  if (cssVar) elem?.style.removeProperty(cssVar);
  elem.style.color = "";
  if (!color || color === "neutral") {
    return;
  }
  if (color?.substring(0, 1) === "#") {
    elem.style.color = color;
    return;
  }
  if (["error", "warning", "caution", "success", "info"].includes(color) && cssVar) {
    elem?.style.setProperty(cssVar, `var(--ids-color-${color}-default)`);
    return;
  }
  if (["error", "warning", "caution", "success", "info"].includes(color) && cssVar) {
    elem?.style.setProperty(cssVar, `var(--ids-color-${color}-default)`);
    return;
  }
  if (["white", "black"].includes(color) && cssVar) {
    elem?.style.setProperty(cssVar, `var(--ids-color-${color})`);
    return;
  }
  if (["red", "yellow", "orange", "green", "blue", "teal", "purple", "neutral"].includes(color) && cssVar) {
    elem?.style.setProperty(cssVar, `var(--ids-color-${color}-default)`);
    return;
  }
  if (/^[a-z]+-\d{2,3}$/.test(color) && cssVar) {
    elem?.style.setProperty(cssVar, `var(--ids-color-${color})`);
    return;
  }
  if (cssVar) elem?.style.setProperty(cssVar, `var(--ids-color-${color})`);
}
function applyTextColorValue(value, elem) {
  elem.style.color = "";
  if (!value || value === "neutral") {
    return;
  }
  if (value?.substring(0, 1) === "#") {
    elem.style.color = value;
    return;
  }
  if (["error", "warning", "caution", "success", "info"].includes(value)) {
    elem.style.color = `var(--ids-color-${value}-default)`;
    return;
  }
  if (["white", "black"].includes(value)) {
    elem.style.color = `var(--ids-color-${value})`;
    return;
  }
  if (["red", "yellow", "orange", "green", "blue", "teal", "purple", "neutral"].includes(value)) {
    elem.style.color = `var(--ids-color-${value}-default)`;
    return;
  }
  if (/^[a-z]+-\d{2,3}$/.test(value)) {
    elem.style.color = `var(--ids-color-${value})`;
    return;
  }
  elem.style.color = `var(--ids-color-${value})`;
}
function isValidColor(color) {
  const hexadecimal = /^#([A-Fa-f0-9]{3}){1,2}$/;
  const colorToken = /^(red|blue|green|purple|teal|yellow|orange|neutral|gray)-(10|20|30|40|50|60|70|80|90|100)$/;
  const cssvariable = /^var\(--ids-color-[a-zA-Z0-9-]+\)$/;
  return hexadecimal.test(color) || cssvariable.test(color) || colorToken.test(color);
}

export {
  hexToRgba,
  rgbaToHex,
  contrastColor,
  builtinToRgba,
  colorNameToRgba,
  adjustColor,
  statusToIDSColor,
  applyColorValue,
  applyTextColorValue,
  isValidColor
};
//# sourceMappingURL=ids-chunk-NFOUOPCI-full.js.map
