/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  BLOCK_ELEMENTS
} from "./ids-chunk-XPCTTAAV-full.js";

// src/components/ids-editor/ids-editor-selection-utils.ts
function blockElem(sel) {
  let tagName = "";
  let el = sel.anchorNode;
  if (el && el.tagName) tagName = el.tagName.toLowerCase();
  while (el && BLOCK_ELEMENTS.indexOf(tagName) === -1) {
    el = el.parentNode;
    if (el && el.tagName) tagName = el.tagName.toLowerCase();
  }
  return { el, tagName };
}
function selectionBlockElems(sel, elem) {
  if (sel.anchorOffset <= 1 && sel.focusOffset === 0) {
    const elements = BLOCK_ELEMENTS.join(", ");
    return [[...elem.querySelectorAll(elements)][0]];
  }
  return [...elem.querySelectorAll(BLOCK_ELEMENTS.join(", "))].filter((el) => sel.containsNode(el, true));
}
function saveSelectionObject(sel) {
  const selection = sel;
  if (!selection.rangeCount || !selection) return null;
  const range = selection.getRangeAt(0);
  return {
    anchorNode: range.startContainer,
    anchorOffset: range.startOffset,
    focusNode: range.endContainer,
    focusOffset: range.endOffset
  };
}
function restoreObjectSelection(selectionObject) {
  if (selectionObject) {
    const selection = window.getSelection();
    selection?.removeAllRanges();
    const range = document.createRange();
    const startLength = selectionObject.anchorNode.textContent?.length || 0;
    const endLength = selectionObject.focusNode.textContent?.length || 0;
    const safeStartOffset = Math.min(selectionObject.anchorOffset, startLength);
    const safeEndOffset = Math.min(selectionObject.focusOffset, endLength);
    range.setStart(selectionObject.anchorNode, safeStartOffset);
    range.setEnd(selectionObject.focusNode, safeEndOffset);
    selection?.addRange(range);
  }
}
function restoreSelection(sel, savedSel) {
  if (savedSel) {
    sel.removeAllRanges();
    savedSel.forEach((s) => sel.addRange(s));
  }
}
function selectionParents(sel, elem) {
  const parents = {};
  if (sel.anchorOffset <= 1 && sel.focusOffset === 0) {
    return [[...elem.querySelectorAll(BLOCK_ELEMENTS.join(", "))][0]];
  }
  if (sel.focusNode && sel.containsNode(elem, true)) {
    let node = sel.focusNode;
    while (node && node !== elem) {
      if (node instanceof HTMLElement) {
        const tag = node.tagName.toLowerCase();
        parents[tag] = { tag, node };
      }
      node = node.parentNode;
    }
  }
  return parents;
}
function findElementInSelection(sel, container, tagName) {
  const range = sel.getRangeAt(0);
  if (range && container.contains(sel.focusNode)) {
    const selectionParent = range.commonAncestorContainer;
    for (let el = selectionParent; el && el !== container; el = el.parentElement) {
      if (el && el.tagName && el.tagName.toLowerCase() === tagName) {
        return el;
      }
    }
    if (!range.collapsed && selectionParent instanceof Element) {
      const elemsInside = [...selectionParent.getElementsByTagName(tagName)];
      const elemRange = document.createRange();
      for (let i = 0; i < elemsInside.length; i++) {
        const elem = elemsInside[i];
        elemRange.selectNodeContents(elem);
        if (range.compareBoundaryPoints(Range.END_TO_START, elemRange) < 0 && range.compareBoundaryPoints(Range.START_TO_END, elemRange) > 0) {
          return elem;
        }
      }
    }
  }
  return null;
}

export {
  blockElem,
  selectionBlockElems,
  saveSelectionObject,
  restoreObjectSelection,
  restoreSelection,
  selectionParents,
  findElementInSelection
};
//# sourceMappingURL=ids-chunk-QGDGN24E-full.js.map
