/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsModal
} from "./ids-chunk-26ESDNQI-full.js";
import {
  customElement,
  scss
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";
import {
  __decorateClass,
  __privateAdd,
  __privateMethod
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-error-page/ids-error-page.scss
var ids_error_page_default = `ids-popup::part(popup) {
  max-width: 335px;
}
/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VSb290IjoiL3Jvb3QvZW50ZXJwcmlzZS9zcmMvY29tcG9uZW50cy9pZHMtZXJyb3ItcGFnZSIsInNvdXJjZXMiOlsiaWRzLWVycm9yLXBhZ2Uuc2NzcyJdLCJuYW1lcyI6W10sIm1hcHBpbmdzIjoiQUFBQTtFQUNFIiwic291cmNlc0NvbnRlbnQiOlsiaWRzLXBvcHVwOjpwYXJ0KHBvcHVwKSB7XG4gIG1heC13aWR0aDogMzM1cHg7XG59XG4iXX0= */`;

// src/components/ids-error-page/ids-error-page.ts
var DEFAULT_ICON = "empty-error-loading";
var _IdsErrorPage_instances, attachEventHandlers_fn, refreshText_fn;
var IdsErrorPage = class extends IdsModal {
  constructor() {
    super();
    __privateAdd(this, _IdsErrorPage_instances);
  }
  connectedCallback() {
    super.connectedCallback();
    __privateMethod(this, _IdsErrorPage_instances, attachEventHandlers_fn).call(this);
    this.overlay.visible = true;
  }
  static get attributes() {
    return [
      ...super.attributes,
      attributes.BUTTON_TEXT,
      attributes.DESCRIPTION,
      attributes.ICON,
      attributes.LABEL
    ];
  }
  template() {
    return `<ids-popup part="modal" class="ids-modal ids-error" type="modal" position-style="viewport">
      <div class="ids-modal-container" slot="content">
        <ids-empty-message icon="${this.icon ?? DEFAULT_ICON}">
          <ids-text
            type="h2"
            font-size="24"
            font-weight="semi-bold"
            label="true"
            slot="label"
          >
          ${this.label ?? "Add Label"}
          </ids-text>
          <ids-text label="true" slot="description">
            ${this.description ?? "Add Description"}
          </ids-text>
          <ids-button class="action-button" slot="button" appearance="primary">
            <span>${this.buttonText ?? "Action"}</span>
          </ids-button>
        </ids-empty-message>
      </div>
    </ids-popup>`;
  }
  /**
   * Set the icon
   * @param {string} value icon id
   * @memberof IdsErrorPage
   */
  set icon(value) {
    if (value) {
      this.setAttribute(attributes.ICON, value);
    } else {
      this.removeAttribute(attributes.ICON);
    }
    if (!this.container) return;
    const emptyMessage = this.container.querySelector("ids-empty-message");
    if (emptyMessage) {
      emptyMessage.icon = value;
    }
  }
  /**
   * Get the icon
   * @returns {string} the icon attribute
   * @readonly
   * @memberof IdsErrorPage
   */
  get icon() {
    return this.getAttribute(attributes.ICON);
  }
  /**
   * Set the label
   * @param {string} value label text
   * @memberof IdsErrorPage
   */
  set label(value) {
    if (value) {
      this.setAttribute(attributes.LABEL, value);
    } else {
      this.removeAttribute(attributes.LABEL);
    }
    __privateMethod(this, _IdsErrorPage_instances, refreshText_fn).call(this, '[slot="label"]', value);
    this.refreshAriaLabel();
  }
  /**
   * Get the label
   * @returns {string} the label text
   * @readonly
   * @memberof IdsErrorPage
   */
  get label() {
    return this.getAttribute(attributes.LABEL);
  }
  /**
   * Set the description text
   * @param {string} value description text
   * @memberof IdsErrorPage
   */
  set description(value) {
    if (value) {
      this.setAttribute(attributes.DESCRIPTION, value);
    } else {
      this.removeAttribute(attributes.DESCRIPTION);
    }
    __privateMethod(this, _IdsErrorPage_instances, refreshText_fn).call(this, '[slot="description"]', value);
    this.refreshAriaLabel();
  }
  /**
   * Get the description text
   * @returns {string} the description text
   * @readonly
   * @memberof IdsErrorPage
   */
  get description() {
    return this.getAttribute(attributes.DESCRIPTION);
  }
  /**
   * Set the button text
   * @param {string} value button text
   * @memberof IdsErrorPage
   */
  set buttonText(value) {
    if (value) {
      this.setAttribute(attributes.BUTTON_TEXT, value);
    } else {
      this.removeAttribute(attributes.BUTTON_TEXT);
    }
    __privateMethod(this, _IdsErrorPage_instances, refreshText_fn).call(this, '[slot="button"]', value);
  }
  /**
   * Get the button text
   * @returns {string} button text
   * @readonly
   * @memberof IdsErrorPage
   */
  get buttonText() {
    return this.getAttribute(attributes.BUTTON_TEXT);
  }
  /**
   * Used for ARIA Labels and other content
   * @readonly
   * @returns {string} concatenating the label and description.
   */
  get ariaLabelContent() {
    const label = this.querySelector('[slot="label"')?.innerText;
    return `${label || ""} ${this.label || ""} ${this.description || ""}`;
  }
};
_IdsErrorPage_instances = new WeakSet();
/**
 * Attach the error page event handlers
 * @private
 */
attachEventHandlers_fn = function() {
  const button = this.container?.querySelector(".action-button");
  const actionBtnEvent = "action-button";
  this.onEvent("click", button, (e) => {
    this.triggerEvent(actionBtnEvent, this, {
      detail: {
        elem: this,
        nativeEvent: e
      }
    });
  });
  this.onEvent("touchend", button, (e) => {
    this.triggerEvent(actionBtnEvent, this, {
      detail: {
        elem: this,
        nativeEvent: e
      }
    });
  });
};
/**
 * Refresh the text attributes
 * @param {string} el dom element selector to query
 * @param {string} value attribute value
 * @private
 */
refreshText_fn = function(el, value) {
  if (!this.container) return;
  const elText = this.container.querySelector(el);
  if (elText) {
    elText.innerHTML = value ? value.toString() : "";
  }
};
IdsErrorPage = __decorateClass([
  customElement("ids-error-page"),
  scss(ids_error_page_default)
], IdsErrorPage);

export {
  IdsErrorPage
};
//# sourceMappingURL=ids-chunk-QT7WDS7O-full.js.map
