/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  getClosestContainerNode
} from "./ids-chunk-LQYSVESW-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-attachment-mixin/ids-attachment-mixin.ts
var IdsAttachmentMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.ATTACHMENT
    ];
  }
  /**
   * Original parent element reference
   */
  originalParentElement;
  /**
   * Attachment behavior's target element reference
   */
  attachmentParentElement;
  /**
   * @param {string | null} val CSS selector string representing a target element
   */
  set attachment(val) {
    if (val && val.length) {
      this.setAttribute(attributes.ATTACHMENT, val);
      this.#setAttachmentParent(val);
    } else {
      this.removeAttribute(attributes.ATTACHMENT);
      this.attachmentParentElement = null;
    }
  }
  /**
   * @returns {string | null} CSS selector string representing a target element
   */
  get attachment() {
    return this.getAttribute(attributes.ATTACHMENT);
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.originalParentElement = this.parentElement;
    if (this.hasAttribute(attributes.ATTACHMENT)) this.#setAttachmentParent(this.getAttribute(attributes.ATTACHMENT));
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
    this.originalParentElement = null;
    this.attachmentParentElement = null;
  }
  #setAttachmentParent(val) {
    const containerNode = getClosestContainerNode(this);
    const parentElem = containerNode.querySelector(`${val}`);
    this.attachmentParentElement = parentElem;
    if (val === "body") {
      this.attachmentParentElement = document.querySelector("body");
    }
  }
  /**
   * Appends this component to the specified target
   * @returns {void}
   */
  appendToTargetParent() {
    if (!this.attachmentParentElement) return;
    if (this.id) {
      const [first, ...others] = this.attachmentParentElement.querySelectorAll(`#${this.id}`);
      if (first && others.length) {
        others.forEach((elem) => {
          elem.remove();
        });
      }
    }
    this.attachmentParentElement.append(this);
  }
  /**
   * Appends this component to the its original parent element
   * @returns {void}
   */
  appendToOriginalParent() {
    if (!this.originalParentElement) return;
    this.originalParentElement.append(this);
  }
};
var ids_attachment_mixin_default = IdsAttachmentMixin;

export {
  ids_attachment_mixin_default
};
//# sourceMappingURL=ids-chunk-R42WXYZK-full.js.map
