/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsMenuButton
} from "./ids-chunk-DC2YKNGX-full.js";
import {
  escapeHTML
} from "./ids-chunk-5K4YUTOH-full.js";
import {
  ids_events_mixin_default
} from "./ids-chunk-KKFANICI-full.js";
import {
  IdsElement
} from "./ids-chunk-UTR2KJV7-full.js";
import {
  customElement
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet,
  __publicField
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-data-grid/ids-data-grid-header.ts
var _columns, _IdsDataGridHeader_instances, attachEventHandlers_fn, attachSortHandler_fn, attachSelectionHandler_fn, attachResizeHandlers_fn, attachReorderHandlers_fn, attachFilterBtnHandler_fn;
var IdsDataGridHeader = class extends ids_events_mixin_default(IdsElement) {
  constructor() {
    super({ noShadowRoot: true });
    __privateAdd(this, _IdsDataGridHeader_instances);
    __publicField(this, "rootNode");
    __publicField(this, "headerCheckbox");
    __publicField(this, "columnCheckbox");
    /**
     * Tracks the state of the header expander
     */
    __publicField(this, "isHeaderExpanderCollapsed", false);
    /** @see IdsDataGridHeader.columns */
    __privateAdd(this, _columns);
    this.state = {
      headerMenuData: null
    };
  }
  connectedCallback() {
    super.connectedCallback();
    __privateMethod(this, _IdsDataGridHeader_instances, attachEventHandlers_fn).call(this);
  }
  /**
   * Reference to the data grid parent
   * @returns {IdsDataGrid} the data grid parent
   */
  get dataGrid() {
    if (!this.rootNode) this.rootNode = this.getRootNode().host;
    return this.rootNode;
  }
  /* Returns all the ids-icon.header-expander elements in an array */
  get expanderIcons() {
    return [...this.querySelectorAll("ids-icon.header-expander")];
  }
  /* Returns all the columns in the header */
  get columns() {
    if (!__privateGet(this, _columns)?.length) {
      __privateSet(this, _columns, [...this.querySelectorAll(".ids-data-grid-header-cell")]);
    }
    return __privateGet(this, _columns);
  }
  /**
   * Returns all the columns in the header
   * @see IdsDataGridCell.isOnScreen()
   * @returns {HTMLElement[]} array of onscreen header columns
   */
  get columnsOnscreen() {
    return [...this.querySelectorAll(".ids-data-grid-header-cell[column-onscreen]")];
  }
  /**
   * Set header expander state
   */
  setIsHeaderExpanderCollapsed() {
    const all = this.dataGrid?.rows?.filter((r) => r?.hasAttribute("aria-expanded")) || [];
    const collapsedRows = all.filter((r) => r?.getAttribute("aria-expanded") === "false");
    if (all.length && all.length === collapsedRows.length) this.isHeaderExpanderCollapsed = true;
  }
  /**
   * Sets the state of the ids-icon.header-expander elements to open/expanded.
   */
  openExpanderIcons() {
    this.isHeaderExpanderCollapsed = false;
    this.expanderIcons?.forEach((iconElement) => {
      iconElement.icon = `plusminus-folder-open`;
    });
  }
  /**
   * Sets the state of the ids-icon.header-expander elements to closed/collapsed.
   */
  closeExpanderIcons() {
    this.isHeaderExpanderCollapsed = true;
    this.expanderIcons?.forEach((iconElement) => {
      iconElement.icon = `plusminus-folder-closed`;
    });
  }
  /**
   * Set the header checkbox state
   * @private
   */
  setHeaderCheckbox() {
    if (!this.dataGrid?.rowSelection || this.dataGrid?.rowSelection === "single" || !this.headerCheckbox) {
      return;
    }
    const selectedCount = this.dataGrid?.selectedRows.length;
    const dataCount = this.dataGrid?.data.length;
    if (selectedCount === 0) {
      this.headerCheckbox.classList.remove("indeterminate");
      this.headerCheckbox.classList.remove("checked");
      this.headerCheckbox.setAttribute("aria-checked", "false");
      return;
    }
    if (selectedCount === dataCount) {
      this.headerCheckbox.classList.remove("indeterminate");
      this.headerCheckbox.classList.add("checked");
      this.headerCheckbox.setAttribute("aria-checked", "true");
      return;
    }
    if (selectedCount !== dataCount) {
      this.headerCheckbox.classList.add("indeterminate");
      this.headerCheckbox.setAttribute("aria-checked", "mixed");
    }
  }
  /**
   * Set the checked status on the column header checkbox
   * @param {number} index Column index
   * @param {boolean} value True for checked, false for unchecked
   */
  setColumnCheckbox(index, value) {
    if (this.columnCheckbox && this.columnCheckbox[index]) {
      const checkbox = this.columnCheckbox[index];
      checkbox.checked = value;
    }
  }
  /**
   * Sets the disabled attribute of header checkbox
   * @param {boolean} value attribute value to set
   */
  disableHeaderCheckbox(value) {
    if (!this.headerCheckbox) {
      return;
    }
    this.headerCheckbox.setAttribute("disabled", String(value));
    this.headerCheckbox.parentElement?.setAttribute("disabled", String(value));
  }
  /**
   * Sets the disabled attribute of header checkbox
   * @param {boolean} value attribute value to set
   */
  hideHeaderCheckbox(value) {
    if (!this.headerCheckbox) {
      return;
    }
    if (value) {
      this.headerCheckbox.setAttribute("hidden", String(value));
    } else {
      this.headerCheckbox.removeAttribute("hidden");
    }
  }
  /**
   * Set the sort column and sort direction on the UI only
   * @param {string} id The column id (or field) to set
   * @param {boolean} ascending Sort ascending (lowest first) or descending (lowest last)
   */
  setSortState(id, ascending) {
    const sortedHeaders = [...this.querySelectorAll(".is-sortable")].map((sorted) => sorted.closest(".ids-data-grid-header-cell"));
    sortedHeaders.forEach((header2) => header2?.removeAttribute("aria-sort"));
    const header = this.querySelector(`[column-id="${id}"]`);
    if (header && sortedHeaders.includes(header)) {
      header.setAttribute("aria-sort", ascending ? "ascending" : "descending");
    }
  }
  /**
   * Resets sort header sort states
   */
  resetSortStates() {
    this.querySelectorAll(".ids-data-grid-header-cell").forEach((elem) => elem.removeAttribute("aria-sort"));
  }
  /**
   * Set filter row to be shown or hidden
   * @private
   * @returns {object} This API object for chaining
   */
  setFilterRow() {
    const nodes = this?.querySelectorAll(".ids-data-grid-header-cell-filter-wrapper");
    nodes?.forEach((n) => n?.classList?.[this.dataGrid?.filterable ? "remove" : "add"]("hidden"));
    this.dataGrid?.triggerEvent(this.dataGrid?.filterable ? "filterrowopened" : "filterrowclosed", this.dataGrid, {
      detail: { elem: this, filterable: this.dataGrid?.filterable }
    });
    return this;
  }
  /**
   * Return the Template for the header contents
   * @param {IdsDataGrid} datagrid visible columns in the data grid
   * @returns {string} The template
   */
  static template(datagrid) {
    const html = `<ids-data-grid-header class="ids-data-grid-header${datagrid.hasFrozenColumns ? " is-frozen" : ""}" role="rowgroup" part="header">
      <ids-data-grid-row class="ids-data-grid-row${datagrid.colSelection ? " has-col-selection" : ""}" role="row">
        ${datagrid.visibleColumns.map((columnData, index) => `${this.headerCellTemplate(datagrid, columnData, index)}`).join("")}
      </ids-data-grid-row>
    </ids-data-grid-header>`;
    return this.columnGroupsTemplate(datagrid) + html;
  }
  /**
   * Returns the markup for a header cell.
   * @param {IdsDataGrid} dataGrid visible columns in the data grid
   * @param {IdsDataGridColumn} column The column info
   * @param {number} index The column index
   * @returns {string} The resuling header cell template
   */
  static headerCellTemplate(dataGrid, column, index) {
    const selectionCheckBoxTemplate = `
      <span class="ids-data-grid-checkbox-container" disabled="${dataGrid.disableHeaderCheckbox}">
        <span
          role="checkbox"
          ${dataGrid.hideHeaderCheckbox ? "hidden" : ""}
          disabled="${dataGrid.disableHeaderCheckbox}"
          aria-checked="false"
          aria-label="${column.name}"
          class="ids-data-grid-checkbox"
        >
        </span>
      </span>
    `;
    const sortIconSize = dataGrid.rowHeight === "xxs" ? 'size="small"' : "";
    const sortIndicatorTemplate = `
      <span class="sort-indicator">
        <ids-icon icon="dropdown" ${sortIconSize}></ids-icon>
        <ids-icon icon="dropdown" ${sortIconSize}></ids-icon>
      </span>
    `;
    const expanderTemplate = `<ids-icon class="header-expander" icon="plusminus-folder-closed"></ids-icon>`;
    const resizerTemplate = `<span class="resizer"></span>`;
    const reorderTemplate = `<div class="reorderer"><ids-icon icon="drag" size="medium"></ids-icon></div>`;
    const showFormatterExpander = ["expander", "tree"].includes(column.formatter?.name ?? "");
    const showHeaderExpander = column?.showHeaderExpander || showFormatterExpander;
    const expander = showHeaderExpander ? expanderTemplate : "";
    const selectionCheckbox = column.id !== "selectionRadio" && column.id === "selectionCheckbox";
    let colName = "";
    if (Array.isArray(column.name)) {
      colName = `
        ${escapeHTML(column.name[0].text)}
        <br>
        ${column.name[1].emphasis === "subtle" ? "<small>" : ""}
        ${escapeHTML(column.name[1].text)}
        ${column.name[1].emphasis === "subtle" ? "</small>" : ""}
      `;
    } else {
      colName = escapeHTML(column.name);
    }
    const headerName = column.id !== "selectionRadio" && column.id !== "selectionCheckbox" && colName ? colName : "";
    const headerLabel = `${dataGrid?.colSelection && column.id !== "selectionRadio" && column.id !== "selectionCheckbox" ? `<div class="ids-checkbox">
        <label>
          <input type="checkbox"/>
          <span class="checkmark"></span>
          <span class="ids-text label-text">${headerName}</span>
        </label>
      </div>` : headerName}`;
    const headerContentTemplate = `
      ${selectionCheckbox ? selectionCheckBoxTemplate : ""}
      ${headerLabel}
    `.trim();
    let cssClasses = "ids-data-grid-header-cell-content";
    cssClasses += column.sortable ? " is-sortable" : "";
    cssClasses += selectionCheckbox ? " has-selectioncheckbox vertical-align-center" : "";
    cssClasses += column.headerIcon ? " has-headericon" : "";
    cssClasses += column.reorderable ? " is-reorderable" : "";
    cssClasses += column?.showHeaderExpander ? " column-header-expander" : "";
    const headerContentWrapperTemplate = `<span class="${cssClasses}">
        ${expander}
        ${column.sortable && (column.headerAlign === "right" || !column.headerAlign && column.align === "right") ? sortIndicatorTemplate : ""}
        <span class="ids-data-grid-header-text">
          ${headerContentTemplate}
        </span>
        ${this.headerIconTemplate(column)}
        ${column.sortable && (column.headerAlign !== "right" && (!column.headerAlign ? column.align !== "right" : true)) ? sortIndicatorTemplate : ""}
      </span>${column.resizable ? resizerTemplate : ""}${column.reorderable ? reorderTemplate : ""}`;
    const headerFilterWrapperTemplate = dataGrid?.filters?.filterTemplate(column) || "";
    let align = column.align ? ` align-${column.align}` : "";
    if (column.headerAlign) {
      align = ` align-${column.headerAlign}`;
    }
    const lastFrozen = dataGrid?.leftFrozenColumns.length;
    let frozen = column?.frozen ? ` frozen frozen-${column?.frozen}${index + 1 === lastFrozen ? " frozen-last" : ""}` : "";
    const lastFrozenData = dataGrid.visibleColumns.filter((obj) => obj.frozen === "left").at(-1);
    const lastFrozenIndex = dataGrid.visibleColumns.findIndex((obj) => obj.id === lastFrozenData?.id);
    if (frozen === "" && index < lastFrozenIndex) {
      frozen = ` frozen frozen-${lastFrozenData?.frozen}`;
      column.frozen = lastFrozenData?.frozen;
    }
    if (index === lastFrozenIndex && frozen !== "" && frozen.indexOf("last") < 0) frozen += ` frozen-last`;
    const isUppercase = () => {
      if (typeof column?.uppercase === "function") return column.uppercase("header-cell", column, index);
      return column?.uppercase === "true" || column?.uppercase === true;
    };
    let headerCssClasses = isUppercase() ? " is-uppercase" : "";
    headerCssClasses += column?.showHeaderExpander || column.sortable || column.reorderable ? " is-actionable" : "";
    const html = `
      <span
        class="ids-data-grid-header-cell${headerCssClasses}${align}${frozen}"
        ${column.reorderable ? 'draggable="true"' : ""}
        part="header-cell"
        aria-colindex="${index + 1}"
        column-id="${column.id}"
        role="columnheader">
        ${headerContentWrapperTemplate}
        ${headerFilterWrapperTemplate}
      </span>
    `;
    return html;
  }
  /**
   * Returns the markup for a header icon.
   * @param {IdsDataGridColumn | IdsDataGridColumnGroup} column The column info
   * @returns {string} The resuling header icon template
   */
  static headerIconTemplate(column) {
    const headerIcon = typeof column?.headerIcon === "string" ? column.headerIcon : "";
    if (headerIcon === "") return "";
    const headerIconTooltip = column.headerIconTooltip || headerIcon;
    return `
      <span class="ids-data-grid-header-icon" data-headericontooltip="${headerIconTooltip}">
        <ids-icon icon="${headerIcon}" size="medium"></ids-icon>
      </span>`;
  }
  /**
   * Returns the markup for the grouped header cells.
   * @param {IdsDataGrid} dataGrid The datagrid reference
   * @returns {string} The resuling header cell template
   */
  static columnGroupsTemplate(dataGrid) {
    if (!dataGrid?.columnGroups) {
      return "";
    }
    let columnGroupHtml = `<ids-data-grid-header class="ids-data-grid-header column-groups" part="header" role="rowgroup">
    <div role="row" class="ids-data-grid-row ids-data-grid-column-groups">`;
    dataGrid?.columnGroups.forEach((columnGroup) => {
      const align = columnGroup.align ? ` align-${columnGroup.align}` : "";
      let cssClasses = "ids-data-grid-header-cell-content";
      cssClasses += columnGroup.headerIcon ? " has-headericon" : "";
      const html = `<span class="ids-data-grid-header-cell${align}" part="header-cell" column-group-id="${columnGroup.id || "id"}" role="columnheader">
        <span class="${cssClasses}">
          <span class="ids-data-grid-header-text">
            ${columnGroup.name || ""}
          </span>
          ${this.headerIconTemplate(columnGroup)}
        </span>
      </span>`;
      columnGroupHtml += html;
    });
    columnGroupHtml += "</div></ids-data-grid-header>";
    return columnGroupHtml;
  }
};
_columns = new WeakMap();
_IdsDataGridHeader_instances = new WeakSet();
/**
 * Handle all header related events
 * @private
 */
attachEventHandlers_fn = function() {
  __privateMethod(this, _IdsDataGridHeader_instances, attachSelectionHandler_fn).call(this);
  __privateMethod(this, _IdsDataGridHeader_instances, attachSortHandler_fn).call(this);
  __privateMethod(this, _IdsDataGridHeader_instances, attachResizeHandlers_fn).call(this);
  __privateMethod(this, _IdsDataGridHeader_instances, attachReorderHandlers_fn).call(this);
  __privateMethod(this, _IdsDataGridHeader_instances, attachFilterBtnHandler_fn).call(this);
};
/**
 * Attach handlers to sort via clicking the headers
 * @private
 */
attachSortHandler_fn = function() {
  this.offEvent("click.sort", this);
  this.onEvent("click.sort", this, (e) => {
    if (this.dataGrid?.isResizing) {
      this.dataGrid.isResizing = false;
      return;
    }
    if (this.dataGrid?.isSelecting) {
      this.dataGrid.isSelecting = false;
      return;
    }
    if (e.target?.classList?.contains("header-expander")) {
      const isColumnHeaderExpander = e.target?.closest(".column-header-expander");
      if (!isColumnHeaderExpander && !this.dataGrid?.showHeaderExpander) return;
      const wasHeaderExpanderCollapsed = this.isHeaderExpanderCollapsed;
      this.isHeaderExpanderCollapsed = !wasHeaderExpanderCollapsed;
      if (wasHeaderExpanderCollapsed) {
        this.dataGrid.expandAll();
      } else {
        this.dataGrid.collapseAll();
      }
      return;
    }
    const sortableHeaderCell = e.target.closest(".is-sortable")?.closest(".ids-data-grid-header-cell");
    if (!sortableHeaderCell) return;
    const id = sortableHeaderCell.getAttribute("column-id");
    const state = sortableHeaderCell.getAttribute("aria-sort") !== "ascending";
    if (!this.dataGrid.disableClientSort) {
      this.dataGrid?.setSortColumn(id, state);
    } else {
      this.dataGrid?.setSortState(id, state, true);
    }
    this.dataGrid?.updateSelectionBorder(true);
    this.dataGrid?.updateSelectedCells();
  });
};
/**
 * Attach handlers to sort via clicking the headers
 * @private
 */
attachSelectionHandler_fn = function() {
  this.headerCheckbox = this.querySelector("ids-data-grid-header .ids-data-grid-checkbox-container .ids-data-grid-checkbox");
  this.offEvent("click.select", this.headerCheckbox);
  this.onEvent("click.select", this.headerCheckbox, (e) => {
    if (e.target.classList.contains("checked") || e.target.classList.contains("indeterminate")) {
      this.dataGrid?.deSelectAllRows();
    } else {
      this.dataGrid?.selectAllRows();
    }
  });
  this.columnCheckbox = this.querySelectorAll("ids-data-grid-header .ids-data-grid-header-text .ids-checkbox input");
  for (let i = 0; i < this.columnCheckbox.length; i++) {
    this.offEvent("click", this.columnCheckbox[i]);
    this.onEvent("click", this.columnCheckbox[i], () => {
      const isSelect = this.columnCheckbox[i].checked;
      this.dataGrid.isSelecting = true;
      if (isSelect) {
        this.dataGrid?.selectColumn(i);
      } else {
        this.dataGrid?.deSelectColumn(i);
      }
    });
  }
};
/**
 * Establish Drag handlers for resize
 * Based on https://htmldom.dev/resize-columns-of-a-table/
 * @private
 */
attachResizeHandlers_fn = function() {
  let x = 0;
  let w = 0;
  let columnId = "";
  let columnElem;
  const mouseMoveHandler = (e) => {
    e.preventDefault();
    const dx = e.clientX - x;
    const isLastColumn = this.dataGrid?.columns[this.dataGrid.columns.length - 1]?.id === columnId;
    if (isLastColumn) {
      const headerElement = this.closest(".ids-data-grid-header");
      const parentElement = headerElement?.parentElement;
      if (headerElement && parentElement) {
        const newWidth = w + (!this.dataGrid?.localeAPI.isRTL() ? dx : -dx);
        if (newWidth >= 92) {
          this.dataGrid?.setColumnWidth(columnId, newWidth);
        }
      }
    } else {
      this.dataGrid?.setColumnWidth(columnId, w + (!this.dataGrid?.localeAPI.isRTL() ? dx : -dx));
    }
    this.dataGrid?.updateSelectionBorder();
  };
  const mouseUpHandler = () => {
    document.removeEventListener("mousemove", mouseMoveHandler);
    document.removeEventListener("mouseup", mouseUpHandler);
    this?.style.setProperty("cursor", "");
    requestAnimationFrame(() => {
      this.dataGrid.isResizing = false;
      columnElem?.parentElement?.querySelectorAll("[draggable]").forEach((el) => el.setAttribute("draggable", "true"));
    });
  };
  this.offEvent("mousedown.resize", this);
  this.onEvent("mousedown.resize", this, (e) => {
    const target = e.target;
    if (!target.classList.contains("resizer")) {
      return;
    }
    x = e.clientX;
    columnElem = target.closest(".ids-data-grid-header-cell");
    columnElem.parentElement?.querySelectorAll("[draggable]").forEach((el) => el.setAttribute("draggable", "false"));
    const colStyles = window.getComputedStyle(columnElem);
    columnId = columnElem.getAttribute("column-id") || "";
    w = parseInt(colStyles.width, 10);
    document.addEventListener("mousemove", mouseMoveHandler);
    document.addEventListener("mouseup", mouseUpHandler);
    this?.style.setProperty("cursor", "col-resize");
    this.dataGrid.isResizing = true;
  });
};
/**
 * Establish Reorder handlers for moving columns
 * @private
 */
attachReorderHandlers_fn = function() {
  const dragArrows = this.dataGrid?.wrapper?.querySelector(".ids-data-grid-sort-arrows");
  let dragger;
  let startIndex = 0;
  let dragInitiated = false;
  let dragParent;
  this.offEvent("mousedown.reorder", this);
  this.onEvent("mousedown.reorder", this, (e) => {
    const nodeName = e.target.nodeName;
    if (nodeName === "IDS-INPUT") {
      dragParent = e.target.closest(".ids-data-grid-header-cell");
      dragParent?.setAttribute("draggable", "false");
    }
  });
  this.offEvent("mouseup.reorder", this);
  this.onEvent("mouseup.reorder", this, () => {
    dragParent?.setAttribute("draggable", "true");
  });
  this.offEvent("dragstart.reorder", this);
  this.onEvent("dragstart.reorder", this, (e) => {
    const selection = window.getSelection();
    if (selection && selection.toString().length > 0) {
      return;
    }
    const target = e.target;
    const nodeName = e.target.nodeName;
    if (this.dataGrid.isResizing || !target || nodeName === "IDS-INPUT") return;
    dragInitiated = true;
    target.classList.add("active-drag-column");
    dragger = target.cloneNode(true);
    dragger.classList.add("dragging");
    if (this.dataGrid?.localeAPI.isRTL()) {
      dragger.style.insetInlineStart = `${this.offsetLeft}px`;
      dragger.style.zIndex = "-5";
    }
    this?.appendChild(dragger);
    e?.dataTransfer?.setDragImage(dragger, this.dataGrid?.localeAPI.isRTL() ? 100 : 10, 18);
    startIndex = target.getAttribute("aria-colindex");
  });
  this.offEvent("dragenter.reorder", this);
  this.onEvent("dragenter.reorder", this, (e) => {
    if (!dragInitiated) {
      if (e.target?.getAttribute("color-variant") === "alternate-formatter") {
        e.target.style.backgroundColor = "var(--ids-data-grid-filter-input-drop-background-color)";
      }
      return;
    }
    const cell = e.target.closest(".ids-data-grid-header-cell");
    if (!cell) return;
    if (cell.classList.contains("active-drag-column")) {
      dragArrows?.style.setProperty("display", "none");
      return;
    }
    const rect = cell.getBoundingClientRect();
    const curIndex = parseInt(cell.getAttribute("aria-colindex") || "0", 10);
    const startIdx = parseInt(startIndex.toString() ?? "0", 10);
    let cellLeft = rect.left + (startIdx < curIndex ? rect.width + 1 : 1);
    const cellRight = rect.left + (startIdx < curIndex ? 1 : rect.width + 1);
    let offsetLeft = 0;
    if (this.offsetParent) {
      offsetLeft = this.offsetParent.getBoundingClientRect().left - this.offsetParent.offsetLeft;
    }
    cellLeft = cellLeft < 3 ? 0 : cellLeft;
    dragArrows?.style.setProperty("display", "");
    dragArrows?.style.setProperty("inset-inline-start", `${this.dataGrid?.localeAPI.isRTL() ? offsetLeft - cellRight : cellLeft - offsetLeft}px`);
    dragArrows?.style.setProperty("height", `${rect.height - 2}px`);
    dragArrows?.style.setProperty("display", "block");
    e.preventDefault();
  });
  this.offEvent("dragover.reorder", this);
  this.onEvent("dragover.reorder", this, (e) => {
    if (!dragInitiated) return;
    e.dataTransfer.dropEffect = "move";
    e.preventDefault();
  });
  this.offEvent("dragleave.reorder", this);
  this.onEvent("dragleave.reorder", this, (e) => {
    if (!dragInitiated && e.target?.getAttribute("color-variant") === "alternate-formatter") {
      e.target.style.backgroundColor = "";
    }
  });
  const removeDragger = (e) => {
    this.querySelector(".active-drag-column")?.classList.remove("active-drag-column");
    dragger?.remove();
    dragArrows?.style.setProperty("display", "none");
    e.preventDefault();
  };
  this.offEvent("dragend.reorder", this);
  this.onEvent("dragend.reorder", this, (e) => {
    if (!dragInitiated) {
      if (e.target?.getAttribute("color-variant") === "alternate-formatter") {
        e.target.style.backgroundColor = "";
      }
      return;
    }
    dragInitiated = false;
    removeDragger(e);
  });
  this.offEvent("drop.reorder", this);
  this.onEvent("drop.reorder", this, (e) => {
    if (!dragInitiated) {
      if (e.target?.getAttribute("color-variant") === "alternate-formatter") {
        e.target.style.backgroundColor = "";
      }
      return;
    }
    dragInitiated = false;
    const cell = e.target.closest(".ids-data-grid-header-cell");
    if (!cell) return;
    this.dataGrid?.moveColumn(startIndex - 1, cell.getAttribute("aria-colindex") - 1);
    removeDragger(e);
  });
};
/**
 * Attaches the event handler for the filter button click event.
 */
attachFilterBtnHandler_fn = function() {
  this.offEvent("click.filterbtn", this);
  this.onEvent("click.filterbtn", this, (evt) => {
    const menuButton = evt.target;
    if (menuButton instanceof IdsMenuButton && menuButton.nextElementSibling?.nodeName !== "IDS-POPUP-MENU") {
      const columnId = menuButton.getAttribute("column-id");
      const column = this.dataGrid.columns.find((col) => col.id === columnId);
      const btnId = menuButton.getAttribute("ref-id") ?? "";
      if (column?.filterType) {
        const popupTemplate = this.dataGrid.filters.filterButtonPopupTemplate(btnId, column.filterType.name, column);
        const gridWrapper = this.closest(".ids-data-grid-wrapper");
        if (gridWrapper) {
          const menuExists = gridWrapper.querySelector(`[target='#btn-${btnId}']`);
          if (!menuExists) gridWrapper.insertAdjacentHTML("beforeend", popupTemplate);
        }
        menuButton.configureMenu();
        menuButton.menuEl?.show();
      }
    }
  });
};
IdsDataGridHeader = __decorateClass([
  customElement("ids-data-grid-header")
], IdsDataGridHeader);

export {
  IdsDataGridHeader
};
//# sourceMappingURL=ids-chunk-R7ZL6UNW-full.js.map
