/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/utils/ids-string-utils/ids-string-utils.ts
function camelCase(str) {
  return str.toLowerCase().replace(/[^a-zA-Z0-9]+(.)/g, (m, chr) => chr.toUpperCase());
}
function kebabCase(str) {
  return str?.replace(/([a-z])([A-Z])/g, "$1-$2").replace(/[()]/g, "").replace(/[\s_]+/g, "-").toLowerCase();
}
function removeDuplicates(str) {
  return str.split("").filter((item, pos, self) => self.indexOf(item) === pos).join("");
}
function removeNewLines(str) {
  return str?.replace(/\r?\n|\r/g, " ") || "";
}
function stringToBool(val) {
  if (typeof val === "string" && val.toLowerCase() === "false" || val === false) {
    return false;
  }
  return typeof val === "string" || val === true;
}
function isValidBooleanValue(value) {
  if (value === null || value === void 0) {
    return false;
  }
  const validValues = /* @__PURE__ */ new Set([true, "true", false, "false"]);
  return validValues.has(value);
}
function stringToNumber(val) {
  return parseFloat(val);
}
function injectTemplate(str, obj) {
  return str?.replace(/\${(.*?)}/g, (_x, g) => {
    let value = obj[g];
    if (value !== void 0) return value;
    if (g.includes(".")) {
      const path = g.split(".");
      path.forEach((key) => {
        value = value?.[key] ?? obj[key];
      });
    }
    return value ?? "&nbsp;";
  });
}
function buildClassAttrib(...classes) {
  const classAttrib = classes.reduce((attribStr, c) => {
    if (attribStr && c) {
      return `${attribStr} ${c}`;
    }
    if (!attribStr && c) {
      return c;
    }
    return attribStr;
  }, "");
  return !classAttrib ? "" : ` class="${classAttrib}"`;
}
function isPrintable(e) {
  const controlKeys = ["Alt", "Shift", "Control", "Meta", "CapsLock", "Enter", "Escape", "Tab"];
  if (controlKeys.indexOf(e.key) > -1 || e.key?.indexOf("Arrow") > -1) {
    return false;
  }
  if (e.altKey && e.keyCode === 38 || e.keyCode > 111 && e.keyCode < 124) {
    return false;
  }
  return true;
}
function escapeRegExp(s) {
  return s.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
}
function trimText(text, threshold) {
  return text.length <= threshold ? text : `${text.substr(0, threshold)}...`;
}

export {
  camelCase,
  kebabCase,
  removeDuplicates,
  removeNewLines,
  stringToBool,
  isValidBooleanValue,
  stringToNumber,
  injectTemplate,
  buildClassAttrib,
  isPrintable,
  escapeRegExp,
  trimText
};
//# sourceMappingURL=ids-chunk-REOQKPVR-full.js.map
