/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  containerBodyCellArgs,
  containerHeaderArgs
} from "./ids-chunk-WSO3TRE4-full.js";
import {
  eventPath,
  findInPath
} from "./ids-chunk-6UX53JJC-full.js";

// src/components/ids-data-grid/ids-data-grid-contextmenu.ts
function getContextmenuElem(isHeader = false) {
  const slotName = isHeader ? "header-contextmenu" : "contextmenu";
  const id = isHeader ? this.headerMenuId : this.menuId;
  const data = isHeader ? this.headerMenuData : this.menuData;
  const slot = () => this.shadowRoot?.querySelector(`slot[name="${slotName}"]`);
  let menu = slot()?.assignedElements()[0];
  if (!menu && id) {
    menu = this.closest("ids-container")?.querySelector(`#${id}`);
  }
  if (!menu && data) {
    this.insertAdjacentHTML("beforeend", `<ids-popup-menu slot="${slotName}" trigger-type="custom"></ids-popup-menu>`);
    menu = slot()?.assignedElements()[0];
    if (menu) menu.data = data;
  }
  return menu;
}
function setContextmenuCompulsoryAttributes(menu) {
  menu?.popup?.setAttribute("align", "top, left");
  menu?.setAttribute("data-contextmenu-element", "");
}
function showContextmenu(e) {
  const { menu: menuEl, target, callbackArgs } = this.contextmenuInfo;
  let isShow = false;
  if (menuEl && target && callbackArgs) {
    const args = { ...callbackArgs, menuEl };
    const isHeaderMenu = callbackArgs.type === "header";
    this.isDynamicContextmenu = true;
    if (!this.triggerVetoableEvent("beforemenushow", args)) {
      this.isDynamicContextmenu = false;
      return isShow;
    }
    if (!this.isDynamicContextmenu) {
      menuEl.data = isHeaderMenu ? this.headerMenuData : this.menuData;
      menuEl.popup?.setAttribute("align", "top, left");
    }
    this.isDynamicContextmenu = false;
    menuEl.popup?.setPosition?.(e.clientX, e.clientY, false, true);
    menuEl.show();
    isShow = true;
    const menuHeight = menuEl.popup?.offsetHeight ?? 0;
    const wrapperHeight = this.wrapper?.offsetHeight ?? 0;
    if (wrapperHeight > 0 && menuHeight > wrapperHeight) {
      menuEl.popup?.setAttribute("max-height", `${wrapperHeight}px`);
      menuEl.popup?.place();
    }
    menuEl.focusTarget.focus();
    this.triggerEvent("menushow", this, {
      bubbles: true,
      detail: { elem: this, data: args }
    });
  }
  return isShow;
}
function handleContextmenu(e, menu, headerMenu) {
  const path = eventPath(e);
  if (menu?.visible) menu?.hide();
  if (headerMenu?.visible) headerMenu?.hide();
  this.contextmenuInfo = {};
  let args = {};
  const columnheader = findInPath(path, '[role="columnheader"]');
  const cellEl = findInPath(path, '[role="gridcell"]');
  if (cellEl && menu) {
    const callbackArgs = containerBodyCellArgs.apply(this, [path, cellEl]);
    args = { menu, target: cellEl, callbackArgs };
  } else if (columnheader && headerMenu) {
    const callbackArgs = containerHeaderArgs.apply(this, [path, columnheader]);
    args = { menu: headerMenu, target: columnheader, callbackArgs };
  }
  this.contextmenuInfo = { ...args };
  if (showContextmenu.apply(this, [e])) e.preventDefault();
}
function handleContextmenuSelectedItem(e, menuEl) {
  if (menuEl) {
    const args = {
      data: {
        ...this.contextmenuInfo.callbackArgs,
        menuSelectedEvent: e,
        menuSelectedValue: e?.detail?.value,
        menuEl
      },
      elem: this
    };
    this.triggerEvent("menuselected", this, { bubbles: true, detail: args });
  }
}
function setContextmenu() {
  this.contextmenuInfo = {};
  const menu = getContextmenuElem.apply(this);
  const headerMenu = getContextmenuElem.apply(this, [true]);
  if (menu || headerMenu) {
    setContextmenuCompulsoryAttributes(menu);
    setContextmenuCompulsoryAttributes(headerMenu);
    this.offEvent("contextmenu.datagrid", this.container);
    this.onEvent("contextmenu.datagrid", this.container, (e) => {
      handleContextmenu.apply(this, [e, menu, headerMenu]);
    });
    if (menu) {
      this.offEvent("selected.datagrid-contextmenu-item", menu);
      this.onEvent("selected.datagrid-contextmenu-item", menu, (e) => {
        handleContextmenuSelectedItem.apply(this, [e, menu]);
      });
    }
    if (headerMenu) {
      this.offEvent("selected.datagrid-header-contextmenu-item", headerMenu);
      this.onEvent("selected.datagrid-header-contextmenu-item", headerMenu, (e) => {
        handleContextmenuSelectedItem.apply(this, [e, headerMenu]);
      });
    }
  }
}

export {
  getContextmenuElem,
  setContextmenu
};
//# sourceMappingURL=ids-chunk-S4SDXIMX-full.js.map
