/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/utils/ids-timer-utils/ids-timer-utils.ts
var RAF = window.requestAnimationFrame;
var CAF = window.cancelAnimationFrame;
function requestAnimationInterval(fn, interval = 0) {
  if (!RAF) return { value: setInterval(fn, interval) };
  let start = (/* @__PURE__ */ new Date()).getTime();
  const handle = {};
  const loop = () => {
    const current = (/* @__PURE__ */ new Date()).getTime();
    const delta = current - start;
    if (delta >= interval) {
      fn(current);
      start = (/* @__PURE__ */ new Date()).getTime();
    }
    handle.value = RAF(loop);
  };
  handle.value = RAF(loop);
  return handle;
}
function clearAnimationInterval(handle) {
  if (handle?.value) {
    if (!CAF) clearInterval(handle.value);
    else CAF(handle.value);
  }
}
function requestAnimationTimeout(fn, timeout = 0) {
  if (!RAF) return { value: setTimeout(fn, timeout) };
  const start = (/* @__PURE__ */ new Date()).getTime();
  const handle = {};
  const loop = () => {
    const current = (/* @__PURE__ */ new Date()).getTime();
    const delta = current - start;
    if (delta >= timeout) fn(current);
    else handle.value = RAF(loop);
  };
  handle.value = RAF(loop);
  return handle;
}
function clearAnimationTimeout(handle) {
  if (handle?.value) {
    if (!CAF) clearTimeout(handle.value);
    else CAF(handle.value);
  }
}
var cssTransitionTimeout = async (timeout) => new Promise((resolve) => {
  const el = document.createElement("div");
  el.classList.add("ids-transition-timeout");
  el.style.setProperty("display", "block");
  el.style.setProperty("position", "absolute");
  el.style.setProperty("visibility", "hidden");
  el.style.setProperty("pointer-events", "none");
  el.style.setProperty("width", "0");
  el.style.setProperty("transition-property", "width");
  el.style.setProperty("transition-timing-function", "linear");
  el.style.setProperty("transition-duration", `${timeout}ms`);
  document.body.append(el);
  const onTransitionEnd = () => {
    el.removeEventListener("transitionend", onTransitionEnd);
    el.remove();
    resolve();
  };
  el.addEventListener("transitionend", onTransitionEnd);
  el.offsetHeight;
  el.style.setProperty("width", "100%");
});

export {
  requestAnimationInterval,
  clearAnimationInterval,
  requestAnimationTimeout,
  clearAnimationTimeout,
  cssTransitionTimeout
};
//# sourceMappingURL=ids-chunk-SF4EDV6P-full.js.map
