/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsZip
} from "./ids-chunk-YK3C62G5-full.js";
import {
  XLSXFormatter
} from "./ids-chunk-KH4KMDY6-full.js";
import {
  CONTENT_TYPES,
  RELS,
  STYLES_XML,
  WORKBOOK_XML,
  WORKBOOK_XML_REL
} from "./ids-chunk-6SVBJPMV-full.js";
import {
  saveAs
} from "./ids-chunk-UIIX26ON-full.js";

// src/utils/ids-excel-exporter/ids-excel-exporter.ts
var DEFAULT_FILENAME = "DataGrid (Export)";
function exportToCSV(data, config) {
  const wrap = (str) => `"${str}"`;
  const fields = config.columns.map((col) => col.id);
  const universalBOM = "\uFEFF";
  const header = config.columns.map((col) => wrap(col.name));
  let csvContent = `${header.join(",")}
`;
  data.forEach((rowData) => {
    const rowStr = fields.map((field) => wrap(rowData[field] ?? ""));
    csvContent += `${rowStr.join(",")}
`;
  });
  const filename = `${config.filename || DEFAULT_FILENAME}.csv`;
  const href = `data:text/csv; charset=utf-8,${encodeURIComponent(universalBOM + csvContent)}`;
  saveAs(filename, href);
}
function exportToXLSX(data, config) {
  const root = new IdsZip();
  root.file("xl/workbook.xml", WORKBOOK_XML);
  root.file("xl/_rels/workbook.xml.rels", WORKBOOK_XML_REL);
  root.file("xl/styles.xml", STYLES_XML);
  root.file("_rels/.rels", RELS);
  root.file("[Content_Types].xml", CONTENT_TYPES);
  const xlsxFormatter = new XLSXFormatter();
  root.file("xl/worksheets/sheet1.xml", xlsxFormatter.generateWorksheet(data, config.columns));
  const zipFile = root.zip("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
  const filename = `${config.filename || DEFAULT_FILENAME}.xlsx`;
  saveAs(filename, zipFile);
}

export {
  exportToCSV,
  exportToXLSX
};
//# sourceMappingURL=ids-chunk-TITK4HN2-full.js.map
