/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  isValidTextDisplay
} from "./ids-chunk-Y2AU2XZ6-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-module-nav/ids-module-nav-text-display-mixin.ts
var IdsModuleNavTextDisplayMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  /**
   * Return the attributes we handle as getters/setters
   * @returns {Array} The attributes as an array
   */
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.TEXT_DISPLAY
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
    if (this.hasAttribute(attributes.TEXT_DISPLAY)) {
      this.textDisplay = this.getAttribute(attributes.TEXT_DISPLAY);
    }
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
  }
  /**
   * Sets the textDisplay property
   * @param {string | null} val textDisplay property value
   */
  set textDisplay(val) {
    const valStr = `${val}`;
    const valid = isValidTextDisplay(valStr);
    if (valid && valStr !== "default") {
      this.setAttribute(attributes.TEXT_DISPLAY, valStr);
    } else {
      this.removeAttribute(attributes.TEXT_DISPLAY);
    }
    this.#setTextDisplay(val);
  }
  /**
   * Gets textDisplay property
   * @returns {string} textDisplay property value
   */
  get textDisplay() {
    return this.getAttribute(attributes.TEXT_DISPLAY);
  }
  #setTextDisplay(val) {
    if (this.container) {
      this.container.classList.remove("text-display-tooltip", "text-display-hidden");
      if (val && val !== "default") this.container.classList.add(`text-display-${val}`);
    }
    if (typeof this.onTextDisplayChange === "function") {
      this.onTextDisplayChange(val);
    }
  }
};
var ids_module_nav_text_display_mixin_default = IdsModuleNavTextDisplayMixin;

export {
  ids_module_nav_text_display_mixin_default
};
//# sourceMappingURL=ids-chunk-TYSL7WUY-full.js.map
