/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsLabelStateAttributes,
  isLabelRequiredValid,
  isLabelStateValid
} from "./ids-chunk-2YP5VUQY-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-label-state-mixin/ids-label-state-parent-mixin.ts
var IdsLabelStateParentMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  connectedCallback() {
    super.connectedCallback?.();
    if (this.hasAttribute(attributes.LABEL_STATE)) {
      this.labelState = this.getAttribute(attributes.LABEL_STATE);
    }
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      ...IdsLabelStateAttributes
    ];
  }
  /**
   * Set the `label` text
   * @param {string} value of the `label` text property
   */
  set label(value) {
    if (value !== null) {
      this.setAttribute(attributes.LABEL, value);
    } else {
      this.removeAttribute(attributes.LABEL);
    }
    if (typeof this.onLabelChange === "function") this.onLabelChange(value);
  }
  get label() {
    return this.getAttribute(attributes.LABEL) ?? "";
  }
  /**
   * Sets the `label-state` attribute on the inner IdsDropDrown
   */
  set labelState(value) {
    if (isLabelStateValid(value)) {
      if (value !== null) {
        this.setAttribute(attributes.LABEL_STATE, value);
      } else {
        this.removeAttribute(attributes.LABEL_STATE);
      }
      if (typeof this.onLabelStateChange === "function") this.onLabelStateChange(value);
    }
  }
  get labelState() {
    return this.getAttribute(attributes.LABEL_STATE);
  }
  /**
   * Set `label-required` attribute
   * @param {string} value The `label-required` attribute
   */
  set labelRequired(value) {
    const isValid = isLabelRequiredValid(value);
    if (isValid) {
      this.setAttribute(attributes.LABEL_REQUIRED, isValid.toString());
    } else {
      this.setAttribute(attributes.LABEL_REQUIRED, "false");
    }
    if (typeof this.onLabelRequiredChange === "function") this.onLabelRequiredChange();
  }
  get labelRequired() {
    const value = this.getAttribute(attributes.LABEL_REQUIRED);
    return value !== null ? stringToBool(value) : true;
  }
};
var ids_label_state_parent_mixin_default = IdsLabelStateParentMixin;

export {
  ids_label_state_parent_mixin_default
};
//# sourceMappingURL=ids-chunk-UBHPK2G5-full.js.map
