/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-data-grid/ids-data-grid-toolbar-mixin.ts
var IdsDataGridToolbarMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  /**
   * Reference to the toolbar element
   */
  #toolbar = null;
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.CONTEXTUAL_TOOLBAR_ID
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.offEvent("rowselected", this);
    this.onEvent("rowselected", this, () => this.toggleToolbar());
    this.offEvent("rowdeselected", this);
    this.onEvent("rowdeselected", this, () => this.toggleToolbar());
    this.offEvent("rowremoved", this);
    this.onEvent("rowremoved", this, () => this.toggleToolbar());
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
    this.#toolbar = null;
    this.offEvent("rowselected", this);
    this.offEvent("rowdeselected", this);
    this.offEvent("rowremoved", this);
  }
  toggleToolbar() {
    const toolbar = this.toolbar;
    const selectedRows = this.dataGrid.selectedRowsAcrossPages;
    toolbar?.classList.toggle("active", selectedRows.length > 0);
    if (!this.toolbarSelectionCountText) return;
    const selectionCountText = this.toolbarSelectionCountText;
    let recordsSelectedText = this.dataGrid.localeAPI.translate("RecordsSelected");
    if (selectedRows.length === 1) {
      recordsSelectedText = this.dataGrid.localeAPI.translate("RecordSelected");
    }
    if (selectedRows.length > 0) {
      recordsSelectedText = recordsSelectedText.replace("{0}", selectedRows.length.toString());
      selectionCountText.textContent = recordsSelectedText;
    }
  }
  /**
   * Reference to the data grid parent
   * @returns {IdsDataGrid} the data grid parent
   */
  get dataGrid() {
    return this;
  }
  /**
   * Set contextualToolbarId attribute
   * @param {string} value - The contextual toolbar id
   */
  set contextualToolbarId(value) {
    if (value) {
      this.setAttribute(attributes.CONTEXTUAL_TOOLBAR_ID, value);
      this.toolbar = document.querySelector(`#${value}`);
    } else {
      this.removeAttribute(attributes.CONTEXTUAL_TOOLBAR_ID);
    }
  }
  /**
   * Get contextualToolbarId attribute value
   * @returns {string} The contextual toolbar id
   */
  get contextualToolbarId() {
    return this.getAttribute(attributes.CONTEXTUAL_TOOLBAR_ID) || "";
  }
  /**
   * Set toolbar
   * @param {HTMLElement | IdsToolbar | null} value - A custom toolbar
   */
  set toolbar(value) {
    this.#toolbar = value;
    this.#toolbar?.classList.add("contextual-toolbar", "toolbar", "ids-datagrid-contextual-toolbar");
  }
  /**
   * Get toolbar
   * @returns {HTMLElement | IdsToolbar | null} value - The custom toolbar
   */
  get toolbar() {
    return this.#toolbar;
  }
  /**
   * Get the selection count text element
   * @returns {IdsText | null} the selection count text element
   */
  get toolbarSelectionCountText() {
    return this.toolbar?.querySelector(".selection-count");
  }
};
var ids_data_grid_toolbar_mixin_default = IdsDataGridToolbarMixin;

export {
  ids_data_grid_toolbar_mixin_default
};
//# sourceMappingURL=ids-chunk-VUYBRVSK-full.js.map
