/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsDropdownCommonAttributes
} from "./ids-chunk-LKR5DNHC-full.js";
import {
  setBooleanAttr
} from "./ids-chunk-RXIFSFPN-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-dropdown/ids-dropdown-attributes-mixin.ts
var IdsDropdownAttributeMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  /**
   * Return the attributes we handle as getters/setters
   * @returns {Array} The attributes in an array
   */
  static get attributes() {
    return [
      ...superclass.attributes,
      ...IdsDropdownCommonAttributes
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
    const dropdownIcon = this.dropdownIcon;
    if (dropdownIcon && typeof this.onDropdownIconChange === "function") {
      this.onDropdownIconChange(dropdownIcon);
    }
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
  }
  /**
   * Sets allow-blank setting
   * @param {string|boolean} value adds blank option if true
   */
  set allowBlank(value) {
    const truthyValue = stringToBool(value);
    if (truthyValue) {
      this.setAttribute(attributes.ALLOW_BLANK, "");
    } else {
      this.removeAttribute(attributes.ALLOW_BLANK);
    }
    if (typeof this.onAllowBlankChange === "function") this.onAllowBlankChange(truthyValue);
  }
  /**
   * Gets allow-blank value
   * @returns {boolean} allow-blank value
   */
  get allowBlank() {
    return stringToBool(this.getAttribute(attributes.ALLOW_BLANK));
  }
  /**
   * When set the value can be cleared with Backspace/Delete
   * @param {boolean|string|null} value clearable value
   */
  set clearable(value) {
    const boolVal = stringToBool(value);
    if (boolVal) {
      this.setAttribute(attributes.CLEARABLE, String(boolVal));
    } else {
      this.removeAttribute(attributes.CLEARABLE);
    }
  }
  get clearable() {
    return stringToBool(this.getAttribute(attributes.CLEARABLE));
  }
  /**
   * When set the blank option will have a text
   * @param {string|null} value blank option text
   */
  set clearableText(value) {
    if (value) {
      this.setAttribute(attributes.CLEARABLE_TEXT, value);
    } else {
      this.removeAttribute(attributes.CLEARABLE_TEXT);
    }
    if (typeof this.onClearableTextChange === "function") this.onClearableTextChange(value);
  }
  get clearableText() {
    return this.getAttribute(attributes.CLEARABLE_TEXT);
  }
  /**
   * @param {string | null} val dropdown icon string
   */
  set dropdownIcon(val) {
    const isValid = typeof val === "string" && val.length;
    if (isValid) {
      this.setAttribute(attributes.DROPDOWN_ICON, `${val}`);
    } else {
      this.removeAttribute(attributes.DROPDOWN_ICON);
    }
    if (typeof this.onDropdownIconChange === "function") this.onDropdownIconChange(val);
  }
  /**
   * @returns {string | null} dropdown icon string
   */
  get dropdownIcon() {
    return this.getAttribute(attributes.DROPDOWN_ICON);
  }
  /**
   * Set the dropdown size
   * @param {string} value The value
   */
  set size(value) {
    if (value) {
      this.setAttribute(attributes.SIZE, value);
      this.container?.classList.toggle("full", value === "full");
    } else {
      this.removeAttribute(attributes.SIZE);
      this.container?.classList.remove("full");
    }
    if (typeof this.onSizeChange === "function") this.onSizeChange(value);
  }
  get size() {
    return this.getAttribute(attributes.SIZE) || "md";
  }
  /**
   * Set the element's ability to display an optional icon in front of the text
   * @param {boolean} value The value
   */
  set showListItemIcon(value) {
    setBooleanAttr(attributes.SHOW_LIST_ITEM_ICON, this, value);
    if (typeof this.onShowListItemIcon === "function") this.onShowListItemIcon(value);
  }
  get showListItemIcon() {
    return this.hasAttribute(attributes.SHOW_LIST_ITEM_ICON);
  }
};
var ids_dropdown_attributes_mixin_default = IdsDropdownAttributeMixin;

export {
  ids_dropdown_attributes_mixin_default
};
//# sourceMappingURL=ids-chunk-WRUW4NIV-full.js.map
