/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  eventPath,
  findInPath
} from "./ids-chunk-6UX53JJC-full.js";
import {
  stringToNumber
} from "./ids-chunk-REOQKPVR-full.js";

// src/components/ids-data-grid/ids-data-grid-container-arguments.ts
var containerTypes = {
  BODY_CELL: "body-cell",
  BODY_CELL_EDITOR: "body-cell-editor",
  HEADER_TITLE: "header-title",
  HEADER_ICON: "header-icon",
  HEADER_FILTER: "header-filter",
  HEADER_FILTER_BUTTON: "header-filter-button"
};
function containerHeaderArgs(path, columnheader) {
  const filterWrapper = findInPath(path, ".ids-data-grid-header-cell-filter-wrapper");
  const isHeaderIcon = !!findInPath(path, ".ids-data-grid-header-icon");
  const isHeaderGroup = columnheader.hasAttribute("column-group-id");
  const types = containerTypes;
  let type = types.HEADER_TITLE;
  if (isHeaderIcon) type = types.HEADER_ICON;
  else if (filterWrapper) {
    const filterButton = findInPath(path, "[data-filter-conditions-button]");
    type = filterButton ? types.HEADER_FILTER_BUTTON : types.HEADER_FILTER;
  }
  let callbackArgs = { type, isHeaderGroup, grid: this };
  if (isHeaderGroup) {
    const columnGroupId = columnheader.getAttribute("column-group-id");
    const columnGroupData = this.columnGroupDataById(columnGroupId);
    callbackArgs = {
      ...callbackArgs,
      columnGroupId,
      columnGroupData,
      rowIndex: 0,
      columnGroupIndex: this.columnGroupIdxById(columnGroupId)
    };
  } else {
    const columnId = columnheader.getAttribute("column-id");
    const columnIndex = this.columnIdxById(columnId);
    const columnData = this.columns[columnIndex];
    callbackArgs = {
      ...callbackArgs,
      columnId,
      columnIndex,
      columnData,
      rowIndex: this.columnGroups ? 1 : 0
    };
  }
  return callbackArgs;
}
function containerBodyCellArgs(path, cellEl) {
  const isEditing = !!findInPath(path, ".is-editing");
  const rowIndex = stringToNumber(findInPath(path, '[role="row"]')?.getAttribute("data-index"));
  const columnIndex = stringToNumber(cellEl.getAttribute("aria-colindex")) - 1;
  const rowData = this.data[rowIndex];
  const columnData = this.columns[columnIndex];
  const columnId = columnData.id;
  const fieldData = rowData[columnId];
  return {
    type: isEditing ? containerTypes.BODY_CELL_EDITOR : containerTypes.BODY_CELL,
    rowData,
    rowIndex,
    columnData,
    columnId,
    columnIndex,
    fieldData,
    grid: this
  };
}
function containerArguments(e) {
  const path = eventPath(e);
  const cellEl = findInPath(path, '[role="gridcell"]');
  const columnheader = findInPath(path, '[role="columnheader"]');
  let args = {};
  if (cellEl) {
    args = containerBodyCellArgs.apply(this, [path, cellEl]);
  } else if (columnheader) {
    args = containerHeaderArgs.apply(this, [path, columnheader]);
  }
  return args;
}

export {
  containerTypes,
  containerHeaderArgs,
  containerBodyCellArgs,
  containerArguments
};
//# sourceMappingURL=ids-chunk-WSO3TRE4-full.js.map
