/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/components/ids-data-grid/ids-data-grid-empty-message.ts
function emptyMessageDefaults() {
  return {
    description: this.localeAPI?.translate("NoDataFilter") || "No data available, make a new filter selection to see more results.",
    icon: "empty-no-data-new",
    label: this.localeAPI?.translate("NoData") || "No data available"
  };
}
function emptyMessageContent() {
  const { description, icon, label } = emptyMessageDefaults.apply(this);
  const em = {
    description: this.emptyMessageDescription || description,
    icon: this.emptyMessageIcon || icon,
    label: this.emptyMessageLabel || label
  };
  return this.suppressEmptyMessage ? "" : `<ids-empty-message icon="${em.icon}" hidden>
    <ids-text type="h2" font-size="20" label="true" slot="label">${em.label}</ids-text>
    <ids-text label="true" slot="description" hidden>${em.description}</ids-text>
  </ids-empty-message>`;
}
function emptyMessageTemplate() {
  return `<slot name="empty-message">${emptyMessageContent.apply(this)}</slot>`;
}
function setEmptyMessageElements() {
  const slotted = this.querySelector("ids-empty-message");
  const em = slotted || this.shadowRoot?.querySelector("ids-empty-message");
  this.emptyMessageElements = {
    em,
    emDesc: em?.querySelector('[slot="description"]'),
    emDescContainer: em?.container?.querySelector(".description"),
    emBtnContainer: em?.container?.querySelector(".button"),
    emIsSlotted: !!slotted,
    emLabel: em?.querySelector('[slot="label"]'),
    vs: this.shadowRoot?.querySelector("ids-virtual-scroll")
  };
}
function resetEmptyMessageElements() {
  this.emptyMessageElements = void 0;
}
function showEmptyMessage() {
  if (this.suppressEmptyMessage) return;
  if (this.initialized && !this.emptyMessageElements) setEmptyMessageElements.apply(this);
  const {
    em,
    emDesc,
    emDescContainer,
    emBtnContainer,
    vs
  } = this.emptyMessageElements || {};
  em?.removeAttribute("hidden");
  const isFiltered = this.datasource.filtered;
  emDescContainer?.toggleAttribute("hidden", !isFiltered);
  emDesc?.toggleAttribute("hidden", !isFiltered);
  if (this.filterable) {
    const hasFilters = this.container?.querySelector(".ids-data-grid-header-cell-filter-wrapper");
    if (hasFilters) {
      em?.classList.add("has-filter-row", `filter-row-size-${this.rowHeight}`);
    }
    if (this.pager) {
      em?.classList.add("has-pager");
    }
  }
  const slottedBtn = emBtnContainer?.querySelector('slot[name="button"]')?.assignedElements();
  emBtnContainer?.toggleAttribute("hidden", !slottedBtn?.length);
  if (this.virtualScroll) {
    vs?.setAttribute("hidden", "");
  }
  this.wrapper?.classList.add("has-empty-message");
}
function hideEmptyMessage() {
  if (this.initialized && !this.emptyMessageElements) setEmptyMessageElements.apply(this);
  const { em, emDesc, vs } = this.emptyMessageElements || {};
  em?.setAttribute("hidden", "");
  emDesc?.setAttribute("hidden", "");
  vs?.removeAttribute("hidden");
  this.wrapper?.classList?.remove("has-empty-message");
}
function IdsDataGridToggleEmptyMessage(hide) {
  hide = hide ?? this.data?.length;
  if (hide || this.suppressEmptyMessage) hideEmptyMessage.apply(this);
  else showEmptyMessage.apply(this);
}
function setEmptyMessage() {
  const d = emptyMessageDefaults.apply(this);
  setEmptyMessageElements.apply(this);
  const {
    em,
    emDesc,
    emIsSlotted,
    emLabel
  } = this.emptyMessageElements;
  const description = emDesc?.textContent?.trim();
  const icon = em?.icon;
  const label = emLabel?.textContent?.trim();
  if (emDesc && description !== this.emptyMessageDescription) {
    if (emIsSlotted && this.emptyMessageDescription) {
      emDesc.innerHTML = this.emptyMessageDescription;
    } else if (!emIsSlotted) {
      emDesc.innerHTML = this.emptyMessageDescription || d.description;
    }
  }
  if (em?.icon && icon !== this.emptyMessageIcon) {
    if (emIsSlotted && this.emptyMessageIcon) {
      em.icon = this.emptyMessageIcon;
    } else if (!emIsSlotted) {
      em.icon = this.emptyMessageIcon || d.icon;
    }
  }
  if (emLabel && label !== this.emptyMessageLabel) {
    if (emIsSlotted && this.emptyMessageLabel) {
      emLabel.innerHTML = this.emptyMessageLabel;
    } else if (!emIsSlotted) {
      emLabel.innerHTML = this.emptyMessageLabel || d.label;
    }
  }
  resetEmptyMessageElements.apply(this);
  this.toggleEmptyMessage();
}

export {
  emptyMessageTemplate,
  setEmptyMessageElements,
  resetEmptyMessageElements,
  showEmptyMessage,
  hideEmptyMessage,
  IdsDataGridToggleEmptyMessage,
  setEmptyMessage
};
//# sourceMappingURL=ids-chunk-X2WRFGSY-full.js.map
