/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsLabelStateAttributes
} from "./ids-chunk-2YP5VUQY-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-editor/ids-editor-shared.ts
var VIEWS = ["editor", "source"];
var PARAGRAPH_SEPARATORS = ["p", "div", "br"];
var HEADERS = ["h1", "h2", "h3", "h4", "h5", "h6"];
var BLOCK_ELEMENTS = [...HEADERS, "p", "div", "blockquote", "pre"];
var FONT_SIZES = ["1", "2", "3", "4", "5", "6", "7"];
var CLASSES = { hidden: "hidden", labelRequired: "no-required-indicator" };
var TEXT_FORMAT_ACTIONS = BLOCK_ELEMENTS.reduce((actions, blockAction) => {
  actions[blockAction] = {
    action: "formatBlock",
    value: blockAction,
    keyid: HEADERS.includes(blockAction) ? `Digit${blockAction.replace("h", "")}|alt` : void 0
  };
  return actions;
}, {});
var FONT_SIZE_ACTIONS = FONT_SIZES.reduce((actions, fontSize) => {
  actions[fontSize] = {
    action: "fontSize",
    value: fontSize
  };
  return actions;
}, {});
var EDITOR_DEFAULTS = {
  disabled: false,
  label: "Ids editor",
  labelHidden: false,
  labelRequired: true,
  modals: {
    hyperlink: {
      url: "http://www.example.com",
      classes: "hyperlink",
      targets: [
        { text: "Same Window", value: "_self" },
        { text: "New Window", value: "_blank", selected: true }
      ],
      // Clickable hyperlink in editor
      isClickable: false,
      showIsClickable: true
    },
    insertimage: {
      url: "",
      alt: ""
    }
  },
  paragraphSeparator: "p",
  pasteAsPlainText: false,
  readonly: false,
  sourceFormatter: false,
  view: "editor"
  // 'editor', 'source'
};
var EDITOR_ATTRIBUTES = [
  ...IdsLabelStateAttributes,
  attributes.DISABLED,
  attributes.PARAGRAPH_SEPARATOR,
  attributes.PASTE_AS_PLAIN_TEXT,
  attributes.PLACEHOLDER,
  attributes.READONLY,
  attributes.SOURCE_FORMATTER,
  attributes.VIEW,
  attributes.VALUE,
  attributes.ACCEPT
];
function qs(s, root) {
  return root?.querySelector(s);
}
function qsAll(s, root) {
  return Array.from(root?.querySelectorAll(s) ?? []);
}
function rgbToHex(rgb) {
  const arrayRgb = rgb.split("(")[1].split(")")[0].split(",");
  const hex = arrayRgb.map((item) => {
    const x = parseInt(item).toString(16);
    return x.length === 1 ? `0${x}` : x;
  }).join("");
  return `#${hex}`;
}

export {
  VIEWS,
  PARAGRAPH_SEPARATORS,
  HEADERS,
  BLOCK_ELEMENTS,
  FONT_SIZES,
  CLASSES,
  TEXT_FORMAT_ACTIONS,
  FONT_SIZE_ACTIONS,
  EDITOR_DEFAULTS,
  EDITOR_ATTRIBUTES,
  qs,
  qsAll,
  rgbToHex
};
//# sourceMappingURL=ids-chunk-XPCTTAAV-full.js.map
