/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  isWidthAbove,
  isWidthBelow
} from "./ids-chunk-OSCW7OSE-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-breakpoint-mixin/ids-breakpoint-mixin.ts
var IdsBreakpointMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.RESPOND_UP,
      attributes.RESPOND_DOWN
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
    this.#teardownRespondUp();
    this.#teardownRespondDown();
  }
  // ===============================================
  // Respond Up
  #mqUp;
  #mqUpChangeHandler;
  onBreakpointUpResponse;
  set respondUp(val) {
    if (val) {
      this.setAttribute(attributes.RESPOND_UP, String(val));
      this.#setupRespondUp(val);
    } else {
      this.removeAttribute(attributes.RESPOND_UP);
      this.#teardownRespondUp();
    }
  }
  get respondUp() {
    return this.getAttribute(attributes.RESPOND_UP);
  }
  #setupRespondUp(val) {
    this.#teardownRespondUp();
    this.#mqUp = isWidthAbove(val);
    this.#mqUpChangeHandler = (e) => {
      if (typeof this.onBreakpointUpResponse === "function") {
        this.onBreakpointUpResponse(val, e.matches);
      }
    };
    this.#mqUp.addEventListener("change", this.#mqUpChangeHandler);
  }
  #teardownRespondUp() {
    if (this.#mqUp) {
      this.#mqUp.removeEventListener("change", this.#mqUpChangeHandler);
      this.#mqUpChangeHandler = void 0;
      this.#mqUp = void 0;
    }
  }
  // ===============================================
  // Respond Down
  #mqDown;
  #mqDownChangeHandler;
  onBreakpointDownResponse;
  set respondDown(val) {
    if (val) {
      this.setAttribute(attributes.RESPOND_DOWN, String(val));
      this.#setupRespondDown(val);
    } else {
      this.removeAttribute(attributes.RESPOND_DOWN);
      this.#teardownRespondDown();
    }
  }
  get respondDown() {
    return this.getAttribute(attributes.RESPOND_DOWN);
  }
  #setupRespondDown(val) {
    this.#teardownRespondDown();
    this.#mqDown = isWidthBelow(val);
    this.#mqDownChangeHandler = (e) => {
      if (typeof this.onBreakpointDownResponse === "function") {
        this.onBreakpointDownResponse(val, e.matches);
      }
    };
    this.#mqDown.addEventListener("change", this.#mqDownChangeHandler);
  }
  #teardownRespondDown() {
    if (this.#mqDown) {
      this.#mqDown.removeEventListener("change", this.#mqDownChangeHandler);
      this.#mqDownChangeHandler = void 0;
      this.#mqDown = void 0;
    }
  }
  // ===============================================
  // General
  respondToCurrentBreakpoint() {
    const simulateChangeEvent = (mq) => new MediaQueryListEvent("change", {
      bubbles: true,
      matches: mq.matches
    });
    if (this.#mqUp) {
      this.#mqUp.dispatchEvent(simulateChangeEvent(this.#mqUp));
    }
    if (this.#mqDown) {
      this.#mqDown.dispatchEvent(simulateChangeEvent(this.#mqDown));
    }
  }
};
var ids_breakpoint_mixin_default = IdsBreakpointMixin;

export {
  ids_breakpoint_mixin_default
};
//# sourceMappingURL=ids-chunk-ZAWCH3TN-full.js.map
