/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsDataGridCell
} from "./ids-chunk-3GKCJCLH-full.js";
import {
  IdsElement
} from "./ids-chunk-UTR2KJV7-full.js";
import {
  customElement
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  nextUntil
} from "./ids-chunk-LQYSVESW-full.js";
import {
  injectTemplate,
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";
import {
  __decorateClass,
  __privateAdd,
  __privateMethod,
  __publicField
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-data-grid/ids-data-grid-row.ts
var _IdsDataGridRow_instances, setAttributes_fn;
var IdsDataGridRow = class extends IdsElement {
  constructor() {
    super({ noShadowRoot: true });
    __privateAdd(this, _IdsDataGridRow_instances);
    __publicField(this, "rootNode");
  }
  /**
   * Return the attributes we handle as getters/setters
   * @returns {Array} The attributes in an array
   */
  static get attributes() {
    return [
      ...super.attributes,
      attributes.DISABLED,
      attributes.ROW_INDEX,
      attributes.DATA_INDEX
    ];
  }
  attributeChangedCallback(name, oldValue, newValue) {
    if (oldValue === newValue) return;
    if (name === attributes.ROW_INDEX) {
      this.renderRow(Number(newValue));
    }
  }
  connectedCallback() {
  }
  /**
   * Reference to the data grid parent
   * @returns {IdsDataGrid} the data grid parent
   */
  get dataGrid() {
    if (!this.rootNode) this.rootNode = this.getRootNode().host;
    return this.rootNode;
  }
  get data() {
    return this.dataGrid?.data || [];
  }
  get rowData() {
    return this.data[this.rowIndex] ?? {};
  }
  get columns() {
    return this.dataGrid?.columns || [];
  }
  get visibleColumns() {
    return this.dataGrid?.visibleColumns || [];
  }
  /* Returns all the editable cell elements in an array */
  get cellsEditable() {
    return [
      ...this.querySelectorAll("ids-data-grid-cell.is-editable:not(.is-readonly,.is-disabled)")
    ];
  }
  get isRowDisabled() {
    return this.dataGrid?.isRowDisabled;
  }
  get dimensions() {
    return this.getBoundingClientRect();
  }
  get expandIcon() {
    return this.querySelectorAll(".ids-data-grid-tree-container ids-button ids-icon");
  }
  /**
   * Set the row disabled state.
   * @param {number} value the value
   */
  set disabled(value) {
    if (stringToBool(value)) {
      this.setAttribute(attributes.DISABLED, "");
      this.setAttribute("aria-disabled", "true");
      this.rowData.disabled = true;
    } else {
      this.removeAttribute(attributes.DISABLED);
      this.removeAttribute("aria-disabled");
      this.rowData.disabled = false;
    }
  }
  get disabled() {
    return this.hasAttribute(attributes.DISABLED);
  }
  /**
   * Set the row index. This index will be used to popuplate data from ids-data-grid.
   * @param {number} value the index
   */
  set rowIndex(value) {
    if (value !== null && value >= 0) {
      this.setAttribute(attributes.ROW_INDEX, String(value));
    } else {
      this.removeAttribute(attributes.ROW_INDEX);
    }
  }
  /**
   * Gets the row index # of this row.
   * @returns {number} the row-index
   */
  get rowIndex() {
    return Number(this.getAttribute(attributes.ROW_INDEX) ?? -1);
  }
  /**
   * Return the row from the cache or template.
   * @param {number} row the row index
   * @returns {string} the row's html
   */
  cacheRow(row) {
    const dataGrid = this.dataGrid;
    const cacheHash = dataGrid.cacheHash;
    const rowIndex = Number(row);
    const selectState = dataGrid.data[row].rowSelected ? dataGrid.cacheSelected : dataGrid.cacheDeselected;
    const cacheKey = `${cacheHash}:${rowIndex}:${selectState}`;
    IdsDataGridRow.rowCache[cacheKey] = IdsDataGridRow.rowCache[cacheKey] ?? this.cellsHTML();
    return IdsDataGridRow.rowCache[cacheKey];
  }
  /**
   * Render the row again from the cache or template.
   * @param {number} row the row index
   */
  renderRow(row) {
    const cells = [...this.children];
    if (this.isRowDisabled && (this.rowData.disabled === void 0 || this.rowData.disabled === null)) {
      this.disabled = this.isRowDisabled(row, this.rowData);
    }
    if (cells.length === this.visibleColumns.length) {
      [...cells].forEach((cell) => cell?.renderCell?.());
    } else {
      this.innerHTML = this.cacheRow(row);
    }
    __privateMethod(this, _IdsDataGridRow_instances, setAttributes_fn).call(this);
  }
  /**
   * Refreshes the row's cells
   */
  refreshRow() {
    this.querySelectorAll(":scope > ids-data-grid-cell").forEach((cell) => cell.refreshCell());
    __privateMethod(this, _IdsDataGridRow_instances, setAttributes_fn).call(this);
  }
  /**
   * Validate all cells in this row
   */
  validateCells() {
    this.querySelectorAll(":scope > ids-data-grid-cell").forEach((cell) => cell.validateCell());
  }
  /**
   * Toggle Selection on the row element (via click/keyboard in the main dataGrid)
   */
  toggleSelection() {
    this.dataGrid?.resetCache();
    const isSelected = this.classList.contains("selected");
    const index = Number(this.getAttribute("data-index"));
    if (isSelected && !this.dataGrid?.suppressRowDeselection) this.dataGrid?.deSelectRow(index);
    else this.dataGrid?.selectRow(index);
    this.dataGrid?.triggerEvent("selectionchanged", this.dataGrid, {
      detail: {
        elem: this,
        selectedRows: this.dataGrid?.selectedRows
      }
    });
  }
  /**
   * Toggle Expand/Collpase on the row element
   * @param {boolean} triggerEvent If true, will trigger event
   */
  toggleExpandCollapse(triggerEvent = true) {
    const isExpanded = this.isExpanded();
    const shouldCollapse = isExpanded === true;
    const shouldExpand = !shouldCollapse;
    if (shouldExpand) {
      this.doExpand();
    }
    if (shouldCollapse) {
      this.doCollapse();
    }
    if (triggerEvent) {
      const eventName = shouldExpand ? "rowexpanded" : "rowcollapsed";
      this.dataGrid?.triggerEvent(eventName, this.dataGrid, {
        bubbles: true,
        detail: {
          elem: this,
          row: this.rowIndex,
          data: this.rowData
        }
      });
    }
  }
  /**
   * Toggle activation on the row element
   */
  toggleRowActivation() {
    const isActivated = this.classList.contains("activated");
    const currentRow = Number(this.getAttribute("aria-rowindex")) - 1;
    if (isActivated && !this.dataGrid?.suppressRowDeactivation) {
      this.dataGrid?.deactivateRow(currentRow);
    } else {
      if (this.dataGrid?.activatedRow.index) this.dataGrid?.deactivateRow(this.dataGrid?.activatedRow.index);
      this.dataGrid?.activateRow(currentRow);
    }
    this.dataGrid?.triggerEvent("activationchanged", this.dataGrid, {
      detail: {
        elem: this,
        data: this.dataGrid?.activatedRow,
        row: Number(this.getAttribute("data-index"))
      }
    });
  }
  /**
   * Select/Deselect all child rows
   * @param {boolean} isSelect true or false to select or deselect
   * @private
   */
  toggleChildRowSelection(isSelect) {
    const level = this?.getAttribute("aria-level");
    nextUntil(this, `[aria-level="${level}"]`).forEach((childRow) => {
      const nodeLevel = Number(childRow.getAttribute("aria-level"));
      if (nodeLevel > Number(level) && this.dataGrid) {
        this.dataGrid.groupSelectsChildren = false;
        if (isSelect) this.dataGrid?.selectRow(Number(childRow.getAttribute("data-index")));
        else this.dataGrid?.deSelectRow(Number(childRow.getAttribute("data-index")));
        this.dataGrid.groupSelectsChildren = true;
      }
    });
  }
  /**
   * Hide/Show all child rows for groupable rows and fire events
   */
  toggleGroupChildRows() {
    const rowData = this.data[Number(this.dataset.index)];
    rowData.groupCollapsed = rowData.groupCollapsed || false;
    const noChildren = rowData.groupChildCount;
    let childRow = this;
    for (let i = 0; i < noChildren; i++) {
      childRow = childRow.nextElementSibling;
      if (!childRow) break;
      childRow.hidden = !rowData.groupCollapsed;
      this.data[Number(childRow.dataset.index)].rowHidden = !rowData.groupCollapsed;
    }
    this.querySelector(".expand-button")?.classList.toggle("expanded");
    rowData.groupCollapsed = !rowData.groupCollapsed;
    this.querySelectorAll(".expand-button ids-icon")?.forEach((icon) => {
      icon?.setAttribute("icon", `plusminus-folder-${rowData.groupCollapsed ? "closed" : "open"}`);
    });
  }
  /**
   * Select this row node
   */
  set selected(select) {
    if (select) {
      this.classList.add("selected");
      this.setAttribute("aria-selected", "true");
      if (this.dataGrid?.rowSelection === "mixed") {
        this?.classList.add("mixed");
      }
    } else {
      this.classList.remove("selected");
      this.removeAttribute("aria-selected");
    }
  }
  get selected() {
    return this.classList.contains("selected");
  }
  /**
   * Updates some attributes/classes on a single row's cells
   * @private
   * @param {number} index the row index
   */
  updateCells(index) {
    const dataGrid = this.dataGrid;
    const row = this;
    const cells = row.children;
    const rowData = dataGrid.data[index];
    let recordIndex = null;
    if (rowData !== void 0) {
      const keyValue = rowData[this.dataGrid.datasource.primaryKey];
      if (keyValue !== void 0) {
        const keyPair = this.dataGrid.datasource.primaryKey;
        recordIndex = this.dataGrid.datasource.getRecordIndex(keyPair, keyValue);
      }
    }
    if (cells?.length) {
      [...cells].forEach((cell, columnIndex) => {
        const columnData = this.dataGrid?.columns[columnIndex];
        let cssPart = columnData?.cssPart || "cell";
        if (this.dataGrid?.rowSelection === "mixed" && row.classList.contains("activated") || (this.dataGrid?.rowSelection === "single" || this.dataGrid?.rowSelection === "multiple") && row.classList.contains("selected")) {
          if (columnData?.cellSelectedCssPart) cssPart = columnData?.cellSelectedCssPart;
          else cssPart = "cell-selected";
        }
        if (typeof cssPart === "function") {
          cssPart = cssPart({
            index,
            columnIndex,
            recordIndex,
            rowData
          });
        }
        cell.setAttribute("part", cssPart);
      });
    }
  }
  /**
   * Return the row's markup
   * @param {Record<string, unknown>} row The row data object
   * @param {number} index The data row index
   * @param {number} ariaRowIndex The indexes for aria-rowindex
   * @param {IdsDataGrid} dataGrid The dataGrid instance
   * @returns {string} The html string for the row
   */
  static template(row, index, ariaRowIndex, dataGrid) {
    let rowClasses = `${row?.rowSelected ? " selected" : ""}`;
    rowClasses += `${row?.rowSelected && dataGrid?.rowSelection === "mixed" ? " mixed" : ""}`;
    rowClasses += `${row?.rowActivated ? " activated" : ""}`;
    let treeAttrs = "";
    if (dataGrid?.treeGrid) {
      treeAttrs += ` aria-setsize="${row.ariaSetSize}" aria-level="${row.ariaLevel}" aria-posinset="${row.ariaPosinset}"`;
      if (row.children?.length) {
        treeAttrs += row.rowExpanded === false ? ` aria-expanded="false"` : ` aria-expanded="true"`;
      }
    }
    if (dataGrid?.pagination === "client-side" && dataGrid?.pageNumber > 1) {
      ariaRowIndex += (Number(dataGrid?.pageNumber) - 1) * Number(dataGrid?.pageSize);
    }
    const isHidden = row?.rowHidden ? " hidden" : "";
    const isRowDisabled = () => {
      const isTrue = (v) => typeof v !== "undefined" && v !== null && (typeof v === "boolean" && v === true || typeof v === "string" && v.toLowerCase() === "true");
      const disabled2 = row.disabled;
      return isTrue(typeof disabled2 === "function" ? disabled2(index, row) : disabled2);
    };
    const canRowDisabled = isRowDisabled();
    const disabled = canRowDisabled ? ' disabled aria-disabled="true"' : "";
    if (row && canRowDisabled) row.idstempcanrowdisabled = canRowDisabled;
    return `
      <ids-data-grid-row
        row-index="${index}"
        role="row"
        part="row"
        aria-rowindex="${ariaRowIndex}"
        data-index="${index}"
        ${isHidden}
        class="ids-data-grid-row${rowClasses}"
        ${treeAttrs}
        ${disabled}
      >
      </ids-data-grid-row>
    `;
  }
  /**
   * Return the cells' markup
   * @returns {string} The html string for the row
   */
  cellsHTML() {
    const rowIndex = this.rowIndex;
    const ariaRowIndex = rowIndex;
    const rowData = this.data[rowIndex];
    const dataGrid = this.dataGrid;
    if (rowData.isGroupRow) {
      const expandButton = `
        <ids-button tabindex="-1" class="expand-button">
          <ids-icon icon="plusminus-folder-open"></ids-icon>
        </ids-button>
      `;
      return `
        <ids-data-grid-cell
          role="gridcell"
          part="cell"
          class="ids-data-grid-cell is-group-cell"
          aria-colindex="1"
        >
          ${expandButton} ${rowData?.groupLabel}
        </ids-data-grid-cell>
      `;
    }
    let expandableRowHtml = "";
    if (dataGrid?.expandableRow) {
      const template = injectTemplate(dataGrid?.querySelector(`#${dataGrid?.expandableRowTemplate}`)?.innerHTML || "", rowData);
      expandableRowHtml = `<div class="ids-data-grid-expandable-row"${this.isExpanded() ? "" : ` hidden`}>${template}</div>`;
    }
    const cellsHtml = dataGrid?.visibleColumns.map((column, columnIndex) => {
      const content = IdsDataGridCell.template(rowData, column, ariaRowIndex, dataGrid);
      return `
        <ids-data-grid-cell
          role="gridcell"
          aria-colindex="${columnIndex + 1}"
        >
          ${content}
        </ids-data-grid-cell>
      `;
    }).join("");
    if (rowData?.idstempcanrowdisabled) delete rowData.idstempcanrowdisabled;
    return `${cellsHtml}${expandableRowHtml}`;
  }
  /**
   * Get the cell HTMLElement
   * @param {number} columnIndex the zero-based column index
   * @returns {IdsDataGridCell} html element for cell
   */
  cellByIndex(columnIndex) {
    columnIndex = Math.max(columnIndex, 0);
    if (columnIndex === 0) {
      return this.querySelector("ids-data-grid-cell") ?? null;
    }
    const cells = this.querySelectorAll("ids-data-grid-cell");
    const maxColumnIndex = cells.length - 1;
    columnIndex = Math.min(columnIndex, maxColumnIndex);
    return cells[columnIndex] ?? null;
  }
  /**
   * Is this row currently expanded
   * @returns {boolean} true if expanded
   */
  isExpanded() {
    const rowData = this.dataGrid.data[this.rowIndex];
    if (this.dataGrid?.expandableRow) {
      return rowData?.rowExpanded === true;
    }
    return rowData?.rowExpanded !== false;
  }
  /**
   * Expand the row element
   */
  doExpand() {
    this.dataGrid?.updateDataset(this.rowIndex, { rowExpanded: true, rowHidden: false });
    __privateMethod(this, _IdsDataGridRow_instances, setAttributes_fn).call(this);
    if (this.dataGrid?.treeGrid) {
      const level = Number(this.getAttribute("aria-level")) || 1;
      const nextLevel = level + 1;
      let parentExpanded = this.isExpanded();
      nextUntil(this, `[aria-level="${level}"]`).forEach((childRow) => {
        const childAriaLevel = Number(childRow.getAttribute("aria-level")) || 1;
        const shouldExpand = childAriaLevel === nextLevel || parentExpanded;
        if (shouldExpand) {
          const childRowIndex = Number(childRow.getAttribute("row-index"));
          this.dataGrid?.updateDataset(childRowIndex, { rowHidden: false });
          childRow.removeAttribute("hidden");
          parentExpanded = childRow.isExpanded?.();
        }
      });
    }
  }
  /**
   * Collapse the row element
   */
  doCollapse() {
    this.dataGrid?.updateDataset(this.rowIndex, { rowExpanded: false });
    __privateMethod(this, _IdsDataGridRow_instances, setAttributes_fn).call(this);
    if (this.dataGrid?.treeGrid) {
      const level = Number(this.getAttribute("aria-level")) || 1;
      nextUntil(this, `[aria-level="${level}"]`).forEach((childRow) => {
        const childAriaLevel = Number(childRow.getAttribute("aria-level")) || 1;
        if (childAriaLevel > level) {
          const childRowIndex = Number(childRow.getAttribute("row-index"));
          this.dataGrid?.updateDataset(childRowIndex, { rowHidden: true });
          childRow?.setAttribute("hidden", "");
        }
      });
    }
  }
};
_IdsDataGridRow_instances = new WeakSet();
/** Set row attributes and classes */
setAttributes_fn = function() {
  const rowIndex = this.rowIndex;
  const rowData = this.rowData;
  const rowExpanded = this.isExpanded();
  let iconType = rowExpanded ? `plusminus-folder-open` : `plusminus-folder-closed`;
  if (this.dataGrid?.expandableRow) {
    iconType = rowExpanded ? `caret-up` : `caret-down`;
  }
  this.setAttribute("data-index", String(rowIndex));
  this.setAttribute("aria-rowindex", String(rowIndex + 1));
  if (rowData?.rowHidden) {
    this.hidden = true;
    this.classList.add("hidden");
    this.setAttribute("hidden", "");
  } else {
    this.hidden = false;
    this.classList.remove("hidden");
    this.removeAttribute("hidden");
  }
  if (rowData?.rowSelected) {
    this.selected = rowData.rowSelected;
  }
  if (!rowData?.rowSelected && this.classList.contains("selected")) {
    this.selected = rowData.rowSelected;
  }
  if (this.dataGrid?.expandableRow) {
    this.setAttribute("aria-expanded", String(!!rowExpanded));
    this.expandIcon?.forEach((icon) => icon.setAttribute("icon", iconType));
    const childRow = this.querySelector(".ids-data-grid-expandable-row");
    if (rowExpanded) {
      childRow?.removeAttribute("hidden");
    } else {
      childRow?.setAttribute("hidden", "");
    }
  }
  if (this.dataGrid.groupable && rowData?.isGroupRow) {
    this.classList.add("is-group-row");
    this.setAttribute("aria-expanded", String(!!rowExpanded));
    if (rowData?.groupCollapsed) {
      this.querySelectorAll(".expand-button ids-icon").forEach((icon) => {
        icon?.setAttribute("icon", "plusminus-folder-closed");
      });
    }
  }
  if (this.dataGrid?.treeGrid) {
    this.setAttribute("aria-setsize", rowData?.ariaSetSize);
    this.setAttribute("aria-level", rowData?.ariaLevel);
    this.setAttribute("aria-posinset", rowData?.ariaPosinset);
    if (rowData?.children?.length) {
      this.setAttribute("aria-expanded", String(!!rowExpanded));
    } else {
      this.removeAttribute("aria-expanded");
    }
    if (rowData?.children?.length) {
      this.expandIcon?.forEach((icon) => icon.setAttribute("icon", iconType));
    }
  }
};
/** Implements row cache */
__publicField(IdsDataGridRow, "rowCache", {});
IdsDataGridRow = __decorateClass([
  customElement("ids-data-grid-row")
], IdsDataGridRow);

export {
  IdsDataGridRow
};
//# sourceMappingURL=ids-chunk-ZPJ4NRQK-full.js.map
