/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsButton,
  ids_button_default
} from "./ids-chunk-BECPNP53-full.js";
import {
  BUTTON_APPEARANCE,
  BUTTON_ATTRIBUTES
} from "./ids-chunk-ZTJAOSP5-full.js";
import {
  customElement,
  scss
} from "./ids-chunk-J6MRYBBM-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";
import {
  __decorateClass
} from "./ids-chunk-35FUK26K-full.js";

// src/components/ids-toggle-button/ids-toggle-button.ts
var DEFAULT_ICON_OFF = "star-outlined";
var DEFAULT_ICON_ON = "star-filled";
var IdsToggleButton = class extends IdsButton {
  constructor() {
    super();
  }
  /**
   * @returns {Array<string>} containing configurable properties on this component
   */
  static get attributes() {
    return BUTTON_ATTRIBUTES.concat([
      attributes.ICON_OFF,
      attributes.ICON_ON,
      attributes.TEXT_OFF,
      attributes.TEXT_ON,
      attributes.PRESSED,
      attributes.DISABLE_ICON
    ]);
  }
  /**
   * Toggle-Button-level `connectedCallback` implementation (adds an icon refresh)
   * @returns {void}
   */
  connectedCallback() {
    super.connectedCallback();
    this.refreshIcon();
    this.refreshText();
  }
  /**
   * Set the pressed (on/off) state
   * @param {boolean | string} val if true, the "toggle" is activated
   */
  set pressed(val) {
    const trueVal = stringToBool(val);
    if (this.state.pressed === trueVal) {
      return;
    }
    this.state.pressed = trueVal;
    this.shouldUpdate = false;
    if (trueVal) {
      this.setAttribute(attributes.PRESSED, trueVal.toString());
    } else {
      this.removeAttribute(attributes.PRESSED);
    }
    this.shouldUpdate = true;
    this.refreshIcon();
    this.refreshText();
    this.dispatchEvent(new CustomEvent("pressed-changed", {
      detail: { pressed: trueVal, element: this },
      bubbles: true,
      composed: true
    }));
  }
  get pressed() {
    return this.state.pressed;
  }
  /**
   * Override setting the "appearance" on Toggle Buttons, since they can only be the default style
   * @param {IdsButtonAppearance | null} val a valid appearance attribute
   */
  set appearance(val) {
    val = BUTTON_APPEARANCE[0];
    super.appearance = val;
  }
  /**
   * @returns {IdsButtonAppearance} the currently set appearance attribute
   */
  get appearance() {
    return super.appearance;
  }
  /**
   * Defines the `unpressed/off` toggle state icon.
   * @param {string} val corresponds to an IdsIcon's `icon` property
   * @returns {void}
   */
  set iconOff(val) {
    if (typeof val === "string" && val.length) {
      this.setAttribute(attributes.ICON_OFF, val);
    } else {
      this.removeAttribute(attributes.ICON_OFF);
    }
    this.refreshIcon();
  }
  /**
   * @returns {string} the current icon representing the `unpressed/off` state
   */
  get iconOff() {
    return this.getAttribute(attributes.ICON_OFF) || DEFAULT_ICON_OFF;
  }
  /**
   * Defines the `pressed/on` toggle state icon.
   * @param {string} val corresponds to an IdsIcon's `icon` property
   * @returns {void}
   */
  set iconOn(val) {
    if (typeof val === "string" && val.length) {
      this.setAttribute(attributes.ICON_ON, val);
    } else {
      this.removeAttribute(attributes.ICON_ON);
    }
    this.refreshIcon();
  }
  /**
   * @returns {string} the current icon representing the `pressed/on` state
   */
  get iconOn() {
    return this.getAttribute(attributes.ICON_ON) || DEFAULT_ICON_ON;
  }
  /**
   * Defines if the icon is disabled
   * @param {string} val `true` to disable the icon
   */
  set disableIcon(val) {
    const value = stringToBool(val);
    if (value) {
      this.setAttribute(attributes.DISABLE_ICON, "");
      this.removeAttribute(attributes.ICON_OFF);
      this.removeAttribute(attributes.ICON_ON);
      this.removeAttribute(attributes.ICON);
    }
  }
  /**
   * Get the `disable-icon` attribute
   * @returns {boolean} `true` if the icon is disabled
   */
  get disableIcon() {
    return this.hasAttribute(attributes.DISABLE_ICON);
  }
  /**
   * Defines the `unpressed/off` toggle state text.
   * @param {string} val `unpressed/off` description text
   * @returns {void}
   */
  set textOff(val) {
    if (typeof val !== "string" || !val.length) {
      this.removeAttribute(attributes.TEXT_OFF);
    } else {
      this.setAttribute(attributes.TEXT_OFF, val);
    }
    this.refreshText();
  }
  /**
   * @returns {string} the current icon representing the `unpressed/off` state
   */
  get textOff() {
    return this.getAttribute("text-off") || "";
  }
  /**
   * Defines the `pressed/on` toggle state icon.
   * @param {string} val corresponds to an IdsIcon's `icon` property
   * @returns {void}
   */
  set textOn(val) {
    if (typeof val !== "string" || !val.length) {
      this.removeAttribute(attributes.TEXT_ON);
    } else {
      this.setAttribute(attributes.TEXT_ON, val);
    }
    this.refreshText();
  }
  /**
   * @returns {string} the current icon representing the `pressed/on` state
   */
  get textOn() {
    return this.getAttribute(attributes.TEXT_ON) || "";
  }
  /**
   * Sets (or creates) a slotted icon that represents the pressed state
   * @private
   * @returns {void}
   */
  refreshIcon() {
    if (this.disableIcon) return;
    this.icon = this[this.pressed ? "iconOn" : "iconOff"];
  }
  /**
   * Sets (or creates) a slotted span that contains text
   * @private
   * @returns {void}
   */
  refreshText() {
    this.text = this[this.pressed ? "textOn" : "textOff"];
  }
  /**
   * Toggles the "pressed" state of the button
   * @returns {void}
   */
  toggle() {
    this.pressed = !this.pressed;
  }
};
IdsToggleButton = __decorateClass([
  customElement("ids-toggle-button"),
  scss(ids_button_default)
], IdsToggleButton);

export {
  IdsToggleButton
};
//# sourceMappingURL=ids-chunk-ZWG6P2SV-full.js.map
