import IdsElement from '../../core/ids-element';
import { IdsColorValue } from '../../utils/ids-color-utils/ids-color-utils';
/**
 * IDS Box Component
 * @type {IdsBox}
 * @inherits IdsElement
 * @part box - the box container element
 */
export default class IdsBox extends IdsElement {
    constructor();
    /**
     * Invoked each time the custom element is appended into a document-connected element.
     */
    connectedCallback(): void;
    /**
     * Return the attributes we handle as getters/setters
     * @returns {Array} The attributes in an array
     */
    static get attributes(): Array<string>;
    /**
     * Create the Template for the contents
     * @returns {string} The template
     */
    template(): string;
    /**
     * If actionable the box can be toggled trigging a state
     * @param {boolean} value set to true for actionable
     */
    set actionable(value: boolean);
    get actionable(): boolean;
    /**
     * Set the background color (as a css variable)
     * @param {IdsColorValue} value css color variable is used
     */
    set backgroundColor(value: IdsColorValue);
    get backgroundColor(): IdsColorValue;
    /**
     * Turns off the borders
     * @param {boolean|null} value Set to false to turn off borders
     */
    set borderless(value: boolean | null);
    get borderless(): boolean | null;
    /**
     * Sets the border radius beyond the default
     * @param {number|null} value Radius to use
     */
    set borderRadius(value: number | null);
    get borderRadius(): number | null;
    /**
     * Sets a width in pixels or percent
     * @param {string} value The width in pixels or as a percent
     */
    set width(value: string);
    get width(): string;
    /**
     * Set a height in pixels or percent
     * @param {string} value The height in pixels or as a percent
     */
    set height(value: string);
    get height(): string;
    /**
     * Turn off the border but leave the shadow
     * @param {boolean|null} value Set to false to turn off
     */
    set shadowed(value: boolean | null);
    get shadowed(): boolean | null;
    /**
     * Set the x axis padding on the box contents (in pixels)
     * @param {string | null} value The value of the paddingX attribute
     */
    set paddingX(value: string | null);
    /**
     * Get the x axis padding
     * @returns {string | null} The number value that represents the paddingX of the box contents
     */
    get paddingX(): string | null;
    /**
     * Set the y axis padding on the box contents (in pixels)
     * @param {string | null} value The value of the paddingY attribute
     */
    set paddingY(value: string | null);
    /**
     * Get the x axis padding
     * @returns {string | null} The number value that represents the paddingY of the box contents
     */
    get paddingY(): string | null;
    /**
     * Set the selected state on the box
     * @param {boolean} val true if this stat should appear "selected"
     */
    set selected(val: boolean);
    get selected(): boolean;
}
