import '../ids-toolbar/ids-toolbar';
import IdsListView from '../ids-list-view/ids-list-view';
import type IdsToolbar from '../ids-toolbar/ids-toolbar';
import type IdsSwappable from '../ids-swappable/ids-swappable';
/**
 * IDS ListBuilder Component
 * @type {IdsListBuilder}
 * @inherits IdsListView
 * @part container - the container element
 */
export default class IdsListBuilder extends IdsListView {
    #private;
    /**
     * Call the constructor and then initialize
     */
    constructor();
    /**
     * A clone of the list item being dragged,
     * it appears during drag to help visualize where the dragged item's position
     */
    placeholder: any;
    /**
     * List of actions can be performed
     */
    actions: {
        ADD: string;
        EDIT: string;
        DELETE: string;
        MOVE_UP: string;
        MOVE_DOWN: string;
    };
    connectedCallback(): void;
    /**
     * Return the attributes we handle as getters/setters
     * @returns {Array<string>} The attributes in an array
     */
    static get attributes(): Array<string>;
    /**
     * Create the Template for the contents
     * @returns {string} The template
     */
    template(): string;
    /**
     * Get toolbar template
     * @returns {string} The template
     */
    toolbarTemplate(): string;
    /**
     * Get toolbar button template
     * @param {object} [options] The button options
     * @param {string} [options.action] The button action
     * @param {string} [options.icon] The button icon
     * @param {string} [options.text] The button text
     * @returns {string} The template
     */
    buttonTemplate(options: {
        action: string;
        icon: string;
        text: string;
    }): string;
    /**
     * Get the parent element
     * @returns {IdsToolbar|null} the parent element
     */
    get parentEl(): IdsSwappable | null | undefined;
    /**
     * Get the toolbar element
     * @returns {IdsToolbar|null} the toolbar element
     */
    get toolbar(): IdsToolbar | null;
    get dataKeys(): Array<any>;
    set dataKeys(val: Array<any>);
    get data(): Array<any>;
    /**
     * Set the data set of the list
     * @param {Array<any>} val The list of items
     */
    set data(val: Array<any>);
    /**
     * Add new item after selected item(s) or at the very end of list
     */
    add(): void;
    /**
     * Edit selected item
     */
    edit(): void;
    /**
     * Delete selected item(s)
     */
    delete(): void;
    /**
     * Move up selected item(s)
     */
    moveUp(): void;
    /**
     * Move down selected item(s)
     */
    moveDown(): void;
    set virtualScroll(value: string | boolean);
    /**
     * List builder does not support VS
     * @returns {boolean} false
     */
    get virtualScroll(): boolean;
}
