import IdsModal from '../ids-modal/ids-modal';
import '../ids-icon/ids-icon';
type IdsMessageAlertType = 'none' | 'error' | 'alert' | 'success' | 'info' | 'warning';
type IdsMessageButton = {
    id?: string;
    text: string;
    click: (e: Event, modal: IdsMessage) => void;
    disabled?: boolean;
    isDefault?: boolean;
    isCancel?: boolean;
};
export interface IdsMessageSettings {
    id?: string;
    status?: IdsMessageAlertType;
    title: string;
    message?: string | null | undefined;
    contents?: string | null | undefined;
    buttons?: IdsMessageButton[];
    width?: string;
    maxWidth?: string;
    minWidth?: string;
}
/**
 * IDS Message Component
 * @type {IdsMessage}
 * @inherits IdsModal
 * @part popup - the popup outer element
 * @part overlay - the inner overlay element
 */
export default class IdsMessage extends IdsModal {
    #private;
    constructor();
    static get attributes(): string[];
    /**
     * @returns {void}
     */
    connectedCallback(): void;
    /**
     * Used for ARIA Labels and other content
     * @readonly
     * @returns {string} concatenating the status and title together.
     */
    get ariaLabelContent(): string;
    /**
     * @returns {string} the current contents of the messsage
     */
    get message(): string;
    /**
     * @param {string} val the desired contents of the message element
     */
    set message(val: string);
    /**
     * @returns {string} the current opacity of the overlay
     */
    get opacity(): string;
    /**
     * @param {string} val the desired opacity of the overlay
     */
    set opacity(val: string | null);
    /**
     * @returns {string} the message's current status type
     */
    get status(): string;
    /**
     * @param {string} val the message's new status type
     */
    set status(val: IdsMessageAlertType | null);
    /**
     * Set the width of the message.
     * @param {string | undefined} value - The width of the message.
     */
    set width(value: string | undefined);
    get width(): string;
    /**
     * Set the max-width of the message.
     * @param {string | undefined} value - The max-width of the message.
     */
    set maxWidth(value: string | undefined);
    get maxWidth(): string;
    /**
     * Set the min-width of the message.
     * @param {string | undefined} value - The min-width of the message.
     */
    set minWidth(value: string | undefined);
    get minWidth(): string;
    isServiceMessage: boolean;
    /**
     * Show the message
     * @param {IdsMessageSettings} settings  The settings for the message
     */
    show(settings?: IdsMessageSettings): Promise<void>;
    /**
     * Hides the message
     * @returns {Promise<void>}
     */
    hide(): Promise<void>;
}
export {};
