import IdsDropdown from '../ids-dropdown/ids-dropdown';
import { IdsDropdownOptions } from '../ids-dropdown/ids-dropdown-common';
import '../ids-tag/ids-tag';
import '../ids-text/ids-text';
import '../ids-list-box/ids-list-box-option';
import '../ids-search-field/ids-search-field';
import type IdsListBoxOption from '../ids-list-box/ids-list-box-option';
/**
 * IDS Multiselect Component
 * @type {IdsMultiselect}
 * @inherits IdsDropdown
 * @part container - the container element
 */
declare class IdsMultiselect extends IdsDropdown {
    #private;
    constructor();
    /**
     * Invoked each time the custom element is add into a document-connected element
     */
    connectedCallback(): void;
    optionsData: IdsDropdownOptions;
    internalSelectedList: Array<string>;
    /**
     * Return the attributes we handle as getters and setters
     * @returns {Array} The attributes in an array
     */
    static get attributes(): any[];
    /**
     * Sets the disabled attribute
     * @param {string|boolean} value string value from the disabled attribute
     */
    set disabled(value: boolean);
    /**
     * Gets the value of the disabled property
     * @returns {boolean} a boolean indicating the elements disabled status
     */
    get disabled(): boolean;
    /**
     * Sets the tags attribute which determines if selected options are displayed as tags
     * @param {string|boolean} value string or boolean that sets the use of tag attribute
     */
    set tags(value: boolean);
    /**
     * returns whether the multiselect is set to display selections as tags
     * @returns {boolean} a boolean indicating tags setting
     */
    get tags(): boolean;
    /**
     * Sets the placeholder attribute
     * @param {string} value - the placeholder text
     */
    set placeholder(value: string);
    /**
     * Get the placeholder attribute
     * @returns {string} the placeholder text
     */
    get placeholder(): string;
    /**
     * sets the max possible selections for multiselect
     * @param {string|number} value the max number of selections allowed
     */
    set max(value: any);
    /**
     * returns the maximum number of allowed selections
     * @returns {number} the maximum number of selectable options
     */
    get max(): number;
    /**
     * Set the selected values of the multiselect using the provided array
     * @param {Array} value the array of values to set as selected
     */
    set value(value: any);
    /**
     * Gets the current value of the component.
     * @returns {Array|string} Returns the internal selected list if it exists and has items,
     * otherwise returns the value attribute from the element.
     * @property {Array|string} value - The current selected value(s).
     */
    get value(): any;
    /**
     * Returns the selected Listbox option based on the Dropdown's value.
     * @returns {IdsListBoxOption[]} the selected option
     */
    get selectedOptions(): IdsListBoxOption[];
    /**
     * Update selected options
     */
    updateSelected(): void;
    /**
     * Rewriting dropdown click events
     */
    attachClickEvent(): void;
    /**
     * Toggles the visibility of the multiselect dropdown
     * @param {boolean} [isOpen] - Optional parameter to force open (true) or closed (false) state
     *                            If not provided, toggles based on current state
     * @returns {void}
     */
    toggle(isOpen?: boolean): Promise<void>;
    /**
     * Establish selection event for keyboard interactions.
     * Overrides a similiar method from IdsDropdown for Multiselect-specific behavior.
     */
    attachKeyboardSelectionEvent(): void;
    /**
     * Removes selected attributes from an option
     * @param {HTMLElement} option element to remove attributes
     */
    deselectOption(option: HTMLElement | undefined | null): void;
    /**
     * Close the dropdown popup
     * Rewriting it to add multiselect value update
     * @param {boolean} noFocus if true do not focus on close
     */
    close(noFocus?: boolean): void;
    /**
     * Set typeahead attribute
     * @param {string | boolean | null} value typeahead value
     */
    set typeahead(value: string | boolean | null);
    /**
     * Get the typeahead attribute
     * @returns {boolean} typeahead attribute value converted to boolean
     */
    get typeahead(): boolean;
}
export default IdsMultiselect;
