/**
 * Handle Personalization colors (and personalization related things)
 */
declare class IdsPersonalization {
    #private;
    /** Holds the personalization color */
    state: {
        color: string;
        useColorProgression: boolean;
    };
    /**
     * Set the primary color and update the UI
     * @param {string} value the primary color
     */
    set color(value: string);
    /**
     * Set the current primary color info
     * @returns {Record<string, string>} An array of related colors
     */
    get color(): string;
    /**
     * Use old method of color progression
     * @param {boolean} value the primary color
     */
    set useColorProgression(value: string);
    /**
     * Determine if using the old method of color progression
     * @returns {boolean} An array of related colors
     */
    get useColorProgression(): boolean;
    /**
     * Calculate color progression based on a single color
     * @param {string} color the primary color
     * @returns {Record<string, string>} An array of related colors
     */
    colorProgression(color: string): {
        primary: string;
        primary10: string;
        primary20: string;
        primary40: string;
        primary30: string;
        primary50: string;
        primary60: string;
        primary70: string;
        primary80: string;
        primary90: string;
        primary100: string;
        contrast: string;
    };
    /** Remove the personalization stylesheet and set to default color */
    resetToDefault(): void;
}
export default IdsPersonalization;
