import IdsTriggerField from '../ids-trigger-field/ids-trigger-field';
import '../ids-trigger-field/ids-trigger-button';
import '../ids-input/ids-input';
import '../ids-icon/ids-icon';
import '../ids-menu-button/ids-menu-button';
import '../ids-popup-menu/ids-popup-menu';
/**
 * IDS Search Field Component
 * @type {IdsSearchField}
 * @inherits IdsTriggerField
 */
export default class IdsSearchField extends IdsTriggerField {
    #private;
    constructor();
    state: any;
    isFormComponent: boolean;
    /**
     * Inherited from `IdsColorVariantMixin`
     * @returns {Array<string>} List of available color variants for this component
     */
    colorVariants: string[];
    /**
     * Inherited from `IdsColorVariantMixin`. If the Color Variant on Search Fields are changed,
     * switch trigger buttons to the "alternate" style instead of an `app-menu` style.
     * @param {string} variantName the new color variant being applied to the Search Field
     */
    onColorVariantRefresh(variantName?: string): void;
    static get attributes(): string[];
    connectedCallback(): void;
    template(): string;
    templateCategoriesButton(): string;
    templateCategoriesMenu(): string;
    /**
     * Expand the search field
     */
    expandField(): void;
    /**
     * Collapse the search field
     * @param {any} event the original click event
     */
    collapseField(event: any): void;
    /**
     * Set focus on the input
     */
    collapsibleFocus(): void;
    /**
     * Disable collapsible
     */
    disableCollapsible(): void;
    /**
     * Enable collapsible
     */
    enableCollapsible(): void;
    /**
     * Get the expand button
     * @readonly
     * @returns {any} the expand button
     */
    get expandButton(): any;
    /**
     * Get the search icon
     * @readonly
     * @returns {any} the search icon
     */
    get searchIcon(): any;
    /**
     * @returns {string[]} returns an array of all the categories that appear in the category dropdown
     */
    get categories(): string[];
    /**
     * @param {string[]} value = sets a list of categories that should appear in the category dropdown
     */
    set categories(value: string[]);
    /**
     * @param {string} value - sets the initial text that appears in the categories dropdown menu
     */
    set category(value: string);
    /**
     * @returns {string} - gets the initial text that appears in the categories dropdown menu
     */
    get category(): string;
    /**
     *  @param {boolean} value - sets if the search field should be collapsible
     */
    set collapsible(value: boolean);
    /**
     * @returns {boolean | string} - gets if the search field should be collapsible
     */
    get collapsible(): boolean;
    /**
     * @param {string} value - sets if the search field should be collapsible
     * based on screen size. Valid values: 'xxl', 'xl', 'lg', 'md', 'sm', 'xs'
     */
    set collapsibleResponsive(value: string);
    /**
     * @returns {string | null} - gets the value of the collapsibleResponsive attribute
     */
    get collapsibleResponsive(): string;
    /**
     * @param {boolean} value - sets if the search field is collapsed
     */
    set collapsed(value: boolean);
    /**
     * @returns {boolean} - gets if the search field is collapsed
     */
    get collapsed(): boolean;
    /**
     * @returns {string[]} returns an array of the currently selected categories
     */
    get selectedCategories(): string[];
    /**
     * @param {string} value - sets title on the search field action-button
     */
    set action(value: string);
    /**
     * @returns {string} - gets the title that appears on the search field action-button
     */
    get action(): string;
    /**
     * @param {boolean} value - allows multiple categories to be selected
     */
    set multiple(value: boolean);
    /**
     * @returns {boolean} determines whether multiple categories to be selected or not
     */
    get multiple(): boolean;
    /**
     * Programmatically sets the search field's value and performs an optional search function
     * @param {any} val the incoming value to search for
     * @returns {Array<any>} containing search results, if applicable
     */
    search(val: any): Promise<any>;
    /**
     * @param {string} val the new value to set
     */
    set value(val: string);
    get value(): string;
    /**
     * Define this method to carry out search functionality
     * (override this method when implementing an IdsSearchField).
     * @param {any} [val] the value to be searched for
     * @returns {Array<any>} containing matching search results
     */
    onSearch(val?: any): any;
}
