/**
 * Parse given template string with each context.
 * @param {string} str The template string
 * @param {any} ctx The context key/value
 * @returns {string} The template value
 */
export declare function parseTemplate(str: string, ctx: any): string;
export declare const editorTemplate = "\n  <div class=\"ids-editor\" part=\"editor\"{disabled}{readonly}>\n    <slot id=\"hidden-slot\" class=\"{hiddenClass}\"></slot>\n    <ids-text id=\"editor-label\" label class=\"{labelClass}{hiddenLabelCss}{requiredLabelCss}\" part=\"editor-label\"{disabled}{readonly}>{labelText}</ids-text>\n    <div class=\"main-container\" part=\"main-container\">\n      <div class=\"toolbar-container\" part=\"toolbar-container\">\n        <slot name=\"toolbar\"></slot>\n      </div>\n      <div class=\"editor-content\">\n        <div id=\"editor-container\" class=\"editor-container\" part=\"editor-container\" aria-multiline=\"true\" role=\"textbox\" aria-labelledby=\"editor-label\"{placeholder}>\n          <slot name=\"editor-slot\" id=\"editor-slot\"></slot>\n        </div>\n        <div class=\"source-container {hiddenClass}\" part=\"source-container\">\n          <div class=\"source-wrapper\">\n            <ul class=\"line-numbers\"></ul>\n            <label class=\"audible\" for=\"source-textarea\">\n              {sourceTextareaLabel}\n            </label>\n            <textarea id=\"source-textarea\" class=\"source-textarea\"{placeholder}></textarea>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>";
export declare const btnEditorModeTemplate = "\n  <ids-button editor-action=\"editormode\" tooltip=\"View Visual\" color-variant=\"alternate-formatter\">\n    <span class=\"audible\">View Visual</span>\n    <ids-icon icon=\"visual\" width=\"50\" viewbox=\"0 0 43 18\"></ids-icon>\n  </ids-button>";
export declare const btnSourceModeTemplate = "\n  <ids-button editor-action=\"sourcemode\" tooltip=\"View Source\" color-variant=\"alternate-formatter\">\n    <span class=\"audible\">View Source</span>\n    <ids-icon icon=\"html\" width=\"50\" viewbox=\"0 0 35 18\"></ids-icon>\n  </ids-button>";
export declare const toolbarTemplate = "\n  <ids-toolbar slot=\"toolbar\" type=\"formatter\">\n    <ids-toolbar-section type=\"buttonset\">\n      <ids-menu-button\n        editor-action=\"formatblock\"\n        id=\"btn-formatblock-{instanceCounter}\"\n        role=\"button\"\n        menu=\"menu-formatblock-{instanceCounter}\"\n        tooltip=\"Choose Font Style\"\n        formatter-width=\"125px\"\n        dropdown-icon\n        no-padding=\"true\"\n        trigger-type=\"click\"\n        color-variant=\"alternate-formatter\">\n        <span>Normal Text</span>\n      </ids-menu-button>\n      <ids-popup-menu id=\"menu-formatblock-{instanceCounter}\" target=\"#btn-formatblock-{instanceCounter}\">\n        <ids-menu-group>\n          <ids-menu-item value=\"p\" selected=\"true\"><ids-text>Normal Text</ids-text></ids-menu-item>\n          <ids-menu-item value=\"h1\"><ids-text font-size=\"28\">Header 1</ids-text></ids-menu-item>\n          <ids-menu-item value=\"h2\"><ids-text font-size=\"24\">Header 2</ids-text></ids-menu-item>\n          <ids-menu-item value=\"h3\"><ids-text font-size=\"20\">Header 3</ids-text></ids-menu-item>\n        </ids-menu-group>\n      </ids-popup-menu>\n      <ids-separator vertical></ids-separator>\n      <ids-button editor-action=\"bold\" tooltip=\"Toggle Bold Text\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Bold</span>\n        <ids-icon icon=\"bold\"></ids-icon>\n      </ids-button>\n      <ids-button editor-action=\"italic\" tooltip=\"Toggle Italic Text\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Italic</span>\n        <ids-icon icon=\"italic\"></ids-icon>\n      </ids-button>\n      <ids-button editor-action=\"underline\" tooltip=\"Toggle Underline Text\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Underline</span>\n        <ids-icon icon=\"underline\"></ids-icon>\n      </ids-button>\n      <ids-button editor-action=\"strikethrough\" tooltip=\"Toggle Strike Through Text\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Strike through</span>\n        <ids-icon icon=\"strike-through\"></ids-icon>\n      </ids-button>\n      <ids-separator vertical></ids-separator>\n      <ids-button editor-action=\"forecolor\" tooltip=\"Text Color\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Text color</span>\n        <ids-icon icon=\"fore-color\"></ids-icon>\n      </ids-button>\n      <ids-separator vertical></ids-separator>\n      <ids-button editor-action=\"alignleft\" tooltip=\"Align Left\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Align left</span>\n        <ids-icon icon=\"left-text-align\"></ids-icon>\n      </ids-button>\n      <ids-button editor-action=\"aligncenter\" tooltip=\"Align Center\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Align center</span>\n        <ids-icon icon=\"center-text\"></ids-icon>\n      </ids-button>\n      <ids-button editor-action=\"alignright\" tooltip=\"Align Right\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Align right</span>\n        <ids-icon icon=\"right-text-align\"></ids-icon>\n      </ids-button>\n      <ids-separator vertical></ids-separator>\n      <ids-button editor-action=\"blockquote\" tooltip=\"Block Quote\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Block quote</span>\n        <ids-icon icon=\"quote\"></ids-icon>\n      </ids-button>\n      <ids-button editor-action=\"orderedlist\" tooltip=\"Insert/Remove Numbered List\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Ordered List</span>\n        <ids-icon icon=\"number-list\"></ids-icon>\n      </ids-button>\n      <ids-button editor-action=\"unorderedlist\" tooltip=\"Insert/Remove Bulleted List\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Unordered List</span>\n        <ids-icon icon=\"bullet-list\"></ids-icon>\n      </ids-button>\n      <ids-separator vertical></ids-separator>\n      <ids-button editor-action=\"hyperlink\" tooltip=\"Insert Hyperlink\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Insert Hyperlink</span>\n        <ids-icon icon=\"link\"></ids-icon>\n      </ids-button>\n      <ids-button editor-action=\"insertimage\" tooltip=\"Insert Image\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Insert Image</span>\n        <ids-icon icon=\"insert-image\"></ids-icon>\n      </ids-button>\n      <ids-separator vertical></ids-separator>\n      <ids-button editor-action=\"clearformatting\" tooltip=\"Clear Formatting\" color-variant=\"alternate-formatter\">\n        <span class=\"audible\">Clear Formatting</span>\n        <ids-icon icon=\"clear-formatting\"></ids-icon>\n      </ids-button>\n      <ids-separator vertical></ids-separator>\n      \n  <ids-button editor-action=\"sourcemode\" tooltip=\"View Source\" color-variant=\"alternate-formatter\">\n    <span class=\"audible\">View Source</span>\n    <ids-icon icon=\"html\" width=\"50\" viewbox=\"0 0 35 18\"></ids-icon>\n  </ids-button>\n      \n  <ids-button editor-action=\"editormode\" tooltip=\"View Visual\" color-variant=\"alternate-formatter\">\n    <span class=\"audible\">View Visual</span>\n    <ids-icon icon=\"visual\" width=\"50\" viewbox=\"0 0 43 18\"></ids-icon>\n  </ids-button>\n    </ids-toolbar-section>\n    <ids-toolbar-more-actions overflow color-variant=\"alternate-formatter\"></ids-toolbar-more-actions>\n  </ids-toolbar>";
export declare const errorMessageTemplate = "\n  <ids-message id=\"errormessage-modal\" status=\"error\">\n    <ids-text slot=\"title\" font-size=\"24\" type=\"h2\" id=\"errormessage-modal-title\">No Selection!</ids-text>\n    <ids-text class=\"demo-contents\" align=\"left\">Please make some selection to complete this task.</ids-text>\n    <ids-modal-button slot=\"buttons\" appearance=\"primary\" id=\"errormessage-modal-ok\">OK</ids-modal-button>\n  </ids-message>";
export declare const hyperlinkModalTemplate = "\n  <ids-modal id=\"{key}-modal\">\n    <ids-text slot=\"title\" font-size=\"24\" type=\"h2\" id=\"{key}-modal-title\">Insert Anchor</ids-text>\n    <ids-layout-grid class=\"data-grid-container\" auto-fit=\"true\" gap=\"md\" no-margins=\"true\" min-col-width=\"300px\">\n      <ids-layout-grid-cell>\n        <ids-input id=\"{key}-modal-input-url\" label=\"Url\" value=\"{url}\" validate=\"required\"></ids-input>\n        {clickableElemHtml}\n        <ids-input id=\"{key}-modal-input-classes\" label=\"Css Class\" value=\"{classes}\"></ids-input>\n        {targetDropdownHtml}\n        <div id=\"{key}-modal-checkbox-remove-container\" class=\"{hiddenClass}\">\n          <ids-checkbox id=\"{key}-modal-checkbox-remove\" label=\"Remove hyperlink\"></ids-checkbox>\n        </div>\n      </ids-layout-grid-cell>\n    </ids-layout-grid>\n    <ids-modal-button slot=\"buttons\" id=\"{key}-modal-cancel-btn\" appearance=\"secondary\">\n      <span>Cancel</span>\n    </ids-modal-button>\n    <ids-modal-button slot=\"buttons\" id=\"{key}-modal-apply-btn\" appearance=\"primary\">\n      <span>Apply</span>\n    </ids-modal-button>\n  </ids-modal>";
export declare const insertimageModalTemplate = "\n  <ids-modal id=\"{key}-modal\">\n    <ids-text slot=\"title\" font-size=\"24\" type=\"h2\" id=\"{key}-modal-title\">Insert Image</ids-text>\n    <ids-layout-grid class=\"data-grid-container\" auto-fit=\"true\" gap=\"md\" no-margins=\"true\" min-col-width=\"300px\">\n      <ids-layout-grid-cell>\n        <ids-input id=\"{key}-modal-input-src\" label=\"Url\" value=\"{url}\" validate=\"required\"></ids-input>\n        <ids-input id=\"{key}-modal-input-alt\" label=\"Alt text\" value=\"{alt}\" validate=\"required\"></ids-input>\n      </ids-layout-grid-cell>\n    </ids-layout-grid>\n\n    <ids-modal-button slot=\"buttons\" id=\"{key}-modal-cancel-btn\" appearance=\"secondary\">\n      <span>Cancel</span>\n    </ids-modal-button>\n    <ids-modal-button slot=\"buttons\" id=\"{key}-modal-apply-btn\" appearance=\"primary\">\n      <span>Apply</span>\n    </ids-modal-button>\n  </ids-modal>";
